/********************************************************************************
** Form generated from reading UI file 'isingwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ISINGWIDGET_H
#define UI_ISINGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDial>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_IsingWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    ServicePresetWidget *preset;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_6;
    QDial *tempDial;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_3;
    QDoubleSpinBox *tempSpinner;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_7;
    QDial *borderGrowthDial;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_4;
    QDoubleSpinBox *borderGrowthSpinner;
    QSpacerItem *horizontalSpacer_5;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_8;
    QDial *spontGrowthDial;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer_6;
    QDoubleSpinBox *spontGrowthSpinner;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *IsingWidget)
    {
        if (IsingWidget->objectName().isEmpty())
            IsingWidget->setObjectName("IsingWidget");
        IsingWidget->resize(568, 296);
#if QT_CONFIG(whatsthis)
        IsingWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-ising/12928/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(IsingWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(IsingWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        preset = new ServicePresetWidget(IsingWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        groupBox = new QGroupBox(IsingWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_6 = new QVBoxLayout(groupBox);
        verticalLayout_6->setObjectName("verticalLayout_6");
        tempDial = new QDial(groupBox);
        tempDial->setObjectName("tempDial");
        tempDial->setMaximum(100);
        tempDial->setOrientation(Qt::Orientation::Vertical);
        tempDial->setNotchesVisible(true);

        verticalLayout_6->addWidget(tempDial);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        tempSpinner = new QDoubleSpinBox(groupBox);
        tempSpinner->setObjectName("tempSpinner");
        tempSpinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        tempSpinner->setMaximum(1.000000000000000);
        tempSpinner->setSingleStep(0.100000000000000);

        horizontalLayout_4->addWidget(tempSpinner);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        verticalLayout_6->addLayout(horizontalLayout_4);


        horizontalLayout_3->addWidget(groupBox);

        groupBox_3 = new QGroupBox(IsingWidget);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_7 = new QVBoxLayout(groupBox_3);
        verticalLayout_7->setObjectName("verticalLayout_7");
        borderGrowthDial = new QDial(groupBox_3);
        borderGrowthDial->setObjectName("borderGrowthDial");
        borderGrowthDial->setMaximum(100);
        borderGrowthDial->setValue(100);
        borderGrowthDial->setNotchesVisible(true);

        verticalLayout_7->addWidget(borderGrowthDial);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);

        borderGrowthSpinner = new QDoubleSpinBox(groupBox_3);
        borderGrowthSpinner->setObjectName("borderGrowthSpinner");
        borderGrowthSpinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        borderGrowthSpinner->setMaximum(1.000000000000000);
        borderGrowthSpinner->setSingleStep(0.100000000000000);
        borderGrowthSpinner->setValue(1.000000000000000);

        horizontalLayout_5->addWidget(borderGrowthSpinner);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);


        verticalLayout_7->addLayout(horizontalLayout_5);


        horizontalLayout_3->addWidget(groupBox_3);

        groupBox_2 = new QGroupBox(IsingWidget);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_8 = new QVBoxLayout(groupBox_2);
        verticalLayout_8->setObjectName("verticalLayout_8");
        spontGrowthDial = new QDial(groupBox_2);
        spontGrowthDial->setObjectName("spontGrowthDial");
        spontGrowthDial->setMaximum(100);
        spontGrowthDial->setValue(100);
        spontGrowthDial->setNotchesVisible(true);

        verticalLayout_8->addWidget(spontGrowthDial);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);

        spontGrowthSpinner = new QDoubleSpinBox(groupBox_2);
        spontGrowthSpinner->setObjectName("spontGrowthSpinner");
        spontGrowthSpinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        spontGrowthSpinner->setMaximum(1.000000000000000);
        spontGrowthSpinner->setSingleStep(0.100000000000000);
        spontGrowthSpinner->setValue(1.000000000000000);

        horizontalLayout_6->addWidget(spontGrowthSpinner);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_7);


        verticalLayout_8->addLayout(horizontalLayout_6);


        horizontalLayout_3->addWidget(groupBox_2);


        verticalLayout->addLayout(horizontalLayout_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(IsingWidget);

        QMetaObject::connectSlotsByName(IsingWidget);
    } // setupUi

    void retranslateUi(QWidget *IsingWidget)
    {
        IsingWidget->setWindowTitle(QCoreApplication::translate("IsingWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("IsingWidget", "Ising Model", nullptr));
        groupBox->setTitle(QCoreApplication::translate("IsingWidget", "Noise Temperature", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("IsingWidget", "Border Growth", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("IsingWidget", "Spontaneous Growth", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IsingWidget: public Ui_IsingWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ISINGWIDGET_H
