/********************************************************************************
** Form generated from reading UI file 'unlinkedfilesdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UNLINKEDFILESDIALOG_H
#define UI_UNLINKEDFILESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_UnlinkedFilesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTableView *tableView;
    QHBoxLayout *horizontalLayout;
    QPushButton *searchFolderButton;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UnlinkedFilesDialog)
    {
        if (UnlinkedFilesDialog->objectName().isEmpty())
            UnlinkedFilesDialog->setObjectName("UnlinkedFilesDialog");
        UnlinkedFilesDialog->resize(625, 300);
#if QT_CONFIG(whatsthis)
        UnlinkedFilesDialog->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/project-management/12574#p-39686-missing-files-7"));
#endif // QT_CONFIG(whatsthis)
        UnlinkedFilesDialog->setSizeGripEnabled(true);
        UnlinkedFilesDialog->setModal(true);
        verticalLayout = new QVBoxLayout(UnlinkedFilesDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(UnlinkedFilesDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        tableView = new QTableView(UnlinkedFilesDialog);
        tableView->setObjectName("tableView");
        tableView->setMinimumSize(QSize(496, 0));
        tableView->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        tableView->setProperty("showDropIndicator", QVariant(false));
        tableView->setDragDropOverwriteMode(false);
        tableView->setAlternatingRowColors(true);
        tableView->setSelectionMode(QAbstractItemView::SelectionMode::SingleSelection);
        tableView->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);
        tableView->setTextElideMode(Qt::TextElideMode::ElideLeft);
        tableView->horizontalHeader()->setHighlightSections(false);
        tableView->horizontalHeader()->setStretchLastSection(true);
        tableView->verticalHeader()->setVisible(false);
        tableView->verticalHeader()->setHighlightSections(false);

        verticalLayout->addWidget(tableView);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        searchFolderButton = new QPushButton(UnlinkedFilesDialog);
        searchFolderButton->setObjectName("searchFolderButton");

        horizontalLayout->addWidget(searchFolderButton);

        buttonBox = new QDialogButtonBox(UnlinkedFilesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        horizontalLayout->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(UnlinkedFilesDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, UnlinkedFilesDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UnlinkedFilesDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(UnlinkedFilesDialog);
    } // setupUi

    void retranslateUi(QDialog *UnlinkedFilesDialog)
    {
        UnlinkedFilesDialog->setWindowTitle(QCoreApplication::translate("UnlinkedFilesDialog", "Missing Files", nullptr));
        label->setText(QCoreApplication::translate("UnlinkedFilesDialog", "There are missing files in your project. Double-click each row to locate a file.", nullptr));
#if QT_CONFIG(tooltip)
        searchFolderButton->setToolTip(QCoreApplication::translate("UnlinkedFilesDialog", "This looks at every file in a folder to see if it matches any of the missing files.", nullptr));
#endif // QT_CONFIG(tooltip)
        searchFolderButton->setText(QCoreApplication::translate("UnlinkedFilesDialog", "Search in Folder...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UnlinkedFilesDialog: public Ui_UnlinkedFilesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_UNLINKEDFILESDIALOG_H
