/********************************************************************************
** Form generated from reading UI file 'decklinkproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DECKLINKPRODUCERWIDGET_H
#define UI_DECKLINKPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DecklinkProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QComboBox *profileCombo;
    QComboBox *deviceCombo;
    QLabel *label_3;
    QLabel *label_2;
    QLabel *label_4;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DecklinkProducerWidget)
    {
        if (DecklinkProducerWidget->objectName().isEmpty())
            DecklinkProducerWidget->setObjectName("DecklinkProducerWidget");
        DecklinkProducerWidget->resize(384, 284);
#if QT_CONFIG(whatsthis)
        DecklinkProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-sdi-hdmi/12934/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(DecklinkProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(DecklinkProducerWidget);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);
        label->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 3, 1);

        profileCombo = new QComboBox(DecklinkProducerWidget);
        profileCombo->setObjectName("profileCombo");

        gridLayout->addWidget(profileCombo, 2, 2, 1, 1);

        deviceCombo = new QComboBox(DecklinkProducerWidget);
        deviceCombo->setObjectName("deviceCombo");

        gridLayout->addWidget(deviceCombo, 1, 2, 1, 1);

        label_3 = new QLabel(DecklinkProducerWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        label_2 = new QLabel(DecklinkProducerWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        label_4 = new QLabel(DecklinkProducerWidget);
        label_4->setObjectName("label_4");
        label_4->setFrameShape(QFrame::Shape::StyledPanel);
        label_4->setFrameShadow(QFrame::Shadow::Plain);
        label_4->setWordWrap(true);
        label_4->setMargin(12);

        verticalLayout->addWidget(label_4);

        verticalSpacer = new QSpacerItem(20, 260, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(DecklinkProducerWidget);

        QMetaObject::connectSlotsByName(DecklinkProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *DecklinkProducerWidget)
    {
        DecklinkProducerWidget->setWindowTitle(QCoreApplication::translate("DecklinkProducerWidget", "Form", nullptr));
        label->setText(QCoreApplication::translate("DecklinkProducerWidget", "SDI/HDMI", nullptr));
        label_3->setText(QCoreApplication::translate("DecklinkProducerWidget", "Device", nullptr));
        label_2->setText(QCoreApplication::translate("DecklinkProducerWidget", "Signal mode", nullptr));
        label_4->setText(QCoreApplication::translate("DecklinkProducerWidget", "Please be aware that not every card model supports automatic signal detection, and not all cards support all of the signal modes.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DecklinkProducerWidget: public Ui_DecklinkProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DECKLINKPRODUCERWIDGET_H
