/********************************************************************************
** Form generated from reading UI file 'colorbarswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORBARSWIDGET_H
#define UI_COLORBARSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ColorBarsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *comboBox;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ColorBarsWidget)
    {
        if (ColorBarsWidget->objectName().isEmpty())
            ColorBarsWidget->setObjectName("ColorBarsWidget");
        ColorBarsWidget->resize(394, 294);
#if QT_CONFIG(whatsthis)
        ColorBarsWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-color-bars/12931/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(ColorBarsWidget);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(ColorBarsWidget);
        label_2->setObjectName("label_2");
        QFont font;
        font.setBold(true);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(ColorBarsWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(label);

        comboBox = new QComboBox(ColorBarsWidget);
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->setObjectName("comboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboBox->sizePolicy().hasHeightForWidth());
        comboBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(comboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ColorBarsWidget);

        QMetaObject::connectSlotsByName(ColorBarsWidget);
    } // setupUi

    void retranslateUi(QWidget *ColorBarsWidget)
    {
        ColorBarsWidget->setWindowTitle(QCoreApplication::translate("ColorBarsWidget", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("ColorBarsWidget", "Color Bars", nullptr));
        label->setText(QCoreApplication::translate("ColorBarsWidget", "Type", nullptr));
        comboBox->setItemText(0, QCoreApplication::translate("ColorBarsWidget", "100% PAL color bars", nullptr));
        comboBox->setItemText(1, QCoreApplication::translate("ColorBarsWidget", "100% PAL color bars with red", nullptr));
        comboBox->setItemText(2, QCoreApplication::translate("ColorBarsWidget", "95% BBC PAL color bars", nullptr));
        comboBox->setItemText(3, QCoreApplication::translate("ColorBarsWidget", "75% EBU color bars", nullptr));
        comboBox->setItemText(4, QCoreApplication::translate("ColorBarsWidget", "SMPTE color bars", nullptr));
        comboBox->setItemText(5, QCoreApplication::translate("ColorBarsWidget", "Philips PM5544", nullptr));
        comboBox->setItemText(6, QCoreApplication::translate("ColorBarsWidget", "FuBK", nullptr));
        comboBox->setItemText(7, QCoreApplication::translate("ColorBarsWidget", "Simplified FuBK", nullptr));

    } // retranslateUi

};

namespace Ui {
    class ColorBarsWidget: public Ui_ColorBarsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLORBARSWIDGET_H
