/****************************************************************************
** Meta object code from reading C++ file 'qmlmetadata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/qmltypes/qmlmetadata.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlmetadata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QmlKeyframesParameterE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlKeyframesParameter::qt_create_metaobjectdata<qt_meta_tag_ZN21QmlKeyframesParameterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlKeyframesParameter",
        "changed",
        "",
        "rangeType",
        "RangeType",
        "name",
        "property",
        "gangedProperties",
        "gangedRectProperties",
        "isCurve",
        "minimum",
        "maximum",
        "units",
        "isRectangle",
        "isColor",
        "MinMax",
        "ClipLength"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rangeType'
        QtMocHelpers::PropertyData<enum RangeType>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'property'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'gangedProperties'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'gangedRectProperties'
        QtMocHelpers::PropertyData<QStringList>(8, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'isCurve'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'minimum'
        QtMocHelpers::PropertyData<double>(10, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'maximum'
        QtMocHelpers::PropertyData<double>(11, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'units'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'isRectangle'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'isColor'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RangeType'
        QtMocHelpers::EnumData<enum RangeType>(4, 4, QMC::EnumFlags{}).add({
            {   15, RangeType::MinMax },
            {   16, RangeType::ClipLength },
        }),
    };
    return QtMocHelpers::metaObjectData<QmlKeyframesParameter, qt_meta_tag_ZN21QmlKeyframesParameterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlKeyframesParameter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QmlKeyframesParameterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QmlKeyframesParameterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QmlKeyframesParameterE_t>.metaTypes,
    nullptr
} };

void QmlKeyframesParameter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlKeyframesParameter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlKeyframesParameter::*)()>(_a, &QmlKeyframesParameter::changed, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum RangeType*>(_v) = _t->m_rangeType; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_name; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_property; break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->m_gangedProperties; break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->m_gangedRectProperties; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_isCurve; break;
        case 6: *reinterpret_cast<double*>(_v) = _t->m_minimum; break;
        case 7: *reinterpret_cast<double*>(_v) = _t->m_maximum; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->m_units; break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->m_isRectangle; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->m_isColor; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_rangeType, *reinterpret_cast<enum RangeType*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_name, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_property, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_gangedProperties, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_gangedRectProperties, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_isCurve, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_minimum, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_maximum, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_units, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_isRectangle, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_isColor, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *QmlKeyframesParameter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlKeyframesParameter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QmlKeyframesParameterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlKeyframesParameter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void QmlKeyframesParameter::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN20QmlKeyframesMetadataE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlKeyframesMetadata::qt_create_metaobjectdata<qt_meta_tag_ZN20QmlKeyframesMetadataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlKeyframesMetadata",
        "changed",
        "",
        "parameter",
        "QmlKeyframesParameter*",
        "propertyName",
        "allowTrim",
        "allowAnimateIn",
        "allowAnimateOut",
        "parameters",
        "QQmlListProperty<QmlKeyframesParameter>",
        "simpleProperties",
        "minimumVersion",
        "enabled",
        "allowOvershoot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'parameter'
        QtMocHelpers::MethodData<QmlKeyframesParameter *(const QString &) const>(3, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'allowTrim'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'allowAnimateIn'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'allowAnimateOut'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'parameters'
        QtMocHelpers::PropertyData<QQmlListProperty<QmlKeyframesParameter>>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'simpleProperties'
        QtMocHelpers::PropertyData<QList<QString>>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'minimumVersion'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'allowOvershoot'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlKeyframesMetadata, qt_meta_tag_ZN20QmlKeyframesMetadataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlKeyframesMetadata::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QmlKeyframesMetadataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QmlKeyframesMetadataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QmlKeyframesMetadataE_t>.metaTypes,
    nullptr
} };

void QmlKeyframesMetadata::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlKeyframesMetadata *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: { QmlKeyframesParameter* _r = _t->parameter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QmlKeyframesParameter**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlKeyframesMetadata::*)()>(_a, &QmlKeyframesMetadata::changed, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_allowTrim; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->m_allowAnimateIn; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_allowAnimateOut; break;
        case 3: *reinterpret_cast<QQmlListProperty<QmlKeyframesParameter>*>(_v) = _t->parameters(); break;
        case 4: *reinterpret_cast<QList<QString>*>(_v) = _t->m_simpleProperties; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_minimumVersion; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_enabled; break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->m_allowOvershoot; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_allowTrim, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_allowAnimateIn, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_allowAnimateOut, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_simpleProperties, *reinterpret_cast<QList<QString>*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_minimumVersion, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_enabled, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_allowOvershoot, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *QmlKeyframesMetadata::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlKeyframesMetadata::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QmlKeyframesMetadataE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlKeyframesMetadata::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void QmlKeyframesMetadata::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN11QmlMetadataE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlMetadata::qt_create_metaobjectdata<qt_meta_tag_ZN11QmlMetadataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlMetadata",
        "changed",
        "",
        "type",
        "PluginType",
        "name",
        "mlt_service",
        "needsGPU",
        "qml",
        "vui",
        "qmlFilePath",
        "QUrl",
        "vuiFilePath",
        "isAudio",
        "isHidden",
        "isFavorite",
        "gpuAlt",
        "allowMultiple",
        "isClipOnly",
        "isTrackOnly",
        "isOutputOnly",
        "isGpuCompatible",
        "keyframes",
        "QmlKeyframesMetadata*",
        "isDeprecated",
        "minimumVersion",
        "keywords",
        "icon",
        "seekReverse",
        "help",
        "Filter",
        "Producer",
        "Transition",
        "Link",
        "FilterSet"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<enum PluginType>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'mlt_service'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'needsGPU'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'qml'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'vui'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'qmlFilePath'
        QtMocHelpers::PropertyData<QUrl>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'vuiFilePath'
        QtMocHelpers::PropertyData<QUrl>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'isAudio'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isHidden'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isFavorite'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'gpuAlt'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'allowMultiple'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isClipOnly'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isTrackOnly'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isOutputOnly'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isGpuCompatible'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'keyframes'
        QtMocHelpers::PropertyData<QmlKeyframesMetadata*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'isDeprecated'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'minimumVersion'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'keywords'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'seekReverse'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'help'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PluginType'
        QtMocHelpers::EnumData<enum PluginType>(4, 4, QMC::EnumFlags{}).add({
            {   30, PluginType::Filter },
            {   31, PluginType::Producer },
            {   32, PluginType::Transition },
            {   33, PluginType::Link },
            {   34, PluginType::FilterSet },
        }),
    };
    return QtMocHelpers::metaObjectData<QmlMetadata, qt_meta_tag_ZN11QmlMetadataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlMetadata::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlMetadataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlMetadataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11QmlMetadataE_t>.metaTypes,
    nullptr
} };

void QmlMetadata::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlMetadata *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlMetadata::*)()>(_a, &QmlMetadata::changed, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QmlKeyframesMetadata* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum PluginType*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->mlt_service(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->needsGPU(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->qmlFileName(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->vuiFileName(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->qmlFilePath(); break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->vuiFilePath(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isAudio(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isHidden(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isFavorite(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->gpuAlt(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->allowMultiple(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isClipOnly(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isTrackOnly(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isOutputOnly(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isGpuCompatible(); break;
        case 17: *reinterpret_cast<QmlKeyframesMetadata**>(_v) = _t->keyframes(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isDeprecated(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->m_minimumVersion; break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->m_keywords; break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->iconFilePath(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->m_seekReverse; break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->m_helpText; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setType(*reinterpret_cast<enum PluginType*>(_v)); break;
        case 1: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->set_mlt_service(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setNeedsGPU(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setQmlFileName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setVuiFileName(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setIsAudio(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setIsHidden(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setIsFavorite(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setGpuAlt(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setAllowMultiple(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setIsClipOnly(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setIsTrackOnly(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setIsOutputOnly(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setIsGpuCompatible(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setIsDeprecated(*reinterpret_cast<bool*>(_v)); break;
        case 19:
            if (QtMocHelpers::setProperty(_t->m_minimumVersion, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 20:
            if (QtMocHelpers::setProperty(_t->m_keywords, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 21: _t->setIconFileName(*reinterpret_cast<QString*>(_v)); break;
        case 22:
            if (QtMocHelpers::setProperty(_t->m_seekReverse, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 23:
            if (QtMocHelpers::setProperty(_t->m_helpText, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *QmlMetadata::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlMetadata::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlMetadataE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlMetadata::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void QmlMetadata::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
