/********************************************************************************
** Form generated from reading UI file 'timelinepropertieswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TIMELINEPROPERTIESWIDGET_H
#define UI_TIMELINEPROPERTIESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TimelinePropertiesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    QWidget *widget;
    QGridLayout *gridLayout;
    QLabel *label_22;
    QHBoxLayout *horizontalLayout_8;
    QLabel *aspectRatioLabel;
    QSpacerItem *horizontalSpacer_8;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_2;
    QLabel *colorspaceLabel;
    QSpacerItem *horizontalSpacer;
    QLabel *label_10;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_9;
    QLabel *scanModeLabel;
    QSpacerItem *horizontalSpacer_9;
    QHBoxLayout *horizontalLayout_16;
    QLabel *frameRateLabel;
    QSpacerItem *horizontalSpacer_16;
    QLabel *label_13;
    QLabel *label_6;
    QLabel *label_4;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_7;
    QLabel *resolutionLabel;
    QSpacerItem *horizontalSpacer_7;
    QLabel *label_14;
    QLabel *label;
    QLabel *dynamicRangeLabel;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_dr;
    QLabel *dynamicRangeValueLabel;
    QSpacerItem *horizontalSpacer_dr;
    QHBoxLayout *horizontalLayout;
    QPushButton *editButton;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *TimelinePropertiesWidget)
    {
        if (TimelinePropertiesWidget->objectName().isEmpty())
            TimelinePropertiesWidget->setObjectName("TimelinePropertiesWidget");
        TimelinePropertiesWidget->resize(269, 282);
#if QT_CONFIG(whatsthis)
        TimelinePropertiesWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/timeline-output/19127/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(TimelinePropertiesWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(TimelinePropertiesWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        widget = new QWidget(TimelinePropertiesWidget);
        widget->setObjectName("widget");
        gridLayout = new QGridLayout(widget);
        gridLayout->setObjectName("gridLayout");
        label_22 = new QLabel(widget);
        label_22->setObjectName("label_22");
        label_22->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_22, 0, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        aspectRatioLabel = new QLabel(widget);
        aspectRatioLabel->setObjectName("aspectRatioLabel");
        aspectRatioLabel->setText(QString::fromUtf8("16 : 9"));

        horizontalLayout_8->addWidget(aspectRatioLabel);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_8);


        gridLayout->addLayout(horizontalLayout_8, 1, 3, 1, 1);

        label_5 = new QLabel(widget);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 3, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        colorspaceLabel = new QLabel(widget);
        colorspaceLabel->setObjectName("colorspaceLabel");
        colorspaceLabel->setText(QString::fromUtf8("ITU-R BT.709"));

        horizontalLayout_2->addWidget(colorspaceLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout_2, 4, 3, 1, 1);

        label_10 = new QLabel(widget);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_10, 2, 0, 1, 1);

        label_3 = new QLabel(widget);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 1, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        scanModeLabel = new QLabel(widget);
        scanModeLabel->setObjectName("scanModeLabel");
        scanModeLabel->setText(QString::fromUtf8("Progressive"));

        horizontalLayout_9->addWidget(scanModeLabel);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_9);


        gridLayout->addLayout(horizontalLayout_9, 3, 3, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        frameRateLabel = new QLabel(widget);
        frameRateLabel->setObjectName("frameRateLabel");
        frameRateLabel->setText(QString::fromUtf8("25 fps"));

        horizontalLayout_16->addWidget(frameRateLabel);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_16);


        gridLayout->addLayout(horizontalLayout_16, 2, 3, 1, 1);

        label_13 = new QLabel(widget);
        label_13->setObjectName("label_13");
        label_13->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_13, 1, 0, 1, 1);

        label_6 = new QLabel(widget);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 4, 1, 1, 1);

        label_4 = new QLabel(widget);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 2, 1, 1, 1);

        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_2, 4, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        resolutionLabel = new QLabel(widget);
        resolutionLabel->setObjectName("resolutionLabel");
        resolutionLabel->setText(QString::fromUtf8("1920 x 1080"));

        horizontalLayout_7->addWidget(resolutionLabel);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_7);


        gridLayout->addLayout(horizontalLayout_7, 0, 3, 1, 1);

        label_14 = new QLabel(widget);
        label_14->setObjectName("label_14");
        label_14->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_14, 3, 0, 1, 1);

        label = new QLabel(widget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 1, 1, 1);

        dynamicRangeLabel = new QLabel(widget);
        dynamicRangeLabel->setObjectName("dynamicRangeLabel");
        dynamicRangeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(dynamicRangeLabel, 5, 0, 1, 1);

        label_7 = new QLabel(widget);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 5, 1, 1, 1);

        horizontalLayout_dr = new QHBoxLayout();
        horizontalLayout_dr->setObjectName("horizontalLayout_dr");
        dynamicRangeValueLabel = new QLabel(widget);
        dynamicRangeValueLabel->setObjectName("dynamicRangeValueLabel");
        dynamicRangeValueLabel->setText(QString::fromUtf8("SDR"));

        horizontalLayout_dr->addWidget(dynamicRangeValueLabel);

        horizontalSpacer_dr = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_dr->addItem(horizontalSpacer_dr);


        gridLayout->addLayout(horizontalLayout_dr, 5, 3, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        editButton = new QPushButton(widget);
        editButton->setObjectName("editButton");

        horizontalLayout->addWidget(editButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout, 6, 3, 1, 1);


        verticalLayout->addWidget(widget);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        retranslateUi(TimelinePropertiesWidget);

        QMetaObject::connectSlotsByName(TimelinePropertiesWidget);
    } // setupUi

    void retranslateUi(QWidget *TimelinePropertiesWidget)
    {
        TimelinePropertiesWidget->setWindowTitle(QCoreApplication::translate("TimelinePropertiesWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Timeline", nullptr));
        label_22->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Resolution", nullptr));
        label_5->setText(QCoreApplication::translate("TimelinePropertiesWidget", ":", nullptr));
        label_10->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Frame rate", nullptr));
        label_3->setText(QCoreApplication::translate("TimelinePropertiesWidget", ":", nullptr));
        label_13->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Aspect ratio", nullptr));
        label_6->setText(QCoreApplication::translate("TimelinePropertiesWidget", ":", nullptr));
        label_4->setText(QCoreApplication::translate("TimelinePropertiesWidget", ":", nullptr));
        label_2->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Colorspace", nullptr));
        label_14->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Scan mode", nullptr));
        label->setText(QCoreApplication::translate("TimelinePropertiesWidget", ":", nullptr));
        dynamicRangeLabel->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Dynamic range", nullptr));
        label_7->setText(QCoreApplication::translate("TimelinePropertiesWidget", ":", nullptr));
        editButton->setText(QCoreApplication::translate("TimelinePropertiesWidget", "Edit...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TimelinePropertiesWidget: public Ui_TimelinePropertiesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TIMELINEPROPERTIESWIDGET_H
