/********************************************************************************
** Form generated from reading UI file 'imageproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGEPRODUCERWIDGET_H
#define UI_IMAGEPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/timespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_ImageProducerWidget
{
public:
    QAction *actionCopyFullFilePath;
    QAction *actionOpenFolder;
    QAction *actionSetFileDate;
    QAction *actionDisableProxy;
    QAction *actionMakeProxy;
    QAction *actionDeleteProxy;
    QAction *actionCopyHashCode;
    QAction *actionShowInFiles;
    QAction *actionReset;
    QVBoxLayout *verticalLayout;
    QLineEdit *filenameLabel;
    QLabel *label_2;
    QPlainTextEdit *notesTextEdit;
    QFormLayout *formLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout_3;
    QLabel *resolutionLabel;
    QLabel *durationLabel;
    QHBoxLayout *horizontalLayout_6;
    TimeSpinBox *durationSpinBox;
    QPushButton *defaultDurationButton;
    QLabel *aspectRatioLabel;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *aspectNumSpinBox;
    QLabel *label_4;
    QSpinBox *aspectDenSpinBox;
    QCheckBox *sequenceCheckBox;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_4;
    QSpinBox *repeatSpinBox;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QPushButton *menuButton;
    QPushButton *proxyButton;
    QPushButton *openWithButton;
    QPushButton *reloadButton;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ImageProducerWidget)
    {
        if (ImageProducerWidget->objectName().isEmpty())
            ImageProducerWidget->setObjectName("ImageProducerWidget");
        ImageProducerWidget->resize(412, 402);
#if QT_CONFIG(whatsthis)
        ImageProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/image-properties/12924/1"));
#endif // QT_CONFIG(whatsthis)
        actionCopyFullFilePath = new QAction(ImageProducerWidget);
        actionCopyFullFilePath->setObjectName("actionCopyFullFilePath");
        actionOpenFolder = new QAction(ImageProducerWidget);
        actionOpenFolder->setObjectName("actionOpenFolder");
        actionSetFileDate = new QAction(ImageProducerWidget);
        actionSetFileDate->setObjectName("actionSetFileDate");
        actionDisableProxy = new QAction(ImageProducerWidget);
        actionDisableProxy->setObjectName("actionDisableProxy");
        actionDisableProxy->setCheckable(true);
        actionMakeProxy = new QAction(ImageProducerWidget);
        actionMakeProxy->setObjectName("actionMakeProxy");
        actionDeleteProxy = new QAction(ImageProducerWidget);
        actionDeleteProxy->setObjectName("actionDeleteProxy");
        actionCopyHashCode = new QAction(ImageProducerWidget);
        actionCopyHashCode->setObjectName("actionCopyHashCode");
        actionShowInFiles = new QAction(ImageProducerWidget);
        actionShowInFiles->setObjectName("actionShowInFiles");
        actionReset = new QAction(ImageProducerWidget);
        actionReset->setObjectName("actionReset");
        actionReset->setMenuRole(QAction::MenuRole::NoRole);
        verticalLayout = new QVBoxLayout(ImageProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        filenameLabel = new QLineEdit(ImageProducerWidget);
        filenameLabel->setObjectName("filenameLabel");
        filenameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(filenameLabel);

        label_2 = new QLabel(ImageProducerWidget);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        notesTextEdit = new QPlainTextEdit(ImageProducerWidget);
        notesTextEdit->setObjectName("notesTextEdit");
        notesTextEdit->setMaximumSize(QSize(16777215, 60));
        notesTextEdit->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        notesTextEdit->setTabChangesFocus(true);

        verticalLayout->addWidget(notesTextEdit);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        label = new QLabel(ImageProducerWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        resolutionLabel = new QLabel(ImageProducerWidget);
        resolutionLabel->setObjectName("resolutionLabel");
        resolutionLabel->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        horizontalLayout_3->addWidget(resolutionLabel);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        durationLabel = new QLabel(ImageProducerWidget);
        durationLabel->setObjectName("durationLabel");
        durationLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, durationLabel);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        durationSpinBox = new TimeSpinBox(ImageProducerWidget);
        durationSpinBox->setObjectName("durationSpinBox");
        durationSpinBox->setMaximumSize(QSize(150, 16777215));
        durationSpinBox->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        durationSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        durationSpinBox->setAccelerated(true);
        durationSpinBox->setKeyboardTracking(false);
        durationSpinBox->setMinimum(1);
        durationSpinBox->setMaximum(2147483647);

        horizontalLayout_6->addWidget(durationSpinBox);

        defaultDurationButton = new QPushButton(ImageProducerWidget);
        defaultDurationButton->setObjectName("defaultDurationButton");

        horizontalLayout_6->addWidget(defaultDurationButton);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_6);

        aspectRatioLabel = new QLabel(ImageProducerWidget);
        aspectRatioLabel->setObjectName("aspectRatioLabel");
        aspectRatioLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, aspectRatioLabel);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        aspectNumSpinBox = new QSpinBox(ImageProducerWidget);
        aspectNumSpinBox->setObjectName("aspectNumSpinBox");
        aspectNumSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        aspectNumSpinBox->setKeyboardTracking(false);
        aspectNumSpinBox->setMinimum(1);
        aspectNumSpinBox->setMaximum(1000);
        aspectNumSpinBox->setValue(1);

        horizontalLayout_2->addWidget(aspectNumSpinBox);

        label_4 = new QLabel(ImageProducerWidget);
        label_4->setObjectName("label_4");

        horizontalLayout_2->addWidget(label_4);

        aspectDenSpinBox = new QSpinBox(ImageProducerWidget);
        aspectDenSpinBox->setObjectName("aspectDenSpinBox");
        aspectDenSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        aspectDenSpinBox->setKeyboardTracking(false);
        aspectDenSpinBox->setMinimum(1);
        aspectDenSpinBox->setMaximum(1000);
        aspectDenSpinBox->setValue(1);

        horizontalLayout_2->addWidget(aspectDenSpinBox);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        sequenceCheckBox = new QCheckBox(ImageProducerWidget);
        sequenceCheckBox->setObjectName("sequenceCheckBox");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, sequenceCheckBox);

        label_3 = new QLabel(ImageProducerWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        repeatSpinBox = new QSpinBox(ImageProducerWidget);
        repeatSpinBox->setObjectName("repeatSpinBox");
        repeatSpinBox->setEnabled(false);
        repeatSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        repeatSpinBox->setKeyboardTracking(false);
        repeatSpinBox->setMinimum(1);
        repeatSpinBox->setMaximum(999);
        repeatSpinBox->setValue(50);

        horizontalLayout_4->addWidget(repeatSpinBox);

        label_5 = new QLabel(ImageProducerWidget);
        label_5->setObjectName("label_5");

        horizontalLayout_4->addWidget(label_5);


        formLayout->setLayout(5, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);


        verticalLayout->addLayout(formLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        menuButton = new QPushButton(ImageProducerWidget);
        menuButton->setObjectName("menuButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("show-menu");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/show-menu.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        menuButton->setIcon(icon);

        horizontalLayout->addWidget(menuButton);

        proxyButton = new QPushButton(ImageProducerWidget);
        proxyButton->setObjectName("proxyButton");

        horizontalLayout->addWidget(proxyButton);

        openWithButton = new QPushButton(ImageProducerWidget);
        openWithButton->setObjectName("openWithButton");

        horizontalLayout->addWidget(openWithButton);

        reloadButton = new QPushButton(ImageProducerWidget);
        reloadButton->setObjectName("reloadButton");

        horizontalLayout->addWidget(reloadButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(filenameLabel, notesTextEdit);
        QWidget::setTabOrder(notesTextEdit, defaultDurationButton);
        QWidget::setTabOrder(defaultDurationButton, aspectNumSpinBox);
        QWidget::setTabOrder(aspectNumSpinBox, aspectDenSpinBox);
        QWidget::setTabOrder(aspectDenSpinBox, sequenceCheckBox);
        QWidget::setTabOrder(sequenceCheckBox, repeatSpinBox);
        QWidget::setTabOrder(repeatSpinBox, menuButton);
        QWidget::setTabOrder(menuButton, openWithButton);
        QWidget::setTabOrder(openWithButton, reloadButton);

        retranslateUi(ImageProducerWidget);
        QObject::connect(sequenceCheckBox, &QCheckBox::toggled, openWithButton, &QPushButton::setDisabled);

        QMetaObject::connectSlotsByName(ImageProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *ImageProducerWidget)
    {
        ImageProducerWidget->setWindowTitle(QCoreApplication::translate("ImageProducerWidget", "Form", nullptr));
        actionCopyFullFilePath->setText(QCoreApplication::translate("ImageProducerWidget", "Copy Full File Path", nullptr));
        actionOpenFolder->setText(QCoreApplication::translate("ImageProducerWidget", "Show In Folder", nullptr));
        actionSetFileDate->setText(QCoreApplication::translate("ImageProducerWidget", "Set Creation Time...", nullptr));
        actionDisableProxy->setText(QCoreApplication::translate("ImageProducerWidget", "Disable Proxy", nullptr));
        actionMakeProxy->setText(QCoreApplication::translate("ImageProducerWidget", "Make Proxy", nullptr));
        actionDeleteProxy->setText(QCoreApplication::translate("ImageProducerWidget", "Delete Proxy", nullptr));
        actionCopyHashCode->setText(QCoreApplication::translate("ImageProducerWidget", "Copy Hash Code", nullptr));
        actionShowInFiles->setText(QCoreApplication::translate("ImageProducerWidget", "Show In Files", nullptr));
        actionReset->setText(QCoreApplication::translate("ImageProducerWidget", "Reset", nullptr));
        label_2->setText(QCoreApplication::translate("ImageProducerWidget", "Comments:", nullptr));
        notesTextEdit->setPlainText(QString());
        label->setText(QCoreApplication::translate("ImageProducerWidget", "Resolution", nullptr));
        resolutionLabel->setText(QCoreApplication::translate("ImageProducerWidget", "x", nullptr));
        durationLabel->setText(QCoreApplication::translate("ImageProducerWidget", "Duration", nullptr));
#if QT_CONFIG(tooltip)
        defaultDurationButton->setToolTip(QCoreApplication::translate("ImageProducerWidget", "Make the current duration value the default value", nullptr));
#endif // QT_CONFIG(tooltip)
        defaultDurationButton->setText(QCoreApplication::translate("ImageProducerWidget", "Set Default", nullptr));
        aspectRatioLabel->setText(QCoreApplication::translate("ImageProducerWidget", "Pixel aspect ratio", nullptr));
        label_4->setText(QCoreApplication::translate("ImageProducerWidget", ":", nullptr));
        sequenceCheckBox->setText(QCoreApplication::translate("ImageProducerWidget", "Image sequence", nullptr));
        label_3->setText(QCoreApplication::translate("ImageProducerWidget", "Repeat", nullptr));
        repeatSpinBox->setSuffix(QCoreApplication::translate("ImageProducerWidget", " frames", nullptr));
        label_5->setText(QCoreApplication::translate("ImageProducerWidget", "per picture", nullptr));
#if QT_CONFIG(tooltip)
        menuButton->setToolTip(QCoreApplication::translate("ImageProducerWidget", "Properties Menu", nullptr));
#endif // QT_CONFIG(tooltip)
        menuButton->setText(QString());
        proxyButton->setText(QCoreApplication::translate("ImageProducerWidget", "Proxy", nullptr));
        openWithButton->setText(QCoreApplication::translate("ImageProducerWidget", "Open With", nullptr));
#if QT_CONFIG(tooltip)
        reloadButton->setToolTip(QCoreApplication::translate("ImageProducerWidget", "Refresh the file in Shotcut if you changed it in another app", nullptr));
#endif // QT_CONFIG(tooltip)
        reloadButton->setText(QCoreApplication::translate("ImageProducerWidget", "Reload", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ImageProducerWidget: public Ui_ImageProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IMAGEPRODUCERWIDGET_H
