/****************************************************************************
** Meta object code from reading C++ file 'timelinedock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/docks/timelinedock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinedock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12TimelineDockE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineDock::qt_create_metaobjectdata<qt_meta_tag_ZN12TimelineDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineDock",
        "currentTrackChanged",
        "",
        "selectionChanged",
        "seeked",
        "position",
        "positionChanged",
        "loopChanged",
        "clipOpened",
        "Mlt::Producer*",
        "producer",
        "dragging",
        "QPointF",
        "pos",
        "duration",
        "dropped",
        "dropAccepted",
        "xml",
        "gainChanged",
        "gain",
        "fadeInChanged",
        "fadeOutChanged",
        "selected",
        "clipClicked",
        "showStatusMessage",
        "clipCopied",
        "clipMoved",
        "fromTrack",
        "toTrack",
        "clipIndex",
        "ripple",
        "filteredClicked",
        "durationChanged",
        "transitionAdded",
        "trackIndex",
        "zoomIn",
        "zoomOut",
        "zoomToFit",
        "setZoom",
        "value",
        "markerRangesChanged",
        "markerSeeked",
        "markerIndex",
        "isRecordingChanged",
        "multitrackSelected",
        "warnTrackLocked",
        "refreshWaveforms",
        "updateThumbnails",
        "trimStarted",
        "trimEnded",
        "addAudioTrack",
        "addVideoTrack",
        "alignSelectedClips",
        "onShowFrame",
        "SharedFrame",
        "frame",
        "onSeeked",
        "append",
        "remove",
        "ignoreTransition",
        "mergeClipWithNext",
        "dryrun",
        "lift",
        "removeSelection",
        "withCopy",
        "liftSelection",
        "incrementCurrentTrack",
        "by",
        "selectTrackHead",
        "selectMultitrack",
        "copy",
        "setTrackName",
        "toggleTrackMute",
        "toggleOtherTracksMute",
        "toggleTrackHidden",
        "toggleOtherTracksHidden",
        "setTrackComposite",
        "composite",
        "setTrackLock",
        "lock",
        "moveClip",
        "onClipMoved",
        "trimClipIn",
        "oldClipIndex",
        "delta",
        "roll",
        "trimClipOut",
        "resizeTransition",
        "insert",
        "seek",
        "overwrite",
        "appendFromPlaylist",
        "Mlt::Playlist*",
        "playlist",
        "skipProxy",
        "emptyTrack",
        "changeGain",
        "fadeIn",
        "fadeOut",
        "seekPreviousEdit",
        "seekNextEdit",
        "seekInPoint",
        "clearSelectionIfInvalid",
        "insertTrack",
        "insertAudioTrack",
        "insertVideoTrack",
        "removeTrack",
        "moveTrack",
        "fromTrackIndex",
        "toTrackIndex",
        "moveTrackUp",
        "moveTrackDown",
        "onProducerChanged",
        "emitSelectedFromSelection",
        "remakeAudioLevels",
        "force",
        "commitTrimCommand",
        "onRowsInserted",
        "QModelIndex",
        "parent",
        "first",
        "last",
        "onRowsRemoved",
        "onRowsMoved",
        "start",
        "end",
        "destination",
        "row",
        "detachAudio",
        "selectAll",
        "selectAllOnCurrentTrack",
        "onProducerModified",
        "replace",
        "createOrEditMarker",
        "createOrEditSelectionMarker",
        "createMarker",
        "editMarker",
        "deleteMarker",
        "seekNextMarker",
        "seekPrevMarker",
        "onFilterModelChanged",
        "initLoad",
        "handleDrop",
        "onLoopChanged",
        "load",
        "onTopLevelChanged",
        "floating",
        "onTransitionAdded",
        "selectClip",
        "onMultitrackClosed",
        "reloadTimelineModels",
        "onRecordStarted",
        "updateRecording",
        "onRecordFinished",
        "AbstractJob*",
        "onWarnTrackLocked",
        "onTimelineRightClicked",
        "onClipRightClicked",
        "onNoMoreEmptyTracks",
        "isAudio",
        "addGenerator",
        "restoreSelection",
        "getGroupForClip",
        "QVariantList",
        "isMultitrackSelected",
        "selectedTrack",
        "isFloating",
        "openProperties",
        "recordAudio",
        "stopRecording",
        "currentTrack",
        "selection",
        "isRecording",
        "loopStart",
        "loopEnd"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentTrackChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'loopChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipOpened'
        QtMocHelpers::SignalData<void(Mlt::Producer *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'dragging'
        QtMocHelpers::SignalData<void(const QPointF &, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Signal 'dropped'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dropAccepted'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'gainChanged'
        QtMocHelpers::SignalData<void(double)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 19 },
        }}),
        // Signal 'fadeInChanged'
        QtMocHelpers::SignalData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Signal 'fadeOutChanged'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Signal 'selected'
        QtMocHelpers::SignalData<void(Mlt::Producer *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'clipClicked'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showStatusMessage'
        QtMocHelpers::SignalData<void(QString)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'clipCopied'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipMoved'
        QtMocHelpers::SignalData<void(int, int, int, int, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 30 },
        }}),
        // Signal 'filteredClicked'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionAdded'
        QtMocHelpers::SignalData<void(int, int, int, bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 5 }, { QMetaType::Bool, 30 },
        }}),
        // Signal 'zoomIn'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomOut'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomToFit'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setZoom'
        QtMocHelpers::SignalData<void(double)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 39 },
        }}),
        // Signal 'markerRangesChanged'
        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'markerSeeked'
        QtMocHelpers::SignalData<void(int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Signal 'isRecordingChanged'
        QtMocHelpers::SignalData<void(bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'multitrackSelected'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'warnTrackLocked'
        QtMocHelpers::SignalData<void(int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Signal 'refreshWaveforms'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateThumbnails'
        QtMocHelpers::SignalData<void(int, int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Signal 'trimStarted'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trimEnded'
        QtMocHelpers::SignalData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addAudioTrack'
        QtMocHelpers::SlotData<int()>(50, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'addVideoTrack'
        QtMocHelpers::SlotData<int()>(51, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'alignSelectedClips'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onShowFrame'
        QtMocHelpers::SlotData<void(const SharedFrame &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'onSeeked'
        QtMocHelpers::SlotData<void(int)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(int, int, bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Bool, 59 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(int, int)>(58, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'mergeClipWithNext'
        QtMocHelpers::SlotData<bool(int, int, bool)>(60, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Bool, 61 },
        }}),
        // Slot 'lift'
        QtMocHelpers::SlotData<void(int, int, bool)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Bool, 59 },
        }}),
        // Slot 'lift'
        QtMocHelpers::SlotData<void(int, int)>(62, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'removeSelection'
        QtMocHelpers::SlotData<void(bool)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 64 },
        }}),
        // Slot 'removeSelection'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'liftSelection'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'incrementCurrentTrack'
        QtMocHelpers::SlotData<void(int)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 67 },
        }}),
        // Slot 'selectTrackHead'
        QtMocHelpers::SlotData<void(int)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'selectMultitrack'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void(int, int)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'setTrackName'
        QtMocHelpers::SlotData<void(int, const QString &)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'toggleTrackMute'
        QtMocHelpers::SlotData<void(int)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'toggleOtherTracksMute'
        QtMocHelpers::SlotData<void(int)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'toggleTrackHidden'
        QtMocHelpers::SlotData<void(int)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'toggleOtherTracksHidden'
        QtMocHelpers::SlotData<void(int)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'setTrackComposite'
        QtMocHelpers::SlotData<void(int, bool)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Bool, 77 },
        }}),
        // Slot 'setTrackLock'
        QtMocHelpers::SlotData<void(int, bool)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Bool, 79 },
        }}),
        // Slot 'moveClip'
        QtMocHelpers::SlotData<bool(int, int, int, int, bool)>(80, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 27 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'onClipMoved'
        QtMocHelpers::SlotData<void(int, int, int, int, bool)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Int, 28 }, { QMetaType::Int, 29 }, { QMetaType::Int, 5 },
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'trimClipIn'
        QtMocHelpers::SlotData<bool(int, int, int, int, bool, bool)>(82, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 83 }, { QMetaType::Int, 84 },
            { QMetaType::Bool, 30 }, { QMetaType::Bool, 85 },
        }}),
        // Slot 'trimClipOut'
        QtMocHelpers::SlotData<bool(int, int, int, bool, bool)>(86, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 84 }, { QMetaType::Bool, 30 },
            { QMetaType::Bool, 85 },
        }}),
        // Slot 'resizeTransition'
        QtMocHelpers::SlotData<bool(int, int, int)>(87, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 84 },
        }}),
        // Slot 'insert'
        QtMocHelpers::SlotData<void(int, int, const QString &, bool)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 5 }, { QMetaType::QString, 17 }, { QMetaType::Bool, 89 },
        }}),
        // Slot 'insert'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(88, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 5 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'insert'
        QtMocHelpers::SlotData<void(int, int)>(88, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'insert'
        QtMocHelpers::SlotData<void(int)>(88, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'overwrite'
        QtMocHelpers::SlotData<void(int, int, const QString &, bool)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 5 }, { QMetaType::QString, 17 }, { QMetaType::Bool, 89 },
        }}),
        // Slot 'overwrite'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(90, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 5 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'overwrite'
        QtMocHelpers::SlotData<void(int, int)>(90, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'overwrite'
        QtMocHelpers::SlotData<void(int)>(90, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'appendFromPlaylist'
        QtMocHelpers::SlotData<void(Mlt::Playlist *, bool, bool)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 92, 93 }, { QMetaType::Bool, 94 }, { QMetaType::Bool, 95 },
        }}),
        // Slot 'changeGain'
        QtMocHelpers::SlotData<bool(int, int, double)>(96, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Double, 19 },
        }}),
        // Slot 'fadeIn'
        QtMocHelpers::SlotData<void(int, int, int)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'fadeIn'
        QtMocHelpers::SlotData<void(int, int)>(97, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'fadeIn'
        QtMocHelpers::SlotData<void(int)>(97, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'fadeOut'
        QtMocHelpers::SlotData<void(int, int, int)>(98, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'fadeOut'
        QtMocHelpers::SlotData<void(int, int)>(98, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'fadeOut'
        QtMocHelpers::SlotData<void(int)>(98, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'seekPreviousEdit'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekNextEdit'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekInPoint'
        QtMocHelpers::SlotData<void(int)>(101, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'clearSelectionIfInvalid'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertTrack'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertAudioTrack'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertVideoTrack'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeTrack'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveTrack'
        QtMocHelpers::SlotData<void(int, int)>(107, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 108 }, { QMetaType::Int, 109 },
        }}),
        // Slot 'moveTrackUp'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveTrackDown'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerChanged'
        QtMocHelpers::SlotData<void(Mlt::Producer *)>(112, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Slot 'emitSelectedFromSelection'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'remakeAudioLevels'
        QtMocHelpers::SlotData<void(int, int, bool)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Bool, 115 },
        }}),
        // Slot 'remakeAudioLevels'
        QtMocHelpers::SlotData<void(int, int)>(114, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'commitTrimCommand'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(117, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 118, 119 }, { QMetaType::Int, 120 }, { QMetaType::Int, 121 },
        }}),
        // Slot 'onRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(122, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 118, 119 }, { QMetaType::Int, 120 }, { QMetaType::Int, 121 },
        }}),
        // Slot 'onRowsMoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(123, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 118, 119 }, { QMetaType::Int, 124 }, { QMetaType::Int, 125 }, { 0x80000000 | 118, 126 },
            { QMetaType::Int, 127 },
        }}),
        // Slot 'detachAudio'
        QtMocHelpers::SlotData<void(int, int)>(128, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectAllOnCurrentTrack'
        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerModified'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'replace'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(132, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'replace'
        QtMocHelpers::SlotData<void(int, int)>(132, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'createOrEditMarker'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createOrEditSelectionMarker'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createMarker'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editMarker'
        QtMocHelpers::SlotData<void(int)>(136, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Slot 'deleteMarker'
        QtMocHelpers::SlotData<void(int)>(137, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Slot 'deleteMarker'
        QtMocHelpers::SlotData<void()>(137, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'seekNextMarker'
        QtMocHelpers::SlotData<void()>(138, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekPrevMarker'
        QtMocHelpers::SlotData<void()>(139, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFilterModelChanged'
        QtMocHelpers::SlotData<void()>(140, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'trimClipIn'
        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'trimClipIn'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'trimClipOut'
        QtMocHelpers::SlotData<void(bool)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'trimClipOut'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'initLoad'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleDrop'
        QtMocHelpers::SlotData<void(int, int, QString)>(142, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 5 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'onLoopChanged'
        QtMocHelpers::SlotData<void(int, int)>(143, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 124 }, { QMetaType::Int, 125 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(bool)>(144, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 115 },
        }}),
        // Slot 'onTopLevelChanged'
        QtMocHelpers::SlotData<void(bool)>(145, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 146 },
        }}),
        // Slot 'onTransitionAdded'
        QtMocHelpers::SlotData<void(int, int, int, bool)>(147, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 5 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'selectClip'
        QtMocHelpers::SlotData<void(int, int)>(148, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'onMultitrackClosed'
        QtMocHelpers::SlotData<void()>(149, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadTimelineModels'
        QtMocHelpers::SlotData<void()>(150, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRecordStarted'
        QtMocHelpers::SlotData<void()>(151, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateRecording'
        QtMocHelpers::SlotData<void()>(152, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRecordFinished'
        QtMocHelpers::SlotData<void(AbstractJob *, bool)>(153, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 154, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'onWarnTrackLocked'
        QtMocHelpers::SlotData<void()>(155, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTimelineRightClicked'
        QtMocHelpers::SlotData<void()>(156, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onClipRightClicked'
        QtMocHelpers::SlotData<void()>(157, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onNoMoreEmptyTracks'
        QtMocHelpers::SlotData<void(bool)>(158, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 159 },
        }}),
        // Slot 'addGenerator'
        QtMocHelpers::SlotData<void()>(160, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'restoreSelection'
        QtMocHelpers::MethodData<void()>(161, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'getGroupForClip'
        QtMocHelpers::MethodData<QVariantList(int, int)>(162, 2, QMC::AccessPublic, 0x80000000 | 163, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 },
        }}),
        // Method 'isMultitrackSelected'
        QtMocHelpers::MethodData<bool() const>(164, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'selectedTrack'
        QtMocHelpers::MethodData<int() const>(165, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'isFloating'
        QtMocHelpers::MethodData<bool() const>(166, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'openProperties'
        QtMocHelpers::MethodData<void()>(167, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'recordAudio'
        QtMocHelpers::MethodData<void()>(168, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'stopRecording'
        QtMocHelpers::MethodData<void()>(169, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'position'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'currentTrack'
        QtMocHelpers::PropertyData<int>(170, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'selection'
        QtMocHelpers::PropertyData<QVariantList>(171, 0x80000000 | 163, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'isRecording'
        QtMocHelpers::PropertyData<bool>(172, QMetaType::Bool, QMC::DefaultPropertyFlags, 26),
        // property 'loopStart'
        QtMocHelpers::PropertyData<int>(173, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'loopEnd'
        QtMocHelpers::PropertyData<int>(174, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimelineDock, qt_meta_tag_ZN12TimelineDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimelineDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TimelineDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TimelineDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12TimelineDockE_t>.metaTypes,
    nullptr
} };

void TimelineDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTrackChanged(); break;
        case 1: _t->selectionChanged(); break;
        case 2: _t->seeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->loopChanged(); break;
        case 5: _t->clipOpened((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 6: _t->dragging((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->dropped(); break;
        case 8: _t->dropAccepted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->gainChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->fadeInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->fadeOutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->selected((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 13: _t->clipClicked(); break;
        case 14: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->clipCopied(); break;
        case 16: _t->clipMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 17: _t->filteredClicked(); break;
        case 18: _t->durationChanged(); break;
        case 19: _t->transitionAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 20: _t->zoomIn(); break;
        case 21: _t->zoomOut(); break;
        case 22: _t->zoomToFit(); break;
        case 23: _t->setZoom((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->markerRangesChanged(); break;
        case 25: _t->markerSeeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->isRecordingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->multitrackSelected(); break;
        case 28: _t->warnTrackLocked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->refreshWaveforms(); break;
        case 30: _t->updateThumbnails((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 31: _t->trimStarted(); break;
        case 32: _t->trimEnded(); break;
        case 33: { int _r = _t->addAudioTrack();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: { int _r = _t->addVideoTrack();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->alignSelectedClips(); break;
        case 36: _t->onShowFrame((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 37: _t->onSeeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->append((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 40: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 41: { bool _r = _t->mergeClipWithNext((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->lift((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 43: _t->lift((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 44: _t->removeSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->removeSelection(); break;
        case 46: _t->liftSelection(); break;
        case 47: _t->incrementCurrentTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->selectTrackHead((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->selectMultitrack(); break;
        case 50: _t->copy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 51: _t->setTrackName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 52: _t->toggleTrackMute((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 53: _t->toggleOtherTracksMute((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->toggleTrackHidden((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 55: _t->toggleOtherTracksHidden((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->setTrackComposite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 57: _t->setTrackLock((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 58: { bool _r = _t->moveClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->onClipMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 60: { bool _r = _t->trimClipIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 61: { bool _r = _t->trimClipOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 62: { bool _r = _t->resizeTransition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 63: _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 64: _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 65: _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 66: _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 67: _t->overwrite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 68: _t->overwrite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 69: _t->overwrite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 70: _t->overwrite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 71: _t->appendFromPlaylist((*reinterpret_cast<std::add_pointer_t<Mlt::Playlist*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 72: { bool _r = _t->changeGain((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 73: _t->fadeIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 74: _t->fadeIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 75: _t->fadeIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 76: _t->fadeOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 77: _t->fadeOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 78: _t->fadeOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 79: _t->seekPreviousEdit(); break;
        case 80: _t->seekNextEdit(); break;
        case 81: _t->seekInPoint((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 82: _t->clearSelectionIfInvalid(); break;
        case 83: _t->insertTrack(); break;
        case 84: _t->insertAudioTrack(); break;
        case 85: _t->insertVideoTrack(); break;
        case 86: _t->removeTrack(); break;
        case 87: _t->moveTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 88: _t->moveTrackUp(); break;
        case 89: _t->moveTrackDown(); break;
        case 90: _t->onProducerChanged((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 91: _t->emitSelectedFromSelection(); break;
        case 92: _t->remakeAudioLevels((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 93: _t->remakeAudioLevels((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 94: _t->commitTrimCommand(); break;
        case 95: _t->onRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 96: _t->onRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 97: _t->onRowsMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 98: _t->detachAudio((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 99: _t->selectAll(); break;
        case 100: _t->selectAllOnCurrentTrack(); break;
        case 101: _t->onProducerModified(); break;
        case 102: _t->replace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 103: _t->replace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 104: _t->createOrEditMarker(); break;
        case 105: _t->createOrEditSelectionMarker(); break;
        case 106: _t->createMarker(); break;
        case 107: _t->editMarker((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 108: _t->deleteMarker((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 109: _t->deleteMarker(); break;
        case 110: _t->seekNextMarker(); break;
        case 111: _t->seekPrevMarker(); break;
        case 112: _t->onFilterModelChanged(); break;
        case 113: _t->trimClipIn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 114: _t->trimClipIn(); break;
        case 115: _t->trimClipOut((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 116: _t->trimClipOut(); break;
        case 117: _t->initLoad(); break;
        case 118: _t->handleDrop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 119: _t->onLoopChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 120: _t->load((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 121: _t->onTopLevelChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 122: _t->onTransitionAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 123: _t->selectClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 124: _t->onMultitrackClosed(); break;
        case 125: _t->reloadTimelineModels(); break;
        case 126: _t->onRecordStarted(); break;
        case 127: _t->updateRecording(); break;
        case 128: _t->onRecordFinished((*reinterpret_cast<std::add_pointer_t<AbstractJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 129: _t->onWarnTrackLocked(); break;
        case 130: _t->onTimelineRightClicked(); break;
        case 131: _t->onClipRightClicked(); break;
        case 132: _t->onNoMoreEmptyTracks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 133: _t->addGenerator(); break;
        case 134: _t->restoreSelection(); break;
        case 135: { QVariantList _r = _t->getGroupForClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 136: { bool _r = _t->isMultitrackSelected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 137: { int _r = _t->selectedTrack();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 138: { bool _r = _t->isFloating();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 139: _t->openProperties(); break;
        case 140: _t->recordAudio(); break;
        case 141: _t->stopRecording(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 128:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< AbstractJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::currentTrackChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::selectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int )>(_a, &TimelineDock::seeked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int )>(_a, &TimelineDock::positionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::loopChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(Mlt::Producer * )>(_a, &TimelineDock::clipOpened, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(const QPointF & , int )>(_a, &TimelineDock::dragging, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::dropped, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(const QString & )>(_a, &TimelineDock::dropAccepted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(double )>(_a, &TimelineDock::gainChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int )>(_a, &TimelineDock::fadeInChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int )>(_a, &TimelineDock::fadeOutChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(Mlt::Producer * )>(_a, &TimelineDock::selected, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::clipClicked, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(QString )>(_a, &TimelineDock::showStatusMessage, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::clipCopied, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int , int , int , int , bool )>(_a, &TimelineDock::clipMoved, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::filteredClicked, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::durationChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int , int , int , bool )>(_a, &TimelineDock::transitionAdded, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::zoomIn, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::zoomOut, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::zoomToFit, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(double )>(_a, &TimelineDock::setZoom, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::markerRangesChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int )>(_a, &TimelineDock::markerSeeked, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(bool )>(_a, &TimelineDock::isRecordingChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::multitrackSelected, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int )>(_a, &TimelineDock::warnTrackLocked, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::refreshWaveforms, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)(int , int )>(_a, &TimelineDock::updateThumbnails, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::trimStarted, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineDock::*)()>(_a, &TimelineDock::trimEnded, 32))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->position(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->currentTrack(); break;
        case 2: *reinterpret_cast<QVariantList*>(_v) = _t->selectionForJS(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isRecording(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->loopStart(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->loopEnd(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setCurrentTrack(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setSelectionFromJS(*reinterpret_cast<QVariantList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TimelineDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TimelineDockE_t>.strings))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int TimelineDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 142)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 142;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 142)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 142;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void TimelineDock::currentTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TimelineDock::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineDock::seeked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TimelineDock::positionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TimelineDock::loopChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TimelineDock::clipOpened(Mlt::Producer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TimelineDock::dragging(const QPointF & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void TimelineDock::dropped()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void TimelineDock::dropAccepted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void TimelineDock::gainChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void TimelineDock::fadeInChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void TimelineDock::fadeOutChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void TimelineDock::selected(Mlt::Producer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void TimelineDock::clipClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void TimelineDock::showStatusMessage(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void TimelineDock::clipCopied()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void TimelineDock::clipMoved(int _t1, int _t2, int _t3, int _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 17
void TimelineDock::filteredClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void TimelineDock::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void TimelineDock::transitionAdded(int _t1, int _t2, int _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 20
void TimelineDock::zoomIn()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void TimelineDock::zoomOut()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void TimelineDock::zoomToFit()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void TimelineDock::setZoom(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void TimelineDock::markerRangesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void TimelineDock::markerSeeked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void TimelineDock::isRecordingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void TimelineDock::multitrackSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void TimelineDock::warnTrackLocked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void TimelineDock::refreshWaveforms()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void TimelineDock::updateThumbnails(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2);
}

// SIGNAL 31
void TimelineDock::trimStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void TimelineDock::trimEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}
QT_WARNING_POP
