/****************************************************************************
** Meta object code from reading C++ file 'hdrpreviewwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/hdrpreviewwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hdrpreviewwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16HdrPreviewWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto HdrPreviewWindow::qt_create_metaobjectdata<qt_meta_tag_ZN16HdrPreviewWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HdrPreviewWindow",
        "hdrGainChanged",
        "",
        "hdrTransferModeChanged",
        "hdrModeRestartRequested",
        "hdrModeConfirmed",
        "available",
        "displayPeakNitsChanged",
        "contentPeakNitsChanged",
        "toneMappingChanged",
        "playingChanged",
        "fullScreenChanged",
        "videoPositionChanged",
        "videoDurationChanged",
        "pushFrame",
        "QVideoFrame",
        "frame",
        "setHdrTransfer",
        "HdrTransfer",
        "transfer",
        "setPlaying",
        "playing",
        "checkEdrHeadroom",
        "onScreenChanged",
        "QScreen*",
        "screen",
        "processPendingScreenChange",
        "setVideoSink",
        "QVideoSink*",
        "sink",
        "triggerPlayPause",
        "triggerRewind",
        "triggerFastForward",
        "toggleFullScreen",
        "seekToFrame",
        "beginSystemMove",
        "hdrGain",
        "hdrTransferMode",
        "displayPeakNits",
        "contentPeakNits",
        "toneMapping",
        "fullScreen",
        "videoPosition",
        "videoDuration",
        "positionText",
        "durationText"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hdrGainChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hdrTransferModeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hdrModeRestartRequested'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hdrModeConfirmed'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'displayPeakNitsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentPeakNitsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toneMappingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playingChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullScreenChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoPositionChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoDurationChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pushFrame'
        QtMocHelpers::SlotData<void(const QVideoFrame &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setHdrTransfer'
        QtMocHelpers::SlotData<void(HdrTransfer)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setPlaying'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'checkEdrHeadroom'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onScreenChanged'
        QtMocHelpers::SlotData<void(QScreen *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'processPendingScreenChange'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'setVideoSink'
        QtMocHelpers::MethodData<void(QVideoSink *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Method 'triggerPlayPause'
        QtMocHelpers::MethodData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'triggerRewind'
        QtMocHelpers::MethodData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'triggerFastForward'
        QtMocHelpers::MethodData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'toggleFullScreen'
        QtMocHelpers::MethodData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'seekToFrame'
        QtMocHelpers::MethodData<void(int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Method 'beginSystemMove'
        QtMocHelpers::MethodData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'hdrGain'
        QtMocHelpers::PropertyData<float>(36, QMetaType::Float, QMC::DefaultPropertyFlags, 0),
        // property 'hdrTransferMode'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'displayPeakNits'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'contentPeakNits'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'toneMapping'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'playing'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'fullScreen'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'videoPosition'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'videoDuration'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'positionText'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'durationText'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HdrPreviewWindow, qt_meta_tag_ZN16HdrPreviewWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HdrPreviewWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HdrPreviewWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HdrPreviewWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16HdrPreviewWindowE_t>.metaTypes,
    nullptr
} };

void HdrPreviewWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HdrPreviewWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hdrGainChanged(); break;
        case 1: _t->hdrTransferModeChanged(); break;
        case 2: _t->hdrModeRestartRequested(); break;
        case 3: _t->hdrModeConfirmed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->displayPeakNitsChanged(); break;
        case 5: _t->contentPeakNitsChanged(); break;
        case 6: _t->toneMappingChanged(); break;
        case 7: _t->playingChanged(); break;
        case 8: _t->fullScreenChanged(); break;
        case 9: _t->videoPositionChanged(); break;
        case 10: _t->videoDurationChanged(); break;
        case 11: _t->pushFrame((*reinterpret_cast<std::add_pointer_t<QVideoFrame>>(_a[1]))); break;
        case 12: _t->setHdrTransfer((*reinterpret_cast<std::add_pointer_t<HdrTransfer>>(_a[1]))); break;
        case 13: _t->setPlaying((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->checkEdrHeadroom(); break;
        case 15: _t->onScreenChanged((*reinterpret_cast<std::add_pointer_t<QScreen*>>(_a[1]))); break;
        case 16: _t->processPendingScreenChange(); break;
        case 17: _t->setVideoSink((*reinterpret_cast<std::add_pointer_t<QVideoSink*>>(_a[1]))); break;
        case 18: _t->triggerPlayPause(); break;
        case 19: _t->triggerRewind(); break;
        case 20: _t->triggerFastForward(); break;
        case 21: _t->toggleFullScreen(); break;
        case 22: _t->seekToFrame((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->beginSystemMove(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QVideoFrame >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QScreen* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QVideoSink* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::hdrGainChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::hdrTransferModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::hdrModeRestartRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)(bool )>(_a, &HdrPreviewWindow::hdrModeConfirmed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::displayPeakNitsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::contentPeakNitsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::toneMappingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::playingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::fullScreenChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::videoPositionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrPreviewWindow::*)()>(_a, &HdrPreviewWindow::videoDurationChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->hdrGain(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->hdrTransferMode(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->displayPeakNits(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->contentPeakNits(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->toneMapping(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPlaying(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isFullScreen(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->videoPosition(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->videoDuration(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->positionText(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->durationText(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setDisplayPeakNits(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setContentPeakNits(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setToneMapping(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *HdrPreviewWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HdrPreviewWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HdrPreviewWindowE_t>.strings))
        return static_cast<void*>(this);
    return QQuickView::qt_metacast(_clname);
}

int HdrPreviewWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void HdrPreviewWindow::hdrGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void HdrPreviewWindow::hdrTransferModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void HdrPreviewWindow::hdrModeRestartRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void HdrPreviewWindow::hdrModeConfirmed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void HdrPreviewWindow::displayPeakNitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void HdrPreviewWindow::contentPeakNitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void HdrPreviewWindow::toneMappingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void HdrPreviewWindow::playingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void HdrPreviewWindow::fullScreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void HdrPreviewWindow::videoPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void HdrPreviewWindow::videoDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
