/********************************************************************************
** Form generated from reading UI file 'glaxnimateproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GLAXNIMATEPRODUCERWIDGET_H
#define UI_GLAXNIMATEPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"
#include "widgets/timespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_GlaxnimateProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLineEdit *lineEdit;
    QLabel *notesLabel;
    QPlainTextEdit *notesTextEdit;
    ServicePresetWidget *preset;
    QGridLayout *gridLayout;
    QPushButton *colorButton;
    QHBoxLayout *horizontalLayout;
    QLabel *colorLabel;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *editButton;
    QPushButton *reloadButton;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    TimeSpinBox *durationSpinBox;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GlaxnimateProducerWidget)
    {
        if (GlaxnimateProducerWidget->objectName().isEmpty())
            GlaxnimateProducerWidget->setObjectName("GlaxnimateProducerWidget");
        GlaxnimateProducerWidget->resize(396, 300);
#if QT_CONFIG(whatsthis)
        GlaxnimateProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-animation/34407/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(GlaxnimateProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        lineEdit = new QLineEdit(GlaxnimateProducerWidget);
        lineEdit->setObjectName("lineEdit");
        lineEdit->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(lineEdit);

        notesLabel = new QLabel(GlaxnimateProducerWidget);
        notesLabel->setObjectName("notesLabel");

        verticalLayout->addWidget(notesLabel);

        notesTextEdit = new QPlainTextEdit(GlaxnimateProducerWidget);
        notesTextEdit->setObjectName("notesTextEdit");
        notesTextEdit->setMaximumSize(QSize(16777215, 60));
        notesTextEdit->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        notesTextEdit->setTabChangesFocus(true);

        verticalLayout->addWidget(notesTextEdit);

        preset = new ServicePresetWidget(GlaxnimateProducerWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        colorButton = new QPushButton(GlaxnimateProducerWidget);
        colorButton->setObjectName("colorButton");

        gridLayout->addWidget(colorButton, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        colorLabel = new QLabel(GlaxnimateProducerWidget);
        colorLabel->setObjectName("colorLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(colorLabel->sizePolicy().hasHeightForWidth());
        colorLabel->setSizePolicy(sizePolicy);
        colorLabel->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        horizontalLayout->addWidget(colorLabel);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_8);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        editButton = new QPushButton(GlaxnimateProducerWidget);
        editButton->setObjectName("editButton");

        horizontalLayout_3->addWidget(editButton);

        reloadButton = new QPushButton(GlaxnimateProducerWidget);
        reloadButton->setObjectName("reloadButton");

        horizontalLayout_3->addWidget(reloadButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout_3, 2, 1, 1, 1);

        label = new QLabel(GlaxnimateProducerWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        durationSpinBox = new TimeSpinBox(GlaxnimateProducerWidget);
        durationSpinBox->setObjectName("durationSpinBox");
        durationSpinBox->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        durationSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        durationSpinBox->setAccelerated(true);
        durationSpinBox->setKeyboardTracking(false);
        durationSpinBox->setMaximum(2147483647);

        horizontalLayout_2->addWidget(durationSpinBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_2, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(lineEdit, notesTextEdit);
        QWidget::setTabOrder(notesTextEdit, preset);
        QWidget::setTabOrder(preset, durationSpinBox);
        QWidget::setTabOrder(durationSpinBox, colorButton);
        QWidget::setTabOrder(colorButton, editButton);
        QWidget::setTabOrder(editButton, reloadButton);

        retranslateUi(GlaxnimateProducerWidget);

        QMetaObject::connectSlotsByName(GlaxnimateProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *GlaxnimateProducerWidget)
    {
        GlaxnimateProducerWidget->setWindowTitle(QCoreApplication::translate("GlaxnimateProducerWidget", "Form", nullptr));
        lineEdit->setText(QCoreApplication::translate("GlaxnimateProducerWidget", "Animation", nullptr));
        notesLabel->setText(QCoreApplication::translate("GlaxnimateProducerWidget", "Comments:", nullptr));
        notesTextEdit->setPlainText(QString());
        colorButton->setText(QCoreApplication::translate("GlaxnimateProducerWidget", "Background color...", nullptr));
        colorLabel->setText(QCoreApplication::translate("GlaxnimateProducerWidget", "#00000000", nullptr));
        editButton->setText(QCoreApplication::translate("GlaxnimateProducerWidget", "Edit...", nullptr));
        reloadButton->setText(QCoreApplication::translate("GlaxnimateProducerWidget", "Reload", nullptr));
        label->setText(QCoreApplication::translate("GlaxnimateProducerWidget", "Duration", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GlaxnimateProducerWidget: public Ui_GlaxnimateProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GLAXNIMATEPRODUCERWIDGET_H
