/****************************************************************************
** Meta object code from reading C++ file 'player.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/player.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'player.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6PlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto Player::qt_create_metaobjectdata<qt_meta_tag_ZN6PlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Player",
        "endOfStream",
        "",
        "showStatusMessage",
        "inChanged",
        "delta",
        "outChanged",
        "played",
        "speed",
        "paused",
        "position",
        "stopped",
        "seeked",
        "rewound",
        "forceChangeDirection",
        "fastForwarded",
        "previousSought",
        "currentPosition",
        "nextSought",
        "zoomChanged",
        "zoom",
        "gridChanged",
        "grid",
        "scrolledHorizontally",
        "x",
        "scrolledVertically",
        "y",
        "tabIndexChanged",
        "index",
        "trimIn",
        "trimOut",
        "loopChanged",
        "start",
        "end",
        "toggleVuiRequested",
        "play",
        "pause",
        "stop",
        "seek",
        "reset",
        "onProducerOpened",
        "onDurationChanged",
        "onFrameDisplayed",
        "SharedFrame",
        "frame",
        "onVolumeChanged",
        "onCaptureStateChanged",
        "rewind",
        "fastForward",
        "showPaused",
        "showPlaying",
        "switchToTab",
        "TabIndex",
        "enableTab",
        "enabled",
        "onTabBarClicked",
        "setStatusLabel",
        "text",
        "timeoutSeconds",
        "QAction*",
        "action",
        "QPalette::ColorRole",
        "role",
        "showIdleStatus",
        "focusPositionSpinner",
        "onMuteButtonToggled",
        "checked",
        "nextFrame",
        "previousFrame",
        "updateSelection",
        "onInChanged",
        "in",
        "onOutChanged",
        "out",
        "onVolumeTriggered",
        "setZoom",
        "factor",
        "QIcon",
        "icon",
        "stepZoom",
        "step",
        "fit",
        "onZoomTriggered",
        "toggleZoom",
        "onGridToggled",
        "toggleGrid",
        "onStatusFinished",
        "onOffsetChanged",
        "QPoint",
        "offset"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'endOfStream'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showStatusMessage'
        QtMocHelpers::SignalData<void(QString)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'inChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'outChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'played'
        QtMocHelpers::SignalData<void(double)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 8 },
        }}),
        // Signal 'paused'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'stopped'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'rewound'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'fastForwarded'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'previousSought'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'previousSought'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextSought'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'nextSought'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(float)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 20 },
        }}),
        // Signal 'gridChanged'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Signal 'scrolledHorizontally'
        QtMocHelpers::SignalData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Signal 'scrolledVertically'
        QtMocHelpers::SignalData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Signal 'tabIndexChanged'
        QtMocHelpers::SignalData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Signal 'trimIn'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trimOut'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loopChanged'
        QtMocHelpers::SignalData<void(int, int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
        }}),
        // Signal 'toggleVuiRequested'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'play'
        QtMocHelpers::SlotData<void(double)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 8 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seek'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerOpened'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'onProducerOpened'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onDurationChanged'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFrameDisplayed'
        QtMocHelpers::SlotData<void(const SharedFrame &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'onVolumeChanged'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'onCaptureStateChanged'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'rewind'
        QtMocHelpers::SlotData<void(bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'rewind'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'fastForward'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'fastForward'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'showPaused'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPlaying'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchToTab'
        QtMocHelpers::SlotData<void(TabIndex)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 52, 28 },
        }}),
        // Slot 'enableTab'
        QtMocHelpers::SlotData<void(TabIndex, bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 52, 28 }, { QMetaType::Bool, 54 },
        }}),
        // Slot 'enableTab'
        QtMocHelpers::SlotData<void(TabIndex)>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 52, 28 },
        }}),
        // Slot 'onTabBarClicked'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setStatusLabel'
        QtMocHelpers::SlotData<void(const QString &, int, QAction *, QPalette::ColorRole)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 }, { QMetaType::Int, 58 }, { 0x80000000 | 59, 60 }, { 0x80000000 | 61, 62 },
        }}),
        // Slot 'setStatusLabel'
        QtMocHelpers::SlotData<void(const QString &, int, QAction *)>(56, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 57 }, { QMetaType::Int, 58 }, { 0x80000000 | 59, 60 },
        }}),
        // Slot 'showIdleStatus'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focusPositionSpinner'
        QtMocHelpers::SlotData<void() const>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMuteButtonToggled'
        QtMocHelpers::SlotData<void(bool)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'nextFrame'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previousFrame'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateSelection'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onInChanged'
        QtMocHelpers::SlotData<void(int)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 71 },
        }}),
        // Slot 'onOutChanged'
        QtMocHelpers::SlotData<void(int)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 73 },
        }}),
        // Slot 'onVolumeTriggered'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(float, const QIcon &)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 76 }, { 0x80000000 | 77, 78 },
        }}),
        // Slot 'stepZoom'
        QtMocHelpers::SlotData<void(float, float)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 80 }, { QMetaType::Float, 81 },
        }}),
        // Slot 'onZoomTriggered'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleZoom'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'onGridToggled'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleGrid'
        QtMocHelpers::SlotData<void(bool)>(85, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'onStatusFinished'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOffsetChanged'
        QtMocHelpers::SlotData<void(const QPoint &)>(87, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 88, 89 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Player, qt_meta_tag_ZN6PlayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Player::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6PlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6PlayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6PlayerE_t>.metaTypes,
    nullptr
} };

void Player::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Player *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->endOfStream(); break;
        case 1: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->inChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->outChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->played((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->paused((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->stopped(); break;
        case 7: _t->seeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->rewound((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->fastForwarded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->previousSought((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->previousSought(); break;
        case 12: _t->nextSought((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->nextSought(); break;
        case 14: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 15: _t->gridChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->scrolledHorizontally((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->scrolledVertically((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->tabIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->trimIn(); break;
        case 20: _t->trimOut(); break;
        case 21: _t->loopChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 22: _t->toggleVuiRequested(); break;
        case 23: _t->play((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 24: _t->play(); break;
        case 25: _t->pause((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->pause(); break;
        case 27: _t->stop(); break;
        case 28: _t->seek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->reset(); break;
        case 30: _t->onProducerOpened((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->onProducerOpened(); break;
        case 32: _t->onDurationChanged(); break;
        case 33: _t->onFrameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 34: _t->onVolumeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->onCaptureStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->rewind((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->rewind(); break;
        case 38: _t->fastForward((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->fastForward(); break;
        case 40: _t->showPaused(); break;
        case 41: _t->showPlaying(); break;
        case 42: _t->switchToTab((*reinterpret_cast<std::add_pointer_t<TabIndex>>(_a[1]))); break;
        case 43: _t->enableTab((*reinterpret_cast<std::add_pointer_t<TabIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 44: _t->enableTab((*reinterpret_cast<std::add_pointer_t<TabIndex>>(_a[1]))); break;
        case 45: _t->onTabBarClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 46: _t->setStatusLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QPalette::ColorRole>>(_a[4]))); break;
        case 47: _t->setStatusLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[3]))); break;
        case 48: _t->showIdleStatus(); break;
        case 49: _t->focusPositionSpinner(); break;
        case 50: _t->onMuteButtonToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: _t->nextFrame(); break;
        case 52: _t->previousFrame(); break;
        case 53: _t->updateSelection(); break;
        case 54: _t->onInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 55: _t->onOutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->onVolumeTriggered(); break;
        case 57: _t->setZoom((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[2]))); break;
        case 58: _t->stepZoom((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2]))); break;
        case 59: _t->onZoomTriggered(); break;
        case 60: _t->toggleZoom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 61: _t->onGridToggled(); break;
        case 62: _t->toggleGrid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: _t->onStatusFinished(); break;
        case 64: _t->onOffsetChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Player::*)()>(_a, &Player::endOfStream, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(QString )>(_a, &Player::showStatusMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::inChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::outChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(double )>(_a, &Player::played, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::paused, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)()>(_a, &Player::stopped, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::seeked, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(bool )>(_a, &Player::rewound, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(bool )>(_a, &Player::fastForwarded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::previousSought, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)()>(_a, &Player::previousSought, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::nextSought, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)()>(_a, &Player::nextSought, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(float )>(_a, &Player::zoomChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::gridChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::scrolledHorizontally, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::scrolledVertically, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int )>(_a, &Player::tabIndexChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)()>(_a, &Player::trimIn, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)()>(_a, &Player::trimOut, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)(int , int )>(_a, &Player::loopChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Player::*)()>(_a, &Player::toggleVuiRequested, 22))
            return;
    }
}

const QMetaObject *Player::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Player::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6PlayerE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Player::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 65)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 65;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 65)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 65;
    }
    return _id;
}

// SIGNAL 0
void Player::endOfStream()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Player::showStatusMessage(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Player::inChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Player::outChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Player::played(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Player::paused(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Player::stopped()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Player::seeked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Player::rewound(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Player::fastForwarded(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Player::previousSought(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Player::previousSought()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Player::nextSought(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Player::nextSought()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Player::zoomChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Player::gridChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Player::scrolledHorizontally(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Player::scrolledVertically(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Player::tabIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Player::trimIn()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Player::trimOut()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Player::loopChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}

// SIGNAL 22
void Player::toggleVuiRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}
QT_WARNING_POP
