/********************************************************************************
** Form generated from reading UI file 'countproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COUNTPRODUCERWIDGET_H
#define UI_COUNTPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"
#include "widgets/timespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_CountProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    ServicePresetWidget *preset;
    QGridLayout *gridLayout;
    QLabel *label1;
    QComboBox *directionCombo;
    QSpacerItem *horizontalSpacer;
    QLabel *label2;
    QComboBox *styleCombo;
    QSpacerItem *horizontalSpacer1;
    QLabel *label3;
    QComboBox *soundCombo;
    QSpacerItem *horizontalSpacer2;
    QLabel *label4;
    QComboBox *backgroundCombo;
    QSpacerItem *horizontalSpacer3;
    QCheckBox *dropCheckBox;
    QLabel *durationLabel;
    TimeSpinBox *durationSpinBox;
    QSpacerItem *horizontalSpacer4;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CountProducerWidget)
    {
        if (CountProducerWidget->objectName().isEmpty())
            CountProducerWidget->setObjectName("CountProducerWidget");
        CountProducerWidget->resize(394, 303);
#if QT_CONFIG(whatsthis)
        CountProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-count/12933/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(CountProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(CountProducerWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        preset = new ServicePresetWidget(CountProducerWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label1 = new QLabel(CountProducerWidget);
        label1->setObjectName("label1");
        label1->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label1, 0, 0, 1, 1);

        directionCombo = new QComboBox(CountProducerWidget);
        directionCombo->setObjectName("directionCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(directionCombo->sizePolicy().hasHeightForWidth());
        directionCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(directionCombo, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        label2 = new QLabel(CountProducerWidget);
        label2->setObjectName("label2");
        label2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label2, 1, 0, 1, 1);

        styleCombo = new QComboBox(CountProducerWidget);
        styleCombo->setObjectName("styleCombo");
        sizePolicy.setHeightForWidth(styleCombo->sizePolicy().hasHeightForWidth());
        styleCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(styleCombo, 1, 1, 1, 1);

        horizontalSpacer1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer1, 1, 2, 1, 1);

        label3 = new QLabel(CountProducerWidget);
        label3->setObjectName("label3");
        label3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label3, 2, 0, 1, 1);

        soundCombo = new QComboBox(CountProducerWidget);
        soundCombo->setObjectName("soundCombo");
        sizePolicy.setHeightForWidth(soundCombo->sizePolicy().hasHeightForWidth());
        soundCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(soundCombo, 2, 1, 1, 1);

        horizontalSpacer2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer2, 2, 2, 1, 1);

        label4 = new QLabel(CountProducerWidget);
        label4->setObjectName("label4");
        label4->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label4, 3, 0, 1, 1);

        backgroundCombo = new QComboBox(CountProducerWidget);
        backgroundCombo->setObjectName("backgroundCombo");
        sizePolicy.setHeightForWidth(backgroundCombo->sizePolicy().hasHeightForWidth());
        backgroundCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(backgroundCombo, 3, 1, 1, 1);

        horizontalSpacer3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer3, 3, 2, 1, 1);

        dropCheckBox = new QCheckBox(CountProducerWidget);
        dropCheckBox->setObjectName("dropCheckBox");

        gridLayout->addWidget(dropCheckBox, 4, 0, 1, 2);

        durationLabel = new QLabel(CountProducerWidget);
        durationLabel->setObjectName("durationLabel");
        durationLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(durationLabel, 5, 0, 1, 1);

        durationSpinBox = new TimeSpinBox(CountProducerWidget);
        durationSpinBox->setObjectName("durationSpinBox");
        durationSpinBox->setMaximumSize(QSize(150, 16777215));
        durationSpinBox->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        durationSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        durationSpinBox->setAccelerated(true);
        durationSpinBox->setKeyboardTracking(false);
        durationSpinBox->setMinimum(1);
        durationSpinBox->setMaximum(2147483647);

        gridLayout->addWidget(durationSpinBox, 5, 1, 1, 1);

        horizontalSpacer4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer4, 5, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(CountProducerWidget);

        QMetaObject::connectSlotsByName(CountProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *CountProducerWidget)
    {
        CountProducerWidget->setWindowTitle(QCoreApplication::translate("CountProducerWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("CountProducerWidget", "Count", nullptr));
        label1->setText(QCoreApplication::translate("CountProducerWidget", "Direction", nullptr));
        label2->setText(QCoreApplication::translate("CountProducerWidget", "Style", nullptr));
#if QT_CONFIG(tooltip)
        label3->setToolTip(QCoreApplication::translate("CountProducerWidget", "<html><head/><body><p>Silent - No sound</p><p>2-Pop - A 1kHz beep exactly two seconds before the out point</p><p>Frame 0 - A 1kHz beep at frame 0 of every second</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label3->setText(QCoreApplication::translate("CountProducerWidget", "Sound", nullptr));
#if QT_CONFIG(tooltip)
        label4->setToolTip(QCoreApplication::translate("CountProducerWidget", "<html><head/><body><p>None - No background</p><p>Clock  - Film style clock animation</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label4->setText(QCoreApplication::translate("CountProducerWidget", "Background", nullptr));
#if QT_CONFIG(tooltip)
        dropCheckBox->setToolTip(QCoreApplication::translate("CountProducerWidget", "Use SMPTE style drop-frame counting for non-integer frame rates. The clock and timecode will advance two frames every minute if necessary to keep time with wall clock time.", nullptr));
#endif // QT_CONFIG(tooltip)
        dropCheckBox->setText(QCoreApplication::translate("CountProducerWidget", "Drop Frame", nullptr));
        durationLabel->setText(QCoreApplication::translate("CountProducerWidget", "Duration", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CountProducerWidget: public Ui_CountProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COUNTPRODUCERWIDGET_H
