/********************************************************************************
** Form generated from reading UI file 'listselectiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISTSELECTIONDIALOG_H
#define UI_LISTSELECTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ListSelectionDialog
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *listWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ListSelectionDialog)
    {
        if (ListSelectionDialog->objectName().isEmpty())
            ListSelectionDialog->setObjectName("ListSelectionDialog");
        ListSelectionDialog->resize(314, 288);
        verticalLayout = new QVBoxLayout(ListSelectionDialog);
        verticalLayout->setObjectName("verticalLayout");
        listWidget = new QListWidget(ListSelectionDialog);
        listWidget->setObjectName("listWidget");
        listWidget->setAlternatingRowColors(true);
        listWidget->setSpacing(4);
        listWidget->setSortingEnabled(true);

        verticalLayout->addWidget(listWidget);

        buttonBox = new QDialogButtonBox(ListSelectionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ListSelectionDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ListSelectionDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ListSelectionDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ListSelectionDialog);
    } // setupUi

    void retranslateUi(QDialog *ListSelectionDialog)
    {
        ListSelectionDialog->setWindowTitle(QCoreApplication::translate("ListSelectionDialog", "Dialog", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ListSelectionDialog: public Ui_ListSelectionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LISTSELECTIONDIALOG_H
