/********************************************************************************
** Form generated from reading UI file 'textviewerdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEXTVIEWERDIALOG_H
#define UI_TEXTVIEWERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_TextViewerDialog
{
public:
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *plainTextEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TextViewerDialog)
    {
        if (TextViewerDialog->objectName().isEmpty())
            TextViewerDialog->setObjectName("TextViewerDialog");
        TextViewerDialog->setWindowModality(Qt::WindowModal);
        TextViewerDialog->resize(709, 398);
        TextViewerDialog->setSizeGripEnabled(true);
        verticalLayout = new QVBoxLayout(TextViewerDialog);
        verticalLayout->setObjectName("verticalLayout");
        plainTextEdit = new QPlainTextEdit(TextViewerDialog);
        plainTextEdit->setObjectName("plainTextEdit");
        plainTextEdit->setUndoRedoEnabled(false);
        plainTextEdit->setReadOnly(true);

        verticalLayout->addWidget(plainTextEdit);

        buttonBox = new QDialogButtonBox(TextViewerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Save);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(TextViewerDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TextViewerDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TextViewerDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TextViewerDialog);
    } // setupUi

    void retranslateUi(QDialog *TextViewerDialog)
    {
        TextViewerDialog->setWindowTitle(QCoreApplication::translate("TextViewerDialog", "Dialog", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TextViewerDialog: public Ui_TextViewerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TEXTVIEWERDIALOG_H
