/********************************************************************************
** Form generated from reading UI file 'colorproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORPRODUCERWIDGET_H
#define UI_COLORPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ColorProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLineEdit *lineEdit;
    QLabel *notesLabel;
    QPlainTextEdit *notesTextEdit;
    ServicePresetWidget *preset;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *colorButton;
    QLabel *colorLabel;
    QSpacerItem *horizontalSpacer_8;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ColorProducerWidget)
    {
        if (ColorProducerWidget->objectName().isEmpty())
            ColorProducerWidget->setObjectName("ColorProducerWidget");
        ColorProducerWidget->resize(396, 296);
#if QT_CONFIG(whatsthis)
        ColorProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-color/12925/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(ColorProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        lineEdit = new QLineEdit(ColorProducerWidget);
        lineEdit->setObjectName("lineEdit");
        lineEdit->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(lineEdit);

        notesLabel = new QLabel(ColorProducerWidget);
        notesLabel->setObjectName("notesLabel");

        verticalLayout->addWidget(notesLabel);

        notesTextEdit = new QPlainTextEdit(ColorProducerWidget);
        notesTextEdit->setObjectName("notesTextEdit");
        notesTextEdit->setMaximumSize(QSize(16777215, 60));
        notesTextEdit->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        notesTextEdit->setTabChangesFocus(true);

        verticalLayout->addWidget(notesTextEdit);

        preset = new ServicePresetWidget(ColorProducerWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        colorButton = new QPushButton(ColorProducerWidget);
        colorButton->setObjectName("colorButton");

        horizontalLayout_2->addWidget(colorButton);

        colorLabel = new QLabel(ColorProducerWidget);
        colorLabel->setObjectName("colorLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(colorLabel->sizePolicy().hasHeightForWidth());
        colorLabel->setSizePolicy(sizePolicy);
        colorLabel->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        horizontalLayout_2->addWidget(colorLabel);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_8);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(lineEdit, notesTextEdit);
        QWidget::setTabOrder(notesTextEdit, colorButton);

        retranslateUi(ColorProducerWidget);

        QMetaObject::connectSlotsByName(ColorProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *ColorProducerWidget)
    {
        ColorProducerWidget->setWindowTitle(QCoreApplication::translate("ColorProducerWidget", "Form", nullptr));
        lineEdit->setText(QCoreApplication::translate("ColorProducerWidget", "Color", nullptr));
        notesLabel->setText(QCoreApplication::translate("ColorProducerWidget", "Comments:", nullptr));
        notesTextEdit->setPlainText(QString());
        colorButton->setText(QCoreApplication::translate("ColorProducerWidget", "Color...", nullptr));
        colorLabel->setText(QCoreApplication::translate("ColorProducerWidget", "#00000000", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ColorProducerWidget: public Ui_ColorProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLORPRODUCERWIDGET_H
