/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/mainwindow.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "audioChannelsChanged",
        "",
        "processingModeChanged",
        "producerOpened",
        "withReopen",
        "profileChanged",
        "openFailed",
        "aboutToShutDown",
        "renameRequested",
        "serviceInChanged",
        "delta",
        "Mlt::Service*",
        "serviceOutChanged",
        "isCompatibleWithProcessingMode",
        "MltXmlChecker&",
        "checker",
        "QString&",
        "fileName",
        "bool&",
        "converted",
        "isXmlRepaired",
        "open",
        "url",
        "const Mlt::Properties*",
        "play",
        "skipConvert",
        "openMultiple",
        "paths",
        "QList<QUrl>",
        "urls",
        "openVideo",
        "openCut",
        "Mlt::Producer*",
        "producer",
        "hideProducer",
        "closeProducer",
        "showStatusMessage",
        "QAction*",
        "action",
        "timeoutSeconds",
        "message",
        "QPalette::ColorRole",
        "role",
        "onStatusMessageClicked",
        "seekPlaylist",
        "start",
        "seekTimeline",
        "position",
        "seekPlayer",
        "seekKeyframes",
        "loadProducerWidget",
        "QWidget*",
        "onProducerOpened",
        "onGpuNotSupported",
        "onShuttle",
        "x",
        "onPropertiesDockTriggered",
        "checked",
        "onFiltersDockTriggered",
        "onElementsDockTriggered",
        "on_actionSave_triggered",
        "onCreateOrEditFilterOnOutput",
        "Mlt::Filter*",
        "filter",
        "key_properties",
        "showSettingsMenu",
        "showUpgradePrompt",
        "on_actionAbout_Shotcut_triggered",
        "on_actionOpenOther_triggered",
        "onProducerChanged",
        "on_actionSave_As_triggered",
        "onEncodeTriggered",
        "onCaptureStateChanged",
        "started",
        "onJobsDockTriggered",
        "onRecentDockTriggered",
        "onPlaylistDockTriggered",
        "onTimelineDockTriggered",
        "onHistoryDockTriggered",
        "onKeyframesDockTriggered",
        "onMarkersDockTriggered",
        "onNotesDockTriggered",
        "onSubtitlesDockTriggered",
        "onFilesDockTriggered",
        "onPlaylistCreated",
        "onPlaylistLoaded",
        "onPlaylistCleared",
        "onPlaylistClosed",
        "onPlaylistModified",
        "onMultitrackCreated",
        "onMultitrackClosed",
        "onMultitrackModified",
        "onMultitrackDurationChanged",
        "onNoteModified",
        "onSubtitleModified",
        "onCutModified",
        "onProducerModified",
        "onFilterModelChanged",
        "updateMarkers",
        "updateThumbnails",
        "on_actionFAQ_triggered",
        "on_actionForum_triggered",
        "on_actionEnterFullScreen_triggered",
        "on_actionRealtime_triggered",
        "on_actionProgressive_triggered",
        "on_actionChannels1_triggered",
        "on_actionChannels2_triggered",
        "on_actionChannels4_triggered",
        "on_actionChannels6_triggered",
        "on_actionOneField_triggered",
        "on_actionYadifTemporal_triggered",
        "on_actionYadifSpatial_triggered",
        "on_actionBwdif_triggered",
        "on_actionNearest_triggered",
        "on_actionBilinear_triggered",
        "on_actionBicubic_triggered",
        "on_actionHyper_triggered",
        "on_actionJack_triggered",
        "onHdrPreviewToggled",
        "onExternalTriggered",
        "onDecklinkHdrMetadataTriggered",
        "onKeyerTriggered",
        "onProfileTriggered",
        "onProfileChanged",
        "on_actionAddCustomProfile_triggered",
        "processMultipleFiles",
        "processSingleFile",
        "onLanguageTriggered",
        "on_actionSystemTheme_triggered",
        "on_actionSystemFusion_triggered",
        "on_actionFusionDark_triggered",
        "on_actionJobPriorityLow_triggered",
        "on_actionJobPriorityNormal_triggered",
        "on_actionFusionLight_triggered",
        "on_actionTutorials_triggered",
        "on_actionRestoreLayout_triggered",
        "on_actionShowTitleBars_triggered",
        "on_actionShowToolbar_triggered",
        "onToolbarVisibilityChanged",
        "visible",
        "on_menuExternal_aboutToShow",
        "on_actionUpgrade_triggered",
        "on_actionOpenXML_triggered",
        "on_actionShowProjectFolder_triggered",
        "onAutosaveTimeout",
        "onFocusChanged",
        "old",
        "now",
        "onFocusObjectChanged",
        "obj",
        "onFocusWindowChanged",
        "QWindow*",
        "window",
        "onTimelineClipSelected",
        "onAddAllToTimeline",
        "Mlt::Playlist*",
        "playlist",
        "skipProxy",
        "emptyTrack",
        "on_actionScrubAudio_triggered",
        "onDrawingMethodTriggered",
        "onGpuAdapterTriggered",
        "on_actionResources_triggered",
        "on_actionApplicationLog_triggered",
        "on_actionClose_triggered",
        "onPlayerTabIndexChanged",
        "index",
        "onUpgradeCheckFinished",
        "QNetworkReply*",
        "reply",
        "onUpgradeTriggered",
        "onClipCopied",
        "on_actionExportEDL_triggered",
        "on_actionExportFrame_triggered",
        "onVideoWidgetImageReady",
        "on_actionAppDataSet_triggered",
        "on_actionAppDataShow_triggered",
        "on_actionNew_triggered",
        "on_actionScreenSnapshot_triggered",
        "on_actionScreenRecording_triggered",
        "on_actionKeyboardShortcuts_triggered",
        "on_actionLayoutLogging_triggered",
        "on_actionLayoutEditing_triggered",
        "on_actionLayoutEffects_triggered",
        "on_actionLayoutColor_triggered",
        "on_actionLayoutAudio_triggered",
        "on_actionLayoutPlayer_triggered",
        "on_actionLayoutPlaylist_triggered",
        "on_actionLayoutClip_triggered",
        "on_actionLayoutAdd_triggered",
        "onLayoutTriggered",
        "on_actionProfileRemove_triggered",
        "on_actionLayoutRemove_triggered",
        "on_actionOpenOther2_triggered",
        "onOpenOtherTriggered",
        "widget",
        "onOpenOtherFinished",
        "result",
        "onHtmlGeneratorTriggered",
        "on_actionClearRecentOnExit_toggled",
        "arg1",
        "onSceneGraphInitialized",
        "adjustMainToolbar",
        "on_actionShowTextUnderIcons_toggled",
        "b",
        "on_actionShowSmallIcons_toggled",
        "onPlaylistInChanged",
        "in",
        "onPlaylistOutChanged",
        "out",
        "on_actionPreviewNone_triggered",
        "on_actionPreview360_triggered",
        "on_actionPreview540_triggered",
        "on_actionPreview720_triggered",
        "on_actionPreview1080_triggered",
        "on_actionPreviewHardwareDecoder_triggered",
        "on_actionTopics_triggered",
        "on_actionSync_triggered",
        "on_actionUseProxy_triggered",
        "on_actionProxyStorageSet_triggered",
        "on_actionProxyStorageShow_triggered",
        "on_actionProxyUseProjectFolder_triggered",
        "on_actionProxyUseHardware_triggered",
        "on_actionProxyConfigureHardware_triggered",
        "updateLayoutSwitcher",
        "clearCurrentLayout",
        "onClipboardChanged",
        "sourceUpdated",
        "resetSourceUpdated",
        "on_actionExportChapters_triggered",
        "on_actionAudioVideoDevice_triggered",
        "on_actionReset_triggered",
        "on_actionBackupSave_triggered",
        "on_actionPauseAfterSeek_triggered",
        "on_actionWhatsThis_triggered",
        "on_actionLeaveSafeMode_triggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'audioChannelsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processingModeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'producerOpened'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'producerOpened'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openFailed'
        QtMocHelpers::SignalData<void(QString)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'aboutToShutDown'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renameRequested'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serviceInChanged'
        QtMocHelpers::SignalData<void(int, Mlt::Service *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 2 },
        }}),
        // Signal 'serviceOutChanged'
        QtMocHelpers::SignalData<void(int, Mlt::Service *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 2 },
        }}),
        // Slot 'isCompatibleWithProcessingMode'
        QtMocHelpers::SlotData<bool(MltXmlChecker &, QString &, bool &)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'isXmlRepaired'
        QtMocHelpers::SlotData<bool(MltXmlChecker &, QString &)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'open'
        QtMocHelpers::SlotData<bool(QString, const Mlt::Properties *, bool, bool)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 24, 2 }, { QMetaType::Bool, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'open'
        QtMocHelpers::SlotData<bool(QString, const Mlt::Properties *, bool)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 24, 2 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'open'
        QtMocHelpers::SlotData<bool(QString, const Mlt::Properties *)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 23 }, { 0x80000000 | 24, 2 },
        }}),
        // Slot 'open'
        QtMocHelpers::SlotData<bool(QString)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'openMultiple'
        QtMocHelpers::SlotData<void(const QStringList &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 28 },
        }}),
        // Slot 'openMultiple'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'openVideo'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openCut'
        QtMocHelpers::SlotData<void(Mlt::Producer *, bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'openCut'
        QtMocHelpers::SlotData<void(Mlt::Producer *)>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'hideProducer'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeProducer'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showStatusMessage'
        QtMocHelpers::SlotData<void(QAction *, int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::Int, 40 },
        }}),
        // Slot 'showStatusMessage'
        QtMocHelpers::SlotData<void(QAction *)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'showStatusMessage'
        QtMocHelpers::SlotData<void(const QString &, int, QPalette::ColorRole)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::Int, 40 }, { 0x80000000 | 42, 43 },
        }}),
        // Slot 'showStatusMessage'
        QtMocHelpers::SlotData<void(const QString &, int)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 41 }, { QMetaType::Int, 40 },
        }}),
        // Slot 'showStatusMessage'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'onStatusMessageClicked'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekPlaylist'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'seekTimeline'
        QtMocHelpers::SlotData<void(int, bool)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 }, { QMetaType::Bool, 49 },
        }}),
        // Slot 'seekTimeline'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'seekKeyframes'
        QtMocHelpers::SlotData<void(int)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'loadProducerWidget'
        QtMocHelpers::SlotData<QWidget *(Mlt::Producer *)>(51, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'onProducerOpened'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'onProducerOpened'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onGpuNotSupported'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onShuttle'
        QtMocHelpers::SlotData<void(float)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 56 },
        }}),
        // Slot 'onPropertiesDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onPropertiesDockTriggered'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onFiltersDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onFiltersDockTriggered'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onElementsDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onElementsDockTriggered'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'on_actionSave_triggered'
        QtMocHelpers::SlotData<bool()>(61, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'onCreateOrEditFilterOnOutput'
        QtMocHelpers::SlotData<void(Mlt::Filter *, const QStringList &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 }, { QMetaType::QStringList, 65 },
        }}),
        // Slot 'showSettingsMenu'
        QtMocHelpers::SlotData<void() const>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showUpgradePrompt'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAbout_Shotcut_triggered'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOpenOther_triggered'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onProducerChanged'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSave_As_triggered'
        QtMocHelpers::SlotData<bool()>(71, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'onEncodeTriggered'
        QtMocHelpers::SlotData<void(bool)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onEncodeTriggered'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onCaptureStateChanged'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'onJobsDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onJobsDockTriggered'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onRecentDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(76, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onRecentDockTriggered'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onPlaylistDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onPlaylistDockTriggered'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onTimelineDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onTimelineDockTriggered'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onHistoryDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onHistoryDockTriggered'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onKeyframesDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(80, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onKeyframesDockTriggered'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onMarkersDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onMarkersDockTriggered'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onNotesDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onNotesDockTriggered'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onSubtitlesDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onSubtitlesDockTriggered'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onFilesDockTriggered'
        QtMocHelpers::SlotData<void(bool)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onFilesDockTriggered'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onPlaylistCreated'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPlaylistLoaded'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPlaylistCleared'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPlaylistClosed'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPlaylistModified'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMultitrackCreated'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMultitrackClosed'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMultitrackModified'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMultitrackDurationChanged'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onNoteModified'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSubtitleModified'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCutModified'
        QtMocHelpers::SlotData<void()>(96, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onProducerModified'
        QtMocHelpers::SlotData<void()>(97, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFilterModelChanged'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMarkers'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateThumbnails'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFAQ_triggered'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionForum_triggered'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionEnterFullScreen_triggered'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRealtime_triggered'
        QtMocHelpers::SlotData<void(bool)>(104, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionProgressive_triggered'
        QtMocHelpers::SlotData<void(bool)>(105, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionChannels1_triggered'
        QtMocHelpers::SlotData<void(bool)>(106, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionChannels2_triggered'
        QtMocHelpers::SlotData<void(bool)>(107, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionChannels4_triggered'
        QtMocHelpers::SlotData<void(bool)>(108, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionChannels6_triggered'
        QtMocHelpers::SlotData<void(bool)>(109, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionOneField_triggered'
        QtMocHelpers::SlotData<void(bool)>(110, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionYadifTemporal_triggered'
        QtMocHelpers::SlotData<void(bool)>(111, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionYadifSpatial_triggered'
        QtMocHelpers::SlotData<void(bool)>(112, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionBwdif_triggered'
        QtMocHelpers::SlotData<void(bool)>(113, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionNearest_triggered'
        QtMocHelpers::SlotData<void(bool)>(114, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionBilinear_triggered'
        QtMocHelpers::SlotData<void(bool)>(115, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionBicubic_triggered'
        QtMocHelpers::SlotData<void(bool)>(116, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionHyper_triggered'
        QtMocHelpers::SlotData<void(bool)>(117, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionJack_triggered'
        QtMocHelpers::SlotData<void(bool)>(118, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onHdrPreviewToggled'
        QtMocHelpers::SlotData<void(bool)>(119, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onExternalTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(120, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'onDecklinkHdrMetadataTriggered'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onKeyerTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(122, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'onProfileTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(123, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'onProfileChanged'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAddCustomProfile_triggered'
        QtMocHelpers::SlotData<void()>(125, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processMultipleFiles'
        QtMocHelpers::SlotData<void()>(126, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processSingleFile'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLanguageTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(128, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'on_actionSystemTheme_triggered'
        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSystemFusion_triggered'
        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFusionDark_triggered'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionJobPriorityLow_triggered'
        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionJobPriorityNormal_triggered'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFusionLight_triggered'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionTutorials_triggered'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionRestoreLayout_triggered'
        QtMocHelpers::SlotData<void()>(136, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShowTitleBars_triggered'
        QtMocHelpers::SlotData<void(bool)>(137, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionShowToolbar_triggered'
        QtMocHelpers::SlotData<void(bool)>(138, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onToolbarVisibilityChanged'
        QtMocHelpers::SlotData<void(bool)>(139, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 140 },
        }}),
        // Slot 'on_menuExternal_aboutToShow'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionUpgrade_triggered'
        QtMocHelpers::SlotData<void()>(142, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOpenXML_triggered'
        QtMocHelpers::SlotData<void()>(143, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShowProjectFolder_triggered'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAutosaveTimeout'
        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFocusChanged'
        QtMocHelpers::SlotData<void(QWidget *, QWidget *) const>(146, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 147 }, { 0x80000000 | 52, 148 },
        }}),
        // Slot 'onFocusObjectChanged'
        QtMocHelpers::SlotData<void(QObject *) const>(149, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 150 },
        }}),
        // Slot 'onFocusWindowChanged'
        QtMocHelpers::SlotData<void(QWindow *) const>(151, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 152, 153 },
        }}),
        // Slot 'onTimelineClipSelected'
        QtMocHelpers::SlotData<void()>(154, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAddAllToTimeline'
        QtMocHelpers::SlotData<void(Mlt::Playlist *, bool, bool)>(155, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 156, 157 }, { QMetaType::Bool, 158 }, { QMetaType::Bool, 159 },
        }}),
        // Slot 'on_actionScrubAudio_triggered'
        QtMocHelpers::SlotData<void(bool)>(160, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'onDrawingMethodTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(161, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'onGpuAdapterTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(162, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'on_actionResources_triggered'
        QtMocHelpers::SlotData<void()>(163, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionApplicationLog_triggered'
        QtMocHelpers::SlotData<void()>(164, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionClose_triggered'
        QtMocHelpers::SlotData<void()>(165, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPlayerTabIndexChanged'
        QtMocHelpers::SlotData<void(int)>(166, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 167 },
        }}),
        // Slot 'onUpgradeCheckFinished'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(168, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 169, 170 },
        }}),
        // Slot 'onUpgradeTriggered'
        QtMocHelpers::SlotData<void()>(171, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onClipCopied'
        QtMocHelpers::SlotData<void()>(172, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExportEDL_triggered'
        QtMocHelpers::SlotData<void()>(173, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExportFrame_triggered'
        QtMocHelpers::SlotData<void()>(174, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onVideoWidgetImageReady'
        QtMocHelpers::SlotData<void()>(175, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAppDataSet_triggered'
        QtMocHelpers::SlotData<void()>(176, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAppDataShow_triggered'
        QtMocHelpers::SlotData<void()>(177, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionNew_triggered'
        QtMocHelpers::SlotData<void()>(178, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionScreenSnapshot_triggered'
        QtMocHelpers::SlotData<void()>(179, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionScreenRecording_triggered'
        QtMocHelpers::SlotData<void()>(180, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionKeyboardShortcuts_triggered'
        QtMocHelpers::SlotData<void()>(181, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutLogging_triggered'
        QtMocHelpers::SlotData<void()>(182, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutEditing_triggered'
        QtMocHelpers::SlotData<void()>(183, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutEffects_triggered'
        QtMocHelpers::SlotData<void()>(184, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutColor_triggered'
        QtMocHelpers::SlotData<void()>(185, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutAudio_triggered'
        QtMocHelpers::SlotData<void()>(186, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutPlayer_triggered'
        QtMocHelpers::SlotData<void()>(187, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutPlaylist_triggered'
        QtMocHelpers::SlotData<void()>(188, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutClip_triggered'
        QtMocHelpers::SlotData<void()>(189, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutAdd_triggered'
        QtMocHelpers::SlotData<void()>(190, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLayoutTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(191, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'on_actionProfileRemove_triggered'
        QtMocHelpers::SlotData<void()>(192, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLayoutRemove_triggered'
        QtMocHelpers::SlotData<void()>(193, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionOpenOther2_triggered'
        QtMocHelpers::SlotData<void()>(194, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOpenOtherTriggered'
        QtMocHelpers::SlotData<void(QWidget *)>(195, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 52, 196 },
        }}),
        // Slot 'onOpenOtherFinished'
        QtMocHelpers::SlotData<void(int)>(197, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 198 },
        }}),
        // Slot 'onOpenOtherTriggered'
        QtMocHelpers::SlotData<void()>(195, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHtmlGeneratorTriggered'
        QtMocHelpers::SlotData<void()>(199, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionClearRecentOnExit_toggled'
        QtMocHelpers::SlotData<void(bool)>(200, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 201 },
        }}),
        // Slot 'onSceneGraphInitialized'
        QtMocHelpers::SlotData<void()>(202, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'adjustMainToolbar'
        QtMocHelpers::SlotData<void()>(203, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShowTextUnderIcons_toggled'
        QtMocHelpers::SlotData<void(bool)>(204, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 205 },
        }}),
        // Slot 'on_actionShowSmallIcons_toggled'
        QtMocHelpers::SlotData<void(bool)>(206, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 205 },
        }}),
        // Slot 'onPlaylistInChanged'
        QtMocHelpers::SlotData<void(int)>(207, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 208 },
        }}),
        // Slot 'onPlaylistOutChanged'
        QtMocHelpers::SlotData<void(int)>(209, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 210 },
        }}),
        // Slot 'on_actionPreviewNone_triggered'
        QtMocHelpers::SlotData<void(bool)>(211, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionPreview360_triggered'
        QtMocHelpers::SlotData<void(bool)>(212, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionPreview540_triggered'
        QtMocHelpers::SlotData<void(bool)>(213, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionPreview720_triggered'
        QtMocHelpers::SlotData<void(bool)>(214, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionPreview1080_triggered'
        QtMocHelpers::SlotData<void(bool)>(215, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionPreviewHardwareDecoder_triggered'
        QtMocHelpers::SlotData<void(bool)>(216, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionTopics_triggered'
        QtMocHelpers::SlotData<void()>(217, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSync_triggered'
        QtMocHelpers::SlotData<void()>(218, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionUseProxy_triggered'
        QtMocHelpers::SlotData<void(bool)>(219, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionProxyStorageSet_triggered'
        QtMocHelpers::SlotData<void()>(220, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionProxyStorageShow_triggered'
        QtMocHelpers::SlotData<void()>(221, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionProxyUseProjectFolder_triggered'
        QtMocHelpers::SlotData<void(bool)>(222, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionProxyUseHardware_triggered'
        QtMocHelpers::SlotData<void(bool)>(223, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionProxyConfigureHardware_triggered'
        QtMocHelpers::SlotData<void()>(224, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateLayoutSwitcher'
        QtMocHelpers::SlotData<void()>(225, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearCurrentLayout'
        QtMocHelpers::SlotData<void()>(226, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onClipboardChanged'
        QtMocHelpers::SlotData<void()>(227, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceUpdated'
        QtMocHelpers::SlotData<void()>(228, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetSourceUpdated'
        QtMocHelpers::SlotData<void()>(229, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExportChapters_triggered'
        QtMocHelpers::SlotData<void()>(230, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionAudioVideoDevice_triggered'
        QtMocHelpers::SlotData<void()>(231, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionReset_triggered'
        QtMocHelpers::SlotData<void()>(232, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionBackupSave_triggered'
        QtMocHelpers::SlotData<void()>(233, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionPauseAfterSeek_triggered'
        QtMocHelpers::SlotData<void(bool)>(234, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'on_actionWhatsThis_triggered'
        QtMocHelpers::SlotData<void()>(235, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionLeaveSafeMode_triggered'
        QtMocHelpers::SlotData<void()>(236, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->audioChannelsChanged(); break;
        case 1: _t->processingModeChanged(); break;
        case 2: _t->producerOpened((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->producerOpened(); break;
        case 4: _t->profileChanged(); break;
        case 5: _t->openFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->aboutToShutDown(); break;
        case 7: _t->renameRequested(); break;
        case 8: _t->serviceInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[2]))); break;
        case 9: _t->serviceOutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[2]))); break;
        case 10: { bool _r = _t->isCompatibleWithProcessingMode((*reinterpret_cast<std::add_pointer_t<MltXmlChecker&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->isXmlRepaired((*reinterpret_cast<std::add_pointer_t<MltXmlChecker&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->open((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Mlt::Properties*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->open((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Mlt::Properties*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->open((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Mlt::Properties*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->open((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->openMultiple((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 17: _t->openMultiple((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 18: _t->openVideo(); break;
        case 19: _t->openCut((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->openCut((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 21: _t->hideProducer(); break;
        case 22: _t->closeProducer(); break;
        case 23: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 25: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPalette::ColorRole>>(_a[3]))); break;
        case 26: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 27: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->onStatusMessageClicked(); break;
        case 29: _t->seekPlaylist((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->seekTimeline((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->seekTimeline((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->seekKeyframes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: { QWidget* _r = _t->loadProducerWidget((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 34: _t->onProducerOpened((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->onProducerOpened(); break;
        case 36: _t->onGpuNotSupported(); break;
        case 37: _t->onShuttle((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 38: _t->onPropertiesDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->onPropertiesDockTriggered(); break;
        case 40: _t->onFiltersDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->onFiltersDockTriggered(); break;
        case 42: _t->onElementsDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->onElementsDockTriggered(); break;
        case 44: { bool _r = _t->on_actionSave_triggered();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->onCreateOrEditFilterOnOutput((*reinterpret_cast<std::add_pointer_t<Mlt::Filter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 46: _t->showSettingsMenu(); break;
        case 47: _t->showUpgradePrompt(); break;
        case 48: _t->on_actionAbout_Shotcut_triggered(); break;
        case 49: _t->on_actionOpenOther_triggered(); break;
        case 50: _t->onProducerChanged(); break;
        case 51: { bool _r = _t->on_actionSave_As_triggered();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->onEncodeTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 53: _t->onEncodeTriggered(); break;
        case 54: _t->onCaptureStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 55: _t->onJobsDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 56: _t->onJobsDockTriggered(); break;
        case 57: _t->onRecentDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 58: _t->onRecentDockTriggered(); break;
        case 59: _t->onPlaylistDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->onPlaylistDockTriggered(); break;
        case 61: _t->onTimelineDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->onTimelineDockTriggered(); break;
        case 63: _t->onHistoryDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 64: _t->onHistoryDockTriggered(); break;
        case 65: _t->onKeyframesDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 66: _t->onKeyframesDockTriggered(); break;
        case 67: _t->onMarkersDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 68: _t->onMarkersDockTriggered(); break;
        case 69: _t->onNotesDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 70: _t->onNotesDockTriggered(); break;
        case 71: _t->onSubtitlesDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 72: _t->onSubtitlesDockTriggered(); break;
        case 73: _t->onFilesDockTriggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: _t->onFilesDockTriggered(); break;
        case 75: _t->onPlaylistCreated(); break;
        case 76: _t->onPlaylistLoaded(); break;
        case 77: _t->onPlaylistCleared(); break;
        case 78: _t->onPlaylistClosed(); break;
        case 79: _t->onPlaylistModified(); break;
        case 80: _t->onMultitrackCreated(); break;
        case 81: _t->onMultitrackClosed(); break;
        case 82: _t->onMultitrackModified(); break;
        case 83: _t->onMultitrackDurationChanged(); break;
        case 84: _t->onNoteModified(); break;
        case 85: _t->onSubtitleModified(); break;
        case 86: _t->onCutModified(); break;
        case 87: _t->onProducerModified(); break;
        case 88: _t->onFilterModelChanged(); break;
        case 89: _t->updateMarkers(); break;
        case 90: _t->updateThumbnails(); break;
        case 91: _t->on_actionFAQ_triggered(); break;
        case 92: _t->on_actionForum_triggered(); break;
        case 93: _t->on_actionEnterFullScreen_triggered(); break;
        case 94: _t->on_actionRealtime_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 95: _t->on_actionProgressive_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 96: _t->on_actionChannels1_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 97: _t->on_actionChannels2_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 98: _t->on_actionChannels4_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 99: _t->on_actionChannels6_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 100: _t->on_actionOneField_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 101: _t->on_actionYadifTemporal_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 102: _t->on_actionYadifSpatial_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 103: _t->on_actionBwdif_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 104: _t->on_actionNearest_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 105: _t->on_actionBilinear_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 106: _t->on_actionBicubic_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 107: _t->on_actionHyper_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 108: _t->on_actionJack_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 109: _t->onHdrPreviewToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 110: _t->onExternalTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 111: _t->onDecklinkHdrMetadataTriggered(); break;
        case 112: _t->onKeyerTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 113: _t->onProfileTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 114: _t->onProfileChanged(); break;
        case 115: _t->on_actionAddCustomProfile_triggered(); break;
        case 116: _t->processMultipleFiles(); break;
        case 117: _t->processSingleFile(); break;
        case 118: _t->onLanguageTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 119: _t->on_actionSystemTheme_triggered(); break;
        case 120: _t->on_actionSystemFusion_triggered(); break;
        case 121: _t->on_actionFusionDark_triggered(); break;
        case 122: _t->on_actionJobPriorityLow_triggered(); break;
        case 123: _t->on_actionJobPriorityNormal_triggered(); break;
        case 124: _t->on_actionFusionLight_triggered(); break;
        case 125: _t->on_actionTutorials_triggered(); break;
        case 126: _t->on_actionRestoreLayout_triggered(); break;
        case 127: _t->on_actionShowTitleBars_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 128: _t->on_actionShowToolbar_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 129: _t->onToolbarVisibilityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 130: _t->on_menuExternal_aboutToShow(); break;
        case 131: _t->on_actionUpgrade_triggered(); break;
        case 132: _t->on_actionOpenXML_triggered(); break;
        case 133: _t->on_actionShowProjectFolder_triggered(); break;
        case 134: _t->onAutosaveTimeout(); break;
        case 135: _t->onFocusChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 136: _t->onFocusObjectChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 137: _t->onFocusWindowChanged((*reinterpret_cast<std::add_pointer_t<QWindow*>>(_a[1]))); break;
        case 138: _t->onTimelineClipSelected(); break;
        case 139: _t->onAddAllToTimeline((*reinterpret_cast<std::add_pointer_t<Mlt::Playlist*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 140: _t->on_actionScrubAudio_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 141: _t->onDrawingMethodTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 142: _t->onGpuAdapterTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 143: _t->on_actionResources_triggered(); break;
        case 144: _t->on_actionApplicationLog_triggered(); break;
        case 145: _t->on_actionClose_triggered(); break;
        case 146: _t->onPlayerTabIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 147: _t->onUpgradeCheckFinished((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 148: _t->onUpgradeTriggered(); break;
        case 149: _t->onClipCopied(); break;
        case 150: _t->on_actionExportEDL_triggered(); break;
        case 151: _t->on_actionExportFrame_triggered(); break;
        case 152: _t->onVideoWidgetImageReady(); break;
        case 153: _t->on_actionAppDataSet_triggered(); break;
        case 154: _t->on_actionAppDataShow_triggered(); break;
        case 155: _t->on_actionNew_triggered(); break;
        case 156: _t->on_actionScreenSnapshot_triggered(); break;
        case 157: _t->on_actionScreenRecording_triggered(); break;
        case 158: _t->on_actionKeyboardShortcuts_triggered(); break;
        case 159: _t->on_actionLayoutLogging_triggered(); break;
        case 160: _t->on_actionLayoutEditing_triggered(); break;
        case 161: _t->on_actionLayoutEffects_triggered(); break;
        case 162: _t->on_actionLayoutColor_triggered(); break;
        case 163: _t->on_actionLayoutAudio_triggered(); break;
        case 164: _t->on_actionLayoutPlayer_triggered(); break;
        case 165: _t->on_actionLayoutPlaylist_triggered(); break;
        case 166: _t->on_actionLayoutClip_triggered(); break;
        case 167: _t->on_actionLayoutAdd_triggered(); break;
        case 168: _t->onLayoutTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 169: _t->on_actionProfileRemove_triggered(); break;
        case 170: _t->on_actionLayoutRemove_triggered(); break;
        case 171: _t->on_actionOpenOther2_triggered(); break;
        case 172: _t->onOpenOtherTriggered((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 173: _t->onOpenOtherFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 174: _t->onOpenOtherTriggered(); break;
        case 175: _t->onHtmlGeneratorTriggered(); break;
        case 176: _t->on_actionClearRecentOnExit_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 177: _t->onSceneGraphInitialized(); break;
        case 178: _t->adjustMainToolbar(); break;
        case 179: _t->on_actionShowTextUnderIcons_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 180: _t->on_actionShowSmallIcons_toggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 181: _t->onPlaylistInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 182: _t->onPlaylistOutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 183: _t->on_actionPreviewNone_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 184: _t->on_actionPreview360_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 185: _t->on_actionPreview540_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 186: _t->on_actionPreview720_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 187: _t->on_actionPreview1080_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 188: _t->on_actionPreviewHardwareDecoder_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 189: _t->on_actionTopics_triggered(); break;
        case 190: _t->on_actionSync_triggered(); break;
        case 191: _t->on_actionUseProxy_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 192: _t->on_actionProxyStorageSet_triggered(); break;
        case 193: _t->on_actionProxyStorageShow_triggered(); break;
        case 194: _t->on_actionProxyUseProjectFolder_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 195: _t->on_actionProxyUseHardware_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 196: _t->on_actionProxyConfigureHardware_triggered(); break;
        case 197: _t->updateLayoutSwitcher(); break;
        case 198: _t->clearCurrentLayout(); break;
        case 199: _t->onClipboardChanged(); break;
        case 200: _t->sourceUpdated(); break;
        case 201: _t->resetSourceUpdated(); break;
        case 202: _t->on_actionExportChapters_triggered(); break;
        case 203: _t->on_actionAudioVideoDevice_triggered(); break;
        case 204: _t->on_actionReset_triggered(); break;
        case 205: _t->on_actionBackupSave_triggered(); break;
        case 206: _t->on_actionPauseAfterSeek_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 207: _t->on_actionWhatsThis_triggered(); break;
        case 208: _t->on_actionLeaveSafeMode_triggered(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 110:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 112:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 113:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 118:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 135:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 141:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 142:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 168:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 172:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::audioChannelsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::processingModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(bool )>(_a, &MainWindow::producerOpened, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::profileChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(QString )>(_a, &MainWindow::openFailed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::aboutToShutDown, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::renameRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(int , Mlt::Service * )>(_a, &MainWindow::serviceInChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(int , Mlt::Service * )>(_a, &MainWindow::serviceOutChanged, 9))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 209)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 209;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 209)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 209;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::audioChannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainWindow::processingModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MainWindow::producerOpened(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 4
void MainWindow::profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MainWindow::openFailed(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MainWindow::aboutToShutDown()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MainWindow::renameRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MainWindow::serviceInChanged(int _t1, Mlt::Service * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void MainWindow::serviceOutChanged(int _t1, Mlt::Service * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}
QT_WARNING_POP
