/****************************************************************************
** Meta object code from reading C++ file 'qmleditmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/qmltypes/qmleditmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmleditmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11QmlEditMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlEditMenu::qt_create_metaobjectdata<qt_meta_tag_ZN11QmlEditMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlEditMenu",
        "showPastePlainChanged",
        "",
        "readOnlyChanged",
        "undoTriggered",
        "redoTriggered",
        "cutTriggered",
        "copyTriggered",
        "pasteTriggered",
        "pastePlainTriggered",
        "deleteTriggered",
        "clearTriggered",
        "selectAllTriggered",
        "popup",
        "showPastePlain",
        "readOnly"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showPastePlainChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readOnlyChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undoTriggered'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redoTriggered'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cutTriggered'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copyTriggered'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pasteTriggered'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pastePlainTriggered'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deleteTriggered'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearTriggered'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAllTriggered'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'popup'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showPastePlain'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'readOnly'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlEditMenu, qt_meta_tag_ZN11QmlEditMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlEditMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlEditMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlEditMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11QmlEditMenuE_t>.metaTypes,
    nullptr
} };

void QmlEditMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlEditMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showPastePlainChanged(); break;
        case 1: _t->readOnlyChanged(); break;
        case 2: _t->undoTriggered(); break;
        case 3: _t->redoTriggered(); break;
        case 4: _t->cutTriggered(); break;
        case 5: _t->copyTriggered(); break;
        case 6: _t->pasteTriggered(); break;
        case 7: _t->pastePlainTriggered(); break;
        case 8: _t->deleteTriggered(); break;
        case 9: _t->clearTriggered(); break;
        case 10: _t->selectAllTriggered(); break;
        case 11: _t->popup(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::showPastePlainChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::readOnlyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::undoTriggered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::redoTriggered, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::cutTriggered, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::copyTriggered, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::pasteTriggered, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::pastePlainTriggered, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::deleteTriggered, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::clearTriggered, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlEditMenu::*)()>(_a, &QmlEditMenu::selectAllTriggered, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_showPastePlain; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->m_readOnly; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_showPastePlain, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->showPastePlainChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_readOnly, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->readOnlyChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *QmlEditMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlEditMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlEditMenuE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlEditMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QmlEditMenu::showPastePlainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QmlEditMenu::readOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QmlEditMenu::undoTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QmlEditMenu::redoTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QmlEditMenu::cutTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QmlEditMenu::copyTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QmlEditMenu::pasteTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QmlEditMenu::pastePlainTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QmlEditMenu::deleteTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QmlEditMenu::clearTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QmlEditMenu::selectAllTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
