/****************************************************************************
** Meta object code from reading C++ file 'settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/settings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ShotcutSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto ShotcutSettings::qt_create_metaobjectdata<qt_meta_tag_ZN15ShotcutSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShotcutSettings",
        "openPathChanged",
        "",
        "savePathChanged",
        "timelineDragScrubChanged",
        "timelineShowWaveformsChanged",
        "timelineShowThumbnailsChanged",
        "timelineRippleChanged",
        "timelineRippleAllTracksChanged",
        "timelineRippleMarkersChanged",
        "timelineSnapChanged",
        "timelineScrollZoomChanged",
        "timelineFramebufferWaveformChanged",
        "playerAudioChannelsChanged",
        "playerGpuChanged",
        "audioInDurationChanged",
        "audioOutDurationChanged",
        "videoInDurationChanged",
        "videoOutDurationChanged",
        "audioInCurveChanged",
        "audioOutCurveChanged",
        "playlistThumbnailsChanged",
        "viewModeChanged",
        "filesViewModeChanged",
        "smallIconsChanged",
        "askOutputFilterChanged",
        "timelineScrollingChanged",
        "timelineAutoAddTracksChanged",
        "timelineRectangleSelectChanged",
        "timeFormatChanged",
        "keyframesDragScrubChanged",
        "timelineAdjustGainChanged",
        "timelineAllowTransitionsChanged",
        "reset",
        "timelineDragScrub",
        "timelineShowWaveforms",
        "timelineShowThumbnails",
        "timelineRipple",
        "timelineRippleAllTracks",
        "timelineRippleMarkers",
        "timelineSnap",
        "timelineScrollZoom",
        "timelineFramebufferWaveform",
        "openPath",
        "savePath",
        "playlistThumbnails",
        "viewMode",
        "playerAudioChannels",
        "playerGPU",
        "audioInDuration",
        "audioOutDuration",
        "videoInDuration",
        "videoOutDuration",
        "audioInCurve",
        "audioOutCurve",
        "smallIcons",
        "askOutputFilter",
        "appDataLocation",
        "timelineScrolling",
        "TimelineScrolling",
        "timelineRectangleSelect",
        "keyframesDragScrub",
        "timelineAdjustGain",
        "timelineAllowTransitions",
        "NoScrolling",
        "CenterPlayhead",
        "PageScrolling",
        "SmoothScrolling"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openPathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'savePathChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineDragScrubChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineShowWaveformsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineShowThumbnailsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineRippleChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineRippleAllTracksChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineRippleMarkersChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineSnapChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineScrollZoomChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineFramebufferWaveformChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerAudioChannelsChanged'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'playerGpuChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioInDurationChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioOutDurationChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoInDurationChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoOutDurationChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioInCurveChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioOutCurveChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playlistThumbnailsChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewModeChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filesViewModeChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'smallIconsChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'askOutputFilterChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineScrollingChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineAutoAddTracksChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineRectangleSelectChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeFormatChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyframesDragScrubChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineAdjustGainChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelineAllowTransitionsChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timelineDragScrub'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'timelineShowWaveforms'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'timelineShowThumbnails'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'timelineRipple'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'timelineRippleAllTracks'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'timelineRippleMarkers'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'timelineSnap'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'timelineScrollZoom'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'timelineFramebufferWaveform'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'openPath'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'savePath'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'playlistThumbnails'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'viewMode'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'playerAudioChannels'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags, 11),
        // property 'playerGPU'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'audioInDuration'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'audioOutDuration'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'videoInDuration'
        QtMocHelpers::PropertyData<double>(51, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'videoOutDuration'
        QtMocHelpers::PropertyData<double>(52, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'audioInCurve'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'audioOutCurve'
        QtMocHelpers::PropertyData<double>(54, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'smallIcons'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'askOutputFilter'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'appDataLocation'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timelineScrolling'
        QtMocHelpers::PropertyData<enum TimelineScrolling>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 24),
        // property 'timelineRectangleSelect'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'keyframesDragScrub'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'timelineAdjustGain'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'timelineAllowTransitions'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TimelineScrolling'
        QtMocHelpers::EnumData<enum TimelineScrolling>(59, 59, QMC::EnumFlags{}).add({
            {   64, TimelineScrolling::NoScrolling },
            {   65, TimelineScrolling::CenterPlayhead },
            {   66, TimelineScrolling::PageScrolling },
            {   67, TimelineScrolling::SmoothScrolling },
        }),
    };
    return QtMocHelpers::metaObjectData<ShotcutSettings, qt_meta_tag_ZN15ShotcutSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ShotcutSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ShotcutSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ShotcutSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ShotcutSettingsE_t>.metaTypes,
    nullptr
} };

void ShotcutSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShotcutSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openPathChanged(); break;
        case 1: _t->savePathChanged(); break;
        case 2: _t->timelineDragScrubChanged(); break;
        case 3: _t->timelineShowWaveformsChanged(); break;
        case 4: _t->timelineShowThumbnailsChanged(); break;
        case 5: _t->timelineRippleChanged(); break;
        case 6: _t->timelineRippleAllTracksChanged(); break;
        case 7: _t->timelineRippleMarkersChanged(); break;
        case 8: _t->timelineSnapChanged(); break;
        case 9: _t->timelineScrollZoomChanged(); break;
        case 10: _t->timelineFramebufferWaveformChanged(); break;
        case 11: _t->playerAudioChannelsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->playerGpuChanged(); break;
        case 13: _t->audioInDurationChanged(); break;
        case 14: _t->audioOutDurationChanged(); break;
        case 15: _t->videoInDurationChanged(); break;
        case 16: _t->videoOutDurationChanged(); break;
        case 17: _t->audioInCurveChanged(); break;
        case 18: _t->audioOutCurveChanged(); break;
        case 19: _t->playlistThumbnailsChanged(); break;
        case 20: _t->viewModeChanged(); break;
        case 21: _t->filesViewModeChanged(); break;
        case 22: _t->smallIconsChanged(); break;
        case 23: _t->askOutputFilterChanged(); break;
        case 24: _t->timelineScrollingChanged(); break;
        case 25: _t->timelineAutoAddTracksChanged(); break;
        case 26: _t->timelineRectangleSelectChanged(); break;
        case 27: _t->timeFormatChanged(); break;
        case 28: _t->keyframesDragScrubChanged(); break;
        case 29: _t->timelineAdjustGainChanged(); break;
        case 30: _t->timelineAllowTransitionsChanged(); break;
        case 31: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::openPathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::savePathChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineDragScrubChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineShowWaveformsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineShowThumbnailsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineRippleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineRippleAllTracksChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineRippleMarkersChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineSnapChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineScrollZoomChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineFramebufferWaveformChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)(int )>(_a, &ShotcutSettings::playerAudioChannelsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::playerGpuChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::audioInDurationChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::audioOutDurationChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::videoInDurationChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::videoOutDurationChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::audioInCurveChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::audioOutCurveChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::playlistThumbnailsChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::viewModeChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::filesViewModeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::smallIconsChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::askOutputFilterChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineScrollingChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineAutoAddTracksChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineRectangleSelectChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timeFormatChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::keyframesDragScrubChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineAdjustGainChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShotcutSettings::*)()>(_a, &ShotcutSettings::timelineAllowTransitionsChanged, 30))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->timelineDragScrub(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->timelineShowWaveforms(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->timelineShowThumbnails(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->timelineRipple(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->timelineRippleAllTracks(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->timelineRippleMarkers(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->timelineSnap(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->timelineScrollZoom(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->timelineFramebufferWaveform(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->openPath(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->savePath(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->playlistThumbnails(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->viewMode(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->playerAudioChannels(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->playerGPU(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->audioInDuration(); break;
        case 16: *reinterpret_cast<double*>(_v) = _t->audioOutDuration(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->videoInDuration(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->videoOutDuration(); break;
        case 19: *reinterpret_cast<double*>(_v) = _t->audioInCurve(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->audioOutCurve(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->smallIcons(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->askOutputFilter(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->appDataLocation(); break;
        case 24: *reinterpret_cast<enum TimelineScrolling*>(_v) = _t->timelineScrolling(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->timelineRectangleSelect(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->keyframesDragScrub(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->timelineAdjustGain(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->timelineAllowTransitions(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTimelineDragScrub(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setTimelineShowWaveforms(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setTimelineShowThumbnails(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setTimelineRipple(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setTimelineRippleAllTracks(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setTimelineRippleMarkers(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setTimelineSnap(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setTimelineScrollZoom(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setTimelineFramebufferWaveform(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setOpenPath(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setSavePath(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setPlaylistThumbnails(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setViewMode(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setAudioInDuration(*reinterpret_cast<double*>(_v)); break;
        case 16: _t->setAudioOutDuration(*reinterpret_cast<double*>(_v)); break;
        case 17: _t->setVideoInDuration(*reinterpret_cast<double*>(_v)); break;
        case 18: _t->setVideoOutDuration(*reinterpret_cast<double*>(_v)); break;
        case 19: _t->setAudioInCurve(*reinterpret_cast<double*>(_v)); break;
        case 20: _t->setAudioOutCurve(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setSmallIcons(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setAskOutputFilter(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setTimelineScrolling(*reinterpret_cast<enum TimelineScrolling*>(_v)); break;
        case 25: _t->setTimelineRectangleSelect(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setKeyframesDragScrub(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setTimelineAdjustGain(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setTimelineAllowTransitions(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ShotcutSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShotcutSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ShotcutSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ShotcutSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void ShotcutSettings::openPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ShotcutSettings::savePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ShotcutSettings::timelineDragScrubChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ShotcutSettings::timelineShowWaveformsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ShotcutSettings::timelineShowThumbnailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ShotcutSettings::timelineRippleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ShotcutSettings::timelineRippleAllTracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ShotcutSettings::timelineRippleMarkersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ShotcutSettings::timelineSnapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ShotcutSettings::timelineScrollZoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ShotcutSettings::timelineFramebufferWaveformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ShotcutSettings::playerAudioChannelsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ShotcutSettings::playerGpuChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ShotcutSettings::audioInDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ShotcutSettings::audioOutDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ShotcutSettings::videoInDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void ShotcutSettings::videoOutDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void ShotcutSettings::audioInCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void ShotcutSettings::audioOutCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void ShotcutSettings::playlistThumbnailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void ShotcutSettings::viewModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void ShotcutSettings::filesViewModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void ShotcutSettings::smallIconsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void ShotcutSettings::askOutputFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void ShotcutSettings::timelineScrollingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void ShotcutSettings::timelineAutoAddTracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void ShotcutSettings::timelineRectangleSelectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void ShotcutSettings::timeFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void ShotcutSettings::keyframesDragScrubChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void ShotcutSettings::timelineAdjustGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void ShotcutSettings::timelineAllowTransitionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}
QT_WARNING_POP
