/********************************************************************************
** Form generated from reading UI file 'video4linuxwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VIDEO4LINUXWIDGET_H
#define UI_VIDEO4LINUXWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_Video4LinuxWidget
{
public:
    QGridLayout *gridLayout_2;
    QSpacerItem *verticalSpacer_7;
    QVBoxLayout *audioLayout;
    QPushButton *applyButton;
    QLineEdit *v4lLineEdit;
    QSpacerItem *horizontalSpacer_13;
    QLabel *label_3;
    QLabel *label_10;
    QDoubleSpinBox *v4lFramerateSpinBox;
    QSpinBox *v4lHeightSpinBox;
    QLabel *label_9;
    QLabel *label_7;
    QLabel *label_5;
    QGroupBox *groupBox_6;
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *v4lStandardCombo;
    QLabel *label_4;
    QSpinBox *v4lChannelSpinBox;
    ServicePresetWidget *preset;
    QLabel *label_2;
    QSpinBox *v4lWidthSpinBox;
    QLabel *label_11;
    QLabel *label_8;
    QComboBox *v4lAudioComboBox;

    void setupUi(QWidget *Video4LinuxWidget)
    {
        if (Video4LinuxWidget->objectName().isEmpty())
            Video4LinuxWidget->setObjectName("Video4LinuxWidget");
        Video4LinuxWidget->resize(421, 406);
#if QT_CONFIG(whatsthis)
        Video4LinuxWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-video4linux/12937/1"));
#endif // QT_CONFIG(whatsthis)
        gridLayout_2 = new QGridLayout(Video4LinuxWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalSpacer_7 = new QSpacerItem(20, 119, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_7, 10, 0, 1, 1);

        audioLayout = new QVBoxLayout();
        audioLayout->setObjectName("audioLayout");

        gridLayout_2->addLayout(audioLayout, 8, 0, 1, 6);

        applyButton = new QPushButton(Video4LinuxWidget);
        applyButton->setObjectName("applyButton");

        gridLayout_2->addWidget(applyButton, 9, 0, 1, 1);

        v4lLineEdit = new QLineEdit(Video4LinuxWidget);
        v4lLineEdit->setObjectName("v4lLineEdit");

        gridLayout_2->addWidget(v4lLineEdit, 2, 1, 1, 3);

        horizontalSpacer_13 = new QSpacerItem(122, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_13, 2, 5, 1, 1);

        label_3 = new QLabel(Video4LinuxWidget);
        label_3->setObjectName("label_3");
        QFont font;
        font.setBold(true);
        label_3->setFont(font);
        label_3->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout_2->addWidget(label_3, 0, 0, 1, 6);

        label_10 = new QLabel(Video4LinuxWidget);
        label_10->setObjectName("label_10");

        gridLayout_2->addWidget(label_10, 4, 3, 1, 1);

        v4lFramerateSpinBox = new QDoubleSpinBox(Video4LinuxWidget);
        v4lFramerateSpinBox->setObjectName("v4lFramerateSpinBox");
        v4lFramerateSpinBox->setMinimum(0.000000000000000);
        v4lFramerateSpinBox->setMaximum(1000.000000000000000);
        v4lFramerateSpinBox->setValue(15.000000000000000);

        gridLayout_2->addWidget(v4lFramerateSpinBox, 4, 1, 1, 1);

        v4lHeightSpinBox = new QSpinBox(Video4LinuxWidget);
        v4lHeightSpinBox->setObjectName("v4lHeightSpinBox");
        v4lHeightSpinBox->setMaximum(4096);
        v4lHeightSpinBox->setValue(480);

        gridLayout_2->addWidget(v4lHeightSpinBox, 3, 3, 1, 1);

        label_9 = new QLabel(Video4LinuxWidget);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_9, 4, 0, 1, 1);

        label_7 = new QLabel(Video4LinuxWidget);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_7, 3, 0, 1, 1);

        label_5 = new QLabel(Video4LinuxWidget);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_5, 2, 0, 1, 1);

        groupBox_6 = new QGroupBox(Video4LinuxWidget);
        groupBox_6->setObjectName("groupBox_6");
        groupBox_6->setFlat(true);
        groupBox_6->setChecked(false);
        gridLayout = new QGridLayout(groupBox_6);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox_6);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        v4lStandardCombo = new QComboBox(groupBox_6);
        v4lStandardCombo->addItem(QString());
        v4lStandardCombo->addItem(QString());
        v4lStandardCombo->addItem(QString());
        v4lStandardCombo->addItem(QString());
        v4lStandardCombo->setObjectName("v4lStandardCombo");

        gridLayout->addWidget(v4lStandardCombo, 0, 1, 1, 1);

        label_4 = new QLabel(groupBox_6);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        v4lChannelSpinBox = new QSpinBox(groupBox_6);
        v4lChannelSpinBox->setObjectName("v4lChannelSpinBox");

        gridLayout->addWidget(v4lChannelSpinBox, 1, 1, 1, 1);


        gridLayout_2->addWidget(groupBox_6, 5, 0, 1, 4);

        preset = new ServicePresetWidget(Video4LinuxWidget);
        preset->setObjectName("preset");

        gridLayout_2->addWidget(preset, 1, 0, 1, 6);

        label_2 = new QLabel(Video4LinuxWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_2, 6, 0, 1, 1);

        v4lWidthSpinBox = new QSpinBox(Video4LinuxWidget);
        v4lWidthSpinBox->setObjectName("v4lWidthSpinBox");
        v4lWidthSpinBox->setMaximum(4096);
        v4lWidthSpinBox->setValue(640);

        gridLayout_2->addWidget(v4lWidthSpinBox, 3, 1, 1, 1);

        label_11 = new QLabel(Video4LinuxWidget);
        label_11->setObjectName("label_11");

        gridLayout_2->addWidget(label_11, 3, 4, 1, 1);

        label_8 = new QLabel(Video4LinuxWidget);
        label_8->setObjectName("label_8");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(label_8, 3, 2, 1, 1);

        v4lAudioComboBox = new QComboBox(Video4LinuxWidget);
        v4lAudioComboBox->addItem(QString());
        v4lAudioComboBox->addItem(QString());
        v4lAudioComboBox->addItem(QString());
        v4lAudioComboBox->setObjectName("v4lAudioComboBox");

        gridLayout_2->addWidget(v4lAudioComboBox, 6, 1, 1, 3);


        retranslateUi(Video4LinuxWidget);

        QMetaObject::connectSlotsByName(Video4LinuxWidget);
    } // setupUi

    void retranslateUi(QWidget *Video4LinuxWidget)
    {
        Video4LinuxWidget->setWindowTitle(QCoreApplication::translate("Video4LinuxWidget", "Form", nullptr));
        applyButton->setText(QCoreApplication::translate("Video4LinuxWidget", "Apply", nullptr));
#if QT_CONFIG(tooltip)
        v4lLineEdit->setToolTip(QCoreApplication::translate("Video4LinuxWidget", "Set the path to the video device file", nullptr));
#endif // QT_CONFIG(tooltip)
        v4lLineEdit->setText(QCoreApplication::translate("Video4LinuxWidget", "/dev/video0", nullptr));
        label_3->setText(QCoreApplication::translate("Video4LinuxWidget", "Video4Linux", nullptr));
        label_10->setText(QCoreApplication::translate("Video4LinuxWidget", "fps", nullptr));
#if QT_CONFIG(tooltip)
        v4lHeightSpinBox->setToolTip(QCoreApplication::translate("Video4LinuxWidget", "Height", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(QCoreApplication::translate("Video4LinuxWidget", "Frame rate", nullptr));
        label_7->setText(QCoreApplication::translate("Video4LinuxWidget", "Resolution", nullptr));
        label_5->setText(QCoreApplication::translate("Video4LinuxWidget", "Device", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("Video4LinuxWidget", "TV Tuner", nullptr));
        label->setText(QCoreApplication::translate("Video4LinuxWidget", "Standard", nullptr));
        v4lStandardCombo->setItemText(0, QCoreApplication::translate("Video4LinuxWidget", "Automatic", nullptr));
        v4lStandardCombo->setItemText(1, QCoreApplication::translate("Video4LinuxWidget", "NTSC", nullptr));
        v4lStandardCombo->setItemText(2, QCoreApplication::translate("Video4LinuxWidget", "PAL", nullptr));
        v4lStandardCombo->setItemText(3, QCoreApplication::translate("Video4LinuxWidget", "SECAM", nullptr));

#if QT_CONFIG(tooltip)
        v4lStandardCombo->setToolTip(QCoreApplication::translate("Video4LinuxWidget", "Set the television standard", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(QCoreApplication::translate("Video4LinuxWidget", "Channel", nullptr));
        label_2->setText(QCoreApplication::translate("Video4LinuxWidget", "Audio Input", nullptr));
#if QT_CONFIG(tooltip)
        v4lWidthSpinBox->setToolTip(QCoreApplication::translate("Video4LinuxWidget", "Width", nullptr));
#endif // QT_CONFIG(tooltip)
        label_11->setText(QCoreApplication::translate("Video4LinuxWidget", "pixels", nullptr));
        label_8->setText(QCoreApplication::translate("Video4LinuxWidget", "X", nullptr));
        v4lAudioComboBox->setItemText(0, QCoreApplication::translate("Video4LinuxWidget", "None", nullptr));
        v4lAudioComboBox->setItemText(1, QCoreApplication::translate("Video4LinuxWidget", "PulseAudio", nullptr));
        v4lAudioComboBox->setItemText(2, QCoreApplication::translate("Video4LinuxWidget", "ALSA", nullptr));

    } // retranslateUi

};

namespace Ui {
    class Video4LinuxWidget: public Ui_Video4LinuxWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_VIDEO4LINUXWIDGET_H
