/********************************************************************************
** Form generated from reading UI file 'transcodedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSCODEDIALOG_H
#define UI_TRANSCODEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/frameratewidget.h"

QT_BEGIN_NAMESPACE

class Ui_TranscodeDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *messageLabel;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QSlider *horizontalSlider;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    QLabel *label_5;
    QLabel *label_6;
    QLabel *formatLabel;
    QCheckBox *checkBox;
    QWidget *advancedWidget;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    FrameRateWidget *fpsWidget;
    QCheckBox *convert709CheckBox;
    QCheckBox *subclipCheckBox;
    QCheckBox *advancedCheckBox;
    QComboBox *frcComboBox;
    QFrame *line;
    QCheckBox *fpsCheckBox;
    QLabel *sampleRateLabel;
    QLabel *fpsLabel;
    QCheckBox *deinterlaceCheckBox;
    QLabel *frcLabel;
    QComboBox *sampleRateComboBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TranscodeDialog)
    {
        if (TranscodeDialog->objectName().isEmpty())
            TranscodeDialog->setObjectName("TranscodeDialog");
        TranscodeDialog->setWindowModality(Qt::WindowModality::WindowModal);
        TranscodeDialog->resize(492, 575);
#if QT_CONFIG(whatsthis)
        TranscodeDialog->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/convert-to-edit-friendly-dialog/47720"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(TranscodeDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SizeConstraint::SetFixedSize);
        messageLabel = new QLabel(TranscodeDialog);
        messageLabel->setObjectName("messageLabel");
        messageLabel->setText(QString::fromUtf8("messageLabel"));
        messageLabel->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        messageLabel->setWordWrap(true);

        verticalLayout->addWidget(messageLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(TranscodeDialog);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(label);

        label_2 = new QLabel(TranscodeDialog);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignCenter);

        horizontalLayout->addWidget(label_2);

        label_3 = new QLabel(TranscodeDialog);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout->addWidget(label_3);


        verticalLayout->addLayout(horizontalLayout);

        horizontalSlider = new QSlider(TranscodeDialog);
        horizontalSlider->setObjectName("horizontalSlider");
        horizontalSlider->setMaximum(2);
        horizontalSlider->setPageStep(1);
        horizontalSlider->setValue(0);
        horizontalSlider->setSliderPosition(0);
        horizontalSlider->setOrientation(Qt::Orientation::Horizontal);
        horizontalSlider->setTickPosition(QSlider::TickPosition::TicksBothSides);

        verticalLayout->addWidget(horizontalSlider);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_4 = new QLabel(TranscodeDialog);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_2->addWidget(label_4);

        label_5 = new QLabel(TranscodeDialog);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignmentFlag::AlignCenter);

        horizontalLayout_2->addWidget(label_5);

        label_6 = new QLabel(TranscodeDialog);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_2->addWidget(label_6);


        verticalLayout->addLayout(horizontalLayout_2);

        formatLabel = new QLabel(TranscodeDialog);
        formatLabel->setObjectName("formatLabel");
        formatLabel->setText(QString::fromUtf8("formatLabel"));
        formatLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(formatLabel);

        checkBox = new QCheckBox(TranscodeDialog);
        checkBox->setObjectName("checkBox");

        verticalLayout->addWidget(checkBox);

        advancedWidget = new QWidget(TranscodeDialog);
        advancedWidget->setObjectName("advancedWidget");
        verticalLayout_2 = new QVBoxLayout(advancedWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        fpsWidget = new FrameRateWidget(advancedWidget);
        fpsWidget->setObjectName("fpsWidget");

        gridLayout->addWidget(fpsWidget, 4, 1, 1, 1);

        convert709CheckBox = new QCheckBox(advancedWidget);
        convert709CheckBox->setObjectName("convert709CheckBox");

        gridLayout->addWidget(convert709CheckBox, 6, 1, 1, 1);

        subclipCheckBox = new QCheckBox(advancedWidget);
        subclipCheckBox->setObjectName("subclipCheckBox");

        gridLayout->addWidget(subclipCheckBox, 1, 1, 1, 1);

        advancedCheckBox = new QCheckBox(advancedWidget);
        advancedCheckBox->setObjectName("advancedCheckBox");

        gridLayout->addWidget(advancedCheckBox, 9, 1, 1, 1);

        frcComboBox = new QComboBox(advancedWidget);
        frcComboBox->setObjectName("frcComboBox");

        gridLayout->addWidget(frcComboBox, 5, 1, 1, 1);

        line = new QFrame(advancedWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 0, 0, 1, 2);

        fpsCheckBox = new QCheckBox(advancedWidget);
        fpsCheckBox->setObjectName("fpsCheckBox");

        gridLayout->addWidget(fpsCheckBox, 3, 1, 1, 1);

        sampleRateLabel = new QLabel(advancedWidget);
        sampleRateLabel->setObjectName("sampleRateLabel");
        sampleRateLabel->setEnabled(true);
        sampleRateLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(sampleRateLabel, 7, 0, 1, 1);

        fpsLabel = new QLabel(advancedWidget);
        fpsLabel->setObjectName("fpsLabel");
        fpsLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(fpsLabel, 4, 0, 1, 1);

        deinterlaceCheckBox = new QCheckBox(advancedWidget);
        deinterlaceCheckBox->setObjectName("deinterlaceCheckBox");

        gridLayout->addWidget(deinterlaceCheckBox, 2, 1, 1, 1);

        frcLabel = new QLabel(advancedWidget);
        frcLabel->setObjectName("frcLabel");
        frcLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(frcLabel, 5, 0, 1, 1);

        sampleRateComboBox = new QComboBox(advancedWidget);
        sampleRateComboBox->addItem(QString());
        sampleRateComboBox->addItem(QString());
        sampleRateComboBox->addItem(QString());
        sampleRateComboBox->setObjectName("sampleRateComboBox");
        sampleRateComboBox->setEnabled(true);

        gridLayout->addWidget(sampleRateComboBox, 7, 1, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        verticalLayout_2->addLayout(gridLayout);


        verticalLayout->addWidget(advancedWidget);

        buttonBox = new QDialogButtonBox(TranscodeDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(TranscodeDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TranscodeDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TranscodeDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TranscodeDialog);
    } // setupUi

    void retranslateUi(QDialog *TranscodeDialog)
    {
        label->setText(QCoreApplication::translate("TranscodeDialog", "good", nullptr));
        label_2->setText(QCoreApplication::translate("TranscodeDialog", "better", nullptr));
        label_3->setText(QCoreApplication::translate("TranscodeDialog", "best", nullptr));
        label_4->setText(QCoreApplication::translate("TranscodeDialog", "medium", nullptr));
        label_5->setText(QCoreApplication::translate("TranscodeDialog", "BIG", nullptr));
        label_6->setText(QCoreApplication::translate("TranscodeDialog", "<span style=\" font-weight:700; color:#ff0000;\">HUGE</span>", nullptr));
        checkBox->setText(QCoreApplication::translate("TranscodeDialog", "Do not show this anymore.", "Convert to edit-friendly format dialog"));
#if QT_CONFIG(tooltip)
        fpsWidget->setToolTip(QCoreApplication::translate("TranscodeDialog", "Override the frame rate to a specific value.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        convert709CheckBox->setToolTip(QCoreApplication::translate("TranscodeDialog", "This is useful when the source video is HDR (High Dynamic Range), which requires tone-mapping to the old, standard range.", nullptr));
#endif // QT_CONFIG(tooltip)
        convert709CheckBox->setText(QCoreApplication::translate("TranscodeDialog", "Convert to BT.709 colorspace", nullptr));
#if QT_CONFIG(tooltip)
        subclipCheckBox->setToolTip(QCoreApplication::translate("TranscodeDialog", "This option converts only the trimmed portion of the source\n"
"clip plus a little instead of the entire clip. When this option is\n"
"used not all of the matching source clips are replaced, instead\n"
"only the currently selected one.", nullptr));
#endif // QT_CONFIG(tooltip)
        subclipCheckBox->setText(QCoreApplication::translate("TranscodeDialog", "Use sub-clip", nullptr));
#if QT_CONFIG(tooltip)
        advancedCheckBox->setToolTip(QCoreApplication::translate("TranscodeDialog", "Enable this to keep the Advanced section open for the next time this dialog appears.", nullptr));
#endif // QT_CONFIG(tooltip)
        advancedCheckBox->setText(QCoreApplication::translate("TranscodeDialog", "Keep Advanced open", nullptr));
#if QT_CONFIG(tooltip)
        frcComboBox->setToolTip(QCoreApplication::translate("TranscodeDialog", "Frame rate conversion method\n"
"\n"
"Duplicate: Duplicate frames.\n"
"Blend: Blend frames.\n"
"Motion Compensation: Interpolate new frames using motion compensation. This method is very slow and may result in artifacts.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        fpsCheckBox->setToolTip(QCoreApplication::translate("TranscodeDialog", "Change the frame rate from its source.", nullptr));
#endif // QT_CONFIG(tooltip)
        fpsCheckBox->setText(QCoreApplication::translate("TranscodeDialog", "Override frame rate", nullptr));
        sampleRateLabel->setText(QCoreApplication::translate("TranscodeDialog", "Sample rate", nullptr));
        fpsLabel->setText(QCoreApplication::translate("TranscodeDialog", "Frames/sec", nullptr));
#if QT_CONFIG(tooltip)
        deinterlaceCheckBox->setToolTip(QCoreApplication::translate("TranscodeDialog", "If the source is interlaced, each interlaced field will be converted to a progressive frame resulting in double frame rate.", nullptr));
#endif // QT_CONFIG(tooltip)
        deinterlaceCheckBox->setText(QCoreApplication::translate("TranscodeDialog", "Deinterlace", nullptr));
        frcLabel->setText(QCoreApplication::translate("TranscodeDialog", "Frame rate conversion", nullptr));
        sampleRateComboBox->setItemText(0, QCoreApplication::translate("TranscodeDialog", "Same as original", nullptr));
        sampleRateComboBox->setItemText(1, QCoreApplication::translate("TranscodeDialog", "44100", nullptr));
        sampleRateComboBox->setItemText(2, QCoreApplication::translate("TranscodeDialog", "48000", nullptr));

        sampleRateComboBox->setCurrentText(QCoreApplication::translate("TranscodeDialog", "Same as original", nullptr));
        (void)TranscodeDialog;
    } // retranslateUi

};

namespace Ui {
    class TranscodeDialog: public Ui_TranscodeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TRANSCODEDIALOG_H
