/********************************************************************************
** Form generated from reading UI file 'durationdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DURATIONDIALOG_H
#define UI_DURATIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "widgets/timespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_DurationDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    TimeSpinBox *spinBox;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DurationDialog)
    {
        if (DurationDialog->objectName().isEmpty())
            DurationDialog->setObjectName("DurationDialog");
        DurationDialog->setWindowModality(Qt::WindowModal);
        DurationDialog->resize(209, 101);
        verticalLayout = new QVBoxLayout(DurationDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(DurationDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        spinBox = new TimeSpinBox(DurationDialog);
        spinBox->setObjectName("spinBox");
        spinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        spinBox->setMinimum(1);
        spinBox->setMaximum(2147483647);

        horizontalLayout->addWidget(spinBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 3, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(DurationDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DurationDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, DurationDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, DurationDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(DurationDialog);
    } // setupUi

    void retranslateUi(QDialog *DurationDialog)
    {
        DurationDialog->setWindowTitle(QCoreApplication::translate("DurationDialog", "Set Duration", nullptr));
        label->setText(QCoreApplication::translate("DurationDialog", "Duration", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DurationDialog: public Ui_DurationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DURATIONDIALOG_H
