/********************************************************************************
** Form generated from reading UI file 'noisewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOISEWIDGET_H
#define UI_NOISEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NoiseWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *NoiseWidget)
    {
        if (NoiseWidget->objectName().isEmpty())
            NoiseWidget->setObjectName("NoiseWidget");
        NoiseWidget->resize(396, 296);
#if QT_CONFIG(whatsthis)
        NoiseWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-noise/12927/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(NoiseWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(NoiseWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        verticalSpacer = new QSpacerItem(20, 262, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(NoiseWidget);

        QMetaObject::connectSlotsByName(NoiseWidget);
    } // setupUi

    void retranslateUi(QWidget *NoiseWidget)
    {
        NoiseWidget->setWindowTitle(QCoreApplication::translate("NoiseWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("NoiseWidget", "Noise", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NoiseWidget: public Ui_NoiseWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NOISEWIDGET_H
