/****************************************************************************
** Meta object code from reading C++ file 'encodedock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/docks/encodedock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'encodedock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EncodeDockE_t {};
} // unnamed namespace

template <> constexpr inline auto EncodeDock::qt_create_metaobjectdata<qt_meta_tag_ZN10EncodeDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EncodeDock",
        "captureStateChanged",
        "",
        "createOrEditFilterOnOutput",
        "Mlt::Filter*",
        "onAudioChannelsChanged",
        "onProducerOpened",
        "onProfileChanged",
        "onReframeChanged",
        "on_hwencodeButton_clicked",
        "detectHardwareEncoders",
        "on_presetsTree_clicked",
        "QModelIndex",
        "index",
        "on_presetsTree_activated",
        "on_encodeButton_clicked",
        "on_streamButton_clicked",
        "on_addPresetButton_clicked",
        "on_removePresetButton_clicked",
        "onFinished",
        "AbstractJob*",
        "isSuccess",
        "on_stopCaptureButton_clicked",
        "on_videoRateControlCombo_activated",
        "on_audioRateControlCombo_activated",
        "on_scanModeCombo_currentIndexChanged",
        "on_presetsSearch_textChanged",
        "search",
        "on_resetButton_clicked",
        "openCaptureFile",
        "on_formatCombo_currentIndexChanged",
        "on_videoBufferDurationChanged",
        "on_gopSpinner_valueChanged",
        "value",
        "on_fromCombo_currentIndexChanged",
        "on_videoCodecCombo_currentIndexChanged",
        "on_audioCodecCombo_currentIndexChanged",
        "setAudioChannels",
        "channels",
        "on_widthSpinner_editingFinished",
        "on_heightSpinner_editingFinished",
        "on_advancedButton_clicked",
        "checked",
        "on_hwencodeCheckBox_clicked",
        "on_hwdecodeCheckBox_clicked",
        "on_advancedCheckBox_clicked",
        "on_fpsSpinner_editingFinished",
        "on_fpsComboBox_activated",
        "arg1",
        "on_videoQualitySpinner_valueChanged",
        "vq",
        "on_audioQualitySpinner_valueChanged",
        "aq",
        "on_parallelCheckbox_clicked",
        "on_resolutionComboBox_activated",
        "on_reframeButton_clicked",
        "on_aspectNumSpinner_valueChanged",
        "on_aspectDenSpinner_valueChanged",
        "on_coverArtButton_clicked",
        "on_hdrMetaButton_clicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'captureStateChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'createOrEditFilterOnOutput'
        QtMocHelpers::SignalData<void(Mlt::Filter *, const QStringList &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::QStringList, 2 },
        }}),
        // Signal 'createOrEditFilterOnOutput'
        QtMocHelpers::SignalData<void(Mlt::Filter *)>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'onAudioChannelsChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerOpened'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProfileChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onReframeChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'on_hwencodeButton_clicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'detectHardwareEncoders'
        QtMocHelpers::SlotData<bool()>(10, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'on_presetsTree_clicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'on_presetsTree_activated'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'on_encodeButton_clicked'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_streamButton_clicked'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_addPresetButton_clicked'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_removePresetButton_clicked'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(AbstractJob *, bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 2 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'on_stopCaptureButton_clicked'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_videoRateControlCombo_activated'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'on_audioRateControlCombo_activated'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'on_scanModeCombo_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'on_presetsSearch_textChanged'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'on_resetButton_clicked'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openCaptureFile'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_formatCombo_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'on_videoBufferDurationChanged'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_gopSpinner_valueChanged'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'on_fromCombo_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'on_videoCodecCombo_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'on_audioCodecCombo_currentIndexChanged'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'setAudioChannels'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'on_widthSpinner_editingFinished'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_heightSpinner_editingFinished'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_advancedButton_clicked'
        QtMocHelpers::SlotData<void(bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'on_hwencodeCheckBox_clicked'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'on_hwdecodeCheckBox_clicked'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'on_advancedCheckBox_clicked'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'on_fpsSpinner_editingFinished'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_fpsComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'on_videoQualitySpinner_valueChanged'
        QtMocHelpers::SlotData<void(int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 50 },
        }}),
        // Slot 'on_audioQualitySpinner_valueChanged'
        QtMocHelpers::SlotData<void(int)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 52 },
        }}),
        // Slot 'on_parallelCheckbox_clicked'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'on_resolutionComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'on_reframeButton_clicked'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_aspectNumSpinner_valueChanged'
        QtMocHelpers::SlotData<void(int)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'on_aspectDenSpinner_valueChanged'
        QtMocHelpers::SlotData<void(int)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'on_coverArtButton_clicked'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_hdrMetaButton_clicked'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EncodeDock, qt_meta_tag_ZN10EncodeDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EncodeDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EncodeDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EncodeDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EncodeDockE_t>.metaTypes,
    nullptr
} };

void EncodeDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EncodeDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->captureStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->createOrEditFilterOnOutput((*reinterpret_cast<std::add_pointer_t<Mlt::Filter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 2: _t->createOrEditFilterOnOutput((*reinterpret_cast<std::add_pointer_t<Mlt::Filter*>>(_a[1]))); break;
        case 3: _t->onAudioChannelsChanged(); break;
        case 4: _t->onProducerOpened(); break;
        case 5: _t->onProfileChanged(); break;
        case 6: _t->onReframeChanged(); break;
        case 7: _t->on_hwencodeButton_clicked(); break;
        case 8: { bool _r = _t->detectHardwareEncoders();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->on_presetsTree_clicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 10: _t->on_presetsTree_activated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->on_encodeButton_clicked(); break;
        case 12: _t->on_streamButton_clicked(); break;
        case 13: _t->on_addPresetButton_clicked(); break;
        case 14: _t->on_removePresetButton_clicked(); break;
        case 15: _t->onFinished((*reinterpret_cast<std::add_pointer_t<AbstractJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 16: _t->on_stopCaptureButton_clicked(); break;
        case 17: _t->on_videoRateControlCombo_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->on_audioRateControlCombo_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->on_scanModeCombo_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->on_presetsSearch_textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->on_resetButton_clicked(); break;
        case 22: _t->openCaptureFile(); break;
        case 23: _t->on_formatCombo_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->on_videoBufferDurationChanged(); break;
        case 25: _t->on_gopSpinner_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->on_fromCombo_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->on_videoCodecCombo_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->on_audioCodecCombo_currentIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->setAudioChannels((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->on_widthSpinner_editingFinished(); break;
        case 31: _t->on_heightSpinner_editingFinished(); break;
        case 32: _t->on_advancedButton_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->on_hwencodeCheckBox_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->on_hwdecodeCheckBox_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->on_advancedCheckBox_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->on_fpsSpinner_editingFinished(); break;
        case 37: _t->on_fpsComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->on_videoQualitySpinner_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->on_audioQualitySpinner_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->on_parallelCheckbox_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->on_resolutionComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 42: _t->on_reframeButton_clicked(); break;
        case 43: _t->on_aspectNumSpinner_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->on_aspectDenSpinner_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->on_coverArtButton_clicked(); break;
        case 46: _t->on_hdrMetaButton_clicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EncodeDock::*)(bool )>(_a, &EncodeDock::captureStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EncodeDock::*)(Mlt::Filter * , const QStringList & )>(_a, &EncodeDock::createOrEditFilterOnOutput, 1))
            return;
    }
}

const QMetaObject *EncodeDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EncodeDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EncodeDockE_t>.strings))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int EncodeDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 47;
    }
    return _id;
}

// SIGNAL 0
void EncodeDock::captureStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void EncodeDock::createOrEditFilterOnOutput(Mlt::Filter * _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
