/********************************************************************************
** Form generated from reading UI file 'filesdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILESDOCK_H
#define UI_FILESDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/playlistlistview.h"
#include "widgets/playlisttable.h"

QT_BEGIN_NAMESPACE

class Ui_FilesDock
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *locationsLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QComboBox *locationsCombo;
    QPushButton *addLocationButton;
    QPushButton *removeLocationButton;
    QHBoxLayout *filtersLayout;
    QSplitter *splitter;
    QTreeView *treeView;
    QWidget *layoutWidget_2;
    QVBoxLayout *verticalLayout_3;
    PlaylistTable *tableView;
    PlaylistListView *listView;

    void setupUi(QDockWidget *FilesDock)
    {
        if (FilesDock->objectName().isEmpty())
            FilesDock->setObjectName("FilesDock");
        FilesDock->resize(460, 278);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        locationsLayout = new QHBoxLayout();
        locationsLayout->setSpacing(5);
        locationsLayout->setObjectName("locationsLayout");
        horizontalSpacer = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        locationsLayout->addItem(horizontalSpacer);

        label = new QLabel(dockWidgetContents);
        label->setObjectName("label");

        locationsLayout->addWidget(label);

        locationsCombo = new QComboBox(dockWidgetContents);
        locationsCombo->setObjectName("locationsCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(locationsCombo->sizePolicy().hasHeightForWidth());
        locationsCombo->setSizePolicy(sizePolicy);
        locationsCombo->setEditable(true);
        locationsCombo->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToMinimumContentsLengthWithIcon);

        locationsLayout->addWidget(locationsCombo);

        addLocationButton = new QPushButton(dockWidgetContents);
        addLocationButton->setObjectName("addLocationButton");
        addLocationButton->setMaximumSize(QSize(20, 20));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/list-add.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addLocationButton->setIcon(icon);

        locationsLayout->addWidget(addLocationButton);

        removeLocationButton = new QPushButton(dockWidgetContents);
        removeLocationButton->setObjectName("removeLocationButton");
        removeLocationButton->setMaximumSize(QSize(20, 20));
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/list-remove.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeLocationButton->setIcon(icon1);

        locationsLayout->addWidget(removeLocationButton);


        verticalLayout->addLayout(locationsLayout);

        filtersLayout = new QHBoxLayout();
        filtersLayout->setObjectName("filtersLayout");

        verticalLayout->addLayout(filtersLayout);

        splitter = new QSplitter(dockWidgetContents);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Orientation::Horizontal);
        treeView = new QTreeView(splitter);
        treeView->setObjectName("treeView");
        treeView->setAcceptDrops(true);
        treeView->setUniformRowHeights(true);
        treeView->setAnimated(true);
        splitter->addWidget(treeView);
        layoutWidget_2 = new QWidget(splitter);
        layoutWidget_2->setObjectName("layoutWidget_2");
        verticalLayout_3 = new QVBoxLayout(layoutWidget_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        tableView = new PlaylistTable(layoutWidget_2);
        tableView->setObjectName("tableView");
        tableView->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        tableView->setDragEnabled(false);
        tableView->setAlternatingRowColors(true);
        tableView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        tableView->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);
        tableView->setHorizontalScrollMode(QAbstractItemView::ScrollMode::ScrollPerPixel);
        tableView->horizontalHeader()->setDefaultSectionSize(200);
        tableView->horizontalHeader()->setProperty("showSortIndicator", QVariant(true));
        tableView->verticalHeader()->setVisible(false);

        verticalLayout_3->addWidget(tableView);

        listView = new PlaylistListView(layoutWidget_2);
        listView->setObjectName("listView");
        listView->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        listView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        listView->setMovement(QListView::Movement::Static);

        verticalLayout_3->addWidget(listView);

        splitter->addWidget(layoutWidget_2);

        verticalLayout->addWidget(splitter);

        FilesDock->setWidget(dockWidgetContents);

        retranslateUi(FilesDock);

        QMetaObject::connectSlotsByName(FilesDock);
    } // setupUi

    void retranslateUi(QDockWidget *FilesDock)
    {
        FilesDock->setWindowTitle(QCoreApplication::translate("FilesDock", "Files", nullptr));
        label->setText(QCoreApplication::translate("FilesDock", "Location", nullptr));
#if QT_CONFIG(tooltip)
        addLocationButton->setToolTip(QCoreApplication::translate("FilesDock", "Add the current folder to the saved locations", nullptr));
#endif // QT_CONFIG(tooltip)
        addLocationButton->setText(QString());
#if QT_CONFIG(tooltip)
        removeLocationButton->setToolTip(QCoreApplication::translate("FilesDock", "Remove the selected location", nullptr));
#endif // QT_CONFIG(tooltip)
        removeLocationButton->setText(QString());
#if QT_CONFIG(tooltip)
        tableView->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class FilesDock: public Ui_FilesDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FILESDOCK_H
