/****************************************************************************
** Meta object code from reading C++ file 'multitrackmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/models/multitrackmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multitrackmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15MultitrackModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MultitrackModel::qt_create_metaobjectdata<qt_meta_tag_ZN15MultitrackModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MultitrackModel",
        "created",
        "",
        "aboutToClose",
        "closed",
        "modified",
        "seeked",
        "position",
        "seekPlayer",
        "trackHeightChanged",
        "trackHeaderWidthChanged",
        "scaleFactorChanged",
        "showStatusMessage",
        "durationChanged",
        "filteredChanged",
        "reloadRequested",
        "appended",
        "trackIndex",
        "clipIndex",
        "inserted",
        "overWritten",
        "removing",
        "Mlt::Service*",
        "service",
        "noMoreEmptyTracks",
        "isAudio",
        "refreshTrackList",
        "setTrackName",
        "row",
        "value",
        "setTrackMute",
        "mute",
        "setTrackHidden",
        "hidden",
        "setTrackComposite",
        "composite",
        "setTrackLock",
        "lock",
        "trimClipIn",
        "delta",
        "ripple",
        "rippleAllTracks",
        "notifyClipIn",
        "trimClipOut",
        "notifyClipOut",
        "moveClip",
        "fromTrack",
        "toTrack",
        "overwriteClip",
        "Mlt::Producer&",
        "clip",
        "seek",
        "overwrite",
        "notify",
        "insertClip",
        "appendClip",
        "removeClip",
        "liftClip",
        "splitClip",
        "joinClips",
        "changeGain",
        "gain",
        "fadeIn",
        "duration",
        "fadeOut",
        "addTransitionValid",
        "addTransition",
        "removeTransition",
        "removeTransitionByTrimIn",
        "removeTransitionByTrimOut",
        "trimTransitionInValid",
        "trimTransitionIn",
        "slip",
        "trimTransitionOutValid",
        "trimTransitionOut",
        "resizeTransitionValid",
        "transitionIndex",
        "addTransitionByTrimInValid",
        "addTransitionByTrimIn",
        "addTransitionByTrimOutValid",
        "addTransitionByTrimOut",
        "removeTransitionByTrimInValid",
        "removeTransitionByTrimOutValid",
        "filterAddedOrRemoved",
        "Mlt::Producer*",
        "producer",
        "onFilterChanged",
        "reload",
        "asynchronous",
        "replace",
        "copyFilters",
        "adjustBackgroundDuration",
        "adjustTrackFilters",
        "audioLevelsReady",
        "QPersistentModelIndex",
        "index",
        "trackHeight",
        "trackHeaderWidth",
        "scaleFactor",
        "filtered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'created'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToClose'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(int, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'trackHeightChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackHeaderWidthChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleFactorChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showStatusMessage'
        QtMocHelpers::SignalData<void(QString)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filteredChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reloadRequested'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appended'
        QtMocHelpers::SignalData<void(int, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'inserted'
        QtMocHelpers::SignalData<void(int, int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'overWritten'
        QtMocHelpers::SignalData<void(int, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'removing'
        QtMocHelpers::SignalData<void(Mlt::Service *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'noMoreEmptyTracks'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'refreshTrackList'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTrackName'
        QtMocHelpers::SlotData<void(int, const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'setTrackMute'
        QtMocHelpers::SlotData<void(int, bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'setTrackHidden'
        QtMocHelpers::SlotData<void(int, bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'setTrackComposite'
        QtMocHelpers::SlotData<void(int, bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'setTrackLock'
        QtMocHelpers::SlotData<void(int, bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Bool, 37 },
        }}),
        // Slot 'trimClipIn'
        QtMocHelpers::SlotData<int(int, int, int, bool, bool)>(38, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 }, { QMetaType::Bool, 40 },
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'notifyClipIn'
        QtMocHelpers::SlotData<void(int, int)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'trimClipOut'
        QtMocHelpers::SlotData<int(int, int, int, bool, bool)>(43, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 }, { QMetaType::Bool, 40 },
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'notifyClipOut'
        QtMocHelpers::SlotData<void(int, int)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'moveClip'
        QtMocHelpers::SlotData<bool(int, int, int, int, bool, bool)>(45, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 46 }, { QMetaType::Int, 47 }, { QMetaType::Int, 18 }, { QMetaType::Int, 7 },
            { QMetaType::Bool, 40 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'overwriteClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &, int, bool)>(48, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'overwriteClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &, int)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'overwrite'
        QtMocHelpers::SlotData<QString(int, Mlt::Producer &, int, bool, bool)>(52, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 51 },
            { QMetaType::Bool, 53 },
        }}),
        // Slot 'overwrite'
        QtMocHelpers::SlotData<QString(int, Mlt::Producer &, int, bool)>(52, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'overwrite'
        QtMocHelpers::SlotData<QString(int, Mlt::Producer &, int)>(52, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'insertClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &, int, bool, bool, bool)>(54, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 41 },
            { QMetaType::Bool, 51 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'insertClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &, int, bool, bool)>(54, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 41 },
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'insertClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &, int, bool)>(54, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'appendClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &, bool, bool)>(55, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Bool, 51 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'appendClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &, bool)>(55, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'appendClip'
        QtMocHelpers::SlotData<int(int, Mlt::Producer &)>(55, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { 0x80000000 | 49, 50 },
        }}),
        // Slot 'removeClip'
        QtMocHelpers::SlotData<void(int, int, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'liftClip'
        QtMocHelpers::SlotData<void(int, int)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'splitClip'
        QtMocHelpers::SlotData<void(int, int, int)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'joinClips'
        QtMocHelpers::SlotData<void(int, int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'changeGain'
        QtMocHelpers::SlotData<void(int, int, double)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Double, 61 },
        }}),
        // Slot 'fadeIn'
        QtMocHelpers::SlotData<void(int, int, int)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 63 },
        }}),
        // Slot 'fadeOut'
        QtMocHelpers::SlotData<void(int, int, int)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 63 },
        }}),
        // Slot 'addTransitionValid'
        QtMocHelpers::SlotData<bool(int, int, int, int, bool)>(65, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 46 }, { QMetaType::Int, 47 }, { QMetaType::Int, 18 }, { QMetaType::Int, 7 },
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'addTransition'
        QtMocHelpers::SlotData<int(int, int, int, bool, bool)>(66, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 7 }, { QMetaType::Bool, 40 },
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'removeTransition'
        QtMocHelpers::SlotData<void(int, int)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'removeTransitionByTrimIn'
        QtMocHelpers::SlotData<void(int, int, int)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'removeTransitionByTrimOut'
        QtMocHelpers::SlotData<void(int, int, int)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'trimTransitionInValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(70, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'trimTransitionIn'
        QtMocHelpers::SlotData<void(int, int, int, bool)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 }, { QMetaType::Bool, 72 },
        }}),
        // Slot 'trimTransitionIn'
        QtMocHelpers::SlotData<void(int, int, int)>(71, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'trimTransitionOutValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(73, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'trimTransitionOut'
        QtMocHelpers::SlotData<void(int, int, int, bool)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 }, { QMetaType::Bool, 72 },
        }}),
        // Slot 'trimTransitionOut'
        QtMocHelpers::SlotData<void(int, int, int)>(74, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'resizeTransitionValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(75, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 76 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'addTransitionByTrimInValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(77, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'addTransitionByTrimIn'
        QtMocHelpers::SlotData<int(int, int, int)>(78, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'addTransitionByTrimOutValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(79, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'addTransitionByTrimOut'
        QtMocHelpers::SlotData<void(int, int, int)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'removeTransitionByTrimInValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(81, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'removeTransitionByTrimOutValid'
        QtMocHelpers::SlotData<bool(int, int, int)>(82, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'filterAddedOrRemoved'
        QtMocHelpers::SlotData<void(Mlt::Producer *)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 84, 85 },
        }}),
        // Slot 'onFilterChanged'
        QtMocHelpers::SlotData<void(Mlt::Service *)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 88 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'replace'
        QtMocHelpers::SlotData<void(int, int, Mlt::Producer &, bool)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { 0x80000000 | 49, 50 }, { QMetaType::Bool, 90 },
        }}),
        // Slot 'replace'
        QtMocHelpers::SlotData<void(int, int, Mlt::Producer &)>(89, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { 0x80000000 | 49, 50 },
        }}),
        // Slot 'adjustBackgroundDuration'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'adjustTrackFilters'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'audioLevelsReady'
        QtMocHelpers::MethodData<void(const QPersistentModelIndex &)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 94, 95 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'trackHeight'
        QtMocHelpers::PropertyData<int>(96, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'trackHeaderWidth'
        QtMocHelpers::PropertyData<int>(97, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'scaleFactor'
        QtMocHelpers::PropertyData<double>(98, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'filtered'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MultitrackModel, qt_meta_tag_ZN15MultitrackModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MultitrackModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MultitrackModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MultitrackModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15MultitrackModelE_t>.metaTypes,
    nullptr
} };

void MultitrackModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultitrackModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->created(); break;
        case 1: _t->aboutToClose(); break;
        case 2: _t->closed(); break;
        case 3: _t->modified(); break;
        case 4: _t->seeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->seeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->trackHeightChanged(); break;
        case 7: _t->trackHeaderWidthChanged(); break;
        case 8: _t->scaleFactorChanged(); break;
        case 9: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->durationChanged(); break;
        case 11: _t->filteredChanged(); break;
        case 12: _t->reloadRequested(); break;
        case 13: _t->appended((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->inserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->overWritten((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->removing((*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[1]))); break;
        case 17: _t->noMoreEmptyTracks((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->refreshTrackList(); break;
        case 19: _t->setTrackName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->setTrackMute((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->setTrackHidden((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 22: _t->setTrackComposite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 23: _t->setTrackLock((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 24: { int _r = _t->trimClipIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->notifyClipIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 26: { int _r = _t->trimClipOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->notifyClipOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: { bool _r = _t->moveClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { int _r = _t->overwriteClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 30: { int _r = _t->overwriteClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 31: { QString _r = _t->overwrite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 32: { QString _r = _t->overwrite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 33: { QString _r = _t->overwrite((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 34: { int _r = _t->insertClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 35: { int _r = _t->insertClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 36: { int _r = _t->insertClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 37: { int _r = _t->appendClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 38: { int _r = _t->appendClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 39: { int _r = _t->appendClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 40: _t->removeClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 41: _t->liftClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 42: _t->splitClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 43: _t->joinClips((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 44: _t->changeGain((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 45: _t->fadeIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 46: _t->fadeOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 47: { bool _r = _t->addTransitionValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: { int _r = _t->addTransition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->removeTransition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 50: _t->removeTransitionByTrimIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 51: _t->removeTransitionByTrimOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 52: { bool _r = _t->trimTransitionInValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->trimTransitionIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 54: _t->trimTransitionIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 55: { bool _r = _t->trimTransitionOutValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 56: _t->trimTransitionOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 57: _t->trimTransitionOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 58: { bool _r = _t->resizeTransitionValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: { bool _r = _t->addTransitionByTrimInValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 60: { int _r = _t->addTransitionByTrimIn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 61: { bool _r = _t->addTransitionByTrimOutValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->addTransitionByTrimOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 63: { bool _r = _t->removeTransitionByTrimInValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 64: { bool _r = _t->removeTransitionByTrimOutValid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 65: _t->filterAddedOrRemoved((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 66: _t->onFilterChanged((*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[1]))); break;
        case 67: _t->reload((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 68: _t->reload(); break;
        case 69: _t->replace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 70: _t->replace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[3]))); break;
        case 71: _t->adjustBackgroundDuration(); break;
        case 72: _t->adjustTrackFilters(); break;
        case 73: _t->audioLevelsReady((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::created, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::aboutToClose, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::closed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::modified, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)(int , bool )>(_a, &MultitrackModel::seeked, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::trackHeightChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::trackHeaderWidthChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::scaleFactorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)(QString )>(_a, &MultitrackModel::showStatusMessage, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::durationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::filteredChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)()>(_a, &MultitrackModel::reloadRequested, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)(int , int )>(_a, &MultitrackModel::appended, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)(int , int )>(_a, &MultitrackModel::inserted, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)(int , int )>(_a, &MultitrackModel::overWritten, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)(Mlt::Service * )>(_a, &MultitrackModel::removing, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultitrackModel::*)(bool )>(_a, &MultitrackModel::noMoreEmptyTracks, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->trackHeight(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->trackHeaderWidth(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->scaleFactor(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isFiltered(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTrackHeight(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setTrackHeaderWidth(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setScaleFactor(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MultitrackModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MultitrackModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MultitrackModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int MultitrackModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 74)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 74;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 74)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 74;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void MultitrackModel::created()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MultitrackModel::aboutToClose()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MultitrackModel::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MultitrackModel::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MultitrackModel::seeked(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 6
void MultitrackModel::trackHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MultitrackModel::trackHeaderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MultitrackModel::scaleFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MultitrackModel::showStatusMessage(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void MultitrackModel::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MultitrackModel::filteredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MultitrackModel::reloadRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MultitrackModel::appended(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void MultitrackModel::inserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void MultitrackModel::overWritten(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void MultitrackModel::removing(Mlt::Service * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void MultitrackModel::noMoreEmptyTracks(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}
QT_WARNING_POP
