/********************************************************************************
** Form generated from reading UI file 'customprofiledialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMPROFILEDIALOG_H
#define UI_CUSTOMPROFILEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CustomProfileDialog
{
public:
    QVBoxLayout *verticalLayout;
    QWidget *widget;
    QGridLayout *gridLayout_2;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *colorspaceCombo;
    QSpacerItem *horizontalSpacer;
    QLabel *label_22;
    QLineEdit *nameEdit;
    QHBoxLayout *horizontalLayout_8;
    QSpinBox *aspectNumSpinner;
    QLabel *label_16;
    QSpinBox *aspectDenSpinner;
    QComboBox *aspectRatioComboBox;
    QSpacerItem *horizontalSpacer_8;
    QLabel *label;
    QHBoxLayout *horizontalLayout_9;
    QComboBox *scanModeCombo;
    QSpacerItem *horizontalSpacer_9;
    QLabel *label_13;
    QHBoxLayout *horizontalLayout_7;
    QSpinBox *widthSpinner;
    QLabel *label_11;
    QSpinBox *heightSpinner;
    QComboBox *resolutionComboBox;
    QSpacerItem *horizontalSpacer_7;
    QLabel *label_10;
    QHBoxLayout *horizontalLayout_16;
    QDoubleSpinBox *fpsSpinner;
    QComboBox *fpsComboBox;
    QSpacerItem *horizontalSpacer_16;
    QLabel *label_14;
    QLabel *dynamicRangeLabel;
    QHBoxLayout *horizontalLayout_10;
    QComboBox *dynamicRangeCombo;
    QSpacerItem *horizontalSpacer_10;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CustomProfileDialog)
    {
        if (CustomProfileDialog->objectName().isEmpty())
            CustomProfileDialog->setObjectName("CustomProfileDialog");
        CustomProfileDialog->resize(496, 410);
#if QT_CONFIG(whatsthis)
        CustomProfileDialog->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/settings-video-mode/12790#p-40331-custom-3"));
#endif // QT_CONFIG(whatsthis)
        CustomProfileDialog->setModal(true);
        verticalLayout = new QVBoxLayout(CustomProfileDialog);
        verticalLayout->setObjectName("verticalLayout");
        widget = new QWidget(CustomProfileDialog);
        widget->setObjectName("widget");
        gridLayout_2 = new QGridLayout(widget);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setVerticalSpacing(3);
        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_2, 7, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        colorspaceCombo = new QComboBox(widget);
        colorspaceCombo->addItem(QString::fromUtf8("ITU-R BT.601"));
        colorspaceCombo->addItem(QString::fromUtf8("ITU-R BT.709"));
        colorspaceCombo->addItem(QString());
        colorspaceCombo->setObjectName("colorspaceCombo");

        horizontalLayout_2->addWidget(colorspaceCombo);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout_2, 7, 1, 1, 2);

        label_22 = new QLabel(widget);
        label_22->setObjectName("label_22");
        label_22->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_22, 2, 0, 1, 1);

        nameEdit = new QLineEdit(widget);
        nameEdit->setObjectName("nameEdit");

        gridLayout_2->addWidget(nameEdit, 0, 1, 1, 2);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        aspectNumSpinner = new QSpinBox(widget);
        aspectNumSpinner->setObjectName("aspectNumSpinner");
        aspectNumSpinner->setMinimum(1);
        aspectNumSpinner->setMaximum(8640);
        aspectNumSpinner->setValue(16);

        horizontalLayout_8->addWidget(aspectNumSpinner);

        label_16 = new QLabel(widget);
        label_16->setObjectName("label_16");

        horizontalLayout_8->addWidget(label_16);

        aspectDenSpinner = new QSpinBox(widget);
        aspectDenSpinner->setObjectName("aspectDenSpinner");
        aspectDenSpinner->setMinimum(1);
        aspectDenSpinner->setMaximum(8640);
        aspectDenSpinner->setValue(9);

        horizontalLayout_8->addWidget(aspectDenSpinner);

        aspectRatioComboBox = new QComboBox(widget);
        aspectRatioComboBox->addItem(QString::fromUtf8("16:9 (wide)"));
        aspectRatioComboBox->addItem(QString::fromUtf8("4:3 (SD)"));
        aspectRatioComboBox->addItem(QString::fromUtf8("9:16 (vertical)"));
        aspectRatioComboBox->addItem(QString::fromUtf8("1:1 (square)"));
        aspectRatioComboBox->addItem(QString::fromUtf8("1.90:1 (DCI)"));
        aspectRatioComboBox->setObjectName("aspectRatioComboBox");
        aspectRatioComboBox->setMaximumSize(QSize(20, 16777215));

        horizontalLayout_8->addWidget(aspectRatioComboBox);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_8);


        gridLayout_2->addLayout(horizontalLayout_8, 3, 1, 1, 2);

        label = new QLabel(widget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        scanModeCombo = new QComboBox(widget);
        scanModeCombo->addItem(QString());
        scanModeCombo->addItem(QString());
        scanModeCombo->setObjectName("scanModeCombo");

        horizontalLayout_9->addWidget(scanModeCombo);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_9);


        gridLayout_2->addLayout(horizontalLayout_9, 6, 1, 1, 2);

        label_13 = new QLabel(widget);
        label_13->setObjectName("label_13");
        label_13->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_13, 3, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        widthSpinner = new QSpinBox(widget);
        widthSpinner->setObjectName("widthSpinner");
        widthSpinner->setMinimum(16);
        widthSpinner->setMaximum(8640);
        widthSpinner->setSingleStep(2);
        widthSpinner->setValue(1280);

        horizontalLayout_7->addWidget(widthSpinner);

        label_11 = new QLabel(widget);
        label_11->setObjectName("label_11");

        horizontalLayout_7->addWidget(label_11);

        heightSpinner = new QSpinBox(widget);
        heightSpinner->setObjectName("heightSpinner");
        heightSpinner->setMinimum(1);
        heightSpinner->setMaximum(8640);
        heightSpinner->setSingleStep(2);
        heightSpinner->setValue(720);

        horizontalLayout_7->addWidget(heightSpinner);

        resolutionComboBox = new QComboBox(widget);
        resolutionComboBox->addItem(QString::fromUtf8("1280 x 720 (HD)"));
        resolutionComboBox->addItem(QString::fromUtf8("1920 x 1080 (FHD)"));
        resolutionComboBox->addItem(QString::fromUtf8("2048 x 1080 (DCI 2K)"));
        resolutionComboBox->addItem(QString::fromUtf8("2560 x 1440 (QHD 2K)"));
        resolutionComboBox->addItem(QString::fromUtf8("2704 x 1520 (2.7K)"));
        resolutionComboBox->addItem(QString::fromUtf8("3840 x 2160 (UHD 4K)"));
        resolutionComboBox->addItem(QString::fromUtf8("4096 x 2160 (DCI 4K)"));
        resolutionComboBox->addItem(QString::fromUtf8("5120 x 2880 (5K)"));
        resolutionComboBox->setObjectName("resolutionComboBox");
        resolutionComboBox->setMaximumSize(QSize(20, 16777215));

        horizontalLayout_7->addWidget(resolutionComboBox);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_7);


        gridLayout_2->addLayout(horizontalLayout_7, 2, 1, 1, 2);

        label_10 = new QLabel(widget);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_10, 5, 0, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        fpsSpinner = new QDoubleSpinBox(widget);
        fpsSpinner->setObjectName("fpsSpinner");
        fpsSpinner->setDecimals(6);
        fpsSpinner->setMinimum(1.000000000000000);
        fpsSpinner->setMaximum(1000.000000000000000);
        fpsSpinner->setValue(25.000000000000000);

        horizontalLayout_16->addWidget(fpsSpinner);

        fpsComboBox = new QComboBox(widget);
        fpsComboBox->addItem(QString::fromUtf8("23.976024"));
        fpsComboBox->addItem(QString::fromUtf8("24"));
        fpsComboBox->addItem(QString::fromUtf8("25"));
        fpsComboBox->addItem(QString::fromUtf8("29.970030"));
        fpsComboBox->addItem(QString::fromUtf8("30"));
        fpsComboBox->addItem(QString::fromUtf8("48"));
        fpsComboBox->addItem(QString::fromUtf8("50"));
        fpsComboBox->addItem(QString::fromUtf8("59.940060"));
        fpsComboBox->addItem(QString::fromUtf8("60"));
        fpsComboBox->setObjectName("fpsComboBox");
        fpsComboBox->setMaximumSize(QSize(20, 16777215));

        horizontalLayout_16->addWidget(fpsComboBox);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_16);


        gridLayout_2->addLayout(horizontalLayout_16, 5, 1, 1, 2);

        label_14 = new QLabel(widget);
        label_14->setObjectName("label_14");
        label_14->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_14, 6, 0, 1, 1);

        dynamicRangeLabel = new QLabel(widget);
        dynamicRangeLabel->setObjectName("dynamicRangeLabel");
        dynamicRangeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(dynamicRangeLabel, 8, 0, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        dynamicRangeCombo = new QComboBox(widget);
        dynamicRangeCombo->addItem(QString::fromUtf8("SDR"));
        dynamicRangeCombo->addItem(QString::fromUtf8("HLG HDR"));
        dynamicRangeCombo->addItem(QString::fromUtf8("PQ HDR"));
        dynamicRangeCombo->setObjectName("dynamicRangeCombo");

        horizontalLayout_10->addWidget(dynamicRangeCombo);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_10);


        gridLayout_2->addLayout(horizontalLayout_10, 8, 1, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 10, 0, 1, 1);

        label_3 = new QLabel(widget);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);
        label_3->setScaledContents(true);
        label_3->setWordWrap(true);
        label_3->setTextInteractionFlags(Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        gridLayout_2->addWidget(label_3, 1, 0, 1, 3);


        verticalLayout->addWidget(widget);

        buttonBox = new QDialogButtonBox(CustomProfileDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(colorspaceCombo);
        label_22->setBuddy(widthSpinner);
        label->setBuddy(nameEdit);
        label_13->setBuddy(aspectNumSpinner);
        label_10->setBuddy(fpsSpinner);
        label_14->setBuddy(scanModeCombo);
        dynamicRangeLabel->setBuddy(dynamicRangeCombo);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(nameEdit, widthSpinner);
        QWidget::setTabOrder(widthSpinner, heightSpinner);
        QWidget::setTabOrder(heightSpinner, aspectNumSpinner);
        QWidget::setTabOrder(aspectNumSpinner, aspectDenSpinner);
        QWidget::setTabOrder(aspectDenSpinner, fpsSpinner);
        QWidget::setTabOrder(fpsSpinner, scanModeCombo);
        QWidget::setTabOrder(scanModeCombo, colorspaceCombo);
        QWidget::setTabOrder(colorspaceCombo, buttonBox);

        retranslateUi(CustomProfileDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CustomProfileDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CustomProfileDialog, qOverload<>(&QDialog::reject));

        colorspaceCombo->setCurrentIndex(1);
        scanModeCombo->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(CustomProfileDialog);
    } // setupUi

    void retranslateUi(QDialog *CustomProfileDialog)
    {
        CustomProfileDialog->setWindowTitle(QCoreApplication::translate("CustomProfileDialog", "Add Custom Video Mode", nullptr));
        label_2->setText(QCoreApplication::translate("CustomProfileDialog", "Colorspace", nullptr));
        colorspaceCombo->setItemText(2, QCoreApplication::translate("CustomProfileDialog", "ITU-R BT.2020", nullptr));

        label_22->setText(QCoreApplication::translate("CustomProfileDialog", "Resolution", nullptr));
        label_16->setText(QCoreApplication::translate("CustomProfileDialog", ":", nullptr));

        label->setText(QCoreApplication::translate("CustomProfileDialog", "Name", nullptr));
        scanModeCombo->setItemText(0, QCoreApplication::translate("CustomProfileDialog", "Interlaced", nullptr));
        scanModeCombo->setItemText(1, QCoreApplication::translate("CustomProfileDialog", "Progressive", nullptr));

        label_13->setText(QCoreApplication::translate("CustomProfileDialog", "Aspect ratio", nullptr));
        label_11->setText(QCoreApplication::translate("CustomProfileDialog", "x", nullptr));

        label_10->setText(QCoreApplication::translate("CustomProfileDialog", "Frames/sec", nullptr));

        label_14->setText(QCoreApplication::translate("CustomProfileDialog", "Scan mode", nullptr));
        dynamicRangeLabel->setText(QCoreApplication::translate("CustomProfileDialog", "Dynamic range", nullptr));

        label_3->setText(QCoreApplication::translate("CustomProfileDialog", "<small>(Leave Name blank to skip saving a preset and use a temporary or project-specific Video Mode.)</small>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CustomProfileDialog: public Ui_CustomProfileDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CUSTOMPROFILEDIALOG_H
