/********************************************************************************
** Form generated from reading UI file 'networkproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NETWORKPRODUCERWIDGET_H
#define UI_NETWORKPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_NetworkProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    ServicePresetWidget *preset;
    QGridLayout *gridLayout;
    QLabel *label_6;
    QLineEdit *urlLineEdit;
    QPushButton *applyButton;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *NetworkProducerWidget)
    {
        if (NetworkProducerWidget->objectName().isEmpty())
            NetworkProducerWidget->setObjectName("NetworkProducerWidget");
        NetworkProducerWidget->resize(394, 294);
#if QT_CONFIG(whatsthis)
        NetworkProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-network/12936/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(NetworkProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(NetworkProducerWidget);
        label_2->setObjectName("label_2");
        QFont font;
        font.setBold(true);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label_2);

        preset = new ServicePresetWidget(NetworkProducerWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_6 = new QLabel(NetworkProducerWidget);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_6, 0, 0, 1, 1);

        urlLineEdit = new QLineEdit(NetworkProducerWidget);
        urlLineEdit->setObjectName("urlLineEdit");

        gridLayout->addWidget(urlLineEdit, 0, 2, 1, 1);

        applyButton = new QPushButton(NetworkProducerWidget);
        applyButton->setObjectName("applyButton");

        gridLayout->addWidget(applyButton, 1, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer_2 = new QSpacerItem(20, 263, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

#if QT_CONFIG(shortcut)
        label_6->setBuddy(urlLineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(NetworkProducerWidget);

        QMetaObject::connectSlotsByName(NetworkProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *NetworkProducerWidget)
    {
        NetworkProducerWidget->setWindowTitle(QCoreApplication::translate("NetworkProducerWidget", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("NetworkProducerWidget", "Network Stream", nullptr));
        label_6->setText(QCoreApplication::translate("NetworkProducerWidget", "&URL", nullptr));
        applyButton->setText(QCoreApplication::translate("NetworkProducerWidget", "Apply", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NetworkProducerWidget: public Ui_NetworkProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NETWORKPRODUCERWIDGET_H
