/****************************************************************************
** Meta object code from reading C++ file 'qmlapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/qmltypes/qmlapplication.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14QmlApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlApplication::qt_create_metaobjectdata<qt_meta_tag_ZN14QmlApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlApplication",
        "paletteChanged",
        "",
        "filtersCopied",
        "filtersPasted",
        "Mlt::Producer*",
        "copyAllFilters",
        "copyEnabledFilters",
        "copyCurrentFilter",
        "clockFromFrames",
        "frames",
        "timeFromFrames",
        "audioChannels",
        "getNextProjectFile",
        "filename",
        "isProjectFolder",
        "showStatusMessage",
        "message",
        "timeoutSeconds",
        "showAddOnFiltersDialog",
        "confirmOutputFilter",
        "contrastingColor",
        "QColor",
        "color",
        "addWipe",
        "filePath",
        "intersects",
        "QRectF",
        "a",
        "b",
        "actionFirstShortcut",
        "actionName",
        "dialogModality",
        "Qt::WindowModality",
        "mousePos",
        "QPoint",
        "toolTipBaseColor",
        "toolTipTextColor",
        "OS",
        "mainWinRect",
        "QRect",
        "hasFiltersOnClipboard",
        "devicePixelRatio",
        "maxTextureSize",
        "wipes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filtersCopied'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filtersPasted'
        QtMocHelpers::SignalData<void(Mlt::Producer *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Method 'copyAllFilters'
        QtMocHelpers::MethodData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyEnabledFilters'
        QtMocHelpers::MethodData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyCurrentFilter'
        QtMocHelpers::MethodData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'clockFromFrames'
        QtMocHelpers::MethodData<QString(int)>(9, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'timeFromFrames'
        QtMocHelpers::MethodData<QString(int)>(11, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'audioChannels'
        QtMocHelpers::MethodData<int()>(12, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'getNextProjectFile'
        QtMocHelpers::MethodData<QString(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'isProjectFolder'
        QtMocHelpers::MethodData<bool()>(15, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'showStatusMessage'
        QtMocHelpers::MethodData<void(const QString &, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
        }}),
        // Method 'showStatusMessage'
        QtMocHelpers::MethodData<void(const QString &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'showAddOnFiltersDialog'
        QtMocHelpers::MethodData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'confirmOutputFilter'
        QtMocHelpers::MethodData<bool()>(20, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'contrastingColor'
        QtMocHelpers::MethodData<QColor(QString)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 23 },
        }}),
        // Method 'addWipe'
        QtMocHelpers::MethodData<bool(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'intersects'
        QtMocHelpers::MethodData<bool(const QRectF &, const QRectF &)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 27, 28 }, { 0x80000000 | 27, 29 },
        }}),
        // Method 'actionFirstShortcut'
        QtMocHelpers::MethodData<QString(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dialogModality'
        QtMocHelpers::PropertyData<Qt::WindowModality>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mousePos'
        QtMocHelpers::PropertyData<QPoint>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'toolTipBaseColor'
        QtMocHelpers::PropertyData<QColor>(36, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'toolTipTextColor'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'OS'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mainWinRect'
        QtMocHelpers::PropertyData<QRect>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'hasFiltersOnClipboard'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'devicePixelRatio'
        QtMocHelpers::PropertyData<qreal>(42, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxTextureSize'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wipes'
        QtMocHelpers::PropertyData<QStringList>(44, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlApplication, qt_meta_tag_ZN14QmlApplicationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QmlApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QmlApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QmlApplicationE_t>.metaTypes,
    nullptr
} };

void QmlApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->paletteChanged(); break;
        case 1: _t->filtersCopied(); break;
        case 2: _t->filtersPasted((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 3: _t->copyAllFilters(); break;
        case 4: _t->copyEnabledFilters(); break;
        case 5: _t->copyCurrentFilter(); break;
        case 6: { QString _r = _t->clockFromFrames((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->timeFromFrames((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->audioChannels();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->getNextProjectFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->isProjectFolder();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->showAddOnFiltersDialog(); break;
        case 14: { bool _r = _t->confirmOutputFilter();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { QColor _r = _t->contrastingColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->addWipe((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->intersects((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->actionFirstShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlApplication::*)()>(_a, &QmlApplication::paletteChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlApplication::*)()>(_a, &QmlApplication::filtersCopied, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlApplication::*)(Mlt::Producer * )>(_a, &QmlApplication::filtersPasted, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Qt::WindowModality*>(_v) = _t->dialogModality(); break;
        case 1: *reinterpret_cast<QPoint*>(_v) = _t->mousePos(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->toolTipBaseColor(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->toolTipTextColor(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->OS(); break;
        case 5: *reinterpret_cast<QRect*>(_v) = _t->mainWinRect(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasFiltersOnClipboard(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->devicePixelRatio(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->maxTextureSize(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->wipes(); break;
        default: break;
        }
    }
}

const QMetaObject *QmlApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QmlApplicationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void QmlApplication::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QmlApplication::filtersCopied()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QmlApplication::filtersPasted(Mlt::Producer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
