/********************************************************************************
** Form generated from reading UI file 'addencodepresetdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDENCODEPRESETDIALOG_H
#define UI_ADDENCODEPRESETDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AddEncodePresetDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *nameEdit;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_3;
    QLineEdit *extensionEdit;
    QSpacerItem *horizontalSpacer_2;
    QPlainTextEdit *propertiesEdit;
    QLabel *label_2;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AddEncodePresetDialog)
    {
        if (AddEncodePresetDialog->objectName().isEmpty())
            AddEncodePresetDialog->setObjectName("AddEncodePresetDialog");
        AddEncodePresetDialog->setWindowModality(Qt::WindowModal);
        AddEncodePresetDialog->resize(400, 350);
        verticalLayout = new QVBoxLayout(AddEncodePresetDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(AddEncodePresetDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        nameEdit = new QLineEdit(AddEncodePresetDialog);
        nameEdit->setObjectName("nameEdit");

        horizontalLayout->addWidget(nameEdit);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_3 = new QLabel(AddEncodePresetDialog);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        extensionEdit = new QLineEdit(AddEncodePresetDialog);
        extensionEdit->setObjectName("extensionEdit");

        horizontalLayout_2->addWidget(extensionEdit);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        propertiesEdit = new QPlainTextEdit(AddEncodePresetDialog);
        propertiesEdit->setObjectName("propertiesEdit");

        verticalLayout->addWidget(propertiesEdit);

        label_2 = new QLabel(AddEncodePresetDialog);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout->addWidget(label_2);

        verticalSpacer = new QSpacerItem(20, 7, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(AddEncodePresetDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(nameEdit, extensionEdit);
        QWidget::setTabOrder(extensionEdit, propertiesEdit);
        QWidget::setTabOrder(propertiesEdit, buttonBox);

        retranslateUi(AddEncodePresetDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AddEncodePresetDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AddEncodePresetDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AddEncodePresetDialog);
    } // setupUi

    void retranslateUi(QDialog *AddEncodePresetDialog)
    {
        AddEncodePresetDialog->setWindowTitle(QCoreApplication::translate("AddEncodePresetDialog", "Dialog", nullptr));
        label->setText(QCoreApplication::translate("AddEncodePresetDialog", "Name", nullptr));
        label_3->setText(QCoreApplication::translate("AddEncodePresetDialog", "File name extension", nullptr));
        extensionEdit->setPlaceholderText(QCoreApplication::translate("AddEncodePresetDialog", "for example, mp4", nullptr));
        label_2->setText(QCoreApplication::translate("AddEncodePresetDialog", "Make final changes to the preset including removing items you do not want to include, or copy/paste the clipboard.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddEncodePresetDialog: public Ui_AddEncodePresetDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDENCODEPRESETDIALOG_H
