/********************************************************************************
** Form generated from reading UI file 'avfoundationproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AVFOUNDATIONPRODUCERWIDGET_H
#define UI_AVFOUNDATIONPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AvfoundationProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGridLayout *gridLayout;
    QComboBox *videoCombo;
    QLabel *label_3;
    QComboBox *audioCombo;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AvfoundationProducerWidget)
    {
        if (AvfoundationProducerWidget->objectName().isEmpty())
            AvfoundationProducerWidget->setObjectName("AvfoundationProducerWidget");
        AvfoundationProducerWidget->resize(384, 284);
#if QT_CONFIG(whatsthis)
        AvfoundationProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-audio-video-device/12935/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(AvfoundationProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(AvfoundationProducerWidget);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);
        label->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        videoCombo = new QComboBox(AvfoundationProducerWidget);
        videoCombo->addItem(QString());
        videoCombo->setObjectName("videoCombo");

        gridLayout->addWidget(videoCombo, 1, 2, 1, 1);

        label_3 = new QLabel(AvfoundationProducerWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        audioCombo = new QComboBox(AvfoundationProducerWidget);
        audioCombo->addItem(QString());
        audioCombo->setObjectName("audioCombo");

        gridLayout->addWidget(audioCombo, 2, 2, 1, 1);

        label_2 = new QLabel(AvfoundationProducerWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 3, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 260, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(AvfoundationProducerWidget);

        QMetaObject::connectSlotsByName(AvfoundationProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *AvfoundationProducerWidget)
    {
        AvfoundationProducerWidget->setWindowTitle(QCoreApplication::translate("AvfoundationProducerWidget", "Form", nullptr));
        label->setText(QCoreApplication::translate("AvfoundationProducerWidget", "Audio/Video Device", nullptr));
        videoCombo->setItemText(0, QCoreApplication::translate("AvfoundationProducerWidget", "None", nullptr));

        label_3->setText(QCoreApplication::translate("AvfoundationProducerWidget", "Video Input", nullptr));
        audioCombo->setItemText(0, QCoreApplication::translate("AvfoundationProducerWidget", "None", nullptr));

        label_2->setText(QCoreApplication::translate("AvfoundationProducerWidget", "Audio Input", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AvfoundationProducerWidget: public Ui_AvfoundationProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AVFOUNDATIONPRODUCERWIDGET_H
