/********************************************************************************
** Form generated from reading UI file 'toneproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TONEPRODUCERWIDGET_H
#define UI_TONEPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ToneProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    ServicePresetWidget *preset;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *frequencySpinBox;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QSpinBox *levelSpinBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ToneProducerWidget)
    {
        if (ToneProducerWidget->objectName().isEmpty())
            ToneProducerWidget->setObjectName("ToneProducerWidget");
        ToneProducerWidget->resize(394, 294);
#if QT_CONFIG(whatsthis)
        ToneProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-audio-tone/12932/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(ToneProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(ToneProducerWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        preset = new ServicePresetWidget(ToneProducerWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ToneProducerWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        frequencySpinBox = new QSpinBox(ToneProducerWidget);
        frequencySpinBox->setObjectName("frequencySpinBox");
        frequencySpinBox->setMinimum(20);
        frequencySpinBox->setMaximum(20000);
        frequencySpinBox->setValue(1000);

        gridLayout->addWidget(frequencySpinBox, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        label_3 = new QLabel(ToneProducerWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        levelSpinBox = new QSpinBox(ToneProducerWidget);
        levelSpinBox->setObjectName("levelSpinBox");
        levelSpinBox->setMinimum(-90);
        levelSpinBox->setMaximum(0);
        levelSpinBox->setValue(0);

        gridLayout->addWidget(levelSpinBox, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ToneProducerWidget);

        QMetaObject::connectSlotsByName(ToneProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *ToneProducerWidget)
    {
        ToneProducerWidget->setWindowTitle(QCoreApplication::translate("ToneProducerWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("ToneProducerWidget", "Audio Tone", nullptr));
        label->setText(QCoreApplication::translate("ToneProducerWidget", "Frequency", nullptr));
        frequencySpinBox->setSuffix(QCoreApplication::translate("ToneProducerWidget", " Hz", nullptr));
        label_3->setText(QCoreApplication::translate("ToneProducerWidget", "Level", nullptr));
        levelSpinBox->setSuffix(QCoreApplication::translate("ToneProducerWidget", " dB", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ToneProducerWidget: public Ui_ToneProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TONEPRODUCERWIDGET_H
