/****************************************************************************
** Meta object code from reading C++ file 'filtercontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/controllers/filtercontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filtercontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16FilterControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto FilterController::qt_create_metaobjectdata<qt_meta_tag_ZN16FilterControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FilterController",
        "currentFilterChanged",
        "",
        "QmlFilter*",
        "filter",
        "QmlMetadata*",
        "meta",
        "index",
        "statusChanged",
        "filterChanged",
        "Mlt::Service*",
        "undoOrRedo",
        "setProducer",
        "Mlt::Producer*",
        "producer",
        "setCurrentFilter",
        "attachedIndex",
        "onFadeInChanged",
        "onFadeOutChanged",
        "onGainChanged",
        "onServiceInChanged",
        "delta",
        "service",
        "onServiceOutChanged",
        "removeCurrent",
        "onProducerChanged",
        "pauseUndoTracking",
        "resumeUndoTracking",
        "handleAddOnServicesChanged",
        "handleAttachedModelChange",
        "handleAttachedModelAboutToReset",
        "addMetadata",
        "handleAttachedRowsAboutToBeRemoved",
        "QModelIndex",
        "parent",
        "first",
        "last",
        "handleAttachedRowsRemoved",
        "handleAttachedRowsInserted",
        "handleAttachDuplicateFailed",
        "onQmlFilterChanged",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentFilterChanged'
        QtMocHelpers::SignalData<void(QmlFilter *, QmlMetadata *, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { QMetaType::Int, 7 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void(Mlt::Service *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'undoOrRedo'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<void(Mlt::Producer *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setCurrentFilter'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'onFadeInChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFadeOutChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onGainChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onServiceInChanged'
        QtMocHelpers::SlotData<void(int, Mlt::Service *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { 0x80000000 | 10, 22 },
        }}),
        // Slot 'onServiceInChanged'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'onServiceOutChanged'
        QtMocHelpers::SlotData<void(int, Mlt::Service *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { 0x80000000 | 10, 22 },
        }}),
        // Slot 'onServiceOutChanged'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'removeCurrent'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerChanged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pauseUndoTracking'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resumeUndoTracking'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleAddOnServicesChanged'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleAttachedModelChange'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleAttachedModelAboutToReset'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addMetadata'
        QtMocHelpers::SlotData<void(QmlMetadata *)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'handleAttachedRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::Int, 35 }, { QMetaType::Int, 36 },
        }}),
        // Slot 'handleAttachedRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::Int, 35 }, { QMetaType::Int, 36 },
        }}),
        // Slot 'handleAttachedRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::Int, 35 }, { QMetaType::Int, 36 },
        }}),
        // Slot 'handleAttachDuplicateFailed'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'onQmlFilterChanged'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FilterController, qt_meta_tag_ZN16FilterControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FilterController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FilterControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FilterControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16FilterControllerE_t>.metaTypes,
    nullptr
} };

void FilterController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilterController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentFilterChanged((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QmlMetadata*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->filterChanged((*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[1]))); break;
        case 3: _t->undoOrRedo(); break;
        case 4: _t->setProducer((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 5: _t->setProducer(); break;
        case 6: _t->setCurrentFilter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->onFadeInChanged(); break;
        case 8: _t->onFadeOutChanged(); break;
        case 9: _t->onGainChanged(); break;
        case 10: _t->onServiceInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[2]))); break;
        case 11: _t->onServiceInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->onServiceOutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[2]))); break;
        case 13: _t->onServiceOutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->removeCurrent(); break;
        case 15: _t->onProducerChanged(); break;
        case 16: _t->pauseUndoTracking(); break;
        case 17: _t->resumeUndoTracking(); break;
        case 18: _t->handleAddOnServicesChanged(); break;
        case 19: _t->handleAttachedModelChange(); break;
        case 20: _t->handleAttachedModelAboutToReset(); break;
        case 21: _t->addMetadata((*reinterpret_cast<std::add_pointer_t<QmlMetadata*>>(_a[1]))); break;
        case 22: _t->handleAttachedRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 23: _t->handleAttachedRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 24: _t->handleAttachedRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 25: _t->handleAttachDuplicateFailed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->onQmlFilterChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QmlFilter* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QmlMetadata* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QmlMetadata* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FilterController::*)(QmlFilter * , QmlMetadata * , int )>(_a, &FilterController::currentFilterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterController::*)(QString )>(_a, &FilterController::statusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterController::*)(Mlt::Service * )>(_a, &FilterController::filterChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterController::*)()>(_a, &FilterController::undoOrRedo, 3))
            return;
    }
}

const QMetaObject *FilterController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilterController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FilterControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FilterController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void FilterController::currentFilterChanged(QmlFilter * _t1, QmlMetadata * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void FilterController::statusChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FilterController::filterChanged(Mlt::Service * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FilterController::undoOrRedo()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
