/********************************************************************************
** Form generated from reading UI file 'systemsyncdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SYSTEMSYNCDIALOG_H
#define UI_SYSTEMSYNCDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SystemSyncDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGridLayout *gridLayout;
    QSlider *syncSlider;
    QPushButton *undoButton;
    QLabel *syncLabel;
    QPushButton *applyButton;
    QSpinBox *syncSpinBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SystemSyncDialog)
    {
        if (SystemSyncDialog->objectName().isEmpty())
            SystemSyncDialog->setObjectName("SystemSyncDialog");
        SystemSyncDialog->resize(546, 205);
        verticalLayout = new QVBoxLayout(SystemSyncDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(SystemSyncDialog);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        syncSlider = new QSlider(SystemSyncDialog);
        syncSlider->setObjectName("syncSlider");
        syncSlider->setMinimum(-250);
        syncSlider->setMaximum(250);
        syncSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(syncSlider, 0, 1, 1, 1);

        undoButton = new QPushButton(SystemSyncDialog);
        undoButton->setObjectName("undoButton");
        undoButton->setText(QString::fromUtf8(""));
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("edit-undo");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/edit-undo.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        undoButton->setIcon(icon);
        undoButton->setAutoDefault(false);

        gridLayout->addWidget(undoButton, 0, 3, 1, 1);

        syncLabel = new QLabel(SystemSyncDialog);
        syncLabel->setObjectName("syncLabel");
        syncLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(syncLabel, 0, 0, 1, 1);

        applyButton = new QPushButton(SystemSyncDialog);
        applyButton->setObjectName("applyButton");

        gridLayout->addWidget(applyButton, 1, 2, 1, 1);

        syncSpinBox = new QSpinBox(SystemSyncDialog);
        syncSpinBox->setObjectName("syncSpinBox");
        syncSpinBox->setMinimum(-250);
        syncSpinBox->setMaximum(250);

        gridLayout->addWidget(syncSpinBox, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 130, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(SystemSyncDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SystemSyncDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SystemSyncDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SystemSyncDialog, qOverload<>(&QDialog::reject));
        QObject::connect(syncSlider, &QSlider::valueChanged, syncSpinBox, &QSpinBox::setValue);

        QMetaObject::connectSlotsByName(SystemSyncDialog);
    } // setupUi

    void retranslateUi(QDialog *SystemSyncDialog)
    {
        SystemSyncDialog->setWindowTitle(QCoreApplication::translate("SystemSyncDialog", "Player Synchronization", nullptr));
        label->setText(QCoreApplication::translate("SystemSyncDialog", "Adjust your playback audio/video synchronization", nullptr));
#if QT_CONFIG(tooltip)
        undoButton->setToolTip(QCoreApplication::translate("SystemSyncDialog", "Reset to default value 0", nullptr));
#endif // QT_CONFIG(tooltip)
        syncLabel->setText(QCoreApplication::translate("SystemSyncDialog", "Video offset", nullptr));
        applyButton->setText(QCoreApplication::translate("SystemSyncDialog", "Apply", nullptr));
        syncSpinBox->setSuffix(QCoreApplication::translate("SystemSyncDialog", " ms", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SystemSyncDialog: public Ui_SystemSyncDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SYSTEMSYNCDIALOG_H
