/********************************************************************************
** Form generated from reading UI file 'encodedock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENCODEDOCK_H
#define UI_ENCODEDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/exportpresetstreeview.h"
#include "widgets/lineeditclear.h"

QT_BEGIN_NAMESPACE

class Ui_EncodeDock
{
public:
    QWidget *dockWidgetContents;
    QHBoxLayout *horizontalLayout_21;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_6;
    LineEditClear *presetsSearch;
    ExportPresetsTreeView *presetsTree;
    QHBoxLayout *horizontalLayout;
    QPushButton *addPresetButton;
    QPushButton *removePresetButton;
    QSpacerItem *horizontalSpacer_2;
    QVBoxLayout *verticalLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_3;
    QLabel *helpLabel;
    QGridLayout *gridLayout_5;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_14;
    QComboBox *formatCombo;
    QSpacerItem *horizontalSpacer_13;
    QLabel *formatLabel;
    QHBoxLayout *horizontalLayout_19;
    QComboBox *fromCombo;
    QSpacerItem *horizontalSpacer_23;
    QHBoxLayout *horizontalLayout_20;
    QCheckBox *hwencodeCheckBox;
    QPushButton *hwencodeButton;
    QSpacerItem *horizontalSpacer_25;
    QTabWidget *tabWidget;
    QWidget *modeTab;
    QGridLayout *gridLayout_6;
    QWidget *widget;
    QGridLayout *gridLayout_2;
    QLabel *reframeLabel;
    QHBoxLayout *horizontalLayout_22;
    QPushButton *reframeButton;
    QSpacerItem *horizontalSpacer_26;
    QHBoxLayout *resampleWarningLayout;
    QPushButton *resampleWarningIcon;
    QLabel *resampleWarningLabel;
    QHBoxLayout *horizontalLayout_16;
    QDoubleSpinBox *fpsSpinner;
    QComboBox *fpsComboBox;
    QSpacerItem *horizontalSpacer_16;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_18;
    QComboBox *interpolationCombo;
    QSpacerItem *horizontalSpacer_22;
    QLabel *label_15;
    QLabel *label_13;
    QLabel *label_2;
    QLabel *label_10;
    QLabel *label_14;
    QLabel *label_24;
    QCheckBox *parallelCheckbox;
    QLabel *label_22;
    QHBoxLayout *horizontalLayout_23;
    QComboBox *rangeComboBox;
    QSpacerItem *horizontalSpacer_27;
    QHBoxLayout *horizontalLayout_9;
    QComboBox *scanModeCombo;
    QSpacerItem *horizontalSpacer_9;
    QSpacerItem *verticalSpacer_4;
    QHBoxLayout *horizontalLayout_7;
    QSpinBox *widthSpinner;
    QLabel *label_11;
    QSpinBox *heightSpinner;
    QComboBox *resolutionComboBox;
    QSpacerItem *horizontalSpacer_7;
    QCheckBox *previewScaleCheckBox;
    QHBoxLayout *horizontalLayout_10;
    QComboBox *fieldOrderCombo;
    QSpacerItem *horizontalSpacer_10;
    QHBoxLayout *horizontalLayout_3;
    QComboBox *deinterlacerCombo;
    QSpacerItem *horizontalSpacer_21;
    QHBoxLayout *horizontalLayout_8;
    QSpinBox *aspectNumSpinner;
    QLabel *label_16;
    QSpinBox *aspectDenSpinner;
    QSpacerItem *horizontalSpacer_8;
    QWidget *videoTab;
    QGridLayout *gridLayout_3;
    QLabel *label_17;
    QHBoxLayout *horizontalLayout_11;
    QComboBox *videoCodecCombo;
    QPushButton *hdrMetaButton;
    QSpacerItem *horizontalSpacer_11;
    QLabel *label_18;
    QHBoxLayout *horizontalLayout_12;
    QSpinBox *gopSpinner;
    QLabel *label_19;
    QSpacerItem *horizontalSpacer_24;
    QCheckBox *strictGopCheckBox;
    QSpacerItem *horizontalSpacer_12;
    QHBoxLayout *videoBitrateLayout;
    QComboBox *videoBitrateCombo;
    QLabel *videoBitrateSuffixLabel;
    QSpacerItem *videoBitrateSpacer;
    QCheckBox *disableVideoCheckbox;
    QCheckBox *hwdecodeCheckBox;
    QCheckBox *dualPassCheckbox;
    QLabel *label_20;
    QHBoxLayout *horizontalLayout_13;
    QSpinBox *bFramesSpinner;
    QSpacerItem *horizontalSpacer_14;
    QSpacerItem *verticalSpacer;
    QLabel *label_12;
    QHBoxLayout *horizontalLayout_15;
    QSpinBox *videoCodecThreadsSpinner;
    QLabel *label_21;
    QSpacerItem *horizontalSpacer_15;
    QLabel *label_23;
    QHBoxLayout *horizontalLayout_17;
    QComboBox *videoRateControlCombo;
    QSpacerItem *horizontalSpacer_17;
    QLabel *videoBufferSizeLabel;
    QHBoxLayout *videoBufferSizeLayout;
    QDoubleSpinBox *videoBufferSizeSpinner;
    QLabel *videoBufferSizeSuffixLabel;
    QSpacerItem *horizontalSpacer_18;
    QLabel *videoQualityLabel;
    QHBoxLayout *videoQualityLayout;
    QSpinBox *videoQualitySpinner;
    QLabel *videoQualitySuffixLabel;
    QSpacerItem *horizontalSpacer_19;
    QLabel *videoBitrateLabel;
    QWidget *audioTab;
    QGridLayout *gridLayout;
    QLabel *channelsLabel;
    QHBoxLayout *ChannelsHorizontalLayout;
    QComboBox *audioChannelsCombo;
    QSpacerItem *channelsHorizontalSpacer;
    QHBoxLayout *horizontalLayout_4;
    QComboBox *sampleRateCombo;
    QLabel *label_9;
    QSpacerItem *horizontalSpacer_6;
    QLabel *label_8;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_6;
    QComboBox *audioCodecCombo;
    QSpacerItem *horizontalSpacer_3;
    QLabel *audioBitrateLabel;
    QHBoxLayout *audioBitrateLayout;
    QComboBox *audioBitrateCombo;
    QLabel *audioBitrateSuffixLabel;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *disableAudioCheckbox;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_5;
    QComboBox *audioRateControlCombo;
    QSpacerItem *horizontalSpacer_5;
    QLabel *audioQualityLabel;
    QHBoxLayout *audioQualityLayout;
    QSpinBox *audioQualitySpinner;
    QLabel *audioQualitySuffixLabel;
    QSpacerItem *horizontalSpacer_20;
    QWidget *metadataTab;
    QGridLayout *gridLayout_10;
    QLabel *coverArtLabel;
    QHBoxLayout *horizontalLayout_26;
    QLineEdit *coverArtLineEdit;
    QPushButton *coverArtButton;
    QLabel *metaTitleLabel;
    QLineEdit *metaTitleLineEdit;
    QLabel *metaArtistLabel;
    QLineEdit *metaArtistLineEdit;
    QLabel *metaCommentLabel;
    QLineEdit *metaCommentLineEdit;
    QLabel *metaCopyrightLabel;
    QLineEdit *metaCopyrightLineEdit;
    QLabel *metaDateLabel;
    QLineEdit *metaDateLineEdit;
    QLabel *metaDescriptionLabel;
    QLineEdit *metaDescriptionLineEdit;
    QLabel *metaGenreLabel;
    QLineEdit *metaGenreLineEdit;
    QLabel *metaLanguageLabel;
    QLineEdit *metaLanguageLineEdit;
    QCheckBox *disableSubtitlesCheckbox;
    QSpacerItem *metadataVerticalSpacer;
    QWidget *otherTab;
    QGridLayout *gridLayout_4;
    QPlainTextEdit *advancedTextEdit;
    QLabel *otherTipLabel;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *encodeButton;
    QPushButton *resetButton;
    QPushButton *advancedButton;
    QCheckBox *advancedCheckBox;
    QPushButton *streamButton;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *stopCaptureLayout;
    QPushButton *stopCaptureButton;
    QSpacerItem *stopCaptureSpacer;

    void setupUi(QDockWidget *EncodeDock)
    {
        if (EncodeDock->objectName().isEmpty())
            EncodeDock->setObjectName("EncodeDock");
        EncodeDock->resize(778, 706);
#if QT_CONFIG(whatsthis)
        EncodeDock->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/export-basics/12953/1"));
#endif // QT_CONFIG(whatsthis)
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        horizontalLayout_21 = new QHBoxLayout(dockWidgetContents);
        horizontalLayout_21->setSpacing(0);
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        horizontalLayout_21->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_6 = new QLabel(dockWidgetContents);
        label_6->setObjectName("label_6");
        label_6->setTextFormat(Qt::TextFormat::RichText);
        label_6->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout_2->addWidget(label_6);

        presetsSearch = new LineEditClear(dockWidgetContents);
        presetsSearch->setObjectName("presetsSearch");

        verticalLayout_2->addWidget(presetsSearch);

        presetsTree = new ExportPresetsTreeView(dockWidgetContents);
        presetsTree->setObjectName("presetsTree");
        presetsTree->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        presetsTree->setProperty("showDropIndicator", QVariant(false));
        presetsTree->setAlternatingRowColors(true);
        presetsTree->header()->setVisible(false);
        presetsTree->header()->setDefaultSectionSize(57);

        verticalLayout_2->addWidget(presetsTree);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        addPresetButton = new QPushButton(dockWidgetContents);
        addPresetButton->setObjectName("addPresetButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/list-add.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addPresetButton->setIcon(icon);

        horizontalLayout->addWidget(addPresetButton);

        removePresetButton = new QPushButton(dockWidgetContents);
        removePresetButton->setObjectName("removePresetButton");
        removePresetButton->setEnabled(false);
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/list-remove.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removePresetButton->setIcon(icon1);

        horizontalLayout->addWidget(removePresetButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout);


        horizontalLayout_21->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        scrollArea = new QScrollArea(dockWidgetContents);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 461, 856));
        verticalLayout_3 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_3->setSpacing(3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(6, 6, 6, 0);
        helpLabel = new QLabel(scrollAreaWidgetContents);
        helpLabel->setObjectName("helpLabel");
        helpLabel->setTextFormat(Qt::TextFormat::RichText);
        helpLabel->setWordWrap(true);

        verticalLayout_3->addWidget(helpLabel);

        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setVerticalSpacing(3);
        label_5 = new QLabel(scrollAreaWidgetContents);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(label_5, 2, 0, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        formatCombo = new QComboBox(scrollAreaWidgetContents);
        formatCombo->setObjectName("formatCombo");

        horizontalLayout_14->addWidget(formatCombo);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_13);


        gridLayout_5->addLayout(horizontalLayout_14, 5, 1, 1, 1);

        formatLabel = new QLabel(scrollAreaWidgetContents);
        formatLabel->setObjectName("formatLabel");
        formatLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_5->addWidget(formatLabel, 5, 0, 1, 1);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        fromCombo = new QComboBox(scrollAreaWidgetContents);
        fromCombo->setObjectName("fromCombo");
        fromCombo->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout_19->addWidget(fromCombo);

        horizontalSpacer_23 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_19->addItem(horizontalSpacer_23);


        gridLayout_5->addLayout(horizontalLayout_19, 2, 1, 1, 1);

        horizontalLayout_20 = new QHBoxLayout();
        horizontalLayout_20->setObjectName("horizontalLayout_20");
        hwencodeCheckBox = new QCheckBox(scrollAreaWidgetContents);
        hwencodeCheckBox->setObjectName("hwencodeCheckBox");

        horizontalLayout_20->addWidget(hwencodeCheckBox);

        hwencodeButton = new QPushButton(scrollAreaWidgetContents);
        hwencodeButton->setObjectName("hwencodeButton");

        horizontalLayout_20->addWidget(hwencodeButton);

        horizontalSpacer_25 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_20->addItem(horizontalSpacer_25);


        gridLayout_5->addLayout(horizontalLayout_20, 4, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_5);

        tabWidget = new QTabWidget(scrollAreaWidgetContents);
        tabWidget->setObjectName("tabWidget");
#if QT_CONFIG(whatsthis)
        tabWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/advanced-export/12956/1"));
#endif // QT_CONFIG(whatsthis)
        tabWidget->setUsesScrollButtons(false);
        tabWidget->setDocumentMode(false);
        modeTab = new QWidget();
        modeTab->setObjectName("modeTab");
        gridLayout_6 = new QGridLayout(modeTab);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        widget = new QWidget(modeTab);
        widget->setObjectName("widget");
        gridLayout_2 = new QGridLayout(widget);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setVerticalSpacing(3);
        reframeLabel = new QLabel(widget);
        reframeLabel->setObjectName("reframeLabel");
        reframeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(reframeLabel, 0, 0, 1, 1);

        horizontalLayout_22 = new QHBoxLayout();
        horizontalLayout_22->setObjectName("horizontalLayout_22");
        reframeButton = new QPushButton(widget);
        reframeButton->setObjectName("reframeButton");

        horizontalLayout_22->addWidget(reframeButton);

        horizontalSpacer_26 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_22->addItem(horizontalSpacer_26);


        gridLayout_2->addLayout(horizontalLayout_22, 0, 1, 1, 1);

        resampleWarningLayout = new QHBoxLayout();
        resampleWarningLayout->setObjectName("resampleWarningLayout");
        resampleWarningLayout->setContentsMargins(8, -1, 8, -1);
        resampleWarningIcon = new QPushButton(widget);
        resampleWarningIcon->setObjectName("resampleWarningIcon");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/oxygen/32x32/status/task-attempt.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        resampleWarningIcon->setIcon(icon2);
        resampleWarningIcon->setFlat(true);

        resampleWarningLayout->addWidget(resampleWarningIcon);

        resampleWarningLabel = new QLabel(widget);
        resampleWarningLabel->setObjectName("resampleWarningLabel");
        resampleWarningLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);
        resampleWarningLabel->setWordWrap(true);
        resampleWarningLabel->setMargin(2);

        resampleWarningLayout->addWidget(resampleWarningLabel);

        resampleWarningLayout->setStretch(1, 10);

        gridLayout_2->addLayout(resampleWarningLayout, 3, 0, 1, 2);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        fpsSpinner = new QDoubleSpinBox(widget);
        fpsSpinner->setObjectName("fpsSpinner");
        fpsSpinner->setDecimals(6);
        fpsSpinner->setMinimum(1.000000000000000);
        fpsSpinner->setMaximum(1000.000000000000000);
        fpsSpinner->setValue(25.000000000000000);

        horizontalLayout_16->addWidget(fpsSpinner);

        fpsComboBox = new QComboBox(widget);
        fpsComboBox->addItem(QString::fromUtf8(""));
        fpsComboBox->addItem(QString::fromUtf8("23.976024"));
        fpsComboBox->addItem(QString::fromUtf8("24"));
        fpsComboBox->addItem(QString::fromUtf8("25"));
        fpsComboBox->addItem(QString::fromUtf8("29.970030"));
        fpsComboBox->addItem(QString::fromUtf8("30"));
        fpsComboBox->addItem(QString::fromUtf8("48"));
        fpsComboBox->addItem(QString::fromUtf8("50"));
        fpsComboBox->addItem(QString::fromUtf8("59.940060"));
        fpsComboBox->addItem(QString::fromUtf8("60"));
        fpsComboBox->setObjectName("fpsComboBox");
        fpsComboBox->setMaximumSize(QSize(20, 16777215));

        horizontalLayout_16->addWidget(fpsComboBox);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_16);


        gridLayout_2->addLayout(horizontalLayout_16, 4, 1, 1, 1);

        label_4 = new QLabel(widget);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_4, 9, 0, 1, 1);

        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        interpolationCombo = new QComboBox(widget);
        interpolationCombo->addItem(QString());
        interpolationCombo->addItem(QString());
        interpolationCombo->addItem(QString());
        interpolationCombo->addItem(QString::fromUtf8("Lanczos (best)"));
        interpolationCombo->setObjectName("interpolationCombo");

        horizontalLayout_18->addWidget(interpolationCombo);

        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_22);


        gridLayout_2->addLayout(horizontalLayout_18, 9, 1, 1, 1);

        label_15 = new QLabel(widget);
        label_15->setObjectName("label_15");
        label_15->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_15, 7, 0, 1, 1);

        label_13 = new QLabel(widget);
        label_13->setObjectName("label_13");
        label_13->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_13, 2, 0, 1, 1);

        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_2, 8, 0, 1, 1);

        label_10 = new QLabel(widget);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_10, 4, 0, 1, 1);

        label_14 = new QLabel(widget);
        label_14->setObjectName("label_14");
        label_14->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_14, 6, 0, 1, 1);

        label_24 = new QLabel(widget);
        label_24->setObjectName("label_24");
        label_24->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_24, 5, 0, 1, 1);

        parallelCheckbox = new QCheckBox(widget);
        parallelCheckbox->setObjectName("parallelCheckbox");
        parallelCheckbox->setChecked(true);

        gridLayout_2->addWidget(parallelCheckbox, 11, 1, 1, 1);

        label_22 = new QLabel(widget);
        label_22->setObjectName("label_22");
        label_22->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_22, 1, 0, 1, 1);

        horizontalLayout_23 = new QHBoxLayout();
        horizontalLayout_23->setObjectName("horizontalLayout_23");
        rangeComboBox = new QComboBox(widget);
        rangeComboBox->addItem(QString());
        rangeComboBox->addItem(QString());
        rangeComboBox->setObjectName("rangeComboBox");

        horizontalLayout_23->addWidget(rangeComboBox);

        horizontalSpacer_27 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_23->addItem(horizontalSpacer_27);


        gridLayout_2->addLayout(horizontalLayout_23, 5, 1, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        scanModeCombo = new QComboBox(widget);
        scanModeCombo->addItem(QString());
        scanModeCombo->addItem(QString());
        scanModeCombo->setObjectName("scanModeCombo");

        horizontalLayout_9->addWidget(scanModeCombo);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_9);


        gridLayout_2->addLayout(horizontalLayout_9, 6, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_4, 12, 1, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        widthSpinner = new QSpinBox(widget);
        widthSpinner->setObjectName("widthSpinner");
        widthSpinner->setMinimum(16);
        widthSpinner->setMaximum(8640);
        widthSpinner->setSingleStep(2);
        widthSpinner->setValue(1280);

        horizontalLayout_7->addWidget(widthSpinner);

        label_11 = new QLabel(widget);
        label_11->setObjectName("label_11");

        horizontalLayout_7->addWidget(label_11);

        heightSpinner = new QSpinBox(widget);
        heightSpinner->setObjectName("heightSpinner");
        heightSpinner->setMinimum(1);
        heightSpinner->setMaximum(8640);
        heightSpinner->setSingleStep(2);
        heightSpinner->setValue(720);

        horizontalLayout_7->addWidget(heightSpinner);

        resolutionComboBox = new QComboBox(widget);
        resolutionComboBox->addItem(QString::fromUtf8("1280 x 720 (HD)"));
        resolutionComboBox->addItem(QString::fromUtf8("1920 x 1080 (FHD)"));
        resolutionComboBox->addItem(QString::fromUtf8("2048 x 1080 (DCI 2K)"));
        resolutionComboBox->addItem(QString::fromUtf8("2560 x 1440 (QHD 2K)"));
        resolutionComboBox->addItem(QString::fromUtf8("2704 x 1520 (2.7K)"));
        resolutionComboBox->addItem(QString::fromUtf8("3840 x 2160 (UHD 4K)"));
        resolutionComboBox->addItem(QString::fromUtf8("4096 x 2160 (DCI 4K)"));
        resolutionComboBox->addItem(QString::fromUtf8("5120 x 2880 (5K)"));
        resolutionComboBox->setObjectName("resolutionComboBox");
        resolutionComboBox->setMaximumSize(QSize(20, 16777215));

        horizontalLayout_7->addWidget(resolutionComboBox);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_7);


        gridLayout_2->addLayout(horizontalLayout_7, 1, 1, 1, 1);

        previewScaleCheckBox = new QCheckBox(widget);
        previewScaleCheckBox->setObjectName("previewScaleCheckBox");

        gridLayout_2->addWidget(previewScaleCheckBox, 10, 1, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        fieldOrderCombo = new QComboBox(widget);
        fieldOrderCombo->addItem(QString());
        fieldOrderCombo->addItem(QString());
        fieldOrderCombo->setObjectName("fieldOrderCombo");
        fieldOrderCombo->setEnabled(false);

        horizontalLayout_10->addWidget(fieldOrderCombo);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_10);


        gridLayout_2->addLayout(horizontalLayout_10, 7, 1, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        deinterlacerCombo = new QComboBox(widget);
        deinterlacerCombo->addItem(QString());
        deinterlacerCombo->addItem(QString());
        deinterlacerCombo->addItem(QString());
        deinterlacerCombo->addItem(QString());
        deinterlacerCombo->setObjectName("deinterlacerCombo");

        horizontalLayout_3->addWidget(deinterlacerCombo);

        horizontalSpacer_21 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_21);


        gridLayout_2->addLayout(horizontalLayout_3, 8, 1, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        aspectNumSpinner = new QSpinBox(widget);
        aspectNumSpinner->setObjectName("aspectNumSpinner");
        aspectNumSpinner->setMinimum(1);
        aspectNumSpinner->setMaximum(8640);
        aspectNumSpinner->setValue(16);

        horizontalLayout_8->addWidget(aspectNumSpinner);

        label_16 = new QLabel(widget);
        label_16->setObjectName("label_16");

        horizontalLayout_8->addWidget(label_16);

        aspectDenSpinner = new QSpinBox(widget);
        aspectDenSpinner->setObjectName("aspectDenSpinner");
        aspectDenSpinner->setMinimum(1);
        aspectDenSpinner->setMaximum(8640);
        aspectDenSpinner->setValue(9);

        horizontalLayout_8->addWidget(aspectDenSpinner);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_8);


        gridLayout_2->addLayout(horizontalLayout_8, 2, 1, 1, 1);


        gridLayout_6->addWidget(widget, 1, 0, 1, 1);

        tabWidget->addTab(modeTab, QString());
        videoTab = new QWidget();
        videoTab->setObjectName("videoTab");
        gridLayout_3 = new QGridLayout(videoTab);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setVerticalSpacing(3);
        label_17 = new QLabel(videoTab);
        label_17->setObjectName("label_17");
        label_17->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_17, 3, 0, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setSpacing(4);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        videoCodecCombo = new QComboBox(videoTab);
        videoCodecCombo->setObjectName("videoCodecCombo");

        horizontalLayout_11->addWidget(videoCodecCombo);

        hdrMetaButton = new QPushButton(videoTab);
        hdrMetaButton->setObjectName("hdrMetaButton");
        hdrMetaButton->setMaximumSize(QSize(40, 16777215));
        hdrMetaButton->setVisible(false);

        horizontalLayout_11->addWidget(hdrMetaButton);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_11);


        gridLayout_3->addLayout(horizontalLayout_11, 3, 1, 1, 1);

        label_18 = new QLabel(videoTab);
        label_18->setObjectName("label_18");
        label_18->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_18, 9, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        gopSpinner = new QSpinBox(videoTab);
        gopSpinner->setObjectName("gopSpinner");
        gopSpinner->setMaximum(999);
        gopSpinner->setValue(100);

        horizontalLayout_12->addWidget(gopSpinner);

        label_19 = new QLabel(videoTab);
        label_19->setObjectName("label_19");

        horizontalLayout_12->addWidget(label_19);

        horizontalSpacer_24 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_24);

        strictGopCheckBox = new QCheckBox(videoTab);
        strictGopCheckBox->setObjectName("strictGopCheckBox");

        horizontalLayout_12->addWidget(strictGopCheckBox);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_12);


        gridLayout_3->addLayout(horizontalLayout_12, 9, 1, 1, 1);

        videoBitrateLayout = new QHBoxLayout();
        videoBitrateLayout->setObjectName("videoBitrateLayout");
        videoBitrateCombo = new QComboBox(videoTab);
        videoBitrateCombo->addItem(QString::fromUtf8("64k"));
        videoBitrateCombo->addItem(QString::fromUtf8("128k"));
        videoBitrateCombo->addItem(QString::fromUtf8("256k"));
        videoBitrateCombo->addItem(QString::fromUtf8("512k"));
        videoBitrateCombo->addItem(QString::fromUtf8("768k"));
        videoBitrateCombo->addItem(QString::fromUtf8("1M"));
        videoBitrateCombo->addItem(QString::fromUtf8("1200k"));
        videoBitrateCombo->addItem(QString::fromUtf8("1500k"));
        videoBitrateCombo->addItem(QString::fromUtf8("2M"));
        videoBitrateCombo->addItem(QString::fromUtf8("2500k"));
        videoBitrateCombo->addItem(QString::fromUtf8("3M"));
        videoBitrateCombo->addItem(QString::fromUtf8("4M"));
        videoBitrateCombo->addItem(QString::fromUtf8("5M"));
        videoBitrateCombo->addItem(QString::fromUtf8("6M"));
        videoBitrateCombo->addItem(QString::fromUtf8("8M"));
        videoBitrateCombo->addItem(QString::fromUtf8("10M"));
        videoBitrateCombo->addItem(QString::fromUtf8("12M"));
        videoBitrateCombo->addItem(QString::fromUtf8("14M"));
        videoBitrateCombo->addItem(QString::fromUtf8("16M"));
        videoBitrateCombo->addItem(QString::fromUtf8("18M"));
        videoBitrateCombo->addItem(QString::fromUtf8("20M"));
        videoBitrateCombo->addItem(QString::fromUtf8("25M"));
        videoBitrateCombo->addItem(QString::fromUtf8("30M"));
        videoBitrateCombo->addItem(QString::fromUtf8("40M"));
        videoBitrateCombo->addItem(QString::fromUtf8("50M"));
        videoBitrateCombo->addItem(QString::fromUtf8("60M"));
        videoBitrateCombo->addItem(QString::fromUtf8("70M"));
        videoBitrateCombo->addItem(QString::fromUtf8("80M"));
        videoBitrateCombo->setObjectName("videoBitrateCombo");
        videoBitrateCombo->setEditable(true);

        videoBitrateLayout->addWidget(videoBitrateCombo);

        videoBitrateSuffixLabel = new QLabel(videoTab);
        videoBitrateSuffixLabel->setObjectName("videoBitrateSuffixLabel");

        videoBitrateLayout->addWidget(videoBitrateSuffixLabel);

        videoBitrateSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        videoBitrateLayout->addItem(videoBitrateSpacer);


        gridLayout_3->addLayout(videoBitrateLayout, 6, 1, 1, 1);

        disableVideoCheckbox = new QCheckBox(videoTab);
        disableVideoCheckbox->setObjectName("disableVideoCheckbox");

        gridLayout_3->addWidget(disableVideoCheckbox, 15, 1, 1, 1);

        hwdecodeCheckBox = new QCheckBox(videoTab);
        hwdecodeCheckBox->setObjectName("hwdecodeCheckBox");

        gridLayout_3->addWidget(hwdecodeCheckBox, 14, 1, 1, 1);

        dualPassCheckbox = new QCheckBox(videoTab);
        dualPassCheckbox->setObjectName("dualPassCheckbox");

        gridLayout_3->addWidget(dualPassCheckbox, 13, 1, 1, 1);

        label_20 = new QLabel(videoTab);
        label_20->setObjectName("label_20");
        label_20->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_20, 10, 0, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        bFramesSpinner = new QSpinBox(videoTab);
        bFramesSpinner->setObjectName("bFramesSpinner");
        bFramesSpinner->setMaximum(8);

        horizontalLayout_13->addWidget(bFramesSpinner);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_14);


        gridLayout_3->addLayout(horizontalLayout_13, 10, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 16, 1, 1, 1);

        label_12 = new QLabel(videoTab);
        label_12->setObjectName("label_12");
        label_12->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_12, 11, 0, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        videoCodecThreadsSpinner = new QSpinBox(videoTab);
        videoCodecThreadsSpinner->setObjectName("videoCodecThreadsSpinner");

        horizontalLayout_15->addWidget(videoCodecThreadsSpinner);

        label_21 = new QLabel(videoTab);
        label_21->setObjectName("label_21");

        horizontalLayout_15->addWidget(label_21);

        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_15);


        gridLayout_3->addLayout(horizontalLayout_15, 11, 1, 1, 1);

        label_23 = new QLabel(videoTab);
        label_23->setObjectName("label_23");
        label_23->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(label_23, 5, 0, 1, 1);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        videoRateControlCombo = new QComboBox(videoTab);
        videoRateControlCombo->addItem(QString());
        videoRateControlCombo->addItem(QString());
        videoRateControlCombo->addItem(QString());
        videoRateControlCombo->addItem(QString());
        videoRateControlCombo->setObjectName("videoRateControlCombo");

        horizontalLayout_17->addWidget(videoRateControlCombo);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_17);


        gridLayout_3->addLayout(horizontalLayout_17, 5, 1, 1, 1);

        videoBufferSizeLabel = new QLabel(videoTab);
        videoBufferSizeLabel->setObjectName("videoBufferSizeLabel");
        videoBufferSizeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(videoBufferSizeLabel, 7, 0, 1, 1);

        videoBufferSizeLayout = new QHBoxLayout();
        videoBufferSizeLayout->setObjectName("videoBufferSizeLayout");
        videoBufferSizeSpinner = new QDoubleSpinBox(videoTab);
        videoBufferSizeSpinner->setObjectName("videoBufferSizeSpinner");
        videoBufferSizeSpinner->setMaximum(99999.000000000000000);
        videoBufferSizeSpinner->setValue(224.000000000000000);

        videoBufferSizeLayout->addWidget(videoBufferSizeSpinner);

        videoBufferSizeSuffixLabel = new QLabel(videoTab);
        videoBufferSizeSuffixLabel->setObjectName("videoBufferSizeSuffixLabel");

        videoBufferSizeLayout->addWidget(videoBufferSizeSuffixLabel);

        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        videoBufferSizeLayout->addItem(horizontalSpacer_18);


        gridLayout_3->addLayout(videoBufferSizeLayout, 7, 1, 1, 1);

        videoQualityLabel = new QLabel(videoTab);
        videoQualityLabel->setObjectName("videoQualityLabel");
        videoQualityLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(videoQualityLabel, 8, 0, 1, 1);

        videoQualityLayout = new QHBoxLayout();
        videoQualityLayout->setObjectName("videoQualityLayout");
        videoQualitySpinner = new QSpinBox(videoTab);
        videoQualitySpinner->setObjectName("videoQualitySpinner");
        videoQualitySpinner->setMinimum(0);
        videoQualitySpinner->setMaximum(100);
        videoQualitySpinner->setValue(50);

        videoQualityLayout->addWidget(videoQualitySpinner);

        videoQualitySuffixLabel = new QLabel(videoTab);
        videoQualitySuffixLabel->setObjectName("videoQualitySuffixLabel");

        videoQualityLayout->addWidget(videoQualitySuffixLabel);

        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        videoQualityLayout->addItem(horizontalSpacer_19);


        gridLayout_3->addLayout(videoQualityLayout, 8, 1, 1, 1);

        videoBitrateLabel = new QLabel(videoTab);
        videoBitrateLabel->setObjectName("videoBitrateLabel");
        videoBitrateLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(videoBitrateLabel, 6, 0, 1, 1);

        tabWidget->addTab(videoTab, QString());
        audioTab = new QWidget();
        audioTab->setObjectName("audioTab");
        gridLayout = new QGridLayout(audioTab);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setVerticalSpacing(3);
        channelsLabel = new QLabel(audioTab);
        channelsLabel->setObjectName("channelsLabel");
        channelsLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(channelsLabel, 1, 0, 1, 1);

        ChannelsHorizontalLayout = new QHBoxLayout();
        ChannelsHorizontalLayout->setObjectName("ChannelsHorizontalLayout");
        audioChannelsCombo = new QComboBox(audioTab);
        audioChannelsCombo->addItem(QString());
        audioChannelsCombo->addItem(QString());
        audioChannelsCombo->addItem(QString());
        audioChannelsCombo->addItem(QString());
        audioChannelsCombo->setObjectName("audioChannelsCombo");

        ChannelsHorizontalLayout->addWidget(audioChannelsCombo);

        channelsHorizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        ChannelsHorizontalLayout->addItem(channelsHorizontalSpacer);


        gridLayout->addLayout(ChannelsHorizontalLayout, 1, 1, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        sampleRateCombo = new QComboBox(audioTab);
        sampleRateCombo->addItem(QString::fromUtf8("8000"));
        sampleRateCombo->addItem(QString::fromUtf8("12000"));
        sampleRateCombo->addItem(QString::fromUtf8("16000"));
        sampleRateCombo->addItem(QString::fromUtf8("22050"));
        sampleRateCombo->addItem(QString::fromUtf8("32000"));
        sampleRateCombo->addItem(QString::fromUtf8("44100"));
        sampleRateCombo->addItem(QString::fromUtf8("48000"));
        sampleRateCombo->addItem(QString::fromUtf8("96000"));
        sampleRateCombo->setObjectName("sampleRateCombo");
        sampleRateCombo->setEditable(true);

        horizontalLayout_4->addWidget(sampleRateCombo);

        label_9 = new QLabel(audioTab);
        label_9->setObjectName("label_9");

        horizontalLayout_4->addWidget(label_9);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_6);


        gridLayout->addLayout(horizontalLayout_4, 2, 1, 1, 1);

        label_8 = new QLabel(audioTab);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_8, 2, 0, 1, 1);

        label_3 = new QLabel(audioTab);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        audioCodecCombo = new QComboBox(audioTab);
        audioCodecCombo->setObjectName("audioCodecCombo");

        horizontalLayout_6->addWidget(audioCodecCombo);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_3);


        gridLayout->addLayout(horizontalLayout_6, 3, 1, 1, 1);

        audioBitrateLabel = new QLabel(audioTab);
        audioBitrateLabel->setObjectName("audioBitrateLabel");
        audioBitrateLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(audioBitrateLabel, 6, 0, 1, 1);

        audioBitrateLayout = new QHBoxLayout();
        audioBitrateLayout->setObjectName("audioBitrateLayout");
        audioBitrateCombo = new QComboBox(audioTab);
        audioBitrateCombo->addItem(QString::fromUtf8("16k"));
        audioBitrateCombo->addItem(QString::fromUtf8("32k"));
        audioBitrateCombo->addItem(QString::fromUtf8("48k"));
        audioBitrateCombo->addItem(QString::fromUtf8("64k"));
        audioBitrateCombo->addItem(QString::fromUtf8("96k"));
        audioBitrateCombo->addItem(QString::fromUtf8("128k"));
        audioBitrateCombo->addItem(QString::fromUtf8("192k"));
        audioBitrateCombo->addItem(QString::fromUtf8("220k"));
        audioBitrateCombo->addItem(QString::fromUtf8("256k"));
        audioBitrateCombo->addItem(QString::fromUtf8("384k"));
        audioBitrateCombo->addItem(QString::fromUtf8("448k"));
        audioBitrateCombo->addItem(QString::fromUtf8("512k"));
        audioBitrateCombo->addItem(QString::fromUtf8("640k"));
        audioBitrateCombo->addItem(QString::fromUtf8("1M"));
        audioBitrateCombo->setObjectName("audioBitrateCombo");
        audioBitrateCombo->setEditable(true);

        audioBitrateLayout->addWidget(audioBitrateCombo);

        audioBitrateSuffixLabel = new QLabel(audioTab);
        audioBitrateSuffixLabel->setObjectName("audioBitrateSuffixLabel");

        audioBitrateLayout->addWidget(audioBitrateSuffixLabel);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        audioBitrateLayout->addItem(horizontalSpacer_4);


        gridLayout->addLayout(audioBitrateLayout, 6, 1, 1, 1);

        disableAudioCheckbox = new QCheckBox(audioTab);
        disableAudioCheckbox->setObjectName("disableAudioCheckbox");

        gridLayout->addWidget(disableAudioCheckbox, 8, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 9, 0, 1, 1);

        label_7 = new QLabel(audioTab);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_7, 4, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        audioRateControlCombo = new QComboBox(audioTab);
        audioRateControlCombo->addItem(QString());
        audioRateControlCombo->addItem(QString());
        audioRateControlCombo->addItem(QString());
        audioRateControlCombo->setObjectName("audioRateControlCombo");

        horizontalLayout_5->addWidget(audioRateControlCombo);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);


        gridLayout->addLayout(horizontalLayout_5, 4, 1, 1, 1);

        audioQualityLabel = new QLabel(audioTab);
        audioQualityLabel->setObjectName("audioQualityLabel");
        audioQualityLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(audioQualityLabel, 7, 0, 1, 1);

        audioQualityLayout = new QHBoxLayout();
        audioQualityLayout->setObjectName("audioQualityLayout");
        audioQualitySpinner = new QSpinBox(audioTab);
        audioQualitySpinner->setObjectName("audioQualitySpinner");
        audioQualitySpinner->setMinimum(0);
        audioQualitySpinner->setMaximum(100);
        audioQualitySpinner->setValue(50);

        audioQualityLayout->addWidget(audioQualitySpinner);

        audioQualitySuffixLabel = new QLabel(audioTab);
        audioQualitySuffixLabel->setObjectName("audioQualitySuffixLabel");

        audioQualityLayout->addWidget(audioQualitySuffixLabel);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        audioQualityLayout->addItem(horizontalSpacer_20);


        gridLayout->addLayout(audioQualityLayout, 7, 1, 1, 1);

        tabWidget->addTab(audioTab, QString());
        metadataTab = new QWidget();
        metadataTab->setObjectName("metadataTab");
        gridLayout_10 = new QGridLayout(metadataTab);
        gridLayout_10->setObjectName("gridLayout_10");
        coverArtLabel = new QLabel(metadataTab);
        coverArtLabel->setObjectName("coverArtLabel");
        coverArtLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(coverArtLabel, 0, 0, 1, 1);

        horizontalLayout_26 = new QHBoxLayout();
        horizontalLayout_26->setObjectName("horizontalLayout_26");
        coverArtLineEdit = new QLineEdit(metadataTab);
        coverArtLineEdit->setObjectName("coverArtLineEdit");

        horizontalLayout_26->addWidget(coverArtLineEdit);

        coverArtButton = new QPushButton(metadataTab);
        coverArtButton->setObjectName("coverArtButton");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/document-open.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        coverArtButton->setIcon(icon3);

        horizontalLayout_26->addWidget(coverArtButton);


        gridLayout_10->addLayout(horizontalLayout_26, 0, 1, 1, 1);

        metaTitleLabel = new QLabel(metadataTab);
        metaTitleLabel->setObjectName("metaTitleLabel");
        metaTitleLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaTitleLabel, 1, 0, 1, 1);

        metaTitleLineEdit = new QLineEdit(metadataTab);
        metaTitleLineEdit->setObjectName("metaTitleLineEdit");

        gridLayout_10->addWidget(metaTitleLineEdit, 1, 1, 1, 1);

        metaArtistLabel = new QLabel(metadataTab);
        metaArtistLabel->setObjectName("metaArtistLabel");
        metaArtistLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaArtistLabel, 2, 0, 1, 1);

        metaArtistLineEdit = new QLineEdit(metadataTab);
        metaArtistLineEdit->setObjectName("metaArtistLineEdit");

        gridLayout_10->addWidget(metaArtistLineEdit, 2, 1, 1, 1);

        metaCommentLabel = new QLabel(metadataTab);
        metaCommentLabel->setObjectName("metaCommentLabel");
        metaCommentLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaCommentLabel, 3, 0, 1, 1);

        metaCommentLineEdit = new QLineEdit(metadataTab);
        metaCommentLineEdit->setObjectName("metaCommentLineEdit");

        gridLayout_10->addWidget(metaCommentLineEdit, 3, 1, 1, 1);

        metaCopyrightLabel = new QLabel(metadataTab);
        metaCopyrightLabel->setObjectName("metaCopyrightLabel");
        metaCopyrightLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaCopyrightLabel, 4, 0, 1, 1);

        metaCopyrightLineEdit = new QLineEdit(metadataTab);
        metaCopyrightLineEdit->setObjectName("metaCopyrightLineEdit");

        gridLayout_10->addWidget(metaCopyrightLineEdit, 4, 1, 1, 1);

        metaDateLabel = new QLabel(metadataTab);
        metaDateLabel->setObjectName("metaDateLabel");
        metaDateLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaDateLabel, 5, 0, 1, 1);

        metaDateLineEdit = new QLineEdit(metadataTab);
        metaDateLineEdit->setObjectName("metaDateLineEdit");

        gridLayout_10->addWidget(metaDateLineEdit, 5, 1, 1, 1);

        metaDescriptionLabel = new QLabel(metadataTab);
        metaDescriptionLabel->setObjectName("metaDescriptionLabel");
        metaDescriptionLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaDescriptionLabel, 6, 0, 1, 1);

        metaDescriptionLineEdit = new QLineEdit(metadataTab);
        metaDescriptionLineEdit->setObjectName("metaDescriptionLineEdit");

        gridLayout_10->addWidget(metaDescriptionLineEdit, 6, 1, 1, 1);

        metaGenreLabel = new QLabel(metadataTab);
        metaGenreLabel->setObjectName("metaGenreLabel");
        metaGenreLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaGenreLabel, 7, 0, 1, 1);

        metaGenreLineEdit = new QLineEdit(metadataTab);
        metaGenreLineEdit->setObjectName("metaGenreLineEdit");

        gridLayout_10->addWidget(metaGenreLineEdit, 7, 1, 1, 1);

        metaLanguageLabel = new QLabel(metadataTab);
        metaLanguageLabel->setObjectName("metaLanguageLabel");
        metaLanguageLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_10->addWidget(metaLanguageLabel, 8, 0, 1, 1);

        metaLanguageLineEdit = new QLineEdit(metadataTab);
        metaLanguageLineEdit->setObjectName("metaLanguageLineEdit");

        gridLayout_10->addWidget(metaLanguageLineEdit, 8, 1, 1, 1);

        disableSubtitlesCheckbox = new QCheckBox(metadataTab);
        disableSubtitlesCheckbox->setObjectName("disableSubtitlesCheckbox");

        gridLayout_10->addWidget(disableSubtitlesCheckbox, 9, 1, 1, 1);

        metadataVerticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_10->addItem(metadataVerticalSpacer, 10, 1, 1, 1);

        tabWidget->addTab(metadataTab, QString());
        otherTab = new QWidget();
        otherTab->setObjectName("otherTab");
        gridLayout_4 = new QGridLayout(otherTab);
        gridLayout_4->setObjectName("gridLayout_4");
        advancedTextEdit = new QPlainTextEdit(otherTab);
        advancedTextEdit->setObjectName("advancedTextEdit");

        gridLayout_4->addWidget(advancedTextEdit, 1, 0, 1, 1);

        otherTipLabel = new QLabel(otherTab);
        otherTipLabel->setObjectName("otherTipLabel");
        otherTipLabel->setWordWrap(true);

        gridLayout_4->addWidget(otherTipLabel, 0, 0, 1, 1);

        tabWidget->addTab(otherTab, QString());

        verticalLayout_3->addWidget(tabWidget);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(scrollArea);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        encodeButton = new QPushButton(dockWidgetContents);
        encodeButton->setObjectName("encodeButton");

        horizontalLayout_2->addWidget(encodeButton);

        resetButton = new QPushButton(dockWidgetContents);
        resetButton->setObjectName("resetButton");

        horizontalLayout_2->addWidget(resetButton);

        advancedButton = new QPushButton(dockWidgetContents);
        advancedButton->setObjectName("advancedButton");
        advancedButton->setCheckable(true);

        horizontalLayout_2->addWidget(advancedButton);

        advancedCheckBox = new QCheckBox(dockWidgetContents);
        advancedCheckBox->setObjectName("advancedCheckBox");

        horizontalLayout_2->addWidget(advancedCheckBox);

        streamButton = new QPushButton(dockWidgetContents);
        streamButton->setObjectName("streamButton");

        horizontalLayout_2->addWidget(streamButton);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        stopCaptureLayout = new QHBoxLayout();
        stopCaptureLayout->setSpacing(6);
        stopCaptureLayout->setObjectName("stopCaptureLayout");
        stopCaptureButton = new QPushButton(dockWidgetContents);
        stopCaptureButton->setObjectName("stopCaptureButton");

        stopCaptureLayout->addWidget(stopCaptureButton);

        stopCaptureSpacer = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        stopCaptureLayout->addItem(stopCaptureSpacer);


        verticalLayout->addLayout(stopCaptureLayout);


        horizontalLayout_21->addLayout(verticalLayout);

        horizontalLayout_21->setStretch(0, 3);
        horizontalLayout_21->setStretch(1, 4);
        EncodeDock->setWidget(dockWidgetContents);
        QWidget::setTabOrder(fromCombo, hwencodeCheckBox);
        QWidget::setTabOrder(hwencodeCheckBox, hwencodeButton);
        QWidget::setTabOrder(hwencodeButton, formatCombo);
        QWidget::setTabOrder(formatCombo, tabWidget);
        QWidget::setTabOrder(tabWidget, widthSpinner);
        QWidget::setTabOrder(widthSpinner, heightSpinner);
        QWidget::setTabOrder(heightSpinner, resolutionComboBox);
        QWidget::setTabOrder(resolutionComboBox, aspectNumSpinner);
        QWidget::setTabOrder(aspectNumSpinner, aspectDenSpinner);
        QWidget::setTabOrder(aspectDenSpinner, fpsSpinner);
        QWidget::setTabOrder(fpsSpinner, fpsComboBox);
        QWidget::setTabOrder(fpsComboBox, scanModeCombo);
        QWidget::setTabOrder(scanModeCombo, fieldOrderCombo);
        QWidget::setTabOrder(fieldOrderCombo, deinterlacerCombo);
        QWidget::setTabOrder(deinterlacerCombo, interpolationCombo);
        QWidget::setTabOrder(interpolationCombo, previewScaleCheckBox);
        QWidget::setTabOrder(previewScaleCheckBox, parallelCheckbox);
        QWidget::setTabOrder(parallelCheckbox, encodeButton);
        QWidget::setTabOrder(encodeButton, resetButton);
        QWidget::setTabOrder(resetButton, advancedButton);
        QWidget::setTabOrder(advancedButton, advancedCheckBox);
        QWidget::setTabOrder(advancedCheckBox, streamButton);
        QWidget::setTabOrder(streamButton, stopCaptureButton);
        QWidget::setTabOrder(stopCaptureButton, presetsSearch);
        QWidget::setTabOrder(presetsSearch, presetsTree);
        QWidget::setTabOrder(presetsTree, addPresetButton);
        QWidget::setTabOrder(addPresetButton, removePresetButton);
        QWidget::setTabOrder(removePresetButton, scrollArea);
        QWidget::setTabOrder(scrollArea, videoCodecCombo);
        QWidget::setTabOrder(videoCodecCombo, videoRateControlCombo);
        QWidget::setTabOrder(videoRateControlCombo, videoBitrateCombo);
        QWidget::setTabOrder(videoBitrateCombo, videoBufferSizeSpinner);
        QWidget::setTabOrder(videoBufferSizeSpinner, videoQualitySpinner);
        QWidget::setTabOrder(videoQualitySpinner, gopSpinner);
        QWidget::setTabOrder(gopSpinner, strictGopCheckBox);
        QWidget::setTabOrder(strictGopCheckBox, bFramesSpinner);
        QWidget::setTabOrder(bFramesSpinner, videoCodecThreadsSpinner);
        QWidget::setTabOrder(videoCodecThreadsSpinner, dualPassCheckbox);
        QWidget::setTabOrder(dualPassCheckbox, disableVideoCheckbox);
        QWidget::setTabOrder(disableVideoCheckbox, audioChannelsCombo);
        QWidget::setTabOrder(audioChannelsCombo, sampleRateCombo);
        QWidget::setTabOrder(sampleRateCombo, audioCodecCombo);
        QWidget::setTabOrder(audioCodecCombo, audioRateControlCombo);
        QWidget::setTabOrder(audioRateControlCombo, audioBitrateCombo);
        QWidget::setTabOrder(audioBitrateCombo, audioQualitySpinner);
        QWidget::setTabOrder(audioQualitySpinner, disableAudioCheckbox);
        QWidget::setTabOrder(disableAudioCheckbox, coverArtLineEdit);
        QWidget::setTabOrder(coverArtLineEdit, coverArtButton);
        QWidget::setTabOrder(coverArtButton, metaTitleLineEdit);
        QWidget::setTabOrder(metaTitleLineEdit, metaArtistLineEdit);
        QWidget::setTabOrder(metaArtistLineEdit, metaCommentLineEdit);
        QWidget::setTabOrder(metaCommentLineEdit, metaCopyrightLineEdit);
        QWidget::setTabOrder(metaCopyrightLineEdit, metaDateLineEdit);
        QWidget::setTabOrder(metaDateLineEdit, metaDescriptionLineEdit);
        QWidget::setTabOrder(metaDescriptionLineEdit, metaGenreLineEdit);
        QWidget::setTabOrder(metaGenreLineEdit, metaLanguageLineEdit);
        QWidget::setTabOrder(metaLanguageLineEdit, disableSubtitlesCheckbox);
        QWidget::setTabOrder(disableSubtitlesCheckbox, advancedTextEdit);

        retranslateUi(EncodeDock);

        tabWidget->setCurrentIndex(0);
        interpolationCombo->setCurrentIndex(1);
        scanModeCombo->setCurrentIndex(1);
        deinterlacerCombo->setCurrentIndex(3);
        videoBitrateCombo->setCurrentIndex(8);
        sampleRateCombo->setCurrentIndex(6);
        audioBitrateCombo->setCurrentIndex(5);
        encodeButton->setDefault(true);


        QMetaObject::connectSlotsByName(EncodeDock);
    } // setupUi

    void retranslateUi(QDockWidget *EncodeDock)
    {
        EncodeDock->setWindowTitle(QCoreApplication::translate("EncodeDock", "Export", nullptr));
        label_6->setText(QCoreApplication::translate("EncodeDock", "<b>Presets</b>", nullptr));
        presetsSearch->setPlaceholderText(QCoreApplication::translate("EncodeDock", "search", nullptr));
#if QT_CONFIG(tooltip)
        addPresetButton->setToolTip(QCoreApplication::translate("EncodeDock", "Add current settings as a new custom preset", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        removePresetButton->setToolTip(QCoreApplication::translate("EncodeDock", "Delete currently selected preset", nullptr));
#endif // QT_CONFIG(tooltip)
        helpLabel->setText(QCoreApplication::translate("EncodeDock", "<html><head/><body><p align=\"center\"><span style=\" font-weight:600;\">Export Help</span></p><p>The defaults create a H.264/AAC MP4 file, which is suitable for most users and purposes. Choose a <span style=\" font-weight:600;\">Preset</span> at the left before deciding to use the <span style=\" font-weight:600;\">Advanced</span> mode. The <span style=\" font-weight:600;\">Advanced</span> mode does not prevent creating an invalid combination of options!</p></body></html>", nullptr));
        label_5->setText(QCoreApplication::translate("EncodeDock", "From", nullptr));
        formatLabel->setText(QCoreApplication::translate("EncodeDock", "Format", nullptr));
        hwencodeCheckBox->setText(QCoreApplication::translate("EncodeDock", "Use hardware encoder", nullptr));
        hwencodeButton->setText(QCoreApplication::translate("EncodeDock", "Configure...", nullptr));
        reframeLabel->setText(QString());
        reframeButton->setText(QCoreApplication::translate("EncodeDock", "Reframe", nullptr));
        resampleWarningIcon->setText(QString());
        resampleWarningLabel->setText(QString());

        label_4->setText(QCoreApplication::translate("EncodeDock", "Interpolation", nullptr));
        interpolationCombo->setItemText(0, QCoreApplication::translate("EncodeDock", "Nearest Neighbor (fast)", nullptr));
        interpolationCombo->setItemText(1, QCoreApplication::translate("EncodeDock", "Bilinear (good)", nullptr));
        interpolationCombo->setItemText(2, QCoreApplication::translate("EncodeDock", "Bicubic (better)", nullptr));

        label_15->setText(QCoreApplication::translate("EncodeDock", "Field order", nullptr));
        label_13->setText(QCoreApplication::translate("EncodeDock", "Aspect ratio", nullptr));
        label_2->setText(QCoreApplication::translate("EncodeDock", "Deinterlacer", nullptr));
        label_10->setText(QCoreApplication::translate("EncodeDock", "Frames/sec", nullptr));
        label_14->setText(QCoreApplication::translate("EncodeDock", "Scan mode", nullptr));
        label_24->setText(QCoreApplication::translate("EncodeDock", "Color range", nullptr));
#if QT_CONFIG(tooltip)
        parallelCheckbox->setToolTip(QCoreApplication::translate("EncodeDock", "This enables multiple image processing threads.\n"
"Sometimes, this can be a problem, and you can\n"
"test if turning this off helps. For example, some\n"
"interlaced AVCHD in conjunction with the YADIF\n"
"deinterlacer has been reported as problematic\n"
"with parallel processing enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        parallelCheckbox->setText(QCoreApplication::translate("EncodeDock", "Parallel processing", nullptr));
        label_22->setText(QCoreApplication::translate("EncodeDock", "Resolution", nullptr));
        rangeComboBox->setItemText(0, QCoreApplication::translate("EncodeDock", "Broadcast Limited (MPEG)", nullptr));
        rangeComboBox->setItemText(1, QCoreApplication::translate("EncodeDock", "Full (JPEG)", nullptr));

        scanModeCombo->setItemText(0, QCoreApplication::translate("EncodeDock", "Interlaced", nullptr));
        scanModeCombo->setItemText(1, QCoreApplication::translate("EncodeDock", "Progressive", nullptr));

        label_11->setText(QCoreApplication::translate("EncodeDock", "x", nullptr));

        previewScaleCheckBox->setText(QCoreApplication::translate("EncodeDock", "Use preview scaling", nullptr));
        fieldOrderCombo->setItemText(0, QCoreApplication::translate("EncodeDock", "Bottom Field First", nullptr));
        fieldOrderCombo->setItemText(1, QCoreApplication::translate("EncodeDock", "Top Field First", nullptr));

        deinterlacerCombo->setItemText(0, QCoreApplication::translate("EncodeDock", "One Field (fast)", nullptr));
        deinterlacerCombo->setItemText(1, QCoreApplication::translate("EncodeDock", "YADIF - temporal only (good)", nullptr));
        deinterlacerCombo->setItemText(2, QCoreApplication::translate("EncodeDock", "YADIF - temporal + spatial (better)", nullptr));
        deinterlacerCombo->setItemText(3, QCoreApplication::translate("EncodeDock", "BWDIF (best)", nullptr));

        label_16->setText(QCoreApplication::translate("EncodeDock", ":", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(modeTab), QCoreApplication::translate("EncodeDock", "Video", nullptr));
        label_17->setText(QCoreApplication::translate("EncodeDock", "Codec", nullptr));
#if QT_CONFIG(tooltip)
        hdrMetaButton->setToolTip(QCoreApplication::translate("EncodeDock", "Set HDR mastering display and content light level metadata", nullptr));
#endif // QT_CONFIG(tooltip)
        hdrMetaButton->setText(QCoreApplication::translate("EncodeDock", "HDR...", nullptr));
        label_18->setText(QCoreApplication::translate("EncodeDock", "GOP", nullptr));
#if QT_CONFIG(tooltip)
        gopSpinner->setToolTip(QCoreApplication::translate("EncodeDock", "GOP = group of pictures, which is the maximum key frame interval", nullptr));
#endif // QT_CONFIG(tooltip)
        label_19->setText(QCoreApplication::translate("EncodeDock", "frames", nullptr));
#if QT_CONFIG(tooltip)
        strictGopCheckBox->setToolTip(QCoreApplication::translate("EncodeDock", "A fixed GOP means that keyframes will\n"
"not be inserted at detected scene changes.", nullptr));
#endif // QT_CONFIG(tooltip)
        strictGopCheckBox->setText(QCoreApplication::translate("EncodeDock", "Fixed", nullptr));

#if QT_CONFIG(tooltip)
        videoBitrateCombo->setToolTip(QCoreApplication::translate("EncodeDock", "The average bit rate", nullptr));
#endif // QT_CONFIG(tooltip)
        videoBitrateSuffixLabel->setText(QCoreApplication::translate("EncodeDock", "b/s", nullptr));
        disableVideoCheckbox->setText(QCoreApplication::translate("EncodeDock", "Disable video", nullptr));
#if QT_CONFIG(tooltip)
        hwdecodeCheckBox->setToolTip(QCoreApplication::translate("EncodeDock", "<p>The hardware decoder for export is usually not very beneficial and is often slower. It may only mildly reduce CPU usage on some systems. Therefore, we recommend to leave it off, but you can test and decide for yourself.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        hwdecodeCheckBox->setText(QCoreApplication::translate("EncodeDock", "Use hardware decoder", nullptr));
        dualPassCheckbox->setText(QCoreApplication::translate("EncodeDock", "Dual pass", nullptr));
        label_20->setText(QCoreApplication::translate("EncodeDock", "B frames", nullptr));
#if QT_CONFIG(tooltip)
        bFramesSpinner->setToolTip(QCoreApplication::translate("EncodeDock", "B frames are the bidirectional \"delta\" pictures\n"
"in temporal compression", nullptr));
#endif // QT_CONFIG(tooltip)
        label_12->setText(QCoreApplication::translate("EncodeDock", "Codec threads", nullptr));
        label_21->setText(QCoreApplication::translate("EncodeDock", "(0 = auto)", nullptr));
        label_23->setText(QCoreApplication::translate("EncodeDock", "Rate control", nullptr));
        videoRateControlCombo->setItemText(0, QCoreApplication::translate("EncodeDock", "Average Bitrate", nullptr));
        videoRateControlCombo->setItemText(1, QCoreApplication::translate("EncodeDock", "Constant Bitrate", nullptr));
        videoRateControlCombo->setItemText(2, QCoreApplication::translate("EncodeDock", "Quality-based VBR", nullptr));
        videoRateControlCombo->setItemText(3, QCoreApplication::translate("EncodeDock", "Constrained VBR", nullptr));

        videoBufferSizeLabel->setText(QCoreApplication::translate("EncodeDock", "Buffer size", nullptr));
        videoBufferSizeSuffixLabel->setText(QCoreApplication::translate("EncodeDock", "KiB", nullptr));
        videoQualityLabel->setText(QCoreApplication::translate("EncodeDock", "Quality", nullptr));
        videoQualitySpinner->setSuffix(QCoreApplication::translate("EncodeDock", " %", nullptr));
        videoQualitySuffixLabel->setText(QCoreApplication::translate("EncodeDock", "TextLabel", nullptr));
        videoBitrateLabel->setText(QCoreApplication::translate("EncodeDock", "Bitrate", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(videoTab), QCoreApplication::translate("EncodeDock", "Codec", nullptr));
        channelsLabel->setText(QCoreApplication::translate("EncodeDock", "Channels", nullptr));
        audioChannelsCombo->setItemText(0, QCoreApplication::translate("EncodeDock", "1 (mono)", nullptr));
        audioChannelsCombo->setItemText(1, QCoreApplication::translate("EncodeDock", "2 (stereo)", nullptr));
        audioChannelsCombo->setItemText(2, QCoreApplication::translate("EncodeDock", "4 (quad/Ambisonics)", nullptr));
        audioChannelsCombo->setItemText(3, QCoreApplication::translate("EncodeDock", "6 (5.1 surround)", nullptr));

#if QT_CONFIG(tooltip)
        audioChannelsCombo->setToolTip(QCoreApplication::translate("EncodeDock", "The number of audio channels in the output.", nullptr));
#endif // QT_CONFIG(tooltip)

        label_9->setText(QCoreApplication::translate("EncodeDock", "Hz", nullptr));
        label_8->setText(QCoreApplication::translate("EncodeDock", "Sample rate", nullptr));
        label_3->setText(QCoreApplication::translate("EncodeDock", "Codec", nullptr));
        audioBitrateLabel->setText(QCoreApplication::translate("EncodeDock", "Bitrate", nullptr));

#if QT_CONFIG(tooltip)
        audioBitrateCombo->setToolTip(QCoreApplication::translate("EncodeDock", "The average bit rate", nullptr));
#endif // QT_CONFIG(tooltip)
        audioBitrateSuffixLabel->setText(QCoreApplication::translate("EncodeDock", "b/s", nullptr));
        disableAudioCheckbox->setText(QCoreApplication::translate("EncodeDock", "Disable audio", nullptr));
        label_7->setText(QCoreApplication::translate("EncodeDock", "Rate control", nullptr));
        audioRateControlCombo->setItemText(0, QCoreApplication::translate("EncodeDock", "Average Bitrate", nullptr));
        audioRateControlCombo->setItemText(1, QCoreApplication::translate("EncodeDock", "Constant Bitrate", nullptr));
        audioRateControlCombo->setItemText(2, QCoreApplication::translate("EncodeDock", "Quality-based VBR", nullptr));

        audioQualityLabel->setText(QCoreApplication::translate("EncodeDock", "Quality", nullptr));
        audioQualitySpinner->setSuffix(QCoreApplication::translate("EncodeDock", " %", nullptr));
        audioQualitySuffixLabel->setText(QCoreApplication::translate("EncodeDock", "TextLabel", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(audioTab), QCoreApplication::translate("EncodeDock", "Audio", nullptr));
        coverArtLabel->setText(QCoreApplication::translate("EncodeDock", "Cover art", nullptr));
        coverArtButton->setText(QString());
#if QT_CONFIG(tooltip)
        coverArtButton->setToolTip(QCoreApplication::translate("EncodeDock", "Browse for cover art image", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(accessibility)
        coverArtButton->setAccessibleName(QCoreApplication::translate("EncodeDock", "Browse cover art", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        coverArtButton->setAccessibleDescription(QCoreApplication::translate("EncodeDock", "Open a file dialog to select a cover art image", nullptr));
#endif // QT_CONFIG(accessibility)
        metaTitleLabel->setText(QCoreApplication::translate("EncodeDock", "Title", nullptr));
        metaArtistLabel->setText(QCoreApplication::translate("EncodeDock", "Artist", nullptr));
        metaCommentLabel->setText(QCoreApplication::translate("EncodeDock", "Comment", nullptr));
        metaCopyrightLabel->setText(QCoreApplication::translate("EncodeDock", "Copyright", nullptr));
        metaDateLabel->setText(QCoreApplication::translate("EncodeDock", "Date", nullptr));
        metaDateLineEdit->setPlaceholderText(QCoreApplication::translate("EncodeDock", "YYYY-MM-DD", nullptr));
        metaDescriptionLabel->setText(QCoreApplication::translate("EncodeDock", "Description", nullptr));
        metaGenreLabel->setText(QCoreApplication::translate("EncodeDock", "Genre", nullptr));
        metaLanguageLabel->setText(QCoreApplication::translate("EncodeDock", "Language", nullptr));
        metaLanguageLineEdit->setPlaceholderText(QCoreApplication::translate("EncodeDock", "eng", nullptr));
        disableSubtitlesCheckbox->setText(QCoreApplication::translate("EncodeDock", "Disable subtitles", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(metadataTab), QCoreApplication::translate("EncodeDock", "Metadata", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(otherTab), QCoreApplication::translate("EncodeDock", "Other", nullptr));
        encodeButton->setText(QCoreApplication::translate("EncodeDock", "Export Video/Audio", nullptr));
#if QT_CONFIG(tooltip)
        resetButton->setToolTip(QCoreApplication::translate("EncodeDock", "Reset options to defaults", nullptr));
#endif // QT_CONFIG(tooltip)
        resetButton->setText(QCoreApplication::translate("EncodeDock", "Reset", nullptr));
        advancedButton->setText(QCoreApplication::translate("EncodeDock", "Advanced", nullptr));
#if QT_CONFIG(tooltip)
        advancedCheckBox->setToolTip(QCoreApplication::translate("EncodeDock", "Always start in Advanced mode", nullptr));
#endif // QT_CONFIG(tooltip)
        advancedCheckBox->setText(QString());
        streamButton->setText(QCoreApplication::translate("EncodeDock", "Stream", nullptr));
        stopCaptureButton->setText(QCoreApplication::translate("EncodeDock", "Stop Capture", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EncodeDock: public Ui_EncodeDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ENCODEDOCK_H
