/****************************************************************************
** Meta object code from reading C++ file 'videowidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/videowidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'videowidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Mlt11VideoWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto Mlt::VideoWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3Mlt11VideoWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Mlt::VideoWidget",
        "frameDisplayed",
        "",
        "SharedFrame",
        "frame",
        "dragStarted",
        "seekTo",
        "x",
        "gpuNotSupported",
        "started",
        "paused",
        "playing",
        "rectChanged",
        "gridChanged",
        "zoomChanged",
        "offsetChanged",
        "QPoint",
        "offset",
        "imageReady",
        "snapToGridChanged",
        "toggleZoom",
        "stepZoom",
        "videoFrameReady",
        "QVideoFrame",
        "hdrTransferChanged",
        "HdrTransfer",
        "transfer",
        "setGrid",
        "grid",
        "setZoom",
        "zoom",
        "setOffsetX",
        "setOffsetY",
        "y",
        "setBlankScene",
        "setCurrentFilter",
        "QmlFilter*",
        "filter",
        "QmlMetadata*",
        "meta",
        "setSnapToGrid",
        "snap",
        "initialize",
        "beforeRendering",
        "renderVideo",
        "onFrameDisplayed",
        "showFrame",
        "Mlt::Frame",
        "p016Buffer",
        "resizeVideo",
        "width",
        "height",
        "onRefreshTimeout",
        "setVideoSink",
        "QVideoSink*",
        "sink",
        "rect",
        "QRectF",
        "snapToGrid",
        "oldVideoOutput"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frameDisplayed'
        QtMocHelpers::SignalData<void(const SharedFrame &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'dragStarted'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekTo'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'gpuNotSupported'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paused'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playing'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rectChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gridChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'offsetChanged'
        QtMocHelpers::SignalData<void(const QPoint &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'offsetChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'imageReady'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snapToGridChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleZoom'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'stepZoom'
        QtMocHelpers::SignalData<void(float, float)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 }, { QMetaType::Float, 2 },
        }}),
        // Signal 'videoFrameReady'
        QtMocHelpers::SignalData<void(const QVideoFrame &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 4 },
        }}),
        // Signal 'hdrTransferChanged'
        QtMocHelpers::SignalData<void(HdrTransfer)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'setGrid'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(float)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 30 },
        }}),
        // Slot 'setOffsetX'
        QtMocHelpers::SlotData<void(int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setOffsetY'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'setBlankScene'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentFilter'
        QtMocHelpers::SlotData<void(QmlFilter *, QmlMetadata *)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'setSnapToGrid'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'beforeRendering'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'renderVideo'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFrameDisplayed'
        QtMocHelpers::SlotData<void(const SharedFrame &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'showFrame'
        QtMocHelpers::SlotData<void(Mlt::Frame, QByteArray)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 4 }, { QMetaType::QByteArray, 48 },
        }}),
        // Slot 'showFrame'
        QtMocHelpers::SlotData<void(Mlt::Frame)>(46, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 4 },
        }}),
        // Slot 'resizeVideo'
        QtMocHelpers::SlotData<void(int, int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 50 }, { QMetaType::Int, 51 },
        }}),
        // Slot 'onRefreshTimeout'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'setVideoSink'
        QtMocHelpers::MethodData<void(QVideoSink *)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rect'
        QtMocHelpers::PropertyData<QRectF>(56, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'grid'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
        // property 'snapToGrid'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags, 13),
        // property 'zoom'
        QtMocHelpers::PropertyData<float>(30, QMetaType::Float, QMC::DefaultPropertyFlags, 9),
        // property 'offset'
        QtMocHelpers::PropertyData<QPoint>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'oldVideoOutput'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VideoWidget, qt_meta_tag_ZN3Mlt11VideoWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Mlt::VideoWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt11VideoWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt11VideoWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Mlt11VideoWidgetE_t>.metaTypes,
    nullptr
} };

void Mlt::VideoWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VideoWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 1: _t->dragStarted(); break;
        case 2: _t->seekTo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->gpuNotSupported(); break;
        case 4: _t->started(); break;
        case 5: _t->paused(); break;
        case 6: _t->playing(); break;
        case 7: _t->rectChanged(); break;
        case 8: _t->gridChanged(); break;
        case 9: _t->zoomChanged(); break;
        case 10: _t->offsetChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 11: _t->offsetChanged(); break;
        case 12: _t->imageReady(); break;
        case 13: _t->snapToGridChanged(); break;
        case 14: _t->toggleZoom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->stepZoom((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2]))); break;
        case 16: _t->videoFrameReady((*reinterpret_cast<std::add_pointer_t<QVideoFrame>>(_a[1]))); break;
        case 17: _t->hdrTransferChanged((*reinterpret_cast<std::add_pointer_t<HdrTransfer>>(_a[1]))); break;
        case 18: _t->setGrid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->setZoom((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 20: _t->setOffsetX((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setOffsetY((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->setBlankScene(); break;
        case 23: _t->setCurrentFilter((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QmlMetadata*>>(_a[2]))); break;
        case 24: _t->setSnapToGrid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->initialize(); break;
        case 26: _t->beforeRendering(); break;
        case 27: _t->renderVideo(); break;
        case 28: _t->onFrameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 29: _t->showFrame((*reinterpret_cast<std::add_pointer_t<Mlt::Frame>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 30: _t->showFrame((*reinterpret_cast<std::add_pointer_t<Mlt::Frame>>(_a[1]))); break;
        case 31: _t->resizeVideo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 32: _t->onRefreshTimeout(); break;
        case 33: _t->setVideoSink((*reinterpret_cast<std::add_pointer_t<QVideoSink*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QVideoFrame >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QVideoSink* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(const SharedFrame & )>(_a, &VideoWidget::frameDisplayed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::dragStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(int )>(_a, &VideoWidget::seekTo, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::gpuNotSupported, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::started, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::paused, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::playing, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::rectChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::gridChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::zoomChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(const QPoint & )>(_a, &VideoWidget::offsetChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::imageReady, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::snapToGridChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(bool )>(_a, &VideoWidget::toggleZoom, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(float , float )>(_a, &VideoWidget::stepZoom, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(const QVideoFrame & )>(_a, &VideoWidget::videoFrameReady, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(HdrTransfer )>(_a, &VideoWidget::hdrTransferChanged, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QRectF*>(_v) = _t->rect(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->grid(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->snapToGrid(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->zoom(); break;
        case 4: *reinterpret_cast<QPoint*>(_v) = _t->offset(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->oldVideoOutput(); break;
        default: break;
        }
    }
}

const QMetaObject *Mlt::VideoWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Mlt::VideoWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt11VideoWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Controller"))
        return static_cast< Controller*>(this);
    return QQuickWidget::qt_metacast(_clname);
}

int Mlt::VideoWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Mlt::VideoWidget::frameDisplayed(const SharedFrame & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Mlt::VideoWidget::dragStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Mlt::VideoWidget::seekTo(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Mlt::VideoWidget::gpuNotSupported()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Mlt::VideoWidget::started()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Mlt::VideoWidget::paused()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Mlt::VideoWidget::playing()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Mlt::VideoWidget::rectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Mlt::VideoWidget::gridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Mlt::VideoWidget::zoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Mlt::VideoWidget::offsetChanged(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 12
void Mlt::VideoWidget::imageReady()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Mlt::VideoWidget::snapToGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Mlt::VideoWidget::toggleZoom(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Mlt::VideoWidget::stepZoom(float _t1, float _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void Mlt::VideoWidget::videoFrameReady(const QVideoFrame & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Mlt::VideoWidget::hdrTransferChanged(HdrTransfer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3Mlt12RenderThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto Mlt::RenderThread::qt_create_metaobjectdata<qt_meta_tag_ZN3Mlt12RenderThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Mlt::RenderThread"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RenderThread, qt_meta_tag_ZN3Mlt12RenderThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Mlt::RenderThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt12RenderThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt12RenderThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Mlt12RenderThreadE_t>.metaTypes,
    nullptr
} };

void Mlt::RenderThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RenderThread *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Mlt::RenderThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Mlt::RenderThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt12RenderThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int Mlt::RenderThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3Mlt13FrameRendererE_t {};
} // unnamed namespace

template <> constexpr inline auto Mlt::FrameRenderer::qt_create_metaobjectdata<qt_meta_tag_ZN3Mlt13FrameRendererE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Mlt::FrameRenderer",
        "frameDisplayed",
        "",
        "SharedFrame",
        "frame",
        "imageReady",
        "showFrame",
        "Mlt::Frame"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frameDisplayed'
        QtMocHelpers::SignalData<void(const SharedFrame &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'imageReady'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'showFrame'
        QtMocHelpers::MethodData<void(Mlt::Frame)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FrameRenderer, qt_meta_tag_ZN3Mlt13FrameRendererE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Mlt::FrameRenderer::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt13FrameRendererE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt13FrameRendererE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Mlt13FrameRendererE_t>.metaTypes,
    nullptr
} };

void Mlt::FrameRenderer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrameRenderer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 1: _t->imageReady(); break;
        case 2: _t->showFrame((*reinterpret_cast<std::add_pointer_t<Mlt::Frame>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FrameRenderer::*)(const SharedFrame & )>(_a, &FrameRenderer::frameDisplayed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameRenderer::*)()>(_a, &FrameRenderer::imageReady, 1))
            return;
    }
}

const QMetaObject *Mlt::FrameRenderer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Mlt::FrameRenderer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Mlt13FrameRendererE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int Mlt::FrameRenderer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Mlt::FrameRenderer::frameDisplayed(const SharedFrame & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Mlt::FrameRenderer::imageReady()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
