/****************************************************************************
** Meta object code from reading C++ file 'qmlfilter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/qmltypes/qmlfilter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlfilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9QmlFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlFilter::qt_create_metaobjectdata<qt_meta_tag_ZN9QmlFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlFilter",
        "presetsChanged",
        "",
        "analyzeFinished",
        "isSuccess",
        "changed",
        "name",
        "inChanged",
        "delta",
        "outChanged",
        "animateInChanged",
        "animateOutChanged",
        "animateInOutChanged",
        "durationChanged",
        "propertyChanged",
        "preset",
        "get",
        "position",
        "getColor",
        "QColor",
        "getDouble",
        "getRect",
        "QRectF",
        "removeRectPercents",
        "getGradient",
        "set",
        "value",
        "mlt_keyframe_type",
        "keyframeType",
        "x",
        "y",
        "width",
        "height",
        "opacity",
        "rect",
        "setGradient",
        "gradient",
        "loadPresets",
        "savePreset",
        "propertyNames",
        "deletePreset",
        "analyze",
        "isAudio",
        "deferJob",
        "framesFromTime",
        "time",
        "getHash",
        "resetProperty",
        "clearSimpleAnimation",
        "keyframeCount",
        "getKeyFrameType",
        "keyIndex",
        "setKeyFrameType",
        "type",
        "getNextKeyframePosition",
        "getPrevKeyframePosition",
        "isAtLeastVersion",
        "version",
        "deselect",
        "crop",
        "copyParameters",
        "pasteParameters",
        "startUndoParameterCommand",
        "desc",
        "endUndoCommand",
        "isNew",
        "path",
        "presets",
        "in",
        "out",
        "animateIn",
        "animateOut",
        "duration",
        "blockSignals",
        "CurrentFilterIndex",
        "NoCurrentFilter",
        "DeselectCurrentFilter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'presetsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'analyzeFinished'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void(QString)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'inChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'outChanged'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'animateInChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'animateOutChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'animateInOutChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertyChanged'
        QtMocHelpers::SignalData<void(QString)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'preset'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QString(QString, int)>(16, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 17 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QString(QString)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'getColor'
        QtMocHelpers::MethodData<QColor(QString, int)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 17 },
        }}),
        // Method 'getColor'
        QtMocHelpers::MethodData<QColor(QString)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 19, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'getDouble'
        QtMocHelpers::MethodData<double(QString, int)>(20, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 17 },
        }}),
        // Method 'getDouble'
        QtMocHelpers::MethodData<double(QString)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'getRect'
        QtMocHelpers::MethodData<QRectF(QString, int)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 17 },
        }}),
        // Method 'getRect'
        QtMocHelpers::MethodData<QRectF(QString)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'removeRectPercents'
        QtMocHelpers::MethodData<void(QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'getGradient'
        QtMocHelpers::MethodData<QStringList(QString)>(24, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, QString, int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 26 }, { QMetaType::Int, 17 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, QString)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 26 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, const QColor &, int, mlt_keyframe_type)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 19, 26 }, { QMetaType::Int, 17 }, { 0x80000000 | 27, 28 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, const QColor &, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 19, 26 }, { QMetaType::Int, 17 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, const QColor &)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 19, 26 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, double, int, mlt_keyframe_type)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Double, 26 }, { QMetaType::Int, 17 }, { 0x80000000 | 27, 28 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, double, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Double, 26 }, { QMetaType::Int, 17 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, double)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Double, 26 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, int, int, mlt_keyframe_type)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 26 }, { QMetaType::Int, 17 }, { 0x80000000 | 27, 28 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, int, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 26 }, { QMetaType::Int, 17 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 26 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, bool, int, mlt_keyframe_type)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Bool, 26 }, { QMetaType::Int, 17 }, { 0x80000000 | 27, 28 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, bool, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Bool, 26 }, { QMetaType::Int, 17 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, bool)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Bool, 26 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, double, double, double, double, double, int, mlt_keyframe_type)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Double, 29 }, { QMetaType::Double, 30 }, { QMetaType::Double, 31 },
            { QMetaType::Double, 32 }, { QMetaType::Double, 33 }, { QMetaType::Int, 17 }, { 0x80000000 | 27, 28 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, double, double, double, double, double, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Double, 29 }, { QMetaType::Double, 30 }, { QMetaType::Double, 31 },
            { QMetaType::Double, 32 }, { QMetaType::Double, 33 }, { QMetaType::Int, 17 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, double, double, double, double, double)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Double, 29 }, { QMetaType::Double, 30 }, { QMetaType::Double, 31 },
            { QMetaType::Double, 32 }, { QMetaType::Double, 33 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, double, double, double, double)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Double, 29 }, { QMetaType::Double, 30 }, { QMetaType::Double, 31 },
            { QMetaType::Double, 32 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, const QRectF &, int, mlt_keyframe_type)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 22, 34 }, { QMetaType::Int, 17 }, { 0x80000000 | 27, 28 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, const QRectF &, int)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 22, 34 }, { QMetaType::Int, 17 },
        }}),
        // Method 'set'
        QtMocHelpers::MethodData<void(QString, const QRectF &)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 22, 34 },
        }}),
        // Method 'setGradient'
        QtMocHelpers::MethodData<void(QString, const QStringList &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QStringList, 36 },
        }}),
        // Method 'loadPresets'
        QtMocHelpers::MethodData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'savePreset'
        QtMocHelpers::MethodData<int(const QStringList &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QStringList, 39 }, { QMetaType::QString, 6 },
        }}),
        // Method 'savePreset'
        QtMocHelpers::MethodData<int(const QStringList &)>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::QStringList, 39 },
        }}),
        // Method 'deletePreset'
        QtMocHelpers::MethodData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'analyze'
        QtMocHelpers::MethodData<void(bool, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Method 'analyze'
        QtMocHelpers::MethodData<void(bool)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Method 'analyze'
        QtMocHelpers::MethodData<void()>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'framesFromTime'
        QtMocHelpers::MethodData<int(const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 45 },
        }}),
        // Method 'getHash'
        QtMocHelpers::MethodData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'resetProperty'
        QtMocHelpers::MethodData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'clearSimpleAnimation'
        QtMocHelpers::MethodData<void(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'keyframeCount'
        QtMocHelpers::MethodData<int(const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'getKeyFrameType'
        QtMocHelpers::MethodData<int(const QString &, int)>(50, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 51 },
        }}),
        // Method 'setKeyFrameType'
        QtMocHelpers::MethodData<void(const QString &, int, int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 51 }, { QMetaType::Int, 53 },
        }}),
        // Method 'getNextKeyframePosition'
        QtMocHelpers::MethodData<int(const QString &, int)>(54, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 17 },
        }}),
        // Method 'getPrevKeyframePosition'
        QtMocHelpers::MethodData<int(const QString &, int)>(55, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 17 },
        }}),
        // Method 'isAtLeastVersion'
        QtMocHelpers::MethodData<bool(const QString &)>(56, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 57 },
        }}),
        // Method 'deselect'
        QtMocHelpers::MethodData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'crop'
        QtMocHelpers::MethodData<void(const QRectF &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 34 },
        }}),
        // Method 'copyParameters'
        QtMocHelpers::MethodData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'pasteParameters'
        QtMocHelpers::MethodData<void(const QStringList &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 39 },
        }}),
        // Method 'startUndoParameterCommand'
        QtMocHelpers::MethodData<void(const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 63 },
        }}),
        // Method 'startUndoParameterCommand'
        QtMocHelpers::MethodData<void()>(62, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'endUndoCommand'
        QtMocHelpers::MethodData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isNew'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'path'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'presets'
        QtMocHelpers::PropertyData<QStringList>(67, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'in'
        QtMocHelpers::PropertyData<int>(68, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'out'
        QtMocHelpers::PropertyData<int>(69, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'animateIn'
        QtMocHelpers::PropertyData<int>(70, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'animateOut'
        QtMocHelpers::PropertyData<int>(71, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(72, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'blockSignals'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CurrentFilterIndex'
        QtMocHelpers::EnumData<enum CurrentFilterIndex>(74, 74, QMC::EnumFlags{}).add({
            {   75, CurrentFilterIndex::NoCurrentFilter },
            {   76, CurrentFilterIndex::DeselectCurrentFilter },
        }),
    };
    return QtMocHelpers::metaObjectData<QmlFilter, qt_meta_tag_ZN9QmlFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QmlFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QmlFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QmlFilterE_t>.metaTypes,
    nullptr
} };

void QmlFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->presetsChanged(); break;
        case 1: _t->analyzeFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->changed(); break;
        case 4: _t->inChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->outChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->animateInChanged(); break;
        case 7: _t->animateOutChanged(); break;
        case 8: _t->animateInOutChanged(); break;
        case 9: _t->durationChanged(); break;
        case 10: _t->propertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->preset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { QString _r = _t->get((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->get((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QColor _r = _t->getColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 15: { QColor _r = _t->getColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 16: { double _r = _t->getDouble((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 17: { double _r = _t->getDouble((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 18: { QRectF _r = _t->getRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 19: { QRectF _r = _t->getRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->removeRectPercents((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: { QStringList _r = _t->getGradient((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 23: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<mlt_keyframe_type>>(_a[4]))); break;
        case 25: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 26: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        case 27: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<mlt_keyframe_type>>(_a[4]))); break;
        case 28: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 29: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2]))); break;
        case 30: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<mlt_keyframe_type>>(_a[4]))); break;
        case 31: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 32: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 33: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<mlt_keyframe_type>>(_a[4]))); break;
        case 34: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 35: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 36: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<mlt_keyframe_type>>(_a[8]))); break;
        case 37: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 38: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6]))); break;
        case 39: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5]))); break;
        case 40: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<mlt_keyframe_type>>(_a[4]))); break;
        case 41: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 42: _t->set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[2]))); break;
        case 43: _t->setGradient((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 44: _t->loadPresets(); break;
        case 45: { int _r = _t->savePreset((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 46: { int _r = _t->savePreset((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->deletePreset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 48: _t->analyze((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 49: _t->analyze((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 50: _t->analyze(); break;
        case 51: { int _r = _t->framesFromTime((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->getHash(); break;
        case 53: _t->resetProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 54: _t->clearSimpleAnimation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 55: { int _r = _t->keyframeCount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: { int _r = _t->getKeyFrameType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->setKeyFrameType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 58: { int _r = _t->getNextKeyframePosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 59: { int _r = _t->getPrevKeyframePosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 60: { bool _r = _t->isAtLeastVersion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 61: _t->deselect(); break;
        case 62: _t->crop((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 63: _t->copyParameters(); break;
        case 64: _t->pasteParameters((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 65: _t->startUndoParameterCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 66: _t->startUndoParameterCommand(); break;
        case 67: _t->endUndoCommand(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)()>(_a, &QmlFilter::presetsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)(bool )>(_a, &QmlFilter::analyzeFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)(QString )>(_a, &QmlFilter::changed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)(int )>(_a, &QmlFilter::inChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)(int )>(_a, &QmlFilter::outChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)()>(_a, &QmlFilter::animateInChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)()>(_a, &QmlFilter::animateOutChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)()>(_a, &QmlFilter::animateInOutChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)()>(_a, &QmlFilter::durationChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlFilter::*)(QString )>(_a, &QmlFilter::propertyChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isNew(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->presets(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->in(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->out(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->animateIn(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->animateOut(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->duration(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->signalsBlocked(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setAnimateIn(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setAnimateOut(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->blockSignals(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QmlFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QmlFilterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 68)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 68;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 68)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 68;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QmlFilter::presetsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QmlFilter::analyzeFinished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QmlFilter::changed(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 4
void QmlFilter::inChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QmlFilter::outChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QmlFilter::animateInChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QmlFilter::animateOutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QmlFilter::animateInOutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QmlFilter::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QmlFilter::propertyChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN15AnalyzeDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto AnalyzeDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN15AnalyzeDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AnalyzeDelegate",
        "onAnalyzeFinished",
        "",
        "AbstractJob*",
        "job",
        "isSuccess"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onAnalyzeFinished'
        QtMocHelpers::SlotData<void(AbstractJob *, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AnalyzeDelegate, qt_meta_tag_ZN15AnalyzeDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AnalyzeDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AnalyzeDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AnalyzeDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15AnalyzeDelegateE_t>.metaTypes,
    nullptr
} };

void AnalyzeDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AnalyzeDelegate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAnalyzeFinished((*reinterpret_cast<std::add_pointer_t<AbstractJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *AnalyzeDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AnalyzeDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AnalyzeDelegateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AnalyzeDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
