/********************************************************************************
** Form generated from reading UI file 'textproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEXTPRODUCERWIDGET_H
#define UI_TEXTPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_TextProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    ServicePresetWidget *preset;
    QPlainTextEdit *plainTextEdit;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *colorButton;
    QLabel *colorLabel;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout;
    QRadioButton *simpleRadioButton;
    QRadioButton *richRadioButton;
    QRadioButton *typeWriterRadioButton;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TextProducerWidget)
    {
        if (TextProducerWidget->objectName().isEmpty())
            TextProducerWidget->setObjectName("TextProducerWidget");
        TextProducerWidget->resize(396, 296);
#if QT_CONFIG(whatsthis)
        TextProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-text/12926/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(TextProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(TextProducerWidget);
        label_2->setObjectName("label_2");
        QFont font;
        font.setBold(true);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label_2);

        preset = new ServicePresetWidget(TextProducerWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        plainTextEdit = new QPlainTextEdit(TextProducerWidget);
        plainTextEdit->setObjectName("plainTextEdit");

        verticalLayout->addWidget(plainTextEdit);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        colorButton = new QPushButton(TextProducerWidget);
        colorButton->setObjectName("colorButton");

        horizontalLayout_2->addWidget(colorButton);

        colorLabel = new QLabel(TextProducerWidget);
        colorLabel->setObjectName("colorLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(colorLabel->sizePolicy().hasHeightForWidth());
        colorLabel->setSizePolicy(sizePolicy);
        colorLabel->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        horizontalLayout_2->addWidget(colorLabel);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_8);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        simpleRadioButton = new QRadioButton(TextProducerWidget);
        simpleRadioButton->setObjectName("simpleRadioButton");
        simpleRadioButton->setChecked(true);

        horizontalLayout->addWidget(simpleRadioButton);

        richRadioButton = new QRadioButton(TextProducerWidget);
        richRadioButton->setObjectName("richRadioButton");

        horizontalLayout->addWidget(richRadioButton);

        typeWriterRadioButton = new QRadioButton(TextProducerWidget);
        typeWriterRadioButton->setObjectName("typeWriterRadioButton");

        horizontalLayout->addWidget(typeWriterRadioButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        label = new QLabel(TextProducerWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignCenter);
        label->setWordWrap(true);
        label->setMargin(10);

        verticalLayout->addWidget(label);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(TextProducerWidget);

        QMetaObject::connectSlotsByName(TextProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *TextProducerWidget)
    {
        TextProducerWidget->setWindowTitle(QCoreApplication::translate("TextProducerWidget", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("TextProducerWidget", "Text", nullptr));
        plainTextEdit->setPlaceholderText(QCoreApplication::translate("TextProducerWidget", "Type or paste the text here", nullptr));
        colorButton->setText(QCoreApplication::translate("TextProducerWidget", "Background color...", nullptr));
        colorLabel->setText(QCoreApplication::translate("TextProducerWidget", "#00000000", nullptr));
        simpleRadioButton->setText(QCoreApplication::translate("TextProducerWidget", "Simple", nullptr));
        richRadioButton->setText(QCoreApplication::translate("TextProducerWidget", "Rich", nullptr));
        typeWriterRadioButton->setText(QCoreApplication::translate("TextProducerWidget", "Typewriter", nullptr));
        label->setText(QCoreApplication::translate("TextProducerWidget", "Text attributes are available in the <b>Filters</b> panel after clicking <b>OK</b>.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TextProducerWidget: public Ui_TextProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TEXTPRODUCERWIDGET_H
