/****************************************************************************
** Meta object code from reading C++ file 'keyframesdock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/docks/keyframesdock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyframesdock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KeyframesDockE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyframesDock::qt_create_metaobjectdata<qt_meta_tag_ZN13KeyframesDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyframesDock",
        "changed",
        "",
        "setZoom",
        "value",
        "zoomIn",
        "zoomOut",
        "zoomToFit",
        "resetZoom",
        "seekPreviousSimple",
        "seekNextSimple",
        "newFilter",
        "timeScaleChanged",
        "dockClicked",
        "setCurrentFilter",
        "QmlFilter*",
        "filter",
        "QmlMetadata*",
        "meta",
        "load",
        "force",
        "reload",
        "onProducerModified",
        "onDockRightClicked",
        "onKeyframeRightClicked",
        "onClipRightClicked",
        "seekPrevious",
        "seekNext",
        "timeScale"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setZoom'
        QtMocHelpers::SignalData<void(double)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Signal 'zoomIn'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomOut'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomToFit'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetZoom'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekPreviousSimple'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekNextSimple'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newFilter'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeScaleChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dockClicked'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentFilter'
        QtMocHelpers::SlotData<void(QmlFilter *, QmlMetadata *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerModified'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDockRightClicked'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onKeyframeRightClicked'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onClipRightClicked'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'seekPrevious'
        QtMocHelpers::MethodData<int()>(26, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'seekNext'
        QtMocHelpers::MethodData<int()>(27, 2, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timeScale'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyframesDock, qt_meta_tag_ZN13KeyframesDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyframesDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KeyframesDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KeyframesDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KeyframesDockE_t>.metaTypes,
    nullptr
} };

void KeyframesDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyframesDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->setZoom((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->zoomIn(); break;
        case 3: _t->zoomOut(); break;
        case 4: _t->zoomToFit(); break;
        case 5: _t->resetZoom(); break;
        case 6: _t->seekPreviousSimple(); break;
        case 7: _t->seekNextSimple(); break;
        case 8: _t->newFilter(); break;
        case 9: _t->timeScaleChanged(); break;
        case 10: _t->dockClicked(); break;
        case 11: _t->setCurrentFilter((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QmlMetadata*>>(_a[2]))); break;
        case 12: _t->load((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->load(); break;
        case 14: _t->reload(); break;
        case 15: _t->onProducerModified(); break;
        case 16: _t->onDockRightClicked(); break;
        case 17: _t->onKeyframeRightClicked(); break;
        case 18: _t->onClipRightClicked(); break;
        case 19: { int _r = _t->seekPrevious();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { int _r = _t->seekNext();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QmlFilter* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QmlMetadata* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)(double )>(_a, &KeyframesDock::setZoom, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::zoomIn, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::zoomOut, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::zoomToFit, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::resetZoom, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::seekPreviousSimple, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::seekNextSimple, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::newFilter, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::timeScaleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframesDock::*)()>(_a, &KeyframesDock::dockClicked, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<double*>(_v) = _t->timeScale(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTimeScale(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeyframesDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyframesDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KeyframesDockE_t>.strings))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int KeyframesDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KeyframesDock::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeyframesDock::setZoom(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KeyframesDock::zoomIn()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeyframesDock::zoomOut()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KeyframesDock::zoomToFit()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KeyframesDock::resetZoom()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KeyframesDock::seekPreviousSimple()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KeyframesDock::seekNextSimple()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KeyframesDock::newFilter()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KeyframesDock::timeScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KeyframesDock::dockClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
