/********************************************************************************
** Form generated from reading UI file 'recentdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RECENTDOCK_H
#define UI_RECENTDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QListView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/lineeditclear.h"

QT_BEGIN_NAMESPACE

class Ui_RecentDock
{
public:
    QAction *actionDelete;
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    LineEditClear *lineEdit;
    QListView *listWidget;

    void setupUi(QDockWidget *RecentDock)
    {
        if (RecentDock->objectName().isEmpty())
            RecentDock->setObjectName("RecentDock");
        RecentDock->resize(396, 296);
        RecentDock->setMinimumSize(QSize(150, 141));
#if QT_CONFIG(whatsthis)
        RecentDock->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/recent-panel/12941/1"));
#endif // QT_CONFIG(whatsthis)
        actionDelete = new QAction(RecentDock);
        actionDelete->setObjectName("actionDelete");
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        lineEdit = new LineEditClear(dockWidgetContents);
        lineEdit->setObjectName("lineEdit");

        verticalLayout->addWidget(lineEdit);

        listWidget = new QListView(dockWidgetContents);
        listWidget->setObjectName("listWidget");
        listWidget->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        listWidget->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        listWidget->setAlternatingRowColors(true);
        listWidget->setSpacing(2);

        verticalLayout->addWidget(listWidget);

        RecentDock->setWidget(dockWidgetContents);

        retranslateUi(RecentDock);

        QMetaObject::connectSlotsByName(RecentDock);
    } // setupUi

    void retranslateUi(QDockWidget *RecentDock)
    {
        RecentDock->setWindowTitle(QCoreApplication::translate("RecentDock", "Recent", nullptr));
        actionDelete->setText(QCoreApplication::translate("RecentDock", "Remove", nullptr));
#if QT_CONFIG(tooltip)
        actionDelete->setToolTip(QCoreApplication::translate("RecentDock", "Remove", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lineEdit->setToolTip(QCoreApplication::translate("RecentDock", "Show only files with name matching text", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEdit->setPlaceholderText(QCoreApplication::translate("RecentDock", "search", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RecentDock: public Ui_RecentDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_RECENTDOCK_H
