/********************************************************************************
** Form generated from reading UI file 'lissajouswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISSAJOUSWIDGET_H
#define UI_LISSAJOUSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDial>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_LissajousWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    ServicePresetWidget *preset;
    QHBoxLayout *horizontalLayout_7;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_9;
    QDial *xratioDial;
    QHBoxLayout *horizontalLayout_8;
    QSpacerItem *horizontalSpacer_9;
    QDoubleSpinBox *xratioSpinner;
    QSpacerItem *horizontalSpacer_10;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_10;
    QDial *yratioDial;
    QHBoxLayout *horizontalLayout_9;
    QSpacerItem *horizontalSpacer_11;
    QDoubleSpinBox *yratioSpinner;
    QSpacerItem *horizontalSpacer_12;
    QSpacerItem *verticalSpacer_4;

    void setupUi(QWidget *LissajousWidget)
    {
        if (LissajousWidget->objectName().isEmpty())
            LissajousWidget->setObjectName("LissajousWidget");
        LissajousWidget->resize(400, 300);
#if QT_CONFIG(whatsthis)
        LissajousWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-lissajous/12929/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(LissajousWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(LissajousWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        preset = new ServicePresetWidget(LissajousWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        groupBox_4 = new QGroupBox(LissajousWidget);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_9 = new QVBoxLayout(groupBox_4);
        verticalLayout_9->setObjectName("verticalLayout_9");
        xratioDial = new QDial(groupBox_4);
        xratioDial->setObjectName("xratioDial");
        xratioDial->setMaximum(100);
        xratioDial->setOrientation(Qt::Orientation::Vertical);
        xratioDial->setNotchesVisible(true);

        verticalLayout_9->addWidget(xratioDial);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_9);

        xratioSpinner = new QDoubleSpinBox(groupBox_4);
        xratioSpinner->setObjectName("xratioSpinner");
        xratioSpinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        xratioSpinner->setMaximum(1.000000000000000);
        xratioSpinner->setSingleStep(0.100000000000000);

        horizontalLayout_8->addWidget(xratioSpinner);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_10);


        verticalLayout_9->addLayout(horizontalLayout_8);


        horizontalLayout_7->addWidget(groupBox_4);

        groupBox_5 = new QGroupBox(LissajousWidget);
        groupBox_5->setObjectName("groupBox_5");
        verticalLayout_10 = new QVBoxLayout(groupBox_5);
        verticalLayout_10->setObjectName("verticalLayout_10");
        yratioDial = new QDial(groupBox_5);
        yratioDial->setObjectName("yratioDial");
        yratioDial->setMaximum(100);
        yratioDial->setNotchesVisible(true);

        verticalLayout_10->addWidget(yratioDial);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_11);

        yratioSpinner = new QDoubleSpinBox(groupBox_5);
        yratioSpinner->setObjectName("yratioSpinner");
        yratioSpinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        yratioSpinner->setMaximum(1.000000000000000);
        yratioSpinner->setSingleStep(0.100000000000000);

        horizontalLayout_9->addWidget(yratioSpinner);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_12);


        verticalLayout_10->addLayout(horizontalLayout_9);


        horizontalLayout_7->addWidget(groupBox_5);


        verticalLayout->addLayout(horizontalLayout_7);

        verticalSpacer_4 = new QSpacerItem(20, 101, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_4);


        retranslateUi(LissajousWidget);

        QMetaObject::connectSlotsByName(LissajousWidget);
    } // setupUi

    void retranslateUi(QWidget *LissajousWidget)
    {
        LissajousWidget->setWindowTitle(QCoreApplication::translate("LissajousWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("LissajousWidget", "Lissajous", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("LissajousWidget", "X Ratio", nullptr));
        groupBox_5->setTitle(QCoreApplication::translate("LissajousWidget", "Y Ratio", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LissajousWidget: public Ui_LissajousWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LISSAJOUSWIDGET_H
