/********************************************************************************
** Form generated from reading UI file 'openotherdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENOTHERDIALOG_H
#define UI_OPENOTHERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/alsawidget.h"
#include "widgets/avfoundationproducerwidget.h"
#include "widgets/blipproducerwidget.h"
#include "widgets/colorbarswidget.h"
#include "widgets/colorproducerwidget.h"
#include "widgets/countproducerwidget.h"
#include "widgets/decklinkproducerwidget.h"
#include "widgets/directshowvideowidget.h"
#include "widgets/glaxnimateproducerwidget.h"
#include "widgets/isingwidget.h"
#include "widgets/lissajouswidget.h"
#include "widgets/networkproducerwidget.h"
#include "widgets/noisewidget.h"
#include "widgets/plasmawidget.h"
#include "widgets/pulseaudiowidget.h"
#include "widgets/textproducerwidget.h"
#include "widgets/toneproducerwidget.h"
#include "widgets/video4linuxwidget.h"

QT_BEGIN_NAMESPACE

class Ui_OpenOtherDialog
{
public:
    QVBoxLayout *verticalLayout_19;
    QSplitter *splitter;
    QTreeWidget *treeWidget;
    QStackedWidget *methodTabWidget;
    QWidget *networkTab;
    QVBoxLayout *verticalLayout_3;
    NetworkProducerWidget *networkWidget;
    QWidget *decklinkTab;
    QVBoxLayout *verticalLayout_2;
    DecklinkProducerWidget *decklinkWidget;
    QWidget *dshowVideoTab;
    QVBoxLayout *verticalLayout_14;
    DirectShowVideoWidget *dshowVideoWidget;
    QWidget *avfoundationTab;
    QVBoxLayout *verticalLayout_15;
    AvfoundationProducerWidget *avfoundationWidget;
    QWidget *colorTab;
    QVBoxLayout *verticalLayout_4;
    ColorProducerWidget *colorWidget;
    QWidget *textTab;
    QVBoxLayout *verticalLayout;
    TextProducerWidget *textWidget;
    QWidget *glaxnimateTab;
    QVBoxLayout *verticalLayout_21;
    GlaxnimateProducerWidget *glaxnimateWidget;
    QWidget *noiseTab;
    QVBoxLayout *verticalLayout_7;
    NoiseWidget *noiseWidget;
    QWidget *isingTab;
    QVBoxLayout *verticalLayout_5;
    IsingWidget *isingWidget;
    QWidget *lissajousTab;
    QVBoxLayout *verticalLayout_12;
    LissajousWidget *lissajousWidget;
    QWidget *plasmaTab;
    QVBoxLayout *verticalLayout_13;
    PlasmaWidget *plasmaWidget;
    QWidget *v4lTab;
    QGridLayout *gridLayout_3;
    Video4LinuxWidget *v4lWidget;
    QWidget *colorbarsTab;
    QVBoxLayout *verticalLayout_6;
    ColorBarsWidget *colorbarsWidget;
    QWidget *pulseTab;
    QVBoxLayout *verticalLayout_8;
    PulseAudioWidget *pulseWidget;
    QWidget *alsaTab;
    QVBoxLayout *verticalLayout_10;
    AlsaWidget *alsaWidget;
    QWidget *toneTab;
    QVBoxLayout *verticalLayout_17;
    ToneProducerWidget *toneWidget;
    QWidget *countTab;
    QVBoxLayout *verticalLayout_18;
    CountProducerWidget *countWidget;
    QWidget *blipTab;
    QVBoxLayout *verticalLayout_20;
    BlipProducerWidget *blipWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OpenOtherDialog)
    {
        if (OpenOtherDialog->objectName().isEmpty())
            OpenOtherDialog->setObjectName("OpenOtherDialog");
        OpenOtherDialog->setWindowModality(Qt::WindowModality::WindowModal);
        OpenOtherDialog->resize(668, 478);
#if QT_CONFIG(whatsthis)
        OpenOtherDialog->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/user-guide-table-of-contents/43285#p-145073-properties-14"));
#endif // QT_CONFIG(whatsthis)
        OpenOtherDialog->setSizeGripEnabled(true);
        verticalLayout_19 = new QVBoxLayout(OpenOtherDialog);
        verticalLayout_19->setObjectName("verticalLayout_19");
        splitter = new QSplitter(OpenOtherDialog);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Orientation::Horizontal);
        splitter->setHandleWidth(0);
        splitter->setChildrenCollapsible(false);
        treeWidget = new QTreeWidget(splitter);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setMinimumSize(QSize(140, 0));
        treeWidget->setRootIsDecorated(false);
        treeWidget->setItemsExpandable(false);
        treeWidget->setExpandsOnDoubleClick(false);
        splitter->addWidget(treeWidget);
        treeWidget->header()->setVisible(false);
        methodTabWidget = new QStackedWidget(splitter);
        methodTabWidget->setObjectName("methodTabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(methodTabWidget->sizePolicy().hasHeightForWidth());
        methodTabWidget->setSizePolicy(sizePolicy);
        networkTab = new QWidget();
        networkTab->setObjectName("networkTab");
        verticalLayout_3 = new QVBoxLayout(networkTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        networkWidget = new NetworkProducerWidget(networkTab);
        networkWidget->setObjectName("networkWidget");

        verticalLayout_3->addWidget(networkWidget);

        methodTabWidget->addWidget(networkTab);
        decklinkTab = new QWidget();
        decklinkTab->setObjectName("decklinkTab");
        verticalLayout_2 = new QVBoxLayout(decklinkTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        decklinkWidget = new DecklinkProducerWidget(decklinkTab);
        decklinkWidget->setObjectName("decklinkWidget");

        verticalLayout_2->addWidget(decklinkWidget);

        methodTabWidget->addWidget(decklinkTab);
        dshowVideoTab = new QWidget();
        dshowVideoTab->setObjectName("dshowVideoTab");
        verticalLayout_14 = new QVBoxLayout(dshowVideoTab);
        verticalLayout_14->setObjectName("verticalLayout_14");
        dshowVideoWidget = new DirectShowVideoWidget(dshowVideoTab);
        dshowVideoWidget->setObjectName("dshowVideoWidget");

        verticalLayout_14->addWidget(dshowVideoWidget);

        methodTabWidget->addWidget(dshowVideoTab);
        avfoundationTab = new QWidget();
        avfoundationTab->setObjectName("avfoundationTab");
        verticalLayout_15 = new QVBoxLayout(avfoundationTab);
        verticalLayout_15->setObjectName("verticalLayout_15");
        avfoundationWidget = new AvfoundationProducerWidget(avfoundationTab);
        avfoundationWidget->setObjectName("avfoundationWidget");

        verticalLayout_15->addWidget(avfoundationWidget);

        methodTabWidget->addWidget(avfoundationTab);
        colorTab = new QWidget();
        colorTab->setObjectName("colorTab");
        verticalLayout_4 = new QVBoxLayout(colorTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        colorWidget = new ColorProducerWidget(colorTab);
        colorWidget->setObjectName("colorWidget");

        verticalLayout_4->addWidget(colorWidget);

        methodTabWidget->addWidget(colorTab);
        textTab = new QWidget();
        textTab->setObjectName("textTab");
        verticalLayout = new QVBoxLayout(textTab);
        verticalLayout->setObjectName("verticalLayout");
        textWidget = new TextProducerWidget(textTab);
        textWidget->setObjectName("textWidget");

        verticalLayout->addWidget(textWidget);

        methodTabWidget->addWidget(textTab);
        glaxnimateTab = new QWidget();
        glaxnimateTab->setObjectName("glaxnimateTab");
        verticalLayout_21 = new QVBoxLayout(glaxnimateTab);
        verticalLayout_21->setObjectName("verticalLayout_21");
        glaxnimateWidget = new GlaxnimateProducerWidget(glaxnimateTab);
        glaxnimateWidget->setObjectName("glaxnimateWidget");

        verticalLayout_21->addWidget(glaxnimateWidget);

        methodTabWidget->addWidget(glaxnimateTab);
        noiseTab = new QWidget();
        noiseTab->setObjectName("noiseTab");
        verticalLayout_7 = new QVBoxLayout(noiseTab);
        verticalLayout_7->setObjectName("verticalLayout_7");
        noiseWidget = new NoiseWidget(noiseTab);
        noiseWidget->setObjectName("noiseWidget");

        verticalLayout_7->addWidget(noiseWidget);

        methodTabWidget->addWidget(noiseTab);
        isingTab = new QWidget();
        isingTab->setObjectName("isingTab");
        verticalLayout_5 = new QVBoxLayout(isingTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        isingWidget = new IsingWidget(isingTab);
        isingWidget->setObjectName("isingWidget");

        verticalLayout_5->addWidget(isingWidget);

        methodTabWidget->addWidget(isingTab);
        lissajousTab = new QWidget();
        lissajousTab->setObjectName("lissajousTab");
        verticalLayout_12 = new QVBoxLayout(lissajousTab);
        verticalLayout_12->setObjectName("verticalLayout_12");
        lissajousWidget = new LissajousWidget(lissajousTab);
        lissajousWidget->setObjectName("lissajousWidget");

        verticalLayout_12->addWidget(lissajousWidget);

        methodTabWidget->addWidget(lissajousTab);
        plasmaTab = new QWidget();
        plasmaTab->setObjectName("plasmaTab");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(10);
        sizePolicy1.setVerticalStretch(10);
        sizePolicy1.setHeightForWidth(plasmaTab->sizePolicy().hasHeightForWidth());
        plasmaTab->setSizePolicy(sizePolicy1);
        verticalLayout_13 = new QVBoxLayout(plasmaTab);
        verticalLayout_13->setObjectName("verticalLayout_13");
        plasmaWidget = new PlasmaWidget(plasmaTab);
        plasmaWidget->setObjectName("plasmaWidget");

        verticalLayout_13->addWidget(plasmaWidget);

        methodTabWidget->addWidget(plasmaTab);
        v4lTab = new QWidget();
        v4lTab->setObjectName("v4lTab");
        gridLayout_3 = new QGridLayout(v4lTab);
        gridLayout_3->setObjectName("gridLayout_3");
        v4lWidget = new Video4LinuxWidget(v4lTab);
        v4lWidget->setObjectName("v4lWidget");

        gridLayout_3->addWidget(v4lWidget, 0, 0, 1, 1);

        methodTabWidget->addWidget(v4lTab);
        colorbarsTab = new QWidget();
        colorbarsTab->setObjectName("colorbarsTab");
        verticalLayout_6 = new QVBoxLayout(colorbarsTab);
        verticalLayout_6->setObjectName("verticalLayout_6");
        colorbarsWidget = new ColorBarsWidget(colorbarsTab);
        colorbarsWidget->setObjectName("colorbarsWidget");

        verticalLayout_6->addWidget(colorbarsWidget);

        methodTabWidget->addWidget(colorbarsTab);
        pulseTab = new QWidget();
        pulseTab->setObjectName("pulseTab");
        verticalLayout_8 = new QVBoxLayout(pulseTab);
        verticalLayout_8->setObjectName("verticalLayout_8");
        pulseWidget = new PulseAudioWidget(pulseTab);
        pulseWidget->setObjectName("pulseWidget");

        verticalLayout_8->addWidget(pulseWidget);

        methodTabWidget->addWidget(pulseTab);
        alsaTab = new QWidget();
        alsaTab->setObjectName("alsaTab");
        verticalLayout_10 = new QVBoxLayout(alsaTab);
        verticalLayout_10->setObjectName("verticalLayout_10");
        alsaWidget = new AlsaWidget(alsaTab);
        alsaWidget->setObjectName("alsaWidget");

        verticalLayout_10->addWidget(alsaWidget);

        methodTabWidget->addWidget(alsaTab);
        toneTab = new QWidget();
        toneTab->setObjectName("toneTab");
        verticalLayout_17 = new QVBoxLayout(toneTab);
        verticalLayout_17->setObjectName("verticalLayout_17");
        toneWidget = new ToneProducerWidget(toneTab);
        toneWidget->setObjectName("toneWidget");

        verticalLayout_17->addWidget(toneWidget);

        methodTabWidget->addWidget(toneTab);
        countTab = new QWidget();
        countTab->setObjectName("countTab");
        verticalLayout_18 = new QVBoxLayout(countTab);
        verticalLayout_18->setObjectName("verticalLayout_18");
        countWidget = new CountProducerWidget(countTab);
        countWidget->setObjectName("countWidget");

        verticalLayout_18->addWidget(countWidget);

        methodTabWidget->addWidget(countTab);
        blipTab = new QWidget();
        blipTab->setObjectName("blipTab");
        verticalLayout_20 = new QVBoxLayout(blipTab);
        verticalLayout_20->setObjectName("verticalLayout_20");
        blipWidget = new BlipProducerWidget(blipTab);
        blipWidget->setObjectName("blipWidget");

        verticalLayout_20->addWidget(blipWidget);

        methodTabWidget->addWidget(blipTab);
        splitter->addWidget(methodTabWidget);

        verticalLayout_19->addWidget(splitter);

        buttonBox = new QDialogButtonBox(OpenOtherDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_19->addWidget(buttonBox);


        retranslateUi(OpenOtherDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, OpenOtherDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, OpenOtherDialog, qOverload<>(&QDialog::reject));

        methodTabWidget->setCurrentIndex(5);


        QMetaObject::connectSlotsByName(OpenOtherDialog);
    } // setupUi

    void retranslateUi(QDialog *OpenOtherDialog)
    {
        OpenOtherDialog->setWindowTitle(QCoreApplication::translate("OpenOtherDialog", "Open Other", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("OpenOtherDialog", "1", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OpenOtherDialog: public Ui_OpenOtherDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENOTHERDIALOG_H
