/********************************************************************************
** Form generated from reading UI file 'playlistdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLAYLISTDOCK_H
#define UI_PLAYLISTDOCK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "docks/playlistdock.h"
#include "widgets/playlistlistview.h"
#include "widgets/playlisttable.h"

QT_BEGIN_NAMESPACE

class Ui_PlaylistDock
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QVBoxLayout *verticalLayout_2;
    QTextBrowser *textBrowser;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *filtersLayout;
    QSplitter *splitter;
    BinTree *treeWidget;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout_3;
    PlaylistTable *tableView;
    PlaylistListView *listView;

    void setupUi(QDockWidget *PlaylistDock)
    {
        if (PlaylistDock->objectName().isEmpty())
            PlaylistDock->setObjectName("PlaylistDock");
        PlaylistDock->resize(460, 278);
#if QT_CONFIG(whatsthis)
        PlaylistDock->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/about-the-playlist/12951/1"));
#endif // QT_CONFIG(whatsthis)
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        stackedWidget = new QStackedWidget(dockWidgetContents);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        verticalLayout_2 = new QVBoxLayout(page);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        textBrowser = new QTextBrowser(page);
        textBrowser->setObjectName("textBrowser");

        verticalLayout_2->addWidget(textBrowser);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_4 = new QVBoxLayout(page_2);
        verticalLayout_4->setSpacing(0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        filtersLayout = new QHBoxLayout();
        filtersLayout->setObjectName("filtersLayout");

        verticalLayout_4->addLayout(filtersLayout);

        splitter = new QSplitter(page_2);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Orientation::Horizontal);
        treeWidget = new BinTree(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        treeWidget->setHeaderItem(__qtreewidgetitem);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setAcceptDrops(true);
        treeWidget->setStyleSheet(QString::fromUtf8("QTreeWidget::item { padding: 10px }"));
        treeWidget->setAlternatingRowColors(true);
        treeWidget->setRootIsDecorated(false);
        splitter->addWidget(treeWidget);
        treeWidget->header()->setVisible(false);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout_3 = new QVBoxLayout(layoutWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        tableView = new PlaylistTable(layoutWidget);
        tableView->setObjectName("tableView");
        tableView->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        tableView->setDragEnabled(false);
        tableView->setAlternatingRowColors(true);
        tableView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        tableView->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);
        tableView->setHorizontalScrollMode(QAbstractItemView::ScrollMode::ScrollPerPixel);
        tableView->horizontalHeader()->setHighlightSections(false);
        tableView->verticalHeader()->setVisible(false);

        verticalLayout_3->addWidget(tableView);

        listView = new PlaylistListView(layoutWidget);
        listView->setObjectName("listView");
        listView->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        listView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        listView->setMovement(QListView::Movement::Static);

        verticalLayout_3->addWidget(listView);

        splitter->addWidget(layoutWidget);

        verticalLayout_4->addWidget(splitter);

        stackedWidget->addWidget(page_2);

        verticalLayout->addWidget(stackedWidget);

        PlaylistDock->setWidget(dockWidgetContents);

        retranslateUi(PlaylistDock);

        stackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(PlaylistDock);
    } // setupUi

    void retranslateUi(QDockWidget *PlaylistDock)
    {
        PlaylistDock->setWindowTitle(QCoreApplication::translate("PlaylistDock", "Playlist", nullptr));
        textBrowser->setHtml(QCoreApplication::translate("PlaylistDock", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body>\n"
"<p style=\" margin-top:12px; margin-bottom:16px; margin-left:-24px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Double-click</span> a playlist item to open it in the player.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:16px; margin-left:-24px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You can freely preview clips without necessarily adding them to the playlist or closing it.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:16px; margin-left:-24px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">To trim or adjust a playlist item <span style=\" font-weight:600;\">Double-click</span> to open it, make the changes, and click the <span style=\" font-weight:600;\">Update</span> icon.</p>\n"
"<p st"
                        "yle=\" margin-top:0px; margin-bottom:16px; margin-left:-24px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Drag-n-drop</span> to rearrange the items.</p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        tableView->setToolTip(QCoreApplication::translate("PlaylistDock", "<html><head/><body><p>Double-click a playlist item to open it in the player.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class PlaylistDock: public Ui_PlaylistDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PLAYLISTDOCK_H
