/********************************************************************************
** Form generated from reading UI file 'avformatproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AVFORMATPRODUCERWIDGET_H
#define UI_AVFORMATPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/timespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_AvformatProducerWidget
{
public:
    QAction *actionOpenFolder;
    QAction *actionCopyFullFilePath;
    QAction *actionFFmpegInfo;
    QAction *actionFFmpegIntegrityCheck;
    QAction *actionFFmpegConvert;
    QAction *actionExtractSubclip;
    QAction *actionExtractSubtitles;
    QAction *actionSetFileDate;
    QAction *actionDisableProxy;
    QAction *actionMakeProxy;
    QAction *actionDeleteProxy;
    QAction *actionCopyHashCode;
    QAction *actionReset;
    QAction *actionSetEquirectangular;
    QAction *actionFFmpegVideoQuality;
    QAction *actionExportGPX;
    QAction *actionBitrateViewer;
    QAction *actionShowInFiles;
    QVBoxLayout *verticalLayout;
    QLineEdit *filenameLabel;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QPlainTextEdit *notesTextEdit;
    QGridLayout *gridLayout_1;
    TimeSpinBox *durationSpinBox;
    QSpacerItem *horizontalSpacer_2;
    QLabel *durationLabel;
    QLineEdit *timelineDurationText;
    QDoubleSpinBox *speedSpinBox;
    QLabel *speedLabel;
    QLabel *timelineDurationLabel;
    QHBoxLayout *horizontalLayout_9;
    QComboBox *speedComboBox;
    QPushButton *applySpeedButton;
    QCheckBox *pitchCheckBox;
    QSpacerItem *horizontalSpacer_10;
    QTabWidget *tabWidget;
    QWidget *videoTab;
    QGridLayout *gridLayout_2;
    QLabel *scanModeLabel;
    QLabel *label_2;
    QLabel *label_5;
    QTableWidget *videoTableWidget;
    QLabel *aspectRatioLabel;
    QHBoxLayout *horizontalLayout_3;
    QLabel *trackLabel;
    QComboBox *videoTrackComboBox;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_4;
    QSpinBox *aspectNumSpinBox;
    QLabel *label_4;
    QSpinBox *aspectDenSpinBox;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout;
    QComboBox *rangeComboBox;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_5;
    QComboBox *scanComboBox;
    QComboBox *fieldOrderComboBox;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout_2;
    QComboBox *rotationComboBox;
    QLabel *label_6;
    QSpacerItem *horizontalSpacer_11;
    QLabel *lutLabel;
    QHBoxLayout *horizontalLayout_12;
    QLineEdit *lutValueLabel;
    QToolButton *lutButton;
    QToolButton *lutClearButton;
    QToolButton *lutCopyButton;
    QToolButton *lutPasteButton;
    QSpacerItem *verticalSpacer_3;
    QWidget *audioTab;
    QGridLayout *gridLayout_3;
    QLabel *trackLabel_2;
    QHBoxLayout *horizontalLayout_6;
    QComboBox *audioTrackComboBox;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer_2;
    QTableWidget *audioTableWidget;
    QSlider *syncSlider;
    QLabel *syncLabel;
    QHBoxLayout *horizontalLayout_7;
    QSpacerItem *horizontalSpacer_7;
    QSpinBox *syncSpinBox;
    QSpacerItem *horizontalSpacer_8;
    QWidget *metadataTab;
    QVBoxLayout *verticalLayout_3;
    QTableWidget *metadataTable;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_8;
    QPushButton *menuButton;
    QPushButton *convertButton;
    QPushButton *reverseButton;
    QPushButton *proxyButton;
    QPushButton *openWithButton;
    QPushButton *reloadButton;
    QSpacerItem *horizontalSpacer_9;

    void setupUi(QWidget *AvformatProducerWidget)
    {
        if (AvformatProducerWidget->objectName().isEmpty())
            AvformatProducerWidget->setObjectName("AvformatProducerWidget");
        AvformatProducerWidget->resize(569, 595);
#if QT_CONFIG(whatsthis)
        AvformatProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/audio-video-properties/12923/1"));
#endif // QT_CONFIG(whatsthis)
        actionOpenFolder = new QAction(AvformatProducerWidget);
        actionOpenFolder->setObjectName("actionOpenFolder");
        actionCopyFullFilePath = new QAction(AvformatProducerWidget);
        actionCopyFullFilePath->setObjectName("actionCopyFullFilePath");
        actionFFmpegInfo = new QAction(AvformatProducerWidget);
        actionFFmpegInfo->setObjectName("actionFFmpegInfo");
        actionFFmpegIntegrityCheck = new QAction(AvformatProducerWidget);
        actionFFmpegIntegrityCheck->setObjectName("actionFFmpegIntegrityCheck");
        actionFFmpegConvert = new QAction(AvformatProducerWidget);
        actionFFmpegConvert->setObjectName("actionFFmpegConvert");
        actionExtractSubclip = new QAction(AvformatProducerWidget);
        actionExtractSubclip->setObjectName("actionExtractSubclip");
        actionExtractSubtitles = new QAction(AvformatProducerWidget);
        actionExtractSubtitles->setObjectName("actionExtractSubtitles");
        actionSetFileDate = new QAction(AvformatProducerWidget);
        actionSetFileDate->setObjectName("actionSetFileDate");
        actionDisableProxy = new QAction(AvformatProducerWidget);
        actionDisableProxy->setObjectName("actionDisableProxy");
        actionDisableProxy->setCheckable(true);
        actionMakeProxy = new QAction(AvformatProducerWidget);
        actionMakeProxy->setObjectName("actionMakeProxy");
        actionDeleteProxy = new QAction(AvformatProducerWidget);
        actionDeleteProxy->setObjectName("actionDeleteProxy");
        actionCopyHashCode = new QAction(AvformatProducerWidget);
        actionCopyHashCode->setObjectName("actionCopyHashCode");
        actionReset = new QAction(AvformatProducerWidget);
        actionReset->setObjectName("actionReset");
        actionSetEquirectangular = new QAction(AvformatProducerWidget);
        actionSetEquirectangular->setObjectName("actionSetEquirectangular");
        actionFFmpegVideoQuality = new QAction(AvformatProducerWidget);
        actionFFmpegVideoQuality->setObjectName("actionFFmpegVideoQuality");
        actionExportGPX = new QAction(AvformatProducerWidget);
        actionExportGPX->setObjectName("actionExportGPX");
        actionExportGPX->setEnabled(false);
        actionBitrateViewer = new QAction(AvformatProducerWidget);
        actionBitrateViewer->setObjectName("actionBitrateViewer");
        actionShowInFiles = new QAction(AvformatProducerWidget);
        actionShowInFiles->setObjectName("actionShowInFiles");
        verticalLayout = new QVBoxLayout(AvformatProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        filenameLabel = new QLineEdit(AvformatProducerWidget);
        filenameLabel->setObjectName("filenameLabel");
        filenameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(filenameLabel);

        scrollArea = new QScrollArea(AvformatProducerWidget);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 543, 534));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(6, 6, 6, 0);
        label = new QLabel(scrollAreaWidgetContents);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        notesTextEdit = new QPlainTextEdit(scrollAreaWidgetContents);
        notesTextEdit->setObjectName("notesTextEdit");
        notesTextEdit->setMaximumSize(QSize(16777215, 60));
        notesTextEdit->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        notesTextEdit->setTabChangesFocus(true);

        verticalLayout_2->addWidget(notesTextEdit);

        gridLayout_1 = new QGridLayout();
        gridLayout_1->setObjectName("gridLayout_1");
        durationSpinBox = new TimeSpinBox(scrollAreaWidgetContents);
        durationSpinBox->setObjectName("durationSpinBox");
        durationSpinBox->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        durationSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        durationSpinBox->setAccelerated(true);
        durationSpinBox->setKeyboardTracking(false);
        durationSpinBox->setMaximum(2147483647);

        gridLayout_1->addWidget(durationSpinBox, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_1->addItem(horizontalSpacer_2, 1, 4, 1, 1);

        durationLabel = new QLabel(scrollAreaWidgetContents);
        durationLabel->setObjectName("durationLabel");
        durationLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_1->addWidget(durationLabel, 1, 0, 1, 1);

        timelineDurationText = new QLineEdit(scrollAreaWidgetContents);
        timelineDurationText->setObjectName("timelineDurationText");

        gridLayout_1->addWidget(timelineDurationText, 1, 3, 1, 1);

        speedSpinBox = new QDoubleSpinBox(scrollAreaWidgetContents);
        speedSpinBox->setObjectName("speedSpinBox");
        speedSpinBox->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        speedSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        speedSpinBox->setAccelerated(true);
        speedSpinBox->setKeyboardTracking(false);
        speedSpinBox->setSuffix(QString::fromUtf8(" x"));
        speedSpinBox->setDecimals(6);
        speedSpinBox->setMinimum(0.002500000000000);
        speedSpinBox->setMaximum(50.000000000000000);
        speedSpinBox->setSingleStep(0.100000000000000);
        speedSpinBox->setValue(1.000000000000000);

        gridLayout_1->addWidget(speedSpinBox, 0, 1, 1, 1);

        speedLabel = new QLabel(scrollAreaWidgetContents);
        speedLabel->setObjectName("speedLabel");
        speedLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_1->addWidget(speedLabel, 0, 0, 1, 1);

        timelineDurationLabel = new QLabel(scrollAreaWidgetContents);
        timelineDurationLabel->setObjectName("timelineDurationLabel");

        gridLayout_1->addWidget(timelineDurationLabel, 1, 2, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        speedComboBox = new QComboBox(scrollAreaWidgetContents);
        speedComboBox->addItem(QString::fromUtf8("0.125"));
        speedComboBox->addItem(QString::fromUtf8("0.25"));
        speedComboBox->addItem(QString::fromUtf8("0.5"));
        speedComboBox->addItem(QString::fromUtf8("1"));
        speedComboBox->addItem(QString::fromUtf8("1.25"));
        speedComboBox->addItem(QString::fromUtf8("1.5"));
        speedComboBox->addItem(QString::fromUtf8("2"));
        speedComboBox->addItem(QString::fromUtf8("3"));
        speedComboBox->addItem(QString::fromUtf8("4"));
        speedComboBox->setObjectName("speedComboBox");
        speedComboBox->setMaximumSize(QSize(20, 16777215));

        horizontalLayout_9->addWidget(speedComboBox);

        applySpeedButton = new QPushButton(scrollAreaWidgetContents);
        applySpeedButton->setObjectName("applySpeedButton");

        horizontalLayout_9->addWidget(applySpeedButton);

        pitchCheckBox = new QCheckBox(scrollAreaWidgetContents);
        pitchCheckBox->setObjectName("pitchCheckBox");

        horizontalLayout_9->addWidget(pitchCheckBox);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_10);


        gridLayout_1->addLayout(horizontalLayout_9, 0, 2, 1, 3);


        verticalLayout_2->addLayout(gridLayout_1);

        tabWidget = new QTabWidget(scrollAreaWidgetContents);
        tabWidget->setObjectName("tabWidget");
        videoTab = new QWidget();
        videoTab->setObjectName("videoTab");
        gridLayout_2 = new QGridLayout(videoTab);
        gridLayout_2->setObjectName("gridLayout_2");
        scanModeLabel = new QLabel(videoTab);
        scanModeLabel->setObjectName("scanModeLabel");
        scanModeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(scanModeLabel, 3, 0, 1, 1);

        label_2 = new QLabel(videoTab);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_2, 4, 0, 1, 1);

        label_5 = new QLabel(videoTab);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(label_5, 5, 0, 1, 1);

        videoTableWidget = new QTableWidget(videoTab);
        if (videoTableWidget->columnCount() < 2)
            videoTableWidget->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        videoTableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        videoTableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        if (videoTableWidget->rowCount() < 6)
            videoTableWidget->setRowCount(6);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        videoTableWidget->setVerticalHeaderItem(0, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        videoTableWidget->setVerticalHeaderItem(1, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        videoTableWidget->setVerticalHeaderItem(2, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        videoTableWidget->setVerticalHeaderItem(3, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        videoTableWidget->setVerticalHeaderItem(4, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        videoTableWidget->setVerticalHeaderItem(5, __qtablewidgetitem7);
        QTableWidgetItem *__qtablewidgetitem8 = new QTableWidgetItem();
        videoTableWidget->setItem(0, 0, __qtablewidgetitem8);
        QTableWidgetItem *__qtablewidgetitem9 = new QTableWidgetItem();
        videoTableWidget->setItem(1, 0, __qtablewidgetitem9);
        QTableWidgetItem *__qtablewidgetitem10 = new QTableWidgetItem();
        videoTableWidget->setItem(2, 0, __qtablewidgetitem10);
        QTableWidgetItem *__qtablewidgetitem11 = new QTableWidgetItem();
        videoTableWidget->setItem(3, 0, __qtablewidgetitem11);
        QTableWidgetItem *__qtablewidgetitem12 = new QTableWidgetItem();
        videoTableWidget->setItem(4, 0, __qtablewidgetitem12);
        QTableWidgetItem *__qtablewidgetitem13 = new QTableWidgetItem();
        videoTableWidget->setItem(5, 0, __qtablewidgetitem13);
        videoTableWidget->setObjectName("videoTableWidget");
        videoTableWidget->setMinimumSize(QSize(0, 80));
        videoTableWidget->setMaximumSize(QSize(16777215, 145));
        videoTableWidget->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        videoTableWidget->setFrameShape(QFrame::Shape::NoFrame);
        videoTableWidget->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        videoTableWidget->setAlternatingRowColors(true);
        videoTableWidget->setSelectionMode(QAbstractItemView::SelectionMode::NoSelection);
        videoTableWidget->setGridStyle(Qt::PenStyle::NoPen);
        videoTableWidget->setRowCount(6);
        videoTableWidget->horizontalHeader()->setVisible(false);
        videoTableWidget->horizontalHeader()->setDefaultSectionSize(110);
        videoTableWidget->horizontalHeader()->setStretchLastSection(true);
        videoTableWidget->verticalHeader()->setVisible(false);
        videoTableWidget->verticalHeader()->setDefaultSectionSize(27);

        gridLayout_2->addWidget(videoTableWidget, 1, 0, 1, 3);

        aspectRatioLabel = new QLabel(videoTab);
        aspectRatioLabel->setObjectName("aspectRatioLabel");
        aspectRatioLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(aspectRatioLabel, 2, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        trackLabel = new QLabel(videoTab);
        trackLabel->setObjectName("trackLabel");
        trackLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_3->addWidget(trackLabel);

        videoTrackComboBox = new QComboBox(videoTab);
        videoTrackComboBox->setObjectName("videoTrackComboBox");
        videoTrackComboBox->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout_3->addWidget(videoTrackComboBox);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);


        gridLayout_2->addLayout(horizontalLayout_3, 0, 0, 1, 3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        aspectNumSpinBox = new QSpinBox(videoTab);
        aspectNumSpinBox->setObjectName("aspectNumSpinBox");
        aspectNumSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        aspectNumSpinBox->setKeyboardTracking(false);
        aspectNumSpinBox->setMinimum(1);
        aspectNumSpinBox->setMaximum(8640);
        aspectNumSpinBox->setValue(16);

        horizontalLayout_4->addWidget(aspectNumSpinBox);

        label_4 = new QLabel(videoTab);
        label_4->setObjectName("label_4");

        horizontalLayout_4->addWidget(label_4);

        aspectDenSpinBox = new QSpinBox(videoTab);
        aspectDenSpinBox->setObjectName("aspectDenSpinBox");
        aspectDenSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        aspectDenSpinBox->setKeyboardTracking(false);
        aspectDenSpinBox->setMinimum(1);
        aspectDenSpinBox->setMaximum(8640);
        aspectDenSpinBox->setValue(9);

        horizontalLayout_4->addWidget(aspectDenSpinBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        gridLayout_2->addLayout(horizontalLayout_4, 2, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        rangeComboBox = new QComboBox(videoTab);
        rangeComboBox->addItem(QString());
        rangeComboBox->addItem(QString());
        rangeComboBox->setObjectName("rangeComboBox");

        horizontalLayout->addWidget(rangeComboBox);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        gridLayout_2->addLayout(horizontalLayout, 4, 2, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        scanComboBox = new QComboBox(videoTab);
        scanComboBox->addItem(QString());
        scanComboBox->addItem(QString());
        scanComboBox->setObjectName("scanComboBox");

        horizontalLayout_5->addWidget(scanComboBox);

        fieldOrderComboBox = new QComboBox(videoTab);
        fieldOrderComboBox->addItem(QString());
        fieldOrderComboBox->addItem(QString());
        fieldOrderComboBox->setObjectName("fieldOrderComboBox");

        horizontalLayout_5->addWidget(fieldOrderComboBox);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);


        gridLayout_2->addLayout(horizontalLayout_5, 3, 2, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        rotationComboBox = new QComboBox(videoTab);
        rotationComboBox->addItem(QString());
        rotationComboBox->addItem(QString());
        rotationComboBox->addItem(QString());
        rotationComboBox->addItem(QString());
        rotationComboBox->setObjectName("rotationComboBox");

        horizontalLayout_2->addWidget(rotationComboBox);

        label_6 = new QLabel(videoTab);
        label_6->setObjectName("label_6");

        horizontalLayout_2->addWidget(label_6);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_11);


        gridLayout_2->addLayout(horizontalLayout_2, 5, 2, 1, 1);

        lutLabel = new QLabel(videoTab);
        lutLabel->setObjectName("lutLabel");
        lutLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_2->addWidget(lutLabel, 6, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        lutValueLabel = new QLineEdit(videoTab);
        lutValueLabel->setObjectName("lutValueLabel");
        lutValueLabel->setMinimumSize(QSize(120, 0));
        lutValueLabel->setReadOnly(true);

        horizontalLayout_12->addWidget(lutValueLabel);

        lutButton = new QToolButton(videoTab);
        lutButton->setObjectName("lutButton");

        horizontalLayout_12->addWidget(lutButton);

        lutClearButton = new QToolButton(videoTab);
        lutClearButton->setObjectName("lutClearButton");

        horizontalLayout_12->addWidget(lutClearButton);

        lutCopyButton = new QToolButton(videoTab);
        lutCopyButton->setObjectName("lutCopyButton");

        horizontalLayout_12->addWidget(lutCopyButton);

        lutPasteButton = new QToolButton(videoTab);
        lutPasteButton->setObjectName("lutPasteButton");

        horizontalLayout_12->addWidget(lutPasteButton);


        gridLayout_2->addLayout(horizontalLayout_12, 6, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_3, 7, 0, 1, 3);

        tabWidget->addTab(videoTab, QString());
        audioTab = new QWidget();
        audioTab->setObjectName("audioTab");
        gridLayout_3 = new QGridLayout(audioTab);
        gridLayout_3->setObjectName("gridLayout_3");
        trackLabel_2 = new QLabel(audioTab);
        trackLabel_2->setObjectName("trackLabel_2");
        trackLabel_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(trackLabel_2, 0, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        audioTrackComboBox = new QComboBox(audioTab);
        audioTrackComboBox->setObjectName("audioTrackComboBox");

        horizontalLayout_6->addWidget(audioTrackComboBox);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);


        gridLayout_3->addLayout(horizontalLayout_6, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 4, 0, 1, 1);

        audioTableWidget = new QTableWidget(audioTab);
        if (audioTableWidget->columnCount() < 2)
            audioTableWidget->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem14 = new QTableWidgetItem();
        audioTableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem14);
        QTableWidgetItem *__qtablewidgetitem15 = new QTableWidgetItem();
        audioTableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem15);
        if (audioTableWidget->rowCount() < 4)
            audioTableWidget->setRowCount(4);
        QTableWidgetItem *__qtablewidgetitem16 = new QTableWidgetItem();
        audioTableWidget->setVerticalHeaderItem(0, __qtablewidgetitem16);
        QTableWidgetItem *__qtablewidgetitem17 = new QTableWidgetItem();
        audioTableWidget->setVerticalHeaderItem(1, __qtablewidgetitem17);
        QTableWidgetItem *__qtablewidgetitem18 = new QTableWidgetItem();
        audioTableWidget->setVerticalHeaderItem(2, __qtablewidgetitem18);
        QTableWidgetItem *__qtablewidgetitem19 = new QTableWidgetItem();
        audioTableWidget->setVerticalHeaderItem(3, __qtablewidgetitem19);
        QTableWidgetItem *__qtablewidgetitem20 = new QTableWidgetItem();
        audioTableWidget->setItem(0, 0, __qtablewidgetitem20);
        QTableWidgetItem *__qtablewidgetitem21 = new QTableWidgetItem();
        audioTableWidget->setItem(1, 0, __qtablewidgetitem21);
        QTableWidgetItem *__qtablewidgetitem22 = new QTableWidgetItem();
        audioTableWidget->setItem(2, 0, __qtablewidgetitem22);
        QTableWidgetItem *__qtablewidgetitem23 = new QTableWidgetItem();
        audioTableWidget->setItem(3, 0, __qtablewidgetitem23);
        audioTableWidget->setObjectName("audioTableWidget");
        audioTableWidget->setMinimumSize(QSize(0, 80));
        audioTableWidget->setMaximumSize(QSize(16777215, 120));
        audioTableWidget->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        audioTableWidget->setFrameShape(QFrame::Shape::NoFrame);
        audioTableWidget->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        audioTableWidget->setAlternatingRowColors(true);
        audioTableWidget->setSelectionMode(QAbstractItemView::SelectionMode::NoSelection);
        audioTableWidget->setGridStyle(Qt::PenStyle::NoPen);
        audioTableWidget->horizontalHeader()->setVisible(false);
        audioTableWidget->horizontalHeader()->setStretchLastSection(true);
        audioTableWidget->verticalHeader()->setVisible(false);
        audioTableWidget->verticalHeader()->setDefaultSectionSize(27);

        gridLayout_3->addWidget(audioTableWidget, 1, 0, 1, 2);

        syncSlider = new QSlider(audioTab);
        syncSlider->setObjectName("syncSlider");
        syncSlider->setMinimum(-1000);
        syncSlider->setMaximum(1000);
        syncSlider->setValue(0);
        syncSlider->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_3->addWidget(syncSlider, 2, 1, 1, 1);

        syncLabel = new QLabel(audioTab);
        syncLabel->setObjectName("syncLabel");
        syncLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_3->addWidget(syncLabel, 2, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_7);

        syncSpinBox = new QSpinBox(audioTab);
        syncSpinBox->setObjectName("syncSpinBox");
        syncSpinBox->setMinimum(-1000);
        syncSpinBox->setMaximum(1000);

        horizontalLayout_7->addWidget(syncSpinBox);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_8);


        gridLayout_3->addLayout(horizontalLayout_7, 3, 1, 1, 1);

        tabWidget->addTab(audioTab, QString());
        metadataTab = new QWidget();
        metadataTab->setObjectName("metadataTab");
        verticalLayout_3 = new QVBoxLayout(metadataTab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        metadataTable = new QTableWidget(metadataTab);
        if (metadataTable->columnCount() < 2)
            metadataTable->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem24 = new QTableWidgetItem();
        metadataTable->setHorizontalHeaderItem(0, __qtablewidgetitem24);
        QTableWidgetItem *__qtablewidgetitem25 = new QTableWidgetItem();
        metadataTable->setHorizontalHeaderItem(1, __qtablewidgetitem25);
        metadataTable->setObjectName("metadataTable");
        metadataTable->setFocusPolicy(Qt::FocusPolicy::TabFocus);
        metadataTable->setFrameShape(QFrame::Shape::NoFrame);
        metadataTable->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        metadataTable->setAlternatingRowColors(true);
        metadataTable->setSelectionMode(QAbstractItemView::SelectionMode::NoSelection);
        metadataTable->setGridStyle(Qt::PenStyle::NoPen);
        metadataTable->horizontalHeader()->setStretchLastSection(true);
        metadataTable->verticalHeader()->setVisible(false);
        metadataTable->verticalHeader()->setDefaultSectionSize(27);

        verticalLayout_3->addWidget(metadataTable);

        tabWidget->addTab(metadataTab, QString());

        verticalLayout_2->addWidget(tabWidget);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(scrollArea);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        menuButton = new QPushButton(AvformatProducerWidget);
        menuButton->setObjectName("menuButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("show-menu");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/show-menu.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        menuButton->setIcon(icon);

        horizontalLayout_8->addWidget(menuButton);

        convertButton = new QPushButton(AvformatProducerWidget);
        convertButton->setObjectName("convertButton");

        horizontalLayout_8->addWidget(convertButton);

        reverseButton = new QPushButton(AvformatProducerWidget);
        reverseButton->setObjectName("reverseButton");

        horizontalLayout_8->addWidget(reverseButton);

        proxyButton = new QPushButton(AvformatProducerWidget);
        proxyButton->setObjectName("proxyButton");

        horizontalLayout_8->addWidget(proxyButton);

        openWithButton = new QPushButton(AvformatProducerWidget);
        openWithButton->setObjectName("openWithButton");

        horizontalLayout_8->addWidget(openWithButton);

        reloadButton = new QPushButton(AvformatProducerWidget);
        reloadButton->setObjectName("reloadButton");

        horizontalLayout_8->addWidget(reloadButton);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_9);


        verticalLayout->addLayout(horizontalLayout_8);

        QWidget::setTabOrder(filenameLabel, notesTextEdit);
        QWidget::setTabOrder(notesTextEdit, speedSpinBox);
        QWidget::setTabOrder(speedSpinBox, speedComboBox);
        QWidget::setTabOrder(speedComboBox, applySpeedButton);
        QWidget::setTabOrder(applySpeedButton, pitchCheckBox);
        QWidget::setTabOrder(pitchCheckBox, durationSpinBox);
        QWidget::setTabOrder(durationSpinBox, timelineDurationText);
        QWidget::setTabOrder(timelineDurationText, tabWidget);
        QWidget::setTabOrder(tabWidget, videoTrackComboBox);
        QWidget::setTabOrder(videoTrackComboBox, aspectNumSpinBox);
        QWidget::setTabOrder(aspectNumSpinBox, aspectDenSpinBox);
        QWidget::setTabOrder(aspectDenSpinBox, scanComboBox);
        QWidget::setTabOrder(scanComboBox, fieldOrderComboBox);
        QWidget::setTabOrder(fieldOrderComboBox, rangeComboBox);
        QWidget::setTabOrder(rangeComboBox, rotationComboBox);
        QWidget::setTabOrder(rotationComboBox, lutButton);
        QWidget::setTabOrder(lutButton, lutClearButton);
        QWidget::setTabOrder(lutClearButton, lutCopyButton);
        QWidget::setTabOrder(lutCopyButton, lutPasteButton);
        QWidget::setTabOrder(lutPasteButton, menuButton);
        QWidget::setTabOrder(menuButton, scrollArea);
        QWidget::setTabOrder(scrollArea, audioTrackComboBox);
        QWidget::setTabOrder(audioTrackComboBox, syncSpinBox);
        QWidget::setTabOrder(syncSpinBox, syncSlider);
        QWidget::setTabOrder(syncSlider, metadataTable);

        retranslateUi(AvformatProducerWidget);
        QObject::connect(syncSlider, &QSlider::valueChanged, syncSpinBox, &QSpinBox::setValue);
        QObject::connect(syncSpinBox, &QSpinBox::valueChanged, syncSlider, &QSlider::setValue);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AvformatProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *AvformatProducerWidget)
    {
        AvformatProducerWidget->setWindowTitle(QCoreApplication::translate("AvformatProducerWidget", "Form", nullptr));
        actionOpenFolder->setText(QCoreApplication::translate("AvformatProducerWidget", "Show In Folder", nullptr));
        actionCopyFullFilePath->setText(QCoreApplication::translate("AvformatProducerWidget", "Copy Full File Path", nullptr));
        actionFFmpegInfo->setText(QCoreApplication::translate("AvformatProducerWidget", "More Information...", nullptr));
        actionFFmpegIntegrityCheck->setText(QCoreApplication::translate("AvformatProducerWidget", "Start Integrity Check Job", nullptr));
        actionFFmpegConvert->setText(QCoreApplication::translate("AvformatProducerWidget", "Convert to Edit-friendly...", nullptr));
        actionExtractSubclip->setText(QCoreApplication::translate("AvformatProducerWidget", "Extract Sub-clip...", nullptr));
        actionExtractSubtitles->setText(QCoreApplication::translate("AvformatProducerWidget", "Extract Subtitles...", nullptr));
        actionSetFileDate->setText(QCoreApplication::translate("AvformatProducerWidget", "Set Creation Time...", nullptr));
        actionDisableProxy->setText(QCoreApplication::translate("AvformatProducerWidget", "Disable Proxy", nullptr));
        actionMakeProxy->setText(QCoreApplication::translate("AvformatProducerWidget", "Make Proxy", nullptr));
        actionDeleteProxy->setText(QCoreApplication::translate("AvformatProducerWidget", "Delete Proxy", nullptr));
        actionCopyHashCode->setText(QCoreApplication::translate("AvformatProducerWidget", "Copy Hash Code", nullptr));
        actionReset->setText(QCoreApplication::translate("AvformatProducerWidget", "Reset", nullptr));
        actionSetEquirectangular->setText(QCoreApplication::translate("AvformatProducerWidget", "Set Equirectangular...", nullptr));
        actionFFmpegVideoQuality->setText(QCoreApplication::translate("AvformatProducerWidget", "Measure Video Quality...", nullptr));
        actionExportGPX->setText(QCoreApplication::translate("AvformatProducerWidget", "Export GPX", nullptr));
#if QT_CONFIG(tooltip)
        actionExportGPX->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Export GPX", nullptr));
#endif // QT_CONFIG(tooltip)
        actionBitrateViewer->setText(QCoreApplication::translate("AvformatProducerWidget", "View Bitrate...", nullptr));
#if QT_CONFIG(tooltip)
        actionBitrateViewer->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "View Bitrate", nullptr));
#endif // QT_CONFIG(tooltip)
        actionShowInFiles->setText(QCoreApplication::translate("AvformatProducerWidget", "Show In Files", nullptr));
        label->setText(QCoreApplication::translate("AvformatProducerWidget", "Comments:", nullptr));
        notesTextEdit->setPlainText(QString());
        durationLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "Duration", nullptr));
        speedLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "Speed", nullptr));
        timelineDurationLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "Timeline", nullptr));

#if QT_CONFIG(tooltip)
        speedComboBox->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Speed Presets", nullptr));
#endif // QT_CONFIG(tooltip)
        applySpeedButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Apply", nullptr));
#if QT_CONFIG(tooltip)
        pitchCheckBox->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Apply pitch compensation when the speed is changed.", nullptr));
#endif // QT_CONFIG(tooltip)
        pitchCheckBox->setText(QCoreApplication::translate("AvformatProducerWidget", "Pitch Compensation", nullptr));
        scanModeLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "Scan mode", nullptr));
        label_2->setText(QCoreApplication::translate("AvformatProducerWidget", "Color range", nullptr));
        label_5->setText(QCoreApplication::translate("AvformatProducerWidget", "Rotation", nullptr));
        QTableWidgetItem *___qtablewidgetitem = videoTableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("AvformatProducerWidget", "Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = videoTableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("AvformatProducerWidget", "Value", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = videoTableWidget->verticalHeaderItem(0);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("AvformatProducerWidget", "Codec", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = videoTableWidget->verticalHeaderItem(1);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("AvformatProducerWidget", "Resolution", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = videoTableWidget->verticalHeaderItem(2);
        ___qtablewidgetitem4->setText(QCoreApplication::translate("AvformatProducerWidget", "Frame rate", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = videoTableWidget->verticalHeaderItem(3);
        ___qtablewidgetitem5->setText(QCoreApplication::translate("AvformatProducerWidget", "Pixel format", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = videoTableWidget->verticalHeaderItem(4);
        ___qtablewidgetitem6->setText(QCoreApplication::translate("AvformatProducerWidget", "Color space", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = videoTableWidget->verticalHeaderItem(5);
        ___qtablewidgetitem7->setText(QCoreApplication::translate("AvformatProducerWidget", "Color transfer", nullptr));

        const bool __sortingEnabled = videoTableWidget->isSortingEnabled();
        videoTableWidget->setSortingEnabled(false);
        QTableWidgetItem *___qtablewidgetitem8 = videoTableWidget->item(0, 0);
        ___qtablewidgetitem8->setText(QCoreApplication::translate("AvformatProducerWidget", "Codec", nullptr));
        QTableWidgetItem *___qtablewidgetitem9 = videoTableWidget->item(1, 0);
        ___qtablewidgetitem9->setText(QCoreApplication::translate("AvformatProducerWidget", "Resolution", nullptr));
        QTableWidgetItem *___qtablewidgetitem10 = videoTableWidget->item(2, 0);
        ___qtablewidgetitem10->setText(QCoreApplication::translate("AvformatProducerWidget", "Frame rate", nullptr));
        QTableWidgetItem *___qtablewidgetitem11 = videoTableWidget->item(3, 0);
        ___qtablewidgetitem11->setText(QCoreApplication::translate("AvformatProducerWidget", "Format", nullptr));
        QTableWidgetItem *___qtablewidgetitem12 = videoTableWidget->item(4, 0);
        ___qtablewidgetitem12->setText(QCoreApplication::translate("AvformatProducerWidget", "Color space", nullptr));
        QTableWidgetItem *___qtablewidgetitem13 = videoTableWidget->item(5, 0);
        ___qtablewidgetitem13->setText(QCoreApplication::translate("AvformatProducerWidget", "Color transfer", nullptr));
        videoTableWidget->setSortingEnabled(__sortingEnabled);

        aspectRatioLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "Aspect ratio", nullptr));
        trackLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "Track", nullptr));
        label_4->setText(QCoreApplication::translate("AvformatProducerWidget", ":", nullptr));
        rangeComboBox->setItemText(0, QCoreApplication::translate("AvformatProducerWidget", "Broadcast Limited (MPEG)", nullptr));
        rangeComboBox->setItemText(1, QCoreApplication::translate("AvformatProducerWidget", "Full (JPEG)", nullptr));

        scanComboBox->setItemText(0, QCoreApplication::translate("AvformatProducerWidget", "Interlaced", nullptr));
        scanComboBox->setItemText(1, QCoreApplication::translate("AvformatProducerWidget", "Progressive", nullptr));

        fieldOrderComboBox->setItemText(0, QCoreApplication::translate("AvformatProducerWidget", "Bottom Field First", nullptr));
        fieldOrderComboBox->setItemText(1, QCoreApplication::translate("AvformatProducerWidget", "Top Field First", nullptr));

        rotationComboBox->setItemText(0, QCoreApplication::translate("AvformatProducerWidget", "0", nullptr));
        rotationComboBox->setItemText(1, QCoreApplication::translate("AvformatProducerWidget", "90", nullptr));
        rotationComboBox->setItemText(2, QCoreApplication::translate("AvformatProducerWidget", "180", nullptr));
        rotationComboBox->setItemText(3, QCoreApplication::translate("AvformatProducerWidget", "270", nullptr));

        label_6->setText(QCoreApplication::translate("AvformatProducerWidget", "\302\260", nullptr));
        lutLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "LUT file", nullptr));
#if QT_CONFIG(tooltip)
        lutButton->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Open LUT file", nullptr));
#endif // QT_CONFIG(tooltip)
        lutButton->setText(QCoreApplication::translate("AvformatProducerWidget", "...", nullptr));
#if QT_CONFIG(tooltip)
        lutClearButton->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Clear LUT file", nullptr));
#endif // QT_CONFIG(tooltip)
        lutClearButton->setText(QCoreApplication::translate("AvformatProducerWidget", "x", nullptr));
#if QT_CONFIG(tooltip)
        lutCopyButton->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Copy LUT file path", nullptr));
#endif // QT_CONFIG(tooltip)
        lutCopyButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Copy", nullptr));
#if QT_CONFIG(tooltip)
        lutPasteButton->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Paste LUT file from clipboard", nullptr));
#endif // QT_CONFIG(tooltip)
        lutPasteButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Paste", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(videoTab), QCoreApplication::translate("AvformatProducerWidget", "Video", nullptr));
        trackLabel_2->setText(QCoreApplication::translate("AvformatProducerWidget", "Track", nullptr));
        QTableWidgetItem *___qtablewidgetitem14 = audioTableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem14->setText(QCoreApplication::translate("AvformatProducerWidget", "Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem15 = audioTableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem15->setText(QCoreApplication::translate("AvformatProducerWidget", "Value", nullptr));
        QTableWidgetItem *___qtablewidgetitem16 = audioTableWidget->verticalHeaderItem(0);
        ___qtablewidgetitem16->setText(QCoreApplication::translate("AvformatProducerWidget", "Codec", nullptr));
        QTableWidgetItem *___qtablewidgetitem17 = audioTableWidget->verticalHeaderItem(1);
        ___qtablewidgetitem17->setText(QCoreApplication::translate("AvformatProducerWidget", "Channels", nullptr));
        QTableWidgetItem *___qtablewidgetitem18 = audioTableWidget->verticalHeaderItem(2);
        ___qtablewidgetitem18->setText(QCoreApplication::translate("AvformatProducerWidget", "Sample rate", nullptr));
        QTableWidgetItem *___qtablewidgetitem19 = audioTableWidget->verticalHeaderItem(3);
        ___qtablewidgetitem19->setText(QCoreApplication::translate("AvformatProducerWidget", "Format", nullptr));

        const bool __sortingEnabled1 = audioTableWidget->isSortingEnabled();
        audioTableWidget->setSortingEnabled(false);
        QTableWidgetItem *___qtablewidgetitem20 = audioTableWidget->item(0, 0);
        ___qtablewidgetitem20->setText(QCoreApplication::translate("AvformatProducerWidget", "Codec", nullptr));
        QTableWidgetItem *___qtablewidgetitem21 = audioTableWidget->item(1, 0);
        ___qtablewidgetitem21->setText(QCoreApplication::translate("AvformatProducerWidget", "Channels", nullptr));
        QTableWidgetItem *___qtablewidgetitem22 = audioTableWidget->item(2, 0);
        ___qtablewidgetitem22->setText(QCoreApplication::translate("AvformatProducerWidget", "Sample rate", nullptr));
        QTableWidgetItem *___qtablewidgetitem23 = audioTableWidget->item(3, 0);
        ___qtablewidgetitem23->setText(QCoreApplication::translate("AvformatProducerWidget", "Format", nullptr));
        audioTableWidget->setSortingEnabled(__sortingEnabled1);

#if QT_CONFIG(tooltip)
        syncSlider->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Adjust the audio/video synchronization. The center position is equivalent to no alteration.", nullptr));
#endif // QT_CONFIG(tooltip)
        syncLabel->setText(QCoreApplication::translate("AvformatProducerWidget", "Sync", nullptr));
        syncSpinBox->setSuffix(QCoreApplication::translate("AvformatProducerWidget", " ms", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(audioTab), QCoreApplication::translate("AvformatProducerWidget", "Audio", nullptr));
        QTableWidgetItem *___qtablewidgetitem24 = metadataTable->horizontalHeaderItem(0);
        ___qtablewidgetitem24->setText(QCoreApplication::translate("AvformatProducerWidget", "Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem25 = metadataTable->horizontalHeaderItem(1);
        ___qtablewidgetitem25->setText(QCoreApplication::translate("AvformatProducerWidget", "Value", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(metadataTab), QCoreApplication::translate("AvformatProducerWidget", "Metadata", nullptr));
#if QT_CONFIG(tooltip)
        menuButton->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Properties Menu", nullptr));
#endif // QT_CONFIG(tooltip)
        menuButton->setText(QString());
#if QT_CONFIG(tooltip)
        convertButton->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Convert to Edit-friendly", nullptr));
#endif // QT_CONFIG(tooltip)
        convertButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Convert...", nullptr));
        reverseButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Reverse...", nullptr));
        proxyButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Proxy", nullptr));
        openWithButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Open With", nullptr));
#if QT_CONFIG(tooltip)
        reloadButton->setToolTip(QCoreApplication::translate("AvformatProducerWidget", "Refresh the file in Shotcut if you changed it in another app", nullptr));
#endif // QT_CONFIG(tooltip)
        reloadButton->setText(QCoreApplication::translate("AvformatProducerWidget", "Reload", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AvformatProducerWidget: public Ui_AvformatProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AVFORMATPRODUCERWIDGET_H
