/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *actionOpen;
    QAction *actionExit;
    QAction *actionAbout_Shotcut;
    QAction *actionAbout_Qt;
    QAction *actionOpenOther;
    QAction *actionSave;
    QAction *actionSave_As;
    QAction *actionEncode;
    QAction *actionForum;
    QAction *actionFAQ;
    QAction *actionEnterFullScreen;
    QAction *actionAudioMeter;
    QAction *actionProperties;
    QAction *actionRecent;
    QAction *actionPlaylist;
    QAction *actionHistory;
    QAction *actionRealtime;
    QAction *actionProgressive;
    QAction *actionNative8bitCpu;
    QAction *actionNative10bitCpu;
    QAction *actionLinear10bitCpu;
    QAction *actionLinear10bitGpuCpu;
    QAction *actionChannels1;
    QAction *actionChannels2;
    QAction *actionChannels4;
    QAction *actionChannels6;
    QAction *actionOneField;
    QAction *actionYadifTemporal;
    QAction *actionYadifSpatial;
    QAction *actionBwdif;
    QAction *actionNearest;
    QAction *actionBilinear;
    QAction *actionBicubic;
    QAction *actionHyper;
    QAction *actionProfileAutomatic;
    QAction *actionExternalNone;
    QAction *actionJack;
    QAction *actionFilters;
    QAction *actionAddCustomProfile;
    QAction *actionSystemTheme;
    QAction *actionSystemFusion;
    QAction *actionFusionDark;
    QAction *actionFusionLight;
    QAction *actionTutorials;
    QAction *actionTimeline;
    QAction *actionRestoreLayout;
    QAction *actionShowTitleBars;
    QAction *actionShowToolbar;
    QAction *actionUpgrade;
    QAction *actionOpenXML;
    QAction *actionScrubAudio;
    QAction *actionDrawingAutomatic;
    QAction *actionDrawingOpenGL;
    QAction *actionDrawingDirectX;
    QAction *actionJobPriorityLow;
    QAction *actionJobPriorityNormal;
    QAction *actionResources;
    QAction *actionApplicationLog;
    QAction *actionProject;
    QAction *actionUser_Interface;
    QAction *actionClose;
    QAction *actionExportEDL;
    QAction *actionExportFrame;
    QAction *actionExportVideo;
    QAction *actionAppDataSet;
    QAction *actionAppDataShow;
    QAction *actionKeyframes;
    QAction *actionNew;
    QAction *actionScreenSnapshot;
    QAction *actionScreenRecording;
    QAction *actionKeyboardShortcuts;
    QAction *actionLayoutAudio;
    QAction *actionLayoutLogging;
    QAction *actionLayoutEditing;
    QAction *actionLayoutEffects;
    QAction *actionLayoutAdd;
    QAction *actionProfileRemove;
    QAction *actionLayoutRemove;
    QAction *actionOpenOther2;
    QAction *actionClearRecentOnExit;
    QAction *actionShowTextUnderIcons;
    QAction *actionShowSmallIcons;
    QAction *actionJobs;
    QAction *actionMarkers;
    QAction *actionNotes;
    QAction *actionSubtitles;
    QAction *actionPreview540;
    QAction *actionPreview720;
    QAction *actionPreview1080;
    QAction *actionPreviewNone;
    QAction *actionPreview360;
    QAction *actionTimeDF;
    QAction *actionTimeFrames;
    QAction *actionTimeClock;
    QAction *actionTimeNDF;
    QAction *actionTopics;
    QAction *actionSync;
    QAction *actionUseProxy;
    QAction *actionProxyStorageSet;
    QAction *actionProxyStorageShow;
    QAction *actionProxyUseProjectFolder;
    QAction *actionProxyUseHardware;
    QAction *actionPreviewHardwareDecoder;
    QAction *actionProxyConfigureHardware;
    QAction *actionLayoutColor;
    QAction *actionLayoutPlayer;
    QAction *undoStartSeparator;
    QAction *undoEndSeparator;
    QAction *dummyAction;
    QAction *actionLayoutPlaylist;
    QAction *actionLayoutClip;
    QAction *actionExportChapters;
    QAction *actionAudioVideoDevice;
    QAction *actionReset;
    QAction *actionBackupSave;
    QAction *actionBackupManually;
    QAction *actionBackupHourly;
    QAction *actionBackupDaily;
    QAction *actionBackupWeekly;
    QAction *actionShowProjectFolder;
    QAction *actionPauseAfterSeek;
    QAction *actionFiles;
    QAction *actionWhatsThis;
    QAction *actionDrawingVulkan;
    QAction *actionLeaveSafeMode;
    QWidget *centralWidget;
    QHBoxLayout *horizontalLayout;
    QMenuBar *menuBar;
    QMenu *menuFile;
    QMenu *menuExport;
    QMenu *menuOtherVersions;
    QMenu *menuNew;
    QMenu *menuView;
    QMenu *menuLayout;
    QMenu *menuEdit;
    QMenu *menuPlayer;
    QMenu *menuExternal;
    QMenu *menuHelp;
    QMenu *menuSettings;
    QMenu *menuAudioChannels;
    QMenu *menuProfile;
    QMenu *menuProcessingMode;
    QMenu *menuLanguage;
    QMenu *menuTheme;
    QMenu *menuDrawingMethod;
    QMenu *menuGpuAdapter;
    QMenu *menuJobPriority;
    QMenu *menuTimeline;
    QMenu *menuPlaylist;
    QMenu *menuData_Directory;
    QMenu *menuPreviewScaling;
    QMenu *menuTimeFormat;
    QMenu *menuProxy;
    QMenu *menuStorage;
    QMenu *menuPlayerSettings;
    QMenu *menuDeinterlacer;
    QMenu *menuInterpolation;
    QMenu *menuBackup;
    QToolBar *mainToolBar;
    QStatusBar *statusBar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(1270, 688);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/shotcut-logo-64.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        MainWindow->setWindowIcon(icon);
        actionOpen = new QAction(MainWindow);
        actionOpen->setObjectName("actionOpen");
        QIcon icon1;
        QString iconThemeName = QString::fromUtf8("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/document-open.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionOpen->setIcon(icon1);
#if QT_CONFIG(shortcut)
        actionOpen->setShortcut(QString::fromUtf8("Ctrl+O"));
#endif // QT_CONFIG(shortcut)
        actionOpen->setIconVisibleInMenu(false);
        actionExit = new QAction(MainWindow);
        actionExit->setObjectName("actionExit");
#if QT_CONFIG(shortcut)
        actionExit->setShortcut(QString::fromUtf8("Ctrl+Q"));
#endif // QT_CONFIG(shortcut)
        actionAbout_Shotcut = new QAction(MainWindow);
        actionAbout_Shotcut->setObjectName("actionAbout_Shotcut");
        actionAbout_Shotcut->setMenuRole(QAction::MenuRole::AboutRole);
        actionAbout_Qt = new QAction(MainWindow);
        actionAbout_Qt->setObjectName("actionAbout_Qt");
        actionAbout_Qt->setMenuRole(QAction::MenuRole::AboutQtRole);
        actionOpenOther = new QAction(MainWindow);
        actionOpenOther->setObjectName("actionOpenOther");
#if QT_CONFIG(shortcut)
        actionOpenOther->setShortcut(QString::fromUtf8("Ctrl+Shift+O"));
#endif // QT_CONFIG(shortcut)
        actionOpenOther->setIconVisibleInMenu(false);
        actionSave = new QAction(MainWindow);
        actionSave->setObjectName("actionSave");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("document-save");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/document-save.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionSave->setIcon(icon2);
#if QT_CONFIG(whatsthis)
        actionSave->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/file-save-and-save-as/12973/1"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(shortcut)
        actionSave->setShortcut(QString::fromUtf8("Ctrl+S"));
#endif // QT_CONFIG(shortcut)
        actionSave->setIconVisibleInMenu(false);
        actionSave_As = new QAction(MainWindow);
        actionSave_As->setObjectName("actionSave_As");
#if QT_CONFIG(whatsthis)
        actionSave_As->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/file-save-and-save-as/12973/1"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(shortcut)
        actionSave_As->setShortcut(QString::fromUtf8("Ctrl+Shift+S"));
#endif // QT_CONFIG(shortcut)
        actionEncode = new QAction(MainWindow);
        actionEncode->setObjectName("actionEncode");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("media-record");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/media-record.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionEncode->setIcon(icon3);
#if QT_CONFIG(whatsthis)
        actionEncode->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/export-basics/12953//1"));
#endif // QT_CONFIG(whatsthis)
        actionForum = new QAction(MainWindow);
        actionForum->setObjectName("actionForum");
        actionFAQ = new QAction(MainWindow);
        actionFAQ->setObjectName("actionFAQ");
        actionEnterFullScreen = new QAction(MainWindow);
        actionEnterFullScreen->setObjectName("actionEnterFullScreen");
        QIcon icon4;
        iconThemeName = QString::fromUtf8("view-fullscreen");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/view-fullscreen.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionEnterFullScreen->setIcon(icon4);
        actionAudioMeter = new QAction(MainWindow);
        actionAudioMeter->setObjectName("actionAudioMeter");
        QIcon icon5;
        iconThemeName = QString::fromUtf8("audio-meter");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QString::fromUtf8(":/icons/light/32x32/audio-meter.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionAudioMeter->setIcon(icon5);
#if QT_CONFIG(whatsthis)
        actionAudioMeter->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/audio-peak-meter-scope/12918/1"));
#endif // QT_CONFIG(whatsthis)
        actionProperties = new QAction(MainWindow);
        actionProperties->setObjectName("actionProperties");
        QIcon icon6;
        iconThemeName = QString::fromUtf8("dialog-information");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QString::fromUtf8(":/icons/oxygen/32x32/status/dialog-information.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionProperties->setIcon(icon6);
#if QT_CONFIG(whatsthis)
        actionProperties->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/user-guide-table-of-contents/43285#p-145073-properties-14"));
#endif // QT_CONFIG(whatsthis)
        actionRecent = new QAction(MainWindow);
        actionRecent->setObjectName("actionRecent");
        QIcon icon7;
        iconThemeName = QString::fromUtf8("document-open-recent");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon7 = QIcon::fromTheme(iconThemeName);
        } else {
            icon7.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/document-open-recent.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionRecent->setIcon(icon7);
#if QT_CONFIG(whatsthis)
        actionRecent->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/recent-panel/12941/1"));
#endif // QT_CONFIG(whatsthis)
        actionPlaylist = new QAction(MainWindow);
        actionPlaylist->setObjectName("actionPlaylist");
        QIcon icon8;
        iconThemeName = QString::fromUtf8("view-media-playlist");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon8 = QIcon::fromTheme(iconThemeName);
        } else {
            icon8.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/view-media-playlist.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionPlaylist->setIcon(icon8);
#if QT_CONFIG(whatsthis)
        actionPlaylist->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/about-the-playlist/12951/1"));
#endif // QT_CONFIG(whatsthis)
        actionHistory = new QAction(MainWindow);
        actionHistory->setObjectName("actionHistory");
        QIcon icon9;
        iconThemeName = QString::fromUtf8("view-history");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon9 = QIcon::fromTheme(iconThemeName);
        } else {
            icon9.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/view-history.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionHistory->setIcon(icon9);
#if QT_CONFIG(whatsthis)
        actionHistory->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/history-panel/12944/1"));
#endif // QT_CONFIG(whatsthis)
        actionRealtime = new QAction(MainWindow);
        actionRealtime->setObjectName("actionRealtime");
        actionRealtime->setCheckable(true);
        actionRealtime->setChecked(true);
        actionProgressive = new QAction(MainWindow);
        actionProgressive->setObjectName("actionProgressive");
        actionProgressive->setCheckable(true);
        actionProgressive->setChecked(true);
        actionNative8bitCpu = new QAction(MainWindow);
        actionNative8bitCpu->setObjectName("actionNative8bitCpu");
        actionNative8bitCpu->setCheckable(true);
        actionNative10bitCpu = new QAction(MainWindow);
        actionNative10bitCpu->setObjectName("actionNative10bitCpu");
        actionNative10bitCpu->setCheckable(true);
        actionLinear10bitCpu = new QAction(MainWindow);
        actionLinear10bitCpu->setObjectName("actionLinear10bitCpu");
        actionLinear10bitCpu->setCheckable(true);
        actionLinear10bitGpuCpu = new QAction(MainWindow);
        actionLinear10bitGpuCpu->setObjectName("actionLinear10bitGpuCpu");
        actionLinear10bitGpuCpu->setCheckable(true);
        actionChannels1 = new QAction(MainWindow);
        actionChannels1->setObjectName("actionChannels1");
        actionChannels1->setCheckable(true);
        actionChannels2 = new QAction(MainWindow);
        actionChannels2->setObjectName("actionChannels2");
        actionChannels2->setCheckable(true);
        actionChannels4 = new QAction(MainWindow);
        actionChannels4->setObjectName("actionChannels4");
        actionChannels4->setCheckable(true);
        actionChannels6 = new QAction(MainWindow);
        actionChannels6->setObjectName("actionChannels6");
        actionChannels6->setCheckable(true);
        actionOneField = new QAction(MainWindow);
        actionOneField->setObjectName("actionOneField");
        actionOneField->setCheckable(true);
        actionOneField->setChecked(true);
        actionYadifTemporal = new QAction(MainWindow);
        actionYadifTemporal->setObjectName("actionYadifTemporal");
        actionYadifTemporal->setCheckable(true);
        actionYadifSpatial = new QAction(MainWindow);
        actionYadifSpatial->setObjectName("actionYadifSpatial");
        actionYadifSpatial->setCheckable(true);
        actionBwdif = new QAction(MainWindow);
        actionBwdif->setObjectName("actionBwdif");
        actionBwdif->setCheckable(true);
        actionNearest = new QAction(MainWindow);
        actionNearest->setObjectName("actionNearest");
        actionNearest->setCheckable(true);
        actionNearest->setChecked(true);
        actionBilinear = new QAction(MainWindow);
        actionBilinear->setObjectName("actionBilinear");
        actionBilinear->setCheckable(true);
        actionBicubic = new QAction(MainWindow);
        actionBicubic->setObjectName("actionBicubic");
        actionBicubic->setCheckable(true);
        actionHyper = new QAction(MainWindow);
        actionHyper->setObjectName("actionHyper");
        actionHyper->setCheckable(true);
        actionProfileAutomatic = new QAction(MainWindow);
        actionProfileAutomatic->setObjectName("actionProfileAutomatic");
        actionProfileAutomatic->setCheckable(true);
        actionProfileAutomatic->setChecked(true);
        actionExternalNone = new QAction(MainWindow);
        actionExternalNone->setObjectName("actionExternalNone");
        actionExternalNone->setCheckable(true);
        actionExternalNone->setChecked(true);
        actionJack = new QAction(MainWindow);
        actionJack->setObjectName("actionJack");
        actionJack->setCheckable(true);
        actionFilters = new QAction(MainWindow);
        actionFilters->setObjectName("actionFilters");
        QIcon icon10;
        iconThemeName = QString::fromUtf8("view-filter");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon10 = QIcon::fromTheme(iconThemeName);
        } else {
            icon10.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/view-filter.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionFilters->setIcon(icon10);
#if QT_CONFIG(whatsthis)
        actionFilters->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/add-search-remove-and-reorder-filters/48127/1"));
#endif // QT_CONFIG(whatsthis)
        actionAddCustomProfile = new QAction(MainWindow);
        actionAddCustomProfile->setObjectName("actionAddCustomProfile");
        actionSystemTheme = new QAction(MainWindow);
        actionSystemTheme->setObjectName("actionSystemTheme");
        actionSystemTheme->setCheckable(true);
        actionSystemFusion = new QAction(MainWindow);
        actionSystemFusion->setObjectName("actionSystemFusion");
        actionSystemFusion->setCheckable(true);
        actionFusionDark = new QAction(MainWindow);
        actionFusionDark->setObjectName("actionFusionDark");
        actionFusionDark->setCheckable(true);
        actionFusionLight = new QAction(MainWindow);
        actionFusionLight->setObjectName("actionFusionLight");
        actionFusionLight->setCheckable(true);
        actionTutorials = new QAction(MainWindow);
        actionTutorials->setObjectName("actionTutorials");
        actionTimeline = new QAction(MainWindow);
        actionTimeline->setObjectName("actionTimeline");
        QIcon icon11;
        iconThemeName = QString::fromUtf8("view-time-schedule");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon11 = QIcon::fromTheme(iconThemeName);
        } else {
            icon11.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/view-time-schedule.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionTimeline->setIcon(icon11);
#if QT_CONFIG(whatsthis)
        actionTimeline->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/about-the-timeline/12952/1"));
#endif // QT_CONFIG(whatsthis)
        actionRestoreLayout = new QAction(MainWindow);
        actionRestoreLayout->setObjectName("actionRestoreLayout");
        actionShowTitleBars = new QAction(MainWindow);
        actionShowTitleBars->setObjectName("actionShowTitleBars");
        actionShowTitleBars->setCheckable(true);
        actionShowToolbar = new QAction(MainWindow);
        actionShowToolbar->setObjectName("actionShowToolbar");
        actionShowToolbar->setCheckable(true);
        actionUpgrade = new QAction(MainWindow);
        actionUpgrade->setObjectName("actionUpgrade");
        actionOpenXML = new QAction(MainWindow);
        actionOpenXML->setObjectName("actionOpenXML");
        actionScrubAudio = new QAction(MainWindow);
        actionScrubAudio->setObjectName("actionScrubAudio");
        actionScrubAudio->setCheckable(true);
        actionDrawingAutomatic = new QAction(MainWindow);
        actionDrawingAutomatic->setObjectName("actionDrawingAutomatic");
        actionDrawingAutomatic->setCheckable(true);
        actionDrawingAutomatic->setChecked(true);
        actionDrawingOpenGL = new QAction(MainWindow);
        actionDrawingOpenGL->setObjectName("actionDrawingOpenGL");
        actionDrawingOpenGL->setCheckable(true);
        actionDrawingOpenGL->setText(QString::fromUtf8("OpenGL"));
        actionDrawingDirectX = new QAction(MainWindow);
        actionDrawingDirectX->setObjectName("actionDrawingDirectX");
        actionDrawingDirectX->setCheckable(true);
        actionDrawingDirectX->setText(QString::fromUtf8("DirectX (ANGLE)"));
        actionJobPriorityLow = new QAction(MainWindow);
        actionJobPriorityLow->setObjectName("actionJobPriorityLow");
        actionJobPriorityLow->setCheckable(true);
        actionJobPriorityNormal = new QAction(MainWindow);
        actionJobPriorityNormal->setObjectName("actionJobPriorityNormal");
        actionJobPriorityNormal->setCheckable(true);
        actionResources = new QAction(MainWindow);
        actionResources->setObjectName("actionResources");
        actionApplicationLog = new QAction(MainWindow);
        actionApplicationLog->setObjectName("actionApplicationLog");
        actionProject = new QAction(MainWindow);
        actionProject->setObjectName("actionProject");
        actionProject->setEnabled(true);
        actionUser_Interface = new QAction(MainWindow);
        actionUser_Interface->setObjectName("actionUser_Interface");
        actionUser_Interface->setEnabled(true);
        actionClose = new QAction(MainWindow);
        actionClose->setObjectName("actionClose");
        QIcon icon12(QIcon::fromTheme(QString::fromUtf8("window-close")));
        actionClose->setIcon(icon12);
#if QT_CONFIG(shortcut)
        actionClose->setShortcut(QString::fromUtf8("Ctrl+W"));
#endif // QT_CONFIG(shortcut)
        actionClose->setIconVisibleInMenu(false);
        actionExportEDL = new QAction(MainWindow);
        actionExportEDL->setObjectName("actionExportEDL");
        actionExportFrame = new QAction(MainWindow);
        actionExportFrame->setObjectName("actionExportFrame");
#if QT_CONFIG(shortcut)
        actionExportFrame->setShortcut(QString::fromUtf8("Ctrl+Shift+E"));
#endif // QT_CONFIG(shortcut)
        actionExportVideo = new QAction(MainWindow);
        actionExportVideo->setObjectName("actionExportVideo");
#if QT_CONFIG(shortcut)
        actionExportVideo->setShortcut(QString::fromUtf8("Ctrl+E"));
#endif // QT_CONFIG(shortcut)
        actionAppDataSet = new QAction(MainWindow);
        actionAppDataSet->setObjectName("actionAppDataSet");
        actionAppDataShow = new QAction(MainWindow);
        actionAppDataShow->setObjectName("actionAppDataShow");
        actionKeyframes = new QAction(MainWindow);
        actionKeyframes->setObjectName("actionKeyframes");
        QIcon icon13;
        iconThemeName = QString::fromUtf8("chronometer");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon13 = QIcon::fromTheme(iconThemeName);
        } else {
            icon13.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/chronometer.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionKeyframes->setIcon(icon13);
#if QT_CONFIG(whatsthis)
        actionKeyframes->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/about-keyframes/12957/1"));
#endif // QT_CONFIG(whatsthis)
        actionNew = new QAction(MainWindow);
        actionNew->setObjectName("actionNew");
        actionScreenSnapshot = new QAction(MainWindow);
        actionScreenSnapshot->setObjectName("actionScreenSnapshot");
        actionScreenSnapshot->setVisible(false);
        actionScreenRecording = new QAction(MainWindow);
        actionScreenRecording->setObjectName("actionScreenRecording");
        actionScreenRecording->setVisible(false);
        actionKeyboardShortcuts = new QAction(MainWindow);
        actionKeyboardShortcuts->setObjectName("actionKeyboardShortcuts");
#if QT_CONFIG(shortcut)
        actionKeyboardShortcuts->setShortcut(QString::fromUtf8("?"));
#endif // QT_CONFIG(shortcut)
        actionLayoutAudio = new QAction(MainWindow);
        actionLayoutAudio->setObjectName("actionLayoutAudio");
        actionLayoutAudio->setCheckable(true);
        actionLayoutLogging = new QAction(MainWindow);
        actionLayoutLogging->setObjectName("actionLayoutLogging");
        actionLayoutLogging->setCheckable(true);
        actionLayoutEditing = new QAction(MainWindow);
        actionLayoutEditing->setObjectName("actionLayoutEditing");
        actionLayoutEditing->setCheckable(true);
        actionLayoutEffects = new QAction(MainWindow);
        actionLayoutEffects->setObjectName("actionLayoutEffects");
        actionLayoutEffects->setCheckable(true);
        actionLayoutAdd = new QAction(MainWindow);
        actionLayoutAdd->setObjectName("actionLayoutAdd");
        actionProfileRemove = new QAction(MainWindow);
        actionProfileRemove->setObjectName("actionProfileRemove");
        actionLayoutRemove = new QAction(MainWindow);
        actionLayoutRemove->setObjectName("actionLayoutRemove");
        actionOpenOther2 = new QAction(MainWindow);
        actionOpenOther2->setObjectName("actionOpenOther2");
        QIcon icon14;
        iconThemeName = QString::fromUtf8("document-new");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon14 = QIcon::fromTheme(iconThemeName);
        } else {
            icon14.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/document-new.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionOpenOther2->setIcon(icon14);
#if QT_CONFIG(whatsthis)
        actionOpenOther2->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/user-guide-table-of-contents/43285#p-145073-properties-14"));
#endif // QT_CONFIG(whatsthis)
        actionOpenOther2->setIconVisibleInMenu(false);
        actionClearRecentOnExit = new QAction(MainWindow);
        actionClearRecentOnExit->setObjectName("actionClearRecentOnExit");
        actionClearRecentOnExit->setCheckable(true);
        actionShowTextUnderIcons = new QAction(MainWindow);
        actionShowTextUnderIcons->setObjectName("actionShowTextUnderIcons");
        actionShowTextUnderIcons->setCheckable(true);
        actionShowSmallIcons = new QAction(MainWindow);
        actionShowSmallIcons->setObjectName("actionShowSmallIcons");
        actionShowSmallIcons->setCheckable(true);
        actionJobs = new QAction(MainWindow);
        actionJobs->setObjectName("actionJobs");
        QIcon icon15;
        iconThemeName = QString::fromUtf8("run-build");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon15 = QIcon::fromTheme(iconThemeName);
        } else {
            icon15.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/run-build.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionJobs->setIcon(icon15);
#if QT_CONFIG(whatsthis)
        actionJobs->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/jobs-panel/12945/1"));
#endif // QT_CONFIG(whatsthis)
        actionMarkers = new QAction(MainWindow);
        actionMarkers->setObjectName("actionMarkers");
        QIcon icon16;
        iconThemeName = QString::fromUtf8("marker");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon16 = QIcon::fromTheme(iconThemeName);
        } else {
            icon16.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/marker.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionMarkers->setIcon(icon16);
#if QT_CONFIG(whatsthis)
        actionMarkers->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/timeline-markers/30535/1"));
#endif // QT_CONFIG(whatsthis)
        actionNotes = new QAction(MainWindow);
        actionNotes->setObjectName("actionNotes");
        QIcon icon17;
        iconThemeName = QString::fromUtf8("document-edit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon17 = QIcon::fromTheme(iconThemeName);
        } else {
            icon17.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/document-edit.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionNotes->setIcon(icon17);
#if QT_CONFIG(whatsthis)
        actionNotes->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/notes-panel/33110/1"));
#endif // QT_CONFIG(whatsthis)
        actionSubtitles = new QAction(MainWindow);
        actionSubtitles->setObjectName("actionSubtitles");
        QIcon icon18;
        iconThemeName = QString::fromUtf8("subtitle");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon18 = QIcon::fromTheme(iconThemeName);
        } else {
            icon18.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/subtitle.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionSubtitles->setIcon(icon18);
#if QT_CONFIG(whatsthis)
        actionSubtitles->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/subtitles-panel/45312/1"));
#endif // QT_CONFIG(whatsthis)
        actionPreview540 = new QAction(MainWindow);
        actionPreview540->setObjectName("actionPreview540");
        actionPreview540->setCheckable(true);
#if QT_CONFIG(shortcut)
        actionPreview540->setShortcut(QString::fromUtf8("F8"));
#endif // QT_CONFIG(shortcut)
        actionPreview720 = new QAction(MainWindow);
        actionPreview720->setObjectName("actionPreview720");
        actionPreview720->setCheckable(true);
#if QT_CONFIG(shortcut)
        actionPreview720->setShortcut(QString::fromUtf8("F9"));
#endif // QT_CONFIG(shortcut)
        actionPreview1080 = new QAction(MainWindow);
        actionPreview1080->setObjectName("actionPreview1080");
        actionPreview1080->setCheckable(true);
        actionPreviewNone = new QAction(MainWindow);
        actionPreviewNone->setObjectName("actionPreviewNone");
        actionPreviewNone->setCheckable(true);
#if QT_CONFIG(shortcut)
        actionPreviewNone->setShortcut(QString::fromUtf8("F6"));
#endif // QT_CONFIG(shortcut)
        actionPreview360 = new QAction(MainWindow);
        actionPreview360->setObjectName("actionPreview360");
        actionPreview360->setCheckable(true);
#if QT_CONFIG(shortcut)
        actionPreview360->setShortcut(QString::fromUtf8("F7"));
#endif // QT_CONFIG(shortcut)
        actionTimeDF = new QAction(MainWindow);
        actionTimeDF->setObjectName("actionTimeDF");
        actionTimeDF->setCheckable(true);
        actionTimeFrames = new QAction(MainWindow);
        actionTimeFrames->setObjectName("actionTimeFrames");
        actionTimeFrames->setCheckable(true);
        actionTimeClock = new QAction(MainWindow);
        actionTimeClock->setObjectName("actionTimeClock");
        actionTimeClock->setCheckable(true);
        actionTimeNDF = new QAction(MainWindow);
        actionTimeNDF->setObjectName("actionTimeNDF");
        actionTimeNDF->setCheckable(true);
        actionTopics = new QAction(MainWindow);
        actionTopics->setObjectName("actionTopics");
#if QT_CONFIG(shortcut)
        actionTopics->setShortcut(QString::fromUtf8("F1"));
#endif // QT_CONFIG(shortcut)
        actionSync = new QAction(MainWindow);
        actionSync->setObjectName("actionSync");
        actionUseProxy = new QAction(MainWindow);
        actionUseProxy->setObjectName("actionUseProxy");
        actionUseProxy->setCheckable(true);
#if QT_CONFIG(shortcut)
        actionUseProxy->setShortcut(QString::fromUtf8("F4"));
#endif // QT_CONFIG(shortcut)
        actionProxyStorageSet = new QAction(MainWindow);
        actionProxyStorageSet->setObjectName("actionProxyStorageSet");
        actionProxyStorageShow = new QAction(MainWindow);
        actionProxyStorageShow->setObjectName("actionProxyStorageShow");
        actionProxyUseProjectFolder = new QAction(MainWindow);
        actionProxyUseProjectFolder->setObjectName("actionProxyUseProjectFolder");
        actionProxyUseProjectFolder->setCheckable(true);
        actionProxyUseProjectFolder->setChecked(true);
        actionProxyUseHardware = new QAction(MainWindow);
        actionProxyUseHardware->setObjectName("actionProxyUseHardware");
        actionProxyUseHardware->setCheckable(true);
        actionPreviewHardwareDecoder = new QAction(MainWindow);
        actionPreviewHardwareDecoder->setObjectName("actionPreviewHardwareDecoder");
        actionPreviewHardwareDecoder->setCheckable(true);
        actionProxyConfigureHardware = new QAction(MainWindow);
        actionProxyConfigureHardware->setObjectName("actionProxyConfigureHardware");
        actionLayoutColor = new QAction(MainWindow);
        actionLayoutColor->setObjectName("actionLayoutColor");
        actionLayoutColor->setCheckable(true);
        actionLayoutPlayer = new QAction(MainWindow);
        actionLayoutPlayer->setObjectName("actionLayoutPlayer");
        actionLayoutPlayer->setCheckable(true);
        undoStartSeparator = new QAction(MainWindow);
        undoStartSeparator->setObjectName("undoStartSeparator");
        undoStartSeparator->setSeparator(true);
        undoEndSeparator = new QAction(MainWindow);
        undoEndSeparator->setObjectName("undoEndSeparator");
        undoEndSeparator->setSeparator(true);
        dummyAction = new QAction(MainWindow);
        dummyAction->setObjectName("dummyAction");
        dummyAction->setText(QString::fromUtf8("X"));
        dummyAction->setVisible(false);
        actionLayoutPlaylist = new QAction(MainWindow);
        actionLayoutPlaylist->setObjectName("actionLayoutPlaylist");
        actionLayoutClip = new QAction(MainWindow);
        actionLayoutClip->setObjectName("actionLayoutClip");
        actionExportChapters = new QAction(MainWindow);
        actionExportChapters->setObjectName("actionExportChapters");
        actionAudioVideoDevice = new QAction(MainWindow);
        actionAudioVideoDevice->setObjectName("actionAudioVideoDevice");
        actionReset = new QAction(MainWindow);
        actionReset->setObjectName("actionReset");
        actionBackupSave = new QAction(MainWindow);
        actionBackupSave->setObjectName("actionBackupSave");
        actionBackupManually = new QAction(MainWindow);
        actionBackupManually->setObjectName("actionBackupManually");
        actionBackupManually->setCheckable(true);
        actionBackupHourly = new QAction(MainWindow);
        actionBackupHourly->setObjectName("actionBackupHourly");
        actionBackupHourly->setCheckable(true);
        actionBackupDaily = new QAction(MainWindow);
        actionBackupDaily->setObjectName("actionBackupDaily");
        actionBackupDaily->setCheckable(true);
        actionBackupWeekly = new QAction(MainWindow);
        actionBackupWeekly->setObjectName("actionBackupWeekly");
        actionBackupWeekly->setCheckable(true);
        actionBackupWeekly->setChecked(true);
        actionShowProjectFolder = new QAction(MainWindow);
        actionShowProjectFolder->setObjectName("actionShowProjectFolder");
        actionPauseAfterSeek = new QAction(MainWindow);
        actionPauseAfterSeek->setObjectName("actionPauseAfterSeek");
        actionPauseAfterSeek->setCheckable(true);
        actionPauseAfterSeek->setChecked(true);
        actionFiles = new QAction(MainWindow);
        actionFiles->setObjectName("actionFiles");
        QIcon icon19;
        iconThemeName = QString::fromUtf8("system-file-manager");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon19 = QIcon::fromTheme(iconThemeName);
        } else {
            icon19.addFile(QString::fromUtf8(":/icons/oxygen/32x32/apps/system-file-manager.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionFiles->setIcon(icon19);
        actionWhatsThis = new QAction(MainWindow);
        actionWhatsThis->setObjectName("actionWhatsThis");
        QIcon icon20;
        iconThemeName = QString::fromUtf8("help-contextual");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon20 = QIcon::fromTheme(iconThemeName);
        } else {
            icon20.addFile(QString::fromUtf8(":/icons/oxygen/32x32/actions/help-contextual.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionWhatsThis->setIcon(icon20);
#if QT_CONFIG(shortcut)
        actionWhatsThis->setShortcut(QString::fromUtf8("Shift+F1"));
#endif // QT_CONFIG(shortcut)
        actionDrawingVulkan = new QAction(MainWindow);
        actionDrawingVulkan->setObjectName("actionDrawingVulkan");
        actionDrawingVulkan->setCheckable(true);
        actionDrawingVulkan->setText(QString::fromUtf8("Vulkan"));
        actionDrawingVulkan->setIconText(QString::fromUtf8("Vulkan"));
#if QT_CONFIG(tooltip)
        actionDrawingVulkan->setToolTip(QString::fromUtf8("Vulkan"));
#endif // QT_CONFIG(tooltip)
        actionLeaveSafeMode = new QAction(MainWindow);
        actionLeaveSafeMode->setObjectName("actionLeaveSafeMode");
        centralWidget = new QWidget(MainWindow);
        centralWidget->setObjectName("centralWidget");
        horizontalLayout = new QHBoxLayout(centralWidget);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(11, 11, 11, 11);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 4, 0, 0);
        MainWindow->setCentralWidget(centralWidget);
        menuBar = new QMenuBar(MainWindow);
        menuBar->setObjectName("menuBar");
        menuBar->setGeometry(QRect(0, 0, 1270, 29));
        menuFile = new QMenu(menuBar);
        menuFile->setObjectName("menuFile");
        menuExport = new QMenu(menuFile);
        menuExport->setObjectName("menuExport");
        menuOtherVersions = new QMenu(menuFile);
        menuOtherVersions->setObjectName("menuOtherVersions");
        menuNew = new QMenu(menuFile);
        menuNew->setObjectName("menuNew");
        menuView = new QMenu(menuBar);
        menuView->setObjectName("menuView");
        menuLayout = new QMenu(menuView);
        menuLayout->setObjectName("menuLayout");
        menuEdit = new QMenu(menuBar);
        menuEdit->setObjectName("menuEdit");
        menuPlayer = new QMenu(menuBar);
        menuPlayer->setObjectName("menuPlayer");
        menuExternal = new QMenu(menuPlayer);
        menuExternal->setObjectName("menuExternal");
        menuHelp = new QMenu(menuBar);
        menuHelp->setObjectName("menuHelp");
        menuSettings = new QMenu(menuBar);
        menuSettings->setObjectName("menuSettings");
        menuAudioChannels = new QMenu(menuSettings);
        menuAudioChannels->setObjectName("menuAudioChannels");
        menuProfile = new QMenu(menuSettings);
        menuProfile->setObjectName("menuProfile");
        menuProcessingMode = new QMenu(menuSettings);
        menuProcessingMode->setObjectName("menuProcessingMode");
        menuLanguage = new QMenu(menuSettings);
        menuLanguage->setObjectName("menuLanguage");
        menuTheme = new QMenu(menuSettings);
        menuTheme->setObjectName("menuTheme");
        menuDrawingMethod = new QMenu(menuSettings);
        menuDrawingMethod->setObjectName("menuDrawingMethod");
        menuGpuAdapter = new QMenu(menuSettings);
        menuGpuAdapter->setObjectName("menuGpuAdapter");
        menuJobPriority = new QMenu(menuSettings);
        menuJobPriority->setObjectName("menuJobPriority");
        menuTimeline = new QMenu(menuSettings);
        menuTimeline->setObjectName("menuTimeline");
        menuPlaylist = new QMenu(menuSettings);
        menuPlaylist->setObjectName("menuPlaylist");
        menuData_Directory = new QMenu(menuSettings);
        menuData_Directory->setObjectName("menuData_Directory");
        menuPreviewScaling = new QMenu(menuSettings);
        menuPreviewScaling->setObjectName("menuPreviewScaling");
        menuTimeFormat = new QMenu(menuSettings);
        menuTimeFormat->setObjectName("menuTimeFormat");
        menuProxy = new QMenu(menuSettings);
        menuProxy->setObjectName("menuProxy");
        menuStorage = new QMenu(menuProxy);
        menuStorage->setObjectName("menuStorage");
        menuPlayerSettings = new QMenu(menuSettings);
        menuPlayerSettings->setObjectName("menuPlayerSettings");
        menuDeinterlacer = new QMenu(menuPlayerSettings);
        menuDeinterlacer->setObjectName("menuDeinterlacer");
        menuInterpolation = new QMenu(menuPlayerSettings);
        menuInterpolation->setObjectName("menuInterpolation");
        menuBackup = new QMenu(menuSettings);
        menuBackup->setObjectName("menuBackup");
        MainWindow->setMenuBar(menuBar);
        mainToolBar = new QToolBar(MainWindow);
        mainToolBar->setObjectName("mainToolBar");
        mainToolBar->setStyleSheet(QString::fromUtf8("QToolButton:checked { color: palette(highlighted-text); background-color: palette(highlight); border: none; padding: 2px }"));
        mainToolBar->setMovable(false);
        mainToolBar->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonFollowStyle);
        mainToolBar->setFloatable(false);
        mainToolBar->setProperty("Movable", QVariant(false));
        MainWindow->addToolBar(Qt::ToolBarArea::TopToolBarArea, mainToolBar);
        statusBar = new QStatusBar(MainWindow);
        statusBar->setObjectName("statusBar");
        MainWindow->setStatusBar(statusBar);

        menuBar->addAction(menuFile->menuAction());
        menuBar->addAction(menuEdit->menuAction());
        menuBar->addAction(menuView->menuAction());
        menuBar->addAction(menuPlayer->menuAction());
        menuBar->addAction(menuSettings->menuAction());
        menuBar->addAction(menuHelp->menuAction());
        menuFile->addAction(menuNew->menuAction());
        menuFile->addAction(actionOpen);
        menuFile->addAction(actionOpenOther);
        menuFile->addAction(actionOpenXML);
        menuFile->addSeparator();
        menuFile->addAction(actionSave);
        menuFile->addAction(actionSave_As);
        menuFile->addAction(actionBackupSave);
        menuFile->addAction(menuOtherVersions->menuAction());
        menuFile->addSeparator();
        menuFile->addAction(actionShowProjectFolder);
        menuFile->addAction(menuExport->menuAction());
        menuFile->addAction(actionClose);
        menuFile->addSeparator();
        menuFile->addAction(actionExit);
        menuExport->addAction(actionExportFrame);
        menuExport->addAction(actionExportVideo);
        menuExport->addAction(actionExportChapters);
        menuExport->addAction(actionExportEDL);
        menuOtherVersions->addSeparator();
        menuNew->addAction(actionNew);
        menuView->addAction(actionEnterFullScreen);
        menuView->addAction(menuLayout->menuAction());
        menuView->addAction(actionShowTitleBars);
        menuView->addAction(actionShowToolbar);
        menuView->addAction(actionShowSmallIcons);
        menuView->addAction(actionShowTextUnderIcons);
        menuView->addSeparator();
        menuLayout->addAction(actionLayoutLogging);
        menuLayout->addAction(actionLayoutEditing);
        menuLayout->addAction(actionLayoutEffects);
        menuLayout->addAction(actionLayoutColor);
        menuLayout->addAction(actionLayoutAudio);
        menuLayout->addAction(actionLayoutPlayer);
        menuLayout->addSeparator();
        menuLayout->addAction(actionLayoutClip);
        menuLayout->addAction(actionLayoutPlaylist);
        menuLayout->addSeparator();
        menuLayout->addAction(actionRestoreLayout);
        menuLayout->addAction(actionLayoutAdd);
        menuPlayer->addAction(menuExternal->menuAction());
        menuPlayer->addSeparator();
        menuExternal->addAction(actionExternalNone);
        menuHelp->addAction(actionTopics);
        menuHelp->addAction(actionKeyboardShortcuts);
        menuHelp->addAction(actionWhatsThis);
        menuHelp->addAction(actionUpgrade);
        menuHelp->addAction(actionFAQ);
        menuHelp->addAction(actionTutorials);
        menuHelp->addAction(actionForum);
        menuHelp->addSeparator();
        menuHelp->addAction(actionAbout_Shotcut);
        menuHelp->addAction(actionAbout_Qt);
        menuSettings->addAction(actionProject);
        menuSettings->addAction(menuProfile->menuAction());
        menuSettings->addAction(menuProcessingMode->menuAction());
        menuSettings->addAction(menuAudioChannels->menuAction());
        menuSettings->addAction(menuBackup->menuAction());
        menuSettings->addAction(actionUser_Interface);
        menuSettings->addAction(menuPreviewScaling->menuAction());
        menuSettings->addAction(menuProxy->menuAction());
        menuSettings->addAction(menuPlayerSettings->menuAction());
        menuSettings->addAction(menuPlaylist->menuAction());
        menuSettings->addAction(menuTimeline->menuAction());
        menuSettings->addAction(menuTimeFormat->menuAction());
        menuSettings->addAction(menuLanguage->menuAction());
        menuSettings->addAction(menuTheme->menuAction());
        menuSettings->addAction(menuDrawingMethod->menuAction());
        menuSettings->addAction(menuGpuAdapter->menuAction());
        menuSettings->addAction(menuJobPriority->menuAction());
        menuSettings->addAction(menuData_Directory->menuAction());
        menuSettings->addAction(actionAudioVideoDevice);
        menuSettings->addAction(actionClearRecentOnExit);
        menuSettings->addSeparator();
        menuSettings->addAction(actionLeaveSafeMode);
        menuSettings->addAction(actionReset);
        menuAudioChannels->addAction(actionChannels1);
        menuAudioChannels->addAction(actionChannels2);
        menuAudioChannels->addAction(actionChannels4);
        menuAudioChannels->addAction(actionChannels6);
        menuProfile->addAction(actionProfileAutomatic);
        menuProcessingMode->addAction(actionNative8bitCpu);
        menuProcessingMode->addAction(actionNative10bitCpu);
        menuProcessingMode->addAction(actionLinear10bitCpu);
        menuProcessingMode->addAction(actionLinear10bitGpuCpu);
        menuTheme->addAction(actionSystemTheme);
        menuTheme->addAction(actionSystemFusion);
        menuTheme->addAction(actionFusionDark);
        menuTheme->addAction(actionFusionLight);
        menuDrawingMethod->addAction(actionDrawingAutomatic);
        menuDrawingMethod->addAction(actionDrawingOpenGL);
        menuDrawingMethod->addAction(actionDrawingDirectX);
        menuDrawingMethod->addAction(actionDrawingVulkan);
        menuJobPriority->addAction(actionJobPriorityLow);
        menuJobPriority->addAction(actionJobPriorityNormal);
        menuData_Directory->addAction(actionAppDataSet);
        menuData_Directory->addAction(actionAppDataShow);
        menuPreviewScaling->addAction(actionPreviewNone);
        menuPreviewScaling->addAction(actionPreview360);
        menuPreviewScaling->addAction(actionPreview540);
        menuPreviewScaling->addAction(actionPreview720);
        menuPreviewScaling->addAction(actionPreview1080);
        menuPreviewScaling->addSeparator();
        menuPreviewScaling->addAction(actionPreviewHardwareDecoder);
        menuTimeFormat->addAction(actionTimeClock);
        menuTimeFormat->addAction(actionTimeDF);
        menuTimeFormat->addAction(actionTimeNDF);
        menuTimeFormat->addAction(actionTimeFrames);
        menuProxy->addAction(actionUseProxy);
        menuProxy->addAction(menuStorage->menuAction());
        menuProxy->addSeparator();
        menuProxy->addAction(actionProxyUseHardware);
        menuProxy->addAction(actionProxyConfigureHardware);
        menuStorage->addAction(actionProxyStorageSet);
        menuStorage->addAction(actionProxyStorageShow);
        menuStorage->addAction(actionProxyUseProjectFolder);
        menuPlayerSettings->addAction(actionPauseAfterSeek);
        menuPlayerSettings->addAction(actionScrubAudio);
        menuPlayerSettings->addAction(actionJack);
        menuPlayerSettings->addAction(actionRealtime);
        menuPlayerSettings->addAction(actionProgressive);
        menuPlayerSettings->addAction(menuDeinterlacer->menuAction());
        menuPlayerSettings->addAction(menuInterpolation->menuAction());
        menuPlayerSettings->addAction(actionSync);
        menuDeinterlacer->addAction(actionOneField);
        menuDeinterlacer->addAction(actionYadifTemporal);
        menuDeinterlacer->addAction(actionYadifSpatial);
        menuDeinterlacer->addAction(actionBwdif);
        menuInterpolation->addAction(actionNearest);
        menuInterpolation->addAction(actionBilinear);
        menuInterpolation->addAction(actionBicubic);
        menuInterpolation->addAction(actionHyper);
        menuBackup->addAction(actionBackupManually);
        menuBackup->addAction(actionBackupHourly);
        menuBackup->addAction(actionBackupDaily);
        menuBackup->addAction(actionBackupWeekly);
        mainToolBar->addAction(actionOpen);
        mainToolBar->addAction(actionOpenOther2);
        mainToolBar->addAction(actionSave);
        mainToolBar->addAction(undoStartSeparator);
        mainToolBar->addAction(undoEndSeparator);
        mainToolBar->addAction(actionAudioMeter);
        mainToolBar->addAction(actionProperties);
        mainToolBar->addAction(actionRecent);
        mainToolBar->addAction(actionNotes);
        mainToolBar->addAction(actionPlaylist);
        mainToolBar->addAction(actionFiles);
        mainToolBar->addAction(actionTimeline);
        mainToolBar->addAction(actionFilters);
        mainToolBar->addAction(actionMarkers);
        mainToolBar->addAction(actionKeyframes);
        mainToolBar->addAction(actionHistory);
        mainToolBar->addAction(actionEncode);
        mainToolBar->addAction(actionJobs);
        mainToolBar->addAction(actionSubtitles);
        mainToolBar->addAction(actionWhatsThis);
        mainToolBar->addAction(dummyAction);
        mainToolBar->addAction(actionLayoutLogging);
        mainToolBar->addAction(actionLayoutEditing);
        mainToolBar->addAction(actionLayoutEffects);
        mainToolBar->addAction(actionLayoutColor);
        mainToolBar->addAction(actionLayoutAudio);
        mainToolBar->addAction(actionLayoutPlayer);

        retranslateUi(MainWindow);
        QObject::connect(actionExit, &QAction::triggered, MainWindow, qOverload<>(&QMainWindow::close));

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("MainWindow", "Shotcut", nullptr));
        actionOpen->setText(QCoreApplication::translate("MainWindow", "&Open File...", nullptr));
#if QT_CONFIG(tooltip)
        actionOpen->setToolTip(QCoreApplication::translate("MainWindow", "Open a video, audio, image, or project file", nullptr));
#endif // QT_CONFIG(tooltip)
        actionExit->setText(QCoreApplication::translate("MainWindow", "E&xit", nullptr));
#if QT_CONFIG(tooltip)
        actionExit->setToolTip(QCoreApplication::translate("MainWindow", "Quit the application", nullptr));
#endif // QT_CONFIG(tooltip)
        actionAbout_Shotcut->setText(QCoreApplication::translate("MainWindow", "&About Shotcut", nullptr));
        actionAbout_Qt->setText(QCoreApplication::translate("MainWindow", "About Qt", nullptr));
        actionOpenOther->setText(QCoreApplication::translate("MainWindow", "Open Other...", nullptr));
#if QT_CONFIG(tooltip)
        actionOpenOther->setToolTip(QCoreApplication::translate("MainWindow", "Open a device, stream or generator", nullptr));
#endif // QT_CONFIG(tooltip)
        actionSave->setText(QCoreApplication::translate("MainWindow", "&Save", nullptr));
#if QT_CONFIG(tooltip)
        actionSave->setToolTip(QCoreApplication::translate("MainWindow", "Save project as a MLT XML file", nullptr));
#endif // QT_CONFIG(tooltip)
        actionSave_As->setText(QCoreApplication::translate("MainWindow", "Save &As...", nullptr));
#if QT_CONFIG(tooltip)
        actionSave_As->setToolTip(QCoreApplication::translate("MainWindow", "Save project to a different MLT XML file", nullptr));
#endif // QT_CONFIG(tooltip)
        actionEncode->setText(QCoreApplication::translate("MainWindow", "Export", nullptr));
#if QT_CONFIG(tooltip)
        actionEncode->setToolTip(QCoreApplication::translate("MainWindow", "Export", nullptr));
#endif // QT_CONFIG(tooltip)
        actionForum->setText(QCoreApplication::translate("MainWindow", "Forum...", nullptr));
        actionFAQ->setText(QCoreApplication::translate("MainWindow", "FAQ...", nullptr));
        actionEnterFullScreen->setText(QCoreApplication::translate("MainWindow", "Enter Full Screen", nullptr));
#if QT_CONFIG(shortcut)
        actionEnterFullScreen->setShortcut(QCoreApplication::translate("MainWindow", "F11", nullptr));
#endif // QT_CONFIG(shortcut)
        actionAudioMeter->setText(QCoreApplication::translate("MainWindow", "Peak Meter", nullptr));
#if QT_CONFIG(tooltip)
        actionAudioMeter->setToolTip(QCoreApplication::translate("MainWindow", "Audio Peak Meter", nullptr));
#endif // QT_CONFIG(tooltip)
        actionProperties->setText(QCoreApplication::translate("MainWindow", "Properties", nullptr));
        actionRecent->setText(QCoreApplication::translate("MainWindow", "Recent", nullptr));
        actionPlaylist->setText(QCoreApplication::translate("MainWindow", "Playlist", nullptr));
        actionHistory->setText(QCoreApplication::translate("MainWindow", "History", nullptr));
        actionRealtime->setText(QCoreApplication::translate("MainWindow", "Realtime (frame dropping)", nullptr));
        actionProgressive->setText(QCoreApplication::translate("MainWindow", "Progressive", nullptr));
        actionNative8bitCpu->setText(QCoreApplication::translate("MainWindow", "Native 8-bit CPU (fast, flexible)", nullptr));
        actionNative10bitCpu->setText(QCoreApplication::translate("MainWindow", "Native 10-bit CPU (slower, better)", nullptr));
        actionLinear10bitCpu->setText(QCoreApplication::translate("MainWindow", "Linear 10-bit CPU (slowest, best)", nullptr));
        actionLinear10bitGpuCpu->setText(QCoreApplication::translate("MainWindow", "Linear 10-bit GPU/CPU (Experimental)", nullptr));
        actionChannels1->setText(QCoreApplication::translate("MainWindow", "1 (mono)", nullptr));
        actionChannels2->setText(QCoreApplication::translate("MainWindow", "2 (stereo)", nullptr));
        actionChannels4->setText(QCoreApplication::translate("MainWindow", "4 (quad/Ambisonics)", nullptr));
        actionChannels6->setText(QCoreApplication::translate("MainWindow", "6 (5.1 surround)", nullptr));
        actionOneField->setText(QCoreApplication::translate("MainWindow", "One Field (fast)", nullptr));
        actionYadifTemporal->setText(QCoreApplication::translate("MainWindow", "YADIF - temporal only (good)", nullptr));
        actionYadifSpatial->setText(QCoreApplication::translate("MainWindow", "YADIF - temporal + spatial (better)", nullptr));
        actionBwdif->setText(QCoreApplication::translate("MainWindow", "BWDIF (best)", nullptr));
        actionNearest->setText(QCoreApplication::translate("MainWindow", "Nearest Neighbor (fast)", nullptr));
        actionBilinear->setText(QCoreApplication::translate("MainWindow", "Bilinear (good)", nullptr));
        actionBicubic->setText(QCoreApplication::translate("MainWindow", "Bicubic (better)", nullptr));
        actionHyper->setText(QCoreApplication::translate("MainWindow", "Lanczos (best)", nullptr));
        actionProfileAutomatic->setText(QCoreApplication::translate("MainWindow", "Automatic", nullptr));
        actionExternalNone->setText(QCoreApplication::translate("MainWindow", "None", nullptr));
        actionJack->setText(QCoreApplication::translate("MainWindow", "Use JACK Audio", nullptr));
        actionFilters->setText(QCoreApplication::translate("MainWindow", "Filters", nullptr));
#if QT_CONFIG(tooltip)
        actionFilters->setToolTip(QCoreApplication::translate("MainWindow", "Filters", nullptr));
#endif // QT_CONFIG(tooltip)
        actionAddCustomProfile->setText(QCoreApplication::translate("MainWindow", "Add...", nullptr));
        actionSystemTheme->setText(QCoreApplication::translate("MainWindow", "System", nullptr));
#if QT_CONFIG(tooltip)
        actionSystemTheme->setToolTip(QCoreApplication::translate("MainWindow", "Use the user or platform style, colors, and icons.", nullptr));
#endif // QT_CONFIG(tooltip)
        actionSystemFusion->setText(QCoreApplication::translate("MainWindow", "System Fusion", nullptr));
        actionFusionDark->setText(QCoreApplication::translate("MainWindow", "Fusion Dark", nullptr));
        actionFusionLight->setText(QCoreApplication::translate("MainWindow", "Fusion Light", nullptr));
        actionTutorials->setText(QCoreApplication::translate("MainWindow", "Tutorials...", nullptr));
        actionTimeline->setText(QCoreApplication::translate("MainWindow", "Timeline", nullptr));
        actionRestoreLayout->setText(QCoreApplication::translate("MainWindow", "Restore Default Layout", nullptr));
#if QT_CONFIG(tooltip)
        actionRestoreLayout->setToolTip(QCoreApplication::translate("MainWindow", "Restore Default Layout", nullptr));
#endif // QT_CONFIG(tooltip)
        actionShowTitleBars->setText(QCoreApplication::translate("MainWindow", "Show Title Bars", nullptr));
        actionShowToolbar->setText(QCoreApplication::translate("MainWindow", "Show Toolbar", nullptr));
        actionUpgrade->setText(QCoreApplication::translate("MainWindow", "Upgrade...", nullptr));
        actionOpenXML->setText(QCoreApplication::translate("MainWindow", "Open MLT XML As Clip...", nullptr));
#if QT_CONFIG(tooltip)
        actionOpenXML->setToolTip(QCoreApplication::translate("MainWindow", "Open a MLT XML project file as a virtual clip", nullptr));
#endif // QT_CONFIG(tooltip)
        actionScrubAudio->setText(QCoreApplication::translate("MainWindow", "Scrub Audio", nullptr));
        actionDrawingAutomatic->setText(QCoreApplication::translate("MainWindow", "Automatic", nullptr));
        actionJobPriorityLow->setText(QCoreApplication::translate("MainWindow", "Low", nullptr));
        actionJobPriorityNormal->setText(QCoreApplication::translate("MainWindow", "Normal", nullptr));
        actionResources->setText(QCoreApplication::translate("MainWindow", "Resources...", nullptr));
        actionApplicationLog->setText(QCoreApplication::translate("MainWindow", "Application Log...", nullptr));
        actionProject->setText(QCoreApplication::translate("MainWindow", "Project", nullptr));
        actionUser_Interface->setText(QCoreApplication::translate("MainWindow", "User Interface", nullptr));
        actionClose->setText(QCoreApplication::translate("MainWindow", "Close", nullptr));
        actionExportEDL->setText(QCoreApplication::translate("MainWindow", "EDL...", nullptr));
        actionExportEDL->setIconText(QCoreApplication::translate("MainWindow", "Export EDL", nullptr));
#if QT_CONFIG(tooltip)
        actionExportEDL->setToolTip(QCoreApplication::translate("MainWindow", "Export EDL", nullptr));
#endif // QT_CONFIG(tooltip)
        actionExportFrame->setText(QCoreApplication::translate("MainWindow", "Frame...", nullptr));
        actionExportFrame->setIconText(QCoreApplication::translate("MainWindow", "Export Frame", nullptr));
#if QT_CONFIG(tooltip)
        actionExportFrame->setToolTip(QCoreApplication::translate("MainWindow", "Export Frame", nullptr));
#endif // QT_CONFIG(tooltip)
        actionExportVideo->setText(QCoreApplication::translate("MainWindow", "Video/Audio...", nullptr));
        actionExportVideo->setIconText(QCoreApplication::translate("MainWindow", "Export Video/Audio", nullptr));
#if QT_CONFIG(tooltip)
        actionExportVideo->setToolTip(QCoreApplication::translate("MainWindow", "Export Video/Audio", nullptr));
#endif // QT_CONFIG(tooltip)
        actionAppDataSet->setText(QCoreApplication::translate("MainWindow", "Set...", nullptr));
        actionAppDataShow->setText(QCoreApplication::translate("MainWindow", "Show...", nullptr));
#if QT_CONFIG(tooltip)
        actionAppDataShow->setToolTip(QCoreApplication::translate("MainWindow", "Show", nullptr));
#endif // QT_CONFIG(tooltip)
        actionKeyframes->setText(QCoreApplication::translate("MainWindow", "Keyframes", nullptr));
#if QT_CONFIG(tooltip)
        actionKeyframes->setToolTip(QCoreApplication::translate("MainWindow", "Keyframes", nullptr));
#endif // QT_CONFIG(tooltip)
        actionNew->setText(QCoreApplication::translate("MainWindow", "Project", nullptr));
#if QT_CONFIG(tooltip)
        actionNew->setToolTip(QCoreApplication::translate("MainWindow", "Project", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionNew->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+N", nullptr));
#endif // QT_CONFIG(shortcut)
        actionScreenSnapshot->setText(QCoreApplication::translate("MainWindow", "Screen Snapshot", nullptr));
#if QT_CONFIG(tooltip)
        actionScreenSnapshot->setToolTip(QCoreApplication::translate("MainWindow", "Capture a screenshot", nullptr));
#endif // QT_CONFIG(tooltip)
        actionScreenRecording->setText(QCoreApplication::translate("MainWindow", "Screen Recording", nullptr));
#if QT_CONFIG(tooltip)
        actionScreenRecording->setToolTip(QCoreApplication::translate("MainWindow", "Record the screen", nullptr));
#endif // QT_CONFIG(tooltip)
        actionKeyboardShortcuts->setText(QCoreApplication::translate("MainWindow", "Actions and Shortcuts...", nullptr));
        actionLayoutAudio->setText(QCoreApplication::translate("MainWindow", "Audio", nullptr));
#if QT_CONFIG(tooltip)
        actionLayoutAudio->setToolTip(QCoreApplication::translate("MainWindow", "Switch to the audio layout", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionLayoutAudio->setShortcut(QCoreApplication::translate("MainWindow", "Alt+5", nullptr));
#endif // QT_CONFIG(shortcut)
        actionLayoutLogging->setText(QCoreApplication::translate("MainWindow", "Logging", nullptr));
#if QT_CONFIG(tooltip)
        actionLayoutLogging->setToolTip(QCoreApplication::translate("MainWindow", "Switch to the logging layout", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionLayoutLogging->setShortcut(QCoreApplication::translate("MainWindow", "Alt+1", nullptr));
#endif // QT_CONFIG(shortcut)
        actionLayoutEditing->setText(QCoreApplication::translate("MainWindow", "Editing", nullptr));
#if QT_CONFIG(tooltip)
        actionLayoutEditing->setToolTip(QCoreApplication::translate("MainWindow", "Switch to the editing layout", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionLayoutEditing->setShortcut(QCoreApplication::translate("MainWindow", "Alt+2", nullptr));
#endif // QT_CONFIG(shortcut)
        actionLayoutEffects->setText(QCoreApplication::translate("MainWindow", "FX", nullptr));
#if QT_CONFIG(tooltip)
        actionLayoutEffects->setToolTip(QCoreApplication::translate("MainWindow", "Switch to the effects layout", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionLayoutEffects->setShortcut(QCoreApplication::translate("MainWindow", "Alt+3", nullptr));
#endif // QT_CONFIG(shortcut)
        actionLayoutAdd->setText(QCoreApplication::translate("MainWindow", "Add...", nullptr));
        actionProfileRemove->setText(QCoreApplication::translate("MainWindow", "Remove...", nullptr));
        actionLayoutRemove->setText(QCoreApplication::translate("MainWindow", "Remove...", nullptr));
        actionOpenOther2->setText(QCoreApplication::translate("MainWindow", "Generate", nullptr));
        actionClearRecentOnExit->setText(QCoreApplication::translate("MainWindow", "Clear Recent on Exit", nullptr));
        actionShowTextUnderIcons->setText(QCoreApplication::translate("MainWindow", "Show Text Under Icons", nullptr));
        actionShowSmallIcons->setText(QCoreApplication::translate("MainWindow", "Show Small Icons", nullptr));
        actionJobs->setText(QCoreApplication::translate("MainWindow", "Jobs", nullptr));
        actionMarkers->setText(QCoreApplication::translate("MainWindow", "Markers", nullptr));
        actionNotes->setText(QCoreApplication::translate("MainWindow", "Notes", nullptr));
        actionSubtitles->setText(QCoreApplication::translate("MainWindow", "Subtitles", nullptr));
        actionPreview540->setText(QCoreApplication::translate("MainWindow", "540p", nullptr));
        actionPreview720->setText(QCoreApplication::translate("MainWindow", "720p", nullptr));
        actionPreview1080->setText(QCoreApplication::translate("MainWindow", "1080p", nullptr));
        actionPreviewNone->setText(QCoreApplication::translate("MainWindow", "None", nullptr));
        actionPreview360->setText(QCoreApplication::translate("MainWindow", "360p", nullptr));
        actionTimeDF->setText(QCoreApplication::translate("MainWindow", "Timecode (Drop-Frame)", nullptr));
        actionTimeFrames->setText(QCoreApplication::translate("MainWindow", "Frames", nullptr));
        actionTimeClock->setText(QCoreApplication::translate("MainWindow", "Clock", nullptr));
        actionTimeNDF->setText(QCoreApplication::translate("MainWindow", "Timecode (Non-Drop Frame)", nullptr));
        actionTopics->setText(QCoreApplication::translate("MainWindow", "Topics", nullptr));
        actionSync->setText(QCoreApplication::translate("MainWindow", "Synchronization...", nullptr));
#if QT_CONFIG(tooltip)
        actionSync->setToolTip(QCoreApplication::translate("MainWindow", "Synchronization", nullptr));
#endif // QT_CONFIG(tooltip)
        actionUseProxy->setText(QCoreApplication::translate("MainWindow", "Use Proxy", nullptr));
        actionProxyStorageSet->setText(QCoreApplication::translate("MainWindow", "Set...", nullptr));
#if QT_CONFIG(tooltip)
        actionProxyStorageSet->setToolTip(QCoreApplication::translate("MainWindow", "Set the proxy storage folder", nullptr));
#endif // QT_CONFIG(tooltip)
        actionProxyStorageShow->setText(QCoreApplication::translate("MainWindow", "Show...", nullptr));
#if QT_CONFIG(tooltip)
        actionProxyStorageShow->setToolTip(QCoreApplication::translate("MainWindow", "Show the proxy storage folder", nullptr));
#endif // QT_CONFIG(tooltip)
        actionProxyUseProjectFolder->setText(QCoreApplication::translate("MainWindow", "Use Project Folder", nullptr));
#if QT_CONFIG(tooltip)
        actionProxyUseProjectFolder->setToolTip(QCoreApplication::translate("MainWindow", "Store proxies in the project folder if defined", nullptr));
#endif // QT_CONFIG(tooltip)
        actionProxyUseHardware->setText(QCoreApplication::translate("MainWindow", "Use Hardware Encoder", nullptr));
        actionPreviewHardwareDecoder->setText(QCoreApplication::translate("MainWindow", "Use Hardware Decoder", nullptr));
        actionProxyConfigureHardware->setText(QCoreApplication::translate("MainWindow", "Configure Hardware Encoder...", nullptr));
        actionLayoutColor->setText(QCoreApplication::translate("MainWindow", "Color", nullptr));
#if QT_CONFIG(tooltip)
        actionLayoutColor->setToolTip(QCoreApplication::translate("MainWindow", "Switch to the color layout", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionLayoutColor->setShortcut(QCoreApplication::translate("MainWindow", "Alt+4", nullptr));
#endif // QT_CONFIG(shortcut)
        actionLayoutPlayer->setText(QCoreApplication::translate("MainWindow", "Player", nullptr));
#if QT_CONFIG(tooltip)
        actionLayoutPlayer->setToolTip(QCoreApplication::translate("MainWindow", "Switch to the player only layout", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionLayoutPlayer->setShortcut(QCoreApplication::translate("MainWindow", "Alt+6", nullptr));
#endif // QT_CONFIG(shortcut)
        actionLayoutPlaylist->setText(QCoreApplication::translate("MainWindow", "Playlist Project", nullptr));
        actionLayoutClip->setText(QCoreApplication::translate("MainWindow", "Clip-only Project", nullptr));
        actionExportChapters->setText(QCoreApplication::translate("MainWindow", "Markers as Chapters...", nullptr));
        actionExportChapters->setIconText(QCoreApplication::translate("MainWindow", "Export Chapters", nullptr));
#if QT_CONFIG(tooltip)
        actionExportChapters->setToolTip(QCoreApplication::translate("MainWindow", "Export Chapters", nullptr));
#endif // QT_CONFIG(tooltip)
        actionAudioVideoDevice->setText(QCoreApplication::translate("MainWindow", "Audio/Video Device...", nullptr));
        actionReset->setText(QCoreApplication::translate("MainWindow", "Reset...", nullptr));
        actionBackupSave->setText(QCoreApplication::translate("MainWindow", "Backup and Save", nullptr));
#if QT_CONFIG(tooltip)
        actionBackupSave->setToolTip(QCoreApplication::translate("MainWindow", "Backup and Save", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionBackupSave->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionBackupManually->setText(QCoreApplication::translate("MainWindow", "Manually", nullptr));
        actionBackupHourly->setText(QCoreApplication::translate("MainWindow", "Hourly", nullptr));
        actionBackupDaily->setText(QCoreApplication::translate("MainWindow", "Daily", nullptr));
        actionBackupWeekly->setText(QCoreApplication::translate("MainWindow", "Weekly", nullptr));
        actionShowProjectFolder->setText(QCoreApplication::translate("MainWindow", "Show Project in Folder", nullptr));
        actionPauseAfterSeek->setText(QCoreApplication::translate("MainWindow", "Pause After Seek", nullptr));
        actionFiles->setText(QCoreApplication::translate("MainWindow", "Files", nullptr));
        actionWhatsThis->setText(QCoreApplication::translate("MainWindow", "What's This?", nullptr));
#if QT_CONFIG(tooltip)
        actionWhatsThis->setToolTip(QCoreApplication::translate("MainWindow", "Get help about something by clicking it", nullptr));
#endif // QT_CONFIG(tooltip)
        actionLeaveSafeMode->setText(QCoreApplication::translate("MainWindow", "Leave Safe Mode", nullptr));
        menuFile->setTitle(QCoreApplication::translate("MainWindow", "&File", nullptr));
        menuExport->setTitle(QCoreApplication::translate("MainWindow", "Export", nullptr));
        menuOtherVersions->setTitle(QCoreApplication::translate("MainWindow", "Other Versions", nullptr));
        menuNew->setTitle(QCoreApplication::translate("MainWindow", "New", nullptr));
        menuView->setTitle(QCoreApplication::translate("MainWindow", "&View", nullptr));
        menuLayout->setTitle(QCoreApplication::translate("MainWindow", "Layout", nullptr));
        menuEdit->setTitle(QCoreApplication::translate("MainWindow", "&Edit", nullptr));
        menuPlayer->setTitle(QCoreApplication::translate("MainWindow", "&Player", nullptr));
        menuExternal->setTitle(QCoreApplication::translate("MainWindow", "External Monitor", nullptr));
        menuHelp->setTitle(QCoreApplication::translate("MainWindow", "&Help", nullptr));
        menuSettings->setTitle(QCoreApplication::translate("MainWindow", "&Settings", nullptr));
        menuAudioChannels->setTitle(QCoreApplication::translate("MainWindow", "Audio Channels", nullptr));
        menuProfile->setTitle(QCoreApplication::translate("MainWindow", "Video Mode", nullptr));
        menuProcessingMode->setTitle(QCoreApplication::translate("MainWindow", "Processing Mode", nullptr));
        menuLanguage->setTitle(QCoreApplication::translate("MainWindow", "Language", nullptr));
        menuTheme->setTitle(QCoreApplication::translate("MainWindow", "Theme", nullptr));
        menuDrawingMethod->setTitle(QCoreApplication::translate("MainWindow", "Display Method", nullptr));
        menuGpuAdapter->setTitle(QCoreApplication::translate("MainWindow", "Graphics Adapter", nullptr));
        menuJobPriority->setTitle(QCoreApplication::translate("MainWindow", "Job Priority", nullptr));
        menuTimeline->setTitle(QCoreApplication::translate("MainWindow", "Timeline", nullptr));
        menuPlaylist->setTitle(QCoreApplication::translate("MainWindow", "Playlist", nullptr));
        menuData_Directory->setTitle(QCoreApplication::translate("MainWindow", "App Data Directory", nullptr));
        menuPreviewScaling->setTitle(QCoreApplication::translate("MainWindow", "Preview Scaling", nullptr));
        menuTimeFormat->setTitle(QCoreApplication::translate("MainWindow", "Time Format", nullptr));
        menuProxy->setTitle(QCoreApplication::translate("MainWindow", "Proxy", nullptr));
        menuStorage->setTitle(QCoreApplication::translate("MainWindow", "Storage", nullptr));
        menuPlayerSettings->setTitle(QCoreApplication::translate("MainWindow", "Player", nullptr));
        menuDeinterlacer->setTitle(QCoreApplication::translate("MainWindow", "Deinterlacer", nullptr));
        menuInterpolation->setTitle(QCoreApplication::translate("MainWindow", "Interpolation", nullptr));
        menuBackup->setTitle(QCoreApplication::translate("MainWindow", "Backup", nullptr));
        mainToolBar->setWindowTitle(QCoreApplication::translate("MainWindow", "Toolbar", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
