/****************************************************************************
** Meta object code from reading C++ file 'avformatproducerwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/widgets/avformatproducerwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'avformatproducerwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22AvformatProducerWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto AvformatProducerWidget::qt_create_metaobjectdata<qt_meta_tag_ZN22AvformatProducerWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AvformatProducerWidget",
        "producerChanged",
        "",
        "Mlt::Producer*",
        "producerReopened",
        "play",
        "modified",
        "showInFiles",
        "updateDuration",
        "rename",
        "offerConvert",
        "message",
        "set709Convert",
        "setSubClip",
        "onProducerChanged",
        "on_videoTrackComboBox_activated",
        "index",
        "on_audioTrackComboBox_activated",
        "on_scanComboBox_activated",
        "on_fieldOrderComboBox_activated",
        "on_aspectNumSpinBox_valueChanged",
        "on_aspectDenSpinBox_valueChanged",
        "on_durationSpinBox_editingFinished",
        "on_speedSpinBox_editingFinished",
        "on_timelineDurationText_editingFinished",
        "on_pitchCheckBox_stateChanged",
        "state",
        "on_syncSlider_valueChanged",
        "value",
        "on_actionOpenFolder_triggered",
        "on_menuButton_clicked",
        "on_actionCopyFullFilePath_triggered",
        "on_notesTextEdit_textChanged",
        "on_actionFFmpegInfo_triggered",
        "on_actionFFmpegIntegrityCheck_triggered",
        "on_actionFFmpegConvert_triggered",
        "on_reverseButton_clicked",
        "on_actionExtractSubclip_triggered",
        "on_actionExtractSubtitles_triggered",
        "on_actionSetFileDate_triggered",
        "on_rangeComboBox_activated",
        "on_filenameLabel_editingFinished",
        "on_convertButton_clicked",
        "on_actionDisableProxy_triggered",
        "checked",
        "on_actionMakeProxy_triggered",
        "on_actionDeleteProxy_triggered",
        "on_actionCopyHashCode_triggered",
        "on_proxyButton_clicked",
        "on_actionReset_triggered",
        "on_actionSetEquirectangular_triggered",
        "on_actionFFmpegVideoQuality_triggered",
        "on_rotationComboBox_activated",
        "on_actionExportGPX_triggered",
        "on_lutButton_clicked",
        "on_lutPasteButton_clicked",
        "on_lutCopyButton_clicked",
        "on_lutClearButton_clicked",
        "on_speedComboBox_textActivated",
        "arg1",
        "reloadProducerValues",
        "on_actionBitrateViewer_triggered",
        "on_actionShowInFiles_triggered",
        "on_openWithButton_clicked",
        "on_reloadButton_clicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'producerChanged'
        QtMocHelpers::SignalData<void(Mlt::Producer *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'producerReopened'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showInFiles'
        QtMocHelpers::SignalData<void(QString)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'updateDuration'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rename'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'offerConvert'
        QtMocHelpers::SlotData<void(QString, bool, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Bool, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'offerConvert'
        QtMocHelpers::SlotData<void(QString, bool)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'offerConvert'
        QtMocHelpers::SlotData<void(QString)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'onProducerChanged'
        QtMocHelpers::SlotData<void(Mlt::Producer *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'on_videoTrackComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'on_audioTrackComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'on_scanComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'on_fieldOrderComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'on_aspectNumSpinBox_valueChanged'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'on_aspectDenSpinBox_valueChanged'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'on_durationSpinBox_editingFinished'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_speedSpinBox_editingFinished'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_timelineDurationText_editingFinished'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pitchCheckBox_stateChanged'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'on_syncSlider_valueChanged'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'on_actionOpenFolder_triggered'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_menuButton_clicked'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyFullFilePath_triggered'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_notesTextEdit_textChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFFmpegInfo_triggered'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFFmpegIntegrityCheck_triggered'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFFmpegConvert_triggered'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_reverseButton_clicked'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExtractSubclip_triggered'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionExtractSubtitles_triggered'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetFileDate_triggered'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_rangeComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'on_filenameLabel_editingFinished'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_convertButton_clicked'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDisableProxy_triggered'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 44 },
        }}),
        // Slot 'on_actionMakeProxy_triggered'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionDeleteProxy_triggered'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionCopyHashCode_triggered'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_proxyButton_clicked'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionReset_triggered'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionSetEquirectangular_triggered'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionFFmpegVideoQuality_triggered'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_rotationComboBox_activated'
        QtMocHelpers::SlotData<void(int)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'on_actionExportGPX_triggered'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_lutButton_clicked'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_lutPasteButton_clicked'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_lutCopyButton_clicked'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_lutClearButton_clicked'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_speedComboBox_textActivated'
        QtMocHelpers::SlotData<void(const QString &)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 59 },
        }}),
        // Slot 'reloadProducerValues'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionBitrateViewer_triggered'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_actionShowInFiles_triggered'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_openWithButton_clicked'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_reloadButton_clicked'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AvformatProducerWidget, qt_meta_tag_ZN22AvformatProducerWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AvformatProducerWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AvformatProducerWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AvformatProducerWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22AvformatProducerWidgetE_t>.metaTypes,
    nullptr
} };

void AvformatProducerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AvformatProducerWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->producerChanged((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 1: _t->producerReopened((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->modified(); break;
        case 3: _t->showInFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->updateDuration(); break;
        case 5: _t->rename(); break;
        case 6: _t->offerConvert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: _t->offerConvert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->offerConvert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->onProducerChanged((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 10: _t->on_videoTrackComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->on_audioTrackComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->on_scanComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->on_fieldOrderComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->on_aspectNumSpinBox_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->on_aspectDenSpinBox_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->on_durationSpinBox_editingFinished(); break;
        case 17: _t->on_speedSpinBox_editingFinished(); break;
        case 18: _t->on_timelineDurationText_editingFinished(); break;
        case 19: _t->on_pitchCheckBox_stateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->on_syncSlider_valueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->on_actionOpenFolder_triggered(); break;
        case 22: _t->on_menuButton_clicked(); break;
        case 23: _t->on_actionCopyFullFilePath_triggered(); break;
        case 24: _t->on_notesTextEdit_textChanged(); break;
        case 25: _t->on_actionFFmpegInfo_triggered(); break;
        case 26: _t->on_actionFFmpegIntegrityCheck_triggered(); break;
        case 27: _t->on_actionFFmpegConvert_triggered(); break;
        case 28: _t->on_reverseButton_clicked(); break;
        case 29: _t->on_actionExtractSubclip_triggered(); break;
        case 30: _t->on_actionExtractSubtitles_triggered(); break;
        case 31: _t->on_actionSetFileDate_triggered(); break;
        case 32: _t->on_rangeComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->on_filenameLabel_editingFinished(); break;
        case 34: _t->on_convertButton_clicked(); break;
        case 35: _t->on_actionDisableProxy_triggered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->on_actionMakeProxy_triggered(); break;
        case 37: _t->on_actionDeleteProxy_triggered(); break;
        case 38: _t->on_actionCopyHashCode_triggered(); break;
        case 39: _t->on_proxyButton_clicked(); break;
        case 40: _t->on_actionReset_triggered(); break;
        case 41: _t->on_actionSetEquirectangular_triggered(); break;
        case 42: _t->on_actionFFmpegVideoQuality_triggered(); break;
        case 43: _t->on_rotationComboBox_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 44: _t->on_actionExportGPX_triggered(); break;
        case 45: _t->on_lutButton_clicked(); break;
        case 46: _t->on_lutPasteButton_clicked(); break;
        case 47: _t->on_lutCopyButton_clicked(); break;
        case 48: _t->on_lutClearButton_clicked(); break;
        case 49: _t->on_speedComboBox_textActivated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 50: _t->reloadProducerValues(); break;
        case 51: _t->on_actionBitrateViewer_triggered(); break;
        case 52: _t->on_actionShowInFiles_triggered(); break;
        case 53: _t->on_openWithButton_clicked(); break;
        case 54: _t->on_reloadButton_clicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AvformatProducerWidget::*)(Mlt::Producer * )>(_a, &AvformatProducerWidget::producerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AvformatProducerWidget::*)(bool )>(_a, &AvformatProducerWidget::producerReopened, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AvformatProducerWidget::*)()>(_a, &AvformatProducerWidget::modified, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AvformatProducerWidget::*)(QString )>(_a, &AvformatProducerWidget::showInFiles, 3))
            return;
    }
}

const QMetaObject *AvformatProducerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AvformatProducerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AvformatProducerWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AbstractProducerWidget"))
        return static_cast< AbstractProducerWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int AvformatProducerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 55;
    }
    return _id;
}

// SIGNAL 0
void AvformatProducerWidget::producerChanged(Mlt::Producer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AvformatProducerWidget::producerReopened(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AvformatProducerWidget::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AvformatProducerWidget::showInFiles(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN9ProbeTaskE_t {};
} // unnamed namespace

template <> constexpr inline auto ProbeTask::qt_create_metaobjectdata<qt_meta_tag_ZN9ProbeTaskE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProbeTask",
        "probeFinished",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'probeFinished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProbeTask, qt_meta_tag_ZN9ProbeTaskE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProbeTask::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ProbeTaskE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ProbeTaskE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ProbeTaskE_t>.metaTypes,
    nullptr
} };

void ProbeTask::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProbeTask *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->probeFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProbeTask::*)()>(_a, &ProbeTask::probeFinished, 0))
            return;
    }
}

const QMetaObject *ProbeTask::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProbeTask::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ProbeTaskE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QRunnable"))
        return static_cast< QRunnable*>(this);
    return QObject::qt_metacast(_clname);
}

int ProbeTask::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ProbeTask::probeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
