/********************************************************************************
** Form generated from reading UI file 'plasmawidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLASMAWIDGET_H
#define UI_PLASMAWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDial>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_PlasmaWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    ServicePresetWidget *preset;
    QHBoxLayout *horizontalLayout_11;
    QGroupBox *groupBox_7;
    QVBoxLayout *verticalLayout_13;
    QDial *speed1Dial;
    QHBoxLayout *horizontalLayout_12;
    QSpacerItem *horizontalSpacer_15;
    QDoubleSpinBox *speed1Spinner;
    QSpacerItem *horizontalSpacer_16;
    QGroupBox *groupBox_8;
    QVBoxLayout *verticalLayout_14;
    QDial *speed2Dial;
    QHBoxLayout *horizontalLayout_13;
    QSpacerItem *horizontalSpacer_17;
    QDoubleSpinBox *speed2Spinner;
    QSpacerItem *horizontalSpacer_18;
    QGroupBox *groupBox_9;
    QVBoxLayout *verticalLayout_15;
    QDial *speed3Dial;
    QHBoxLayout *horizontalLayout_14;
    QSpacerItem *horizontalSpacer_19;
    QDoubleSpinBox *speed3Spinner;
    QSpacerItem *horizontalSpacer_20;
    QHBoxLayout *horizontalLayout_15;
    QGroupBox *groupBox_10;
    QVBoxLayout *verticalLayout_16;
    QDial *speed4Dial;
    QHBoxLayout *horizontalLayout_16;
    QSpacerItem *horizontalSpacer_21;
    QDoubleSpinBox *speed4Spinner;
    QSpacerItem *horizontalSpacer_22;
    QGroupBox *groupBox_11;
    QVBoxLayout *verticalLayout_17;
    QDial *move1Dial;
    QHBoxLayout *horizontalLayout_17;
    QSpacerItem *horizontalSpacer_23;
    QDoubleSpinBox *move1Spinner;
    QSpacerItem *horizontalSpacer_24;
    QGroupBox *groupBox_12;
    QVBoxLayout *verticalLayout_18;
    QDial *move2Dial;
    QHBoxLayout *horizontalLayout_18;
    QSpacerItem *horizontalSpacer_25;
    QDoubleSpinBox *move2Spinner;
    QSpacerItem *horizontalSpacer_26;
    QSpacerItem *verticalSpacer_6;

    void setupUi(QWidget *PlasmaWidget)
    {
        if (PlasmaWidget->objectName().isEmpty())
            PlasmaWidget->setObjectName("PlasmaWidget");
        PlasmaWidget->resize(391, 378);
#if QT_CONFIG(whatsthis)
        PlasmaWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-plasma/12930/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(PlasmaWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(PlasmaWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        preset = new ServicePresetWidget(PlasmaWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        groupBox_7 = new QGroupBox(PlasmaWidget);
        groupBox_7->setObjectName("groupBox_7");
        verticalLayout_13 = new QVBoxLayout(groupBox_7);
        verticalLayout_13->setObjectName("verticalLayout_13");
        speed1Dial = new QDial(groupBox_7);
        speed1Dial->setObjectName("speed1Dial");
        speed1Dial->setMaximum(100);
        speed1Dial->setValue(100);
        speed1Dial->setOrientation(Qt::Orientation::Vertical);
        speed1Dial->setNotchesVisible(true);

        verticalLayout_13->addWidget(speed1Dial);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_15);

        speed1Spinner = new QDoubleSpinBox(groupBox_7);
        speed1Spinner->setObjectName("speed1Spinner");
        speed1Spinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        speed1Spinner->setMaximum(1.000000000000000);
        speed1Spinner->setSingleStep(0.100000000000000);
        speed1Spinner->setValue(1.000000000000000);

        horizontalLayout_12->addWidget(speed1Spinner);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_16);


        verticalLayout_13->addLayout(horizontalLayout_12);


        horizontalLayout_11->addWidget(groupBox_7);

        groupBox_8 = new QGroupBox(PlasmaWidget);
        groupBox_8->setObjectName("groupBox_8");
        verticalLayout_14 = new QVBoxLayout(groupBox_8);
        verticalLayout_14->setObjectName("verticalLayout_14");
        speed2Dial = new QDial(groupBox_8);
        speed2Dial->setObjectName("speed2Dial");
        speed2Dial->setMaximum(100);
        speed2Dial->setValue(100);
        speed2Dial->setNotchesVisible(true);

        verticalLayout_14->addWidget(speed2Dial);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_17);

        speed2Spinner = new QDoubleSpinBox(groupBox_8);
        speed2Spinner->setObjectName("speed2Spinner");
        speed2Spinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        speed2Spinner->setMaximum(1.000000000000000);
        speed2Spinner->setSingleStep(0.100000000000000);
        speed2Spinner->setValue(1.000000000000000);

        horizontalLayout_13->addWidget(speed2Spinner);

        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_18);


        verticalLayout_14->addLayout(horizontalLayout_13);


        horizontalLayout_11->addWidget(groupBox_8);

        groupBox_9 = new QGroupBox(PlasmaWidget);
        groupBox_9->setObjectName("groupBox_9");
        verticalLayout_15 = new QVBoxLayout(groupBox_9);
        verticalLayout_15->setObjectName("verticalLayout_15");
        speed3Dial = new QDial(groupBox_9);
        speed3Dial->setObjectName("speed3Dial");
        speed3Dial->setMaximum(100);
        speed3Dial->setValue(100);
        speed3Dial->setNotchesVisible(true);

        verticalLayout_15->addWidget(speed3Dial);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_19);

        speed3Spinner = new QDoubleSpinBox(groupBox_9);
        speed3Spinner->setObjectName("speed3Spinner");
        speed3Spinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        speed3Spinner->setMaximum(1.000000000000000);
        speed3Spinner->setSingleStep(0.100000000000000);
        speed3Spinner->setValue(1.000000000000000);

        horizontalLayout_14->addWidget(speed3Spinner);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_20);


        verticalLayout_15->addLayout(horizontalLayout_14);


        horizontalLayout_11->addWidget(groupBox_9);


        verticalLayout->addLayout(horizontalLayout_11);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        groupBox_10 = new QGroupBox(PlasmaWidget);
        groupBox_10->setObjectName("groupBox_10");
        verticalLayout_16 = new QVBoxLayout(groupBox_10);
        verticalLayout_16->setObjectName("verticalLayout_16");
        speed4Dial = new QDial(groupBox_10);
        speed4Dial->setObjectName("speed4Dial");
        speed4Dial->setMaximum(100);
        speed4Dial->setValue(100);
        speed4Dial->setOrientation(Qt::Orientation::Vertical);
        speed4Dial->setNotchesVisible(true);

        verticalLayout_16->addWidget(speed4Dial);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        horizontalSpacer_21 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_21);

        speed4Spinner = new QDoubleSpinBox(groupBox_10);
        speed4Spinner->setObjectName("speed4Spinner");
        speed4Spinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        speed4Spinner->setMaximum(1.000000000000000);
        speed4Spinner->setSingleStep(0.100000000000000);
        speed4Spinner->setValue(1.000000000000000);

        horizontalLayout_16->addWidget(speed4Spinner);

        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_22);


        verticalLayout_16->addLayout(horizontalLayout_16);


        horizontalLayout_15->addWidget(groupBox_10);

        groupBox_11 = new QGroupBox(PlasmaWidget);
        groupBox_11->setObjectName("groupBox_11");
        verticalLayout_17 = new QVBoxLayout(groupBox_11);
        verticalLayout_17->setObjectName("verticalLayout_17");
        move1Dial = new QDial(groupBox_11);
        move1Dial->setObjectName("move1Dial");
        move1Dial->setMaximum(100);
        move1Dial->setValue(100);
        move1Dial->setNotchesVisible(true);

        verticalLayout_17->addWidget(move1Dial);

        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalSpacer_23 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_23);

        move1Spinner = new QDoubleSpinBox(groupBox_11);
        move1Spinner->setObjectName("move1Spinner");
        move1Spinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        move1Spinner->setMaximum(1.000000000000000);
        move1Spinner->setSingleStep(0.100000000000000);
        move1Spinner->setValue(1.000000000000000);

        horizontalLayout_17->addWidget(move1Spinner);

        horizontalSpacer_24 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_24);


        verticalLayout_17->addLayout(horizontalLayout_17);


        horizontalLayout_15->addWidget(groupBox_11);

        groupBox_12 = new QGroupBox(PlasmaWidget);
        groupBox_12->setObjectName("groupBox_12");
        verticalLayout_18 = new QVBoxLayout(groupBox_12);
        verticalLayout_18->setObjectName("verticalLayout_18");
        move2Dial = new QDial(groupBox_12);
        move2Dial->setObjectName("move2Dial");
        move2Dial->setMaximum(100);
        move2Dial->setValue(100);
        move2Dial->setNotchesVisible(true);

        verticalLayout_18->addWidget(move2Dial);

        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        horizontalSpacer_25 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_25);

        move2Spinner = new QDoubleSpinBox(groupBox_12);
        move2Spinner->setObjectName("move2Spinner");
        move2Spinner->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        move2Spinner->setMaximum(1.000000000000000);
        move2Spinner->setSingleStep(0.100000000000000);
        move2Spinner->setValue(1.000000000000000);

        horizontalLayout_18->addWidget(move2Spinner);

        horizontalSpacer_26 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_18->addItem(horizontalSpacer_26);


        verticalLayout_18->addLayout(horizontalLayout_18);


        horizontalLayout_15->addWidget(groupBox_12);


        verticalLayout->addLayout(horizontalLayout_15);

        verticalSpacer_6 = new QSpacerItem(20, 99, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_6);


        retranslateUi(PlasmaWidget);

        QMetaObject::connectSlotsByName(PlasmaWidget);
    } // setupUi

    void retranslateUi(QWidget *PlasmaWidget)
    {
        PlasmaWidget->setWindowTitle(QCoreApplication::translate("PlasmaWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("PlasmaWidget", "Plasma", nullptr));
        groupBox_7->setTitle(QCoreApplication::translate("PlasmaWidget", "Speed 1", nullptr));
        groupBox_8->setTitle(QCoreApplication::translate("PlasmaWidget", "Speed 2", nullptr));
        groupBox_9->setTitle(QCoreApplication::translate("PlasmaWidget", "Speed 3", nullptr));
        groupBox_10->setTitle(QCoreApplication::translate("PlasmaWidget", "Speed 4", nullptr));
        groupBox_11->setTitle(QCoreApplication::translate("PlasmaWidget", "Move 1", nullptr));
        groupBox_12->setTitle(QCoreApplication::translate("PlasmaWidget", "Move 2", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PlasmaWidget: public Ui_PlasmaWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PLASMAWIDGET_H
