/****************************************************************************
** Meta object code from reading C++ file 'screencapture.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/screencapture/screencapture.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screencapture.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ScreenCaptureE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenCapture::qt_create_metaobjectdata<qt_meta_tag_ZN13ScreenCaptureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenCapture",
        "finished",
        "",
        "success",
        "beginRecording",
        "QRect",
        "captureRect",
        "recordAudio",
        "onSelectionCanceled",
        "minimizeShotcut",
        "onCaptureModeSelected",
        "CaptureMode",
        "mode",
        "onRectangleSelected",
        "rect",
        "onWindowSelected",
        "onImageRectangleSelected",
        "onImageWindowSelected",
        "onPortalResponse",
        "response",
        "QVariantMap",
        "results"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'beginRecording'
        QtMocHelpers::SignalData<void(const QRect &, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'onSelectionCanceled'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimizeShotcut'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCaptureModeSelected'
        QtMocHelpers::SlotData<void(enum CaptureMode, bool, bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Bool, 9 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'onRectangleSelected'
        QtMocHelpers::SlotData<void(const QRect &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Slot 'onWindowSelected'
        QtMocHelpers::SlotData<void(const QRect &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Slot 'onImageRectangleSelected'
        QtMocHelpers::SlotData<void(const QRect &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Slot 'onImageWindowSelected'
        QtMocHelpers::SlotData<void(const QRect &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Slot 'onPortalResponse'
        QtMocHelpers::SlotData<void(uint, const QVariantMap &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 19 }, { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenCapture, qt_meta_tag_ZN13ScreenCaptureE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenCapture::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ScreenCaptureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ScreenCaptureE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ScreenCaptureE_t>.metaTypes,
    nullptr
} };

void ScreenCapture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenCapture *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->beginRecording((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->onSelectionCanceled(); break;
        case 3: _t->minimizeShotcut(); break;
        case 4: _t->onCaptureModeSelected((*reinterpret_cast<std::add_pointer_t<enum CaptureMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 5: _t->onRectangleSelected((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 6: _t->onWindowSelected((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 7: _t->onImageRectangleSelected((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 8: _t->onImageWindowSelected((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 9: _t->onPortalResponse((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenCapture::*)(bool )>(_a, &ScreenCapture::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCapture::*)(const QRect & , bool )>(_a, &ScreenCapture::beginRecording, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCapture::*)()>(_a, &ScreenCapture::onSelectionCanceled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCapture::*)()>(_a, &ScreenCapture::minimizeShotcut, 3))
            return;
    }
}

const QMetaObject *ScreenCapture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenCapture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ScreenCaptureE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenCapture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void ScreenCapture::finished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ScreenCapture::beginRecording(const QRect & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void ScreenCapture::onSelectionCanceled()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ScreenCapture::minimizeShotcut()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
