/*
 * Copyright (c) 2026 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ADDONFILTERSDIALOG_H
#define ADDONFILTERSDIALOG_H

#include <QDialog>

class AddOnServiceModel;
class QLabel;
class LineEditClear;
class QTreeWidget;
class QTreeWidgetItem;

class AddOnFiltersDialog : public QDialog
{
    Q_OBJECT

public:
    explicit AddOnFiltersDialog(AddOnServiceModel *model, QWidget *parent = nullptr);

private slots:
    void onSearchTextChanged(const QString &text);
    void onItemChanged(QTreeWidgetItem *item, int column);
    void onApply();

private:
    void populate();
    void updateSelectedCount();
    void adjustColumnWidths();

    AddOnServiceModel *m_model;
    LineEditClear *m_searchField;
    QTreeWidget *m_listWidget;
    QLabel *m_selectedCountLabel;
};

#endif // ADDONFILTERSDIALOG_H
