/****************************************************************************
** Meta object code from reading C++ file 'motiontrackermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/models/motiontrackermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'motiontrackermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18MotionTrackerModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MotionTrackerModel::qt_create_metaobjectdata<qt_meta_tag_ZN18MotionTrackerModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MotionTrackerModel",
        "removeFromService",
        "",
        "Mlt::Service*",
        "service",
        "setName",
        "QmlFilter*",
        "filter",
        "name",
        "nextName",
        "reset",
        "property",
        "row",
        "trackingData",
        "QList<QRectF>",
        "keyframeIntervalFrames",
        "undo",
        "propertyName",
        "nameProperty",
        "operationProperty"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'removeFromService'
        QtMocHelpers::SlotData<void(Mlt::Service *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'setName'
        QtMocHelpers::MethodData<void(QmlFilter *, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Method 'nextName'
        QtMocHelpers::MethodData<QString() const>(9, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'reset'
        QtMocHelpers::MethodData<void(QmlFilter *, const QString &, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
        }}),
        // Method 'trackingData'
        QtMocHelpers::MethodData<QList<QRectF>(int) const>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'keyframeIntervalFrames'
        QtMocHelpers::MethodData<int(int) const>(15, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'undo'
        QtMocHelpers::MethodData<void(QmlFilter *, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 17 },
        }}),
        // Method 'undo'
        QtMocHelpers::MethodData<void(QmlFilter *)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Method 'undo'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'nameProperty'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'operationProperty'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MotionTrackerModel, qt_meta_tag_ZN18MotionTrackerModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MotionTrackerModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MotionTrackerModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MotionTrackerModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18MotionTrackerModelE_t>.metaTypes,
    nullptr
} };

void MotionTrackerModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MotionTrackerModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removeFromService((*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[1]))); break;
        case 1: _t->setName((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: { QString _r = _t->nextName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->reset((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: { QList<QRectF> _r = _t->trackingData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QRectF>*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->keyframeIntervalFrames((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->undo((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->undo((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1]))); break;
        case 8: _t->undo(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->trackerNameProperty(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->trackerOperationProperty(); break;
        default: break;
        }
    }
}

const QMetaObject *MotionTrackerModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MotionTrackerModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MotionTrackerModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int MotionTrackerModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
