/****************************************************************************
** Meta object code from reading C++ file 'attachedfiltersmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/models/attachedfiltersmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'attachedfiltersmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20AttachedFiltersModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AttachedFiltersModel::qt_create_metaobjectdata<qt_meta_tag_ZN20AttachedFiltersModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AttachedFiltersModel",
        "changed",
        "",
        "duplicateAddFailed",
        "index",
        "trackTitleChanged",
        "isProducerSelectedChanged",
        "supportsLinksChanged",
        "addedOrRemoved",
        "Mlt::Producer*",
        "requestConvert",
        "set709Convert",
        "withSubClip",
        "add",
        "QmlMetadata*",
        "meta",
        "addService",
        "Mlt::Service*",
        "service",
        "remove",
        "row",
        "move",
        "fromRow",
        "toRow",
        "pasteFilters",
        "producerTitle",
        "isProducerSelected",
        "supportsLinks"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'duplicateAddFailed'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'trackTitleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isProducerSelectedChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportsLinksChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addedOrRemoved'
        QtMocHelpers::SignalData<void(Mlt::Producer *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'requestConvert'
        QtMocHelpers::SignalData<void(QString, bool, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Bool, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'add'
        QtMocHelpers::SlotData<int(QmlMetadata *)>(13, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'addService'
        QtMocHelpers::SlotData<int(Mlt::Service *)>(16, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'move'
        QtMocHelpers::SlotData<bool(int, int)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'pasteFilters'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'producerTitle'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'isProducerSelected'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'supportsLinks'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AttachedFiltersModel, qt_meta_tag_ZN20AttachedFiltersModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AttachedFiltersModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AttachedFiltersModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AttachedFiltersModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20AttachedFiltersModelE_t>.metaTypes,
    nullptr
} };

void AttachedFiltersModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttachedFiltersModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->duplicateAddFailed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->trackTitleChanged(); break;
        case 3: _t->isProducerSelectedChanged(); break;
        case 4: _t->supportsLinksChanged(); break;
        case 5: _t->addedOrRemoved((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 6: _t->requestConvert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: { int _r = _t->add((*reinterpret_cast<std::add_pointer_t<QmlMetadata*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->addService((*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: { bool _r = _t->move((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->pasteFilters(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AttachedFiltersModel::*)()>(_a, &AttachedFiltersModel::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttachedFiltersModel::*)(int )>(_a, &AttachedFiltersModel::duplicateAddFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttachedFiltersModel::*)()>(_a, &AttachedFiltersModel::trackTitleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttachedFiltersModel::*)()>(_a, &AttachedFiltersModel::isProducerSelectedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttachedFiltersModel::*)()>(_a, &AttachedFiltersModel::supportsLinksChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttachedFiltersModel::*)(Mlt::Producer * )>(_a, &AttachedFiltersModel::addedOrRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttachedFiltersModel::*)(QString , bool , bool )>(_a, &AttachedFiltersModel::requestConvert, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->producerTitle(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isProducerSelected(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->supportsLinks(); break;
        default: break;
        }
    }
}

const QMetaObject *AttachedFiltersModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AttachedFiltersModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AttachedFiltersModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AttachedFiltersModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void AttachedFiltersModel::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AttachedFiltersModel::duplicateAddFailed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AttachedFiltersModel::trackTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AttachedFiltersModel::isProducerSelectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AttachedFiltersModel::supportsLinksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AttachedFiltersModel::addedOrRemoved(Mlt::Producer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AttachedFiltersModel::requestConvert(QString _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
