/********************************************************************************
** Form generated from reading UI file 'htmlgeneratorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HTMLGENERATORWIDGET_H
#define UI_HTMLGENERATORWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_HtmlGeneratorWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QStackedWidget *stackedWidget;
    QWidget *iconPage;
    QVBoxLayout *iconPageLayout;
    QListWidget *presetIconView;
    QWidget *editorPage;
    QVBoxLayout *editorPageLayout;
    QScrollArea *scrollArea;
    QWidget *HTML;
    QVBoxLayout *verticalLayout_2;
    ServicePresetWidget *preset;
    QLabel *textLabel;
    QVBoxLayout *textVerticalLayout;
    QHBoxLayout *line1HorizontalLayout;
    QLabel *line1Label;
    QLineEdit *line1LineEdit;
    QHBoxLayout *line2HorizontalLayout;
    QLabel *line2Label;
    QLineEdit *line2LineEdit;
    QHBoxLayout *line3HorizontalLayout;
    QLabel *line3Label;
    QLineEdit *line3LineEdit;
    QPushButton *bodyToggleButton;
    QVBoxLayout *bodyVerticalLayout;
    QHBoxLayout *bodyHorizontalLayout;
    QPushButton *colorButton;
    QLabel *colorLabel;
    QPushButton *pushButton;
    QLabel *bodySpacerLabel;
    QPlainTextEdit *bodyTextEdit;
    QPushButton *cssToggleButton;
    QVBoxLayout *cssVerticalLayout;
    QPlainTextEdit *cssTextEdit;
    QPushButton *javascriptToggleButton;
    QVBoxLayout *javascriptVerticalLayout;
    QPlainTextEdit *javascriptTextEdit;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *imageButton;
    QPushButton *videoButton;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *HtmlGeneratorWidget)
    {
        if (HtmlGeneratorWidget->objectName().isEmpty())
            HtmlGeneratorWidget->setObjectName("HtmlGeneratorWidget");
        HtmlGeneratorWidget->resize(597, 815);
#if QT_CONFIG(whatsthis)
        HtmlGeneratorWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/image-video-from-html-generator/50214/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(HtmlGeneratorWidget);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(HtmlGeneratorWidget);
        label_2->setObjectName("label_2");
        QFont font;
        font.setBold(true);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label_2);

        stackedWidget = new QStackedWidget(HtmlGeneratorWidget);
        stackedWidget->setObjectName("stackedWidget");
        iconPage = new QWidget();
        iconPage->setObjectName("iconPage");
        iconPageLayout = new QVBoxLayout(iconPage);
        iconPageLayout->setObjectName("iconPageLayout");
        iconPageLayout->setContentsMargins(0, 0, 0, 0);
        presetIconView = new QListWidget(iconPage);
        presetIconView->setObjectName("presetIconView");
        presetIconView->setAutoFillBackground(false);
        presetIconView->setStyleSheet(QString::fromUtf8("QListWidget {\n"
"	background-color: palette(window);\n"
"}"));
        presetIconView->setFrameShape(QFrame::Shape::NoFrame);
        presetIconView->setIconSize(QSize(128, 128));
        presetIconView->setMovement(QListView::Movement::Static);
        presetIconView->setResizeMode(QListView::ResizeMode::Adjust);
        presetIconView->setSpacing(10);
        presetIconView->setViewMode(QListView::ViewMode::IconMode);
        presetIconView->setUniformItemSizes(true);

        iconPageLayout->addWidget(presetIconView);

        stackedWidget->addWidget(iconPage);
        editorPage = new QWidget();
        editorPage->setObjectName("editorPage");
        editorPageLayout = new QVBoxLayout(editorPage);
        editorPageLayout->setObjectName("editorPageLayout");
        editorPageLayout->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(editorPage);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        HTML = new QWidget();
        HTML->setObjectName("HTML");
        HTML->setGeometry(QRect(0, 0, 437, 557));
        verticalLayout_2 = new QVBoxLayout(HTML);
        verticalLayout_2->setSpacing(3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(6, 6, 6, 0);
        preset = new ServicePresetWidget(HTML);
        preset->setObjectName("preset");

        verticalLayout_2->addWidget(preset);

        textLabel = new QLabel(HTML);
        textLabel->setObjectName("textLabel");
        textLabel->setFont(font);
        textLabel->setVisible(false);

        verticalLayout_2->addWidget(textLabel);

        textVerticalLayout = new QVBoxLayout();
        textVerticalLayout->setObjectName("textVerticalLayout");
        textVerticalLayout->setContentsMargins(20, 0, 0, 0);
        line1HorizontalLayout = new QHBoxLayout();
        line1HorizontalLayout->setObjectName("line1HorizontalLayout");
        line1Label = new QLabel(HTML);
        line1Label->setObjectName("line1Label");

        line1HorizontalLayout->addWidget(line1Label);

        line1LineEdit = new QLineEdit(HTML);
        line1LineEdit->setObjectName("line1LineEdit");

        line1HorizontalLayout->addWidget(line1LineEdit);


        textVerticalLayout->addLayout(line1HorizontalLayout);

        line2HorizontalLayout = new QHBoxLayout();
        line2HorizontalLayout->setObjectName("line2HorizontalLayout");
        line2Label = new QLabel(HTML);
        line2Label->setObjectName("line2Label");

        line2HorizontalLayout->addWidget(line2Label);

        line2LineEdit = new QLineEdit(HTML);
        line2LineEdit->setObjectName("line2LineEdit");

        line2HorizontalLayout->addWidget(line2LineEdit);


        textVerticalLayout->addLayout(line2HorizontalLayout);

        line3HorizontalLayout = new QHBoxLayout();
        line3HorizontalLayout->setObjectName("line3HorizontalLayout");
        line3Label = new QLabel(HTML);
        line3Label->setObjectName("line3Label");

        line3HorizontalLayout->addWidget(line3Label);

        line3LineEdit = new QLineEdit(HTML);
        line3LineEdit->setObjectName("line3LineEdit");

        line3HorizontalLayout->addWidget(line3LineEdit);


        textVerticalLayout->addLayout(line3HorizontalLayout);


        verticalLayout_2->addLayout(textVerticalLayout);

        bodyToggleButton = new QPushButton(HTML);
        bodyToggleButton->setObjectName("bodyToggleButton");
        bodyToggleButton->setStyleSheet(QString::fromUtf8("QPushButton { text-align: left; font-weight: bold; }"));
        bodyToggleButton->setCheckable(true);
        bodyToggleButton->setChecked(false);
        bodyToggleButton->setFlat(true);

        verticalLayout_2->addWidget(bodyToggleButton);

        bodyVerticalLayout = new QVBoxLayout();
        bodyVerticalLayout->setObjectName("bodyVerticalLayout");
        bodyVerticalLayout->setContentsMargins(20, 0, 0, 0);
        bodyHorizontalLayout = new QHBoxLayout();
        bodyHorizontalLayout->setObjectName("bodyHorizontalLayout");
        colorButton = new QPushButton(HTML);
        colorButton->setObjectName("colorButton");

        bodyHorizontalLayout->addWidget(colorButton);

        colorLabel = new QLabel(HTML);
        colorLabel->setObjectName("colorLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(colorLabel->sizePolicy().hasHeightForWidth());
        colorLabel->setSizePolicy(sizePolicy);
        colorLabel->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        bodyHorizontalLayout->addWidget(colorLabel);

        pushButton = new QPushButton(HTML);
        pushButton->setObjectName("pushButton");

        bodyHorizontalLayout->addWidget(pushButton);

        bodySpacerLabel = new QLabel(HTML);
        bodySpacerLabel->setObjectName("bodySpacerLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(2);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(bodySpacerLabel->sizePolicy().hasHeightForWidth());
        bodySpacerLabel->setSizePolicy(sizePolicy1);
        bodySpacerLabel->setText(QString::fromUtf8(""));

        bodyHorizontalLayout->addWidget(bodySpacerLabel);


        bodyVerticalLayout->addLayout(bodyHorizontalLayout);

        bodyTextEdit = new QPlainTextEdit(HTML);
        bodyTextEdit->setObjectName("bodyTextEdit");

        bodyVerticalLayout->addWidget(bodyTextEdit);


        verticalLayout_2->addLayout(bodyVerticalLayout);

        cssToggleButton = new QPushButton(HTML);
        cssToggleButton->setObjectName("cssToggleButton");
        cssToggleButton->setStyleSheet(QString::fromUtf8("QPushButton { text-align: left; font-weight: bold; }"));
        cssToggleButton->setCheckable(true);
        cssToggleButton->setChecked(false);
        cssToggleButton->setFlat(true);

        verticalLayout_2->addWidget(cssToggleButton);

        cssVerticalLayout = new QVBoxLayout();
        cssVerticalLayout->setObjectName("cssVerticalLayout");
        cssVerticalLayout->setContentsMargins(20, 0, 0, 0);
        cssTextEdit = new QPlainTextEdit(HTML);
        cssTextEdit->setObjectName("cssTextEdit");

        cssVerticalLayout->addWidget(cssTextEdit);


        verticalLayout_2->addLayout(cssVerticalLayout);

        javascriptToggleButton = new QPushButton(HTML);
        javascriptToggleButton->setObjectName("javascriptToggleButton");
        javascriptToggleButton->setStyleSheet(QString::fromUtf8("QPushButton { text-align: left; font-weight: bold; }"));
        javascriptToggleButton->setCheckable(true);
        javascriptToggleButton->setChecked(false);
        javascriptToggleButton->setFlat(true);

        verticalLayout_2->addWidget(javascriptToggleButton);

        javascriptVerticalLayout = new QVBoxLayout();
        javascriptVerticalLayout->setObjectName("javascriptVerticalLayout");
        javascriptVerticalLayout->setContentsMargins(20, 0, 0, 0);
        javascriptTextEdit = new QPlainTextEdit(HTML);
        javascriptTextEdit->setObjectName("javascriptTextEdit");

        javascriptVerticalLayout->addWidget(javascriptTextEdit);


        verticalLayout_2->addLayout(javascriptVerticalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        scrollArea->setWidget(HTML);

        editorPageLayout->addWidget(scrollArea);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        imageButton = new QPushButton(editorPage);
        imageButton->setObjectName("imageButton");

        horizontalLayout->addWidget(imageButton);

        videoButton = new QPushButton(editorPage);
        videoButton->setObjectName("videoButton");

        horizontalLayout->addWidget(videoButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        editorPageLayout->addLayout(horizontalLayout);

        stackedWidget->addWidget(editorPage);

        verticalLayout->addWidget(stackedWidget);


        retranslateUi(HtmlGeneratorWidget);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(HtmlGeneratorWidget);
    } // setupUi

    void retranslateUi(QWidget *HtmlGeneratorWidget)
    {
        HtmlGeneratorWidget->setWindowTitle(QCoreApplication::translate("HtmlGeneratorWidget", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("HtmlGeneratorWidget", "HTML", nullptr));
        textLabel->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Text", nullptr));
        line1Label->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Line 1", nullptr));
        line2Label->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Line 2", nullptr));
        line3Label->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Line 3", nullptr));
#if QT_CONFIG(tooltip)
        bodyToggleButton->setToolTip(QCoreApplication::translate("HtmlGeneratorWidget", "Click to expand or collapse the Body section", nullptr));
#endif // QT_CONFIG(tooltip)
        bodyToggleButton->setText(QCoreApplication::translate("HtmlGeneratorWidget", "\342\226\266 Body", nullptr));
        colorButton->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Background color...", nullptr));
        colorLabel->setText(QCoreApplication::translate("HtmlGeneratorWidget", "#00000000", nullptr));
#if QT_CONFIG(tooltip)
        pushButton->setToolTip(QCoreApplication::translate("HtmlGeneratorWidget", "Click to set color to transparent", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Transparent", nullptr));
        bodyTextEdit->setPlaceholderText(QCoreApplication::translate("HtmlGeneratorWidget", "Do not include <html>, <head>, or <body> here", nullptr));
#if QT_CONFIG(tooltip)
        cssToggleButton->setToolTip(QCoreApplication::translate("HtmlGeneratorWidget", "Click to expand or collapse the CSS section", nullptr));
#endif // QT_CONFIG(tooltip)
        cssToggleButton->setText(QCoreApplication::translate("HtmlGeneratorWidget", "\342\226\266 CSS", nullptr));
        cssTextEdit->setPlaceholderText(QCoreApplication::translate("HtmlGeneratorWidget", "Type or paste stylesheets here", nullptr));
#if QT_CONFIG(tooltip)
        javascriptToggleButton->setToolTip(QCoreApplication::translate("HtmlGeneratorWidget", "Click to expand or collapse the JavaScript section", nullptr));
#endif // QT_CONFIG(tooltip)
        javascriptToggleButton->setText(QCoreApplication::translate("HtmlGeneratorWidget", "\342\226\266 JavaScript", nullptr));
        javascriptTextEdit->setPlaceholderText(QCoreApplication::translate("HtmlGeneratorWidget", "Type or paste JavaScript code here", nullptr));
        imageButton->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Generate Image...", nullptr));
        videoButton->setText(QCoreApplication::translate("HtmlGeneratorWidget", "Generate Video...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class HtmlGeneratorWidget: public Ui_HtmlGeneratorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HTMLGENERATORWIDGET_H
