/****************************************************************************
** Meta object code from reading C++ file 'qmlproducer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/qmltypes/qmlproducer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlproducer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11QmlProducerE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlProducer::qt_create_metaobjectdata<qt_meta_tag_ZN11QmlProducerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlProducer",
        "producerChanged",
        "",
        "positionChanged",
        "position",
        "seeked",
        "inChanged",
        "delta",
        "outChanged",
        "audioLevelsChanged",
        "durationChanged",
        "lengthChanged",
        "setProducer",
        "Mlt::Producer&",
        "producer",
        "remakeAudioLevels",
        "isKeyframesVisible",
        "getMltProducer",
        "Mlt::Producer*",
        "get",
        "name",
        "getDouble",
        "getRect",
        "QRectF",
        "outOfBounds",
        "newGlaxnimateFile",
        "filename",
        "launchGlaxnimate",
        "in",
        "out",
        "aspectRatio",
        "duration",
        "length",
        "resource",
        "mlt_service",
        "hash",
        "fadeIn",
        "fadeOut",
        "speed",
        "displayAspectRatio"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'producerChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'inChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'outChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'audioLevelsChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<void(Mlt::Producer &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'remakeAudioLevels'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Method 'getMltProducer'
        QtMocHelpers::MethodData<Mlt::Producer *()>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'remakeAudioLevels'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'get'
        QtMocHelpers::MethodData<QString(QString, int)>(19, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 20 }, { QMetaType::Int, 4 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QString(QString)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::QString, 20 },
        }}),
        // Method 'getDouble'
        QtMocHelpers::MethodData<double(QString, int)>(21, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::QString, 20 }, { QMetaType::Int, 4 },
        }}),
        // Method 'getDouble'
        QtMocHelpers::MethodData<double(QString)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Double, {{
            { QMetaType::QString, 20 },
        }}),
        // Method 'getRect'
        QtMocHelpers::MethodData<QRectF(QString, int)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 20 }, { QMetaType::Int, 4 },
        }}),
        // Method 'getRect'
        QtMocHelpers::MethodData<QRectF(QString)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 23, {{
            { QMetaType::QString, 20 },
        }}),
        // Method 'outOfBounds'
        QtMocHelpers::MethodData<bool()>(24, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'newGlaxnimateFile'
        QtMocHelpers::MethodData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'launchGlaxnimate'
        QtMocHelpers::MethodData<void(const QString &) const>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Method 'launchGlaxnimate'
        QtMocHelpers::MethodData<void() const>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'in'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'out'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'aspectRatio'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'length'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags, 7),
        // property 'resource'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'mlt_service'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'hash'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'fadeIn'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'fadeOut'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'speed'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags, 0),
        // property 'position'
        QtMocHelpers::PropertyData<int>(4, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'displayAspectRatio'
        QtMocHelpers::PropertyData<double>(39, QMetaType::Double, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlProducer, qt_meta_tag_ZN11QmlProducerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlProducer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlProducerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlProducerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11QmlProducerE_t>.metaTypes,
    nullptr
} };

void QmlProducer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlProducer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->producerChanged(); break;
        case 1: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->seeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->inChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->outChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->audioLevelsChanged(); break;
        case 6: _t->durationChanged(); break;
        case 7: _t->lengthChanged(); break;
        case 8: _t->setProducer((*reinterpret_cast<std::add_pointer_t<Mlt::Producer&>>(_a[1]))); break;
        case 9: _t->remakeAudioLevels((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: { Mlt::Producer* _r = _t->getMltProducer();
            if (_a[0]) *reinterpret_cast<Mlt::Producer**>(_a[0]) = std::move(_r); }  break;
        case 11: _t->remakeAudioLevels(); break;
        case 12: { QString _r = _t->get((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->get((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { double _r = _t->getDouble((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 15: { double _r = _t->getDouble((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 16: { QRectF _r = _t->getRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 17: { QRectF _r = _t->getRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->outOfBounds();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->newGlaxnimateFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->launchGlaxnimate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->launchGlaxnimate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)()>(_a, &QmlProducer::producerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)(int )>(_a, &QmlProducer::positionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)(int )>(_a, &QmlProducer::seeked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)(int )>(_a, &QmlProducer::inChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)(int )>(_a, &QmlProducer::outChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)()>(_a, &QmlProducer::audioLevelsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)()>(_a, &QmlProducer::durationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlProducer::*)()>(_a, &QmlProducer::lengthChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->in(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->out(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->aspectRatio(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->duration(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->length(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->resource(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->mlt_service(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->hash(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->fadeIn(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->fadeOut(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->speed(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->position(); break;
        case 13: *reinterpret_cast<double*>(_v) = _t->displayAspectRatio(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 12: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QmlProducer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlProducer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlProducerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlProducer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void QmlProducer::producerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QmlProducer::positionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QmlProducer::seeked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QmlProducer::inChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QmlProducer::outChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QmlProducer::audioLevelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QmlProducer::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QmlProducer::lengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
