/********************************************************************************
** Form generated from reading UI file 'lumamixtransition.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LUMAMIXTRANSITION_H
#define UI_LUMAMIXTRANSITION_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/timespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_LumaMixTransition
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *softnessLabel;
    QSlider *softnessSlider;
    QSpinBox *softnessSpinner;
    QHBoxLayout *horizontalLayout;
    QListWidget *lumaCombo;
    QLabel *label_4;
    QToolButton *favoriteButton;
    QLabel *customLumaLabel;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *crossfadeRadioButton;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *mixRadioButton;
    QLabel *label_6;
    QSlider *mixSlider;
    QLabel *label_7;
    QSpinBox *mixSpinner;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *invertCheckBox;
    QCheckBox *previewCheckBox;
    QLabel *durationLabel;
    QHBoxLayout *durationLayout;
    TimeSpinBox *durationSpinBox;
    QSpacerItem *durationSpacer;
    QLabel *label;
    QLabel *getCustomLabel;
    QSpacerItem *verticalSpacer;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *LumaMixTransition)
    {
        if (LumaMixTransition->objectName().isEmpty())
            LumaMixTransition->setObjectName("LumaMixTransition");
        LumaMixTransition->resize(398, 372);
#if QT_CONFIG(whatsthis)
        LumaMixTransition->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/changing-the-type-of-video-transition/12959/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(LumaMixTransition);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(LumaMixTransition);
        label_2->setObjectName("label_2");
        QFont font;
        font.setBold(true);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        softnessLabel = new QLabel(LumaMixTransition);
        softnessLabel->setObjectName("softnessLabel");
        softnessLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        softnessLabel->setWordWrap(true);

        horizontalLayout_2->addWidget(softnessLabel);

        softnessSlider = new QSlider(LumaMixTransition);
        softnessSlider->setObjectName("softnessSlider");
        softnessSlider->setMaximum(100);
        softnessSlider->setValue(20);
        softnessSlider->setOrientation(Qt::Orientation::Horizontal);

        horizontalLayout_2->addWidget(softnessSlider);

        softnessSpinner = new QSpinBox(LumaMixTransition);
        softnessSpinner->setObjectName("softnessSpinner");
        softnessSpinner->setMaximum(100);
        softnessSpinner->setValue(20);

        horizontalLayout_2->addWidget(softnessSpinner);


        gridLayout->addLayout(horizontalLayout_2, 4, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        lumaCombo = new QListWidget(LumaMixTransition);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        new QListWidgetItem(lumaCombo);
        lumaCombo->setObjectName("lumaCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lumaCombo->sizePolicy().hasHeightForWidth());
        lumaCombo->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(lumaCombo);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 2);

        label_4 = new QLabel(LumaMixTransition);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_4, 6, 0, 1, 1);

        favoriteButton = new QToolButton(LumaMixTransition);
        favoriteButton->setObjectName("favoriteButton");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/oxygen/32x32/places/bookmarks.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        favoriteButton->setIcon(icon);

        gridLayout->addWidget(favoriteButton, 2, 0, 1, 1);

        customLumaLabel = new QLabel(LumaMixTransition);
        customLumaLabel->setObjectName("customLumaLabel");

        gridLayout->addWidget(customLumaLabel, 2, 1, 1, 2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        crossfadeRadioButton = new QRadioButton(LumaMixTransition);
        buttonGroup = new QButtonGroup(LumaMixTransition);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(crossfadeRadioButton);
        crossfadeRadioButton->setObjectName("crossfadeRadioButton");

        horizontalLayout_3->addWidget(crossfadeRadioButton);


        gridLayout->addLayout(horizontalLayout_3, 6, 1, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        mixRadioButton = new QRadioButton(LumaMixTransition);
        buttonGroup->addButton(mixRadioButton);
        mixRadioButton->setObjectName("mixRadioButton");

        horizontalLayout_4->addWidget(mixRadioButton);

        label_6 = new QLabel(LumaMixTransition);
        label_6->setObjectName("label_6");

        horizontalLayout_4->addWidget(label_6);

        mixSlider = new QSlider(LumaMixTransition);
        mixSlider->setObjectName("mixSlider");
        mixSlider->setMaximum(100);
        mixSlider->setOrientation(Qt::Orientation::Horizontal);

        horizontalLayout_4->addWidget(mixSlider);

        label_7 = new QLabel(LumaMixTransition);
        label_7->setObjectName("label_7");

        horizontalLayout_4->addWidget(label_7);

        mixSpinner = new QSpinBox(LumaMixTransition);
        mixSpinner->setObjectName("mixSpinner");
        mixSpinner->setMaximum(100);

        horizontalLayout_4->addWidget(mixSpinner);

        horizontalLayout_4->setStretch(2, 1);

        gridLayout->addLayout(horizontalLayout_4, 7, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 4, 2, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        invertCheckBox = new QCheckBox(LumaMixTransition);
        invertCheckBox->setObjectName("invertCheckBox");

        horizontalLayout_5->addWidget(invertCheckBox);

        previewCheckBox = new QCheckBox(LumaMixTransition);
        previewCheckBox->setObjectName("previewCheckBox");

        horizontalLayout_5->addWidget(previewCheckBox);


        gridLayout->addLayout(horizontalLayout_5, 3, 1, 1, 1);

        durationLabel = new QLabel(LumaMixTransition);
        durationLabel->setObjectName("durationLabel");
        durationLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(durationLabel, 8, 0, 1, 1);

        durationLayout = new QHBoxLayout();
        durationLayout->setObjectName("durationLayout");
        durationSpinBox = new TimeSpinBox(LumaMixTransition);
        durationSpinBox->setObjectName("durationSpinBox");
        durationSpinBox->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        durationSpinBox->setAccelerated(true);
        durationSpinBox->setKeyboardTracking(false);
        durationSpinBox->setMinimum(1);

        durationLayout->addWidget(durationSpinBox);

        durationSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        durationLayout->addItem(durationSpacer);


        gridLayout->addLayout(durationLayout, 8, 1, 1, 1);

        label = new QLabel(LumaMixTransition);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTop|Qt::AlignmentFlag::AlignTrailing);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        getCustomLabel = new QLabel(LumaMixTransition);
        getCustomLabel->setObjectName("getCustomLabel");
        getCustomLabel->setOpenExternalLinks(true);

        gridLayout->addWidget(getCustomLabel, 5, 1, 1, 2);

        gridLayout->setColumnStretch(1, 10);
        gridLayout->setColumnStretch(2, 9);

        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 91, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(lumaCombo, favoriteButton);
        QWidget::setTabOrder(favoriteButton, invertCheckBox);
        QWidget::setTabOrder(invertCheckBox, previewCheckBox);
        QWidget::setTabOrder(previewCheckBox, softnessSlider);
        QWidget::setTabOrder(softnessSlider, softnessSpinner);
        QWidget::setTabOrder(softnessSpinner, crossfadeRadioButton);
        QWidget::setTabOrder(crossfadeRadioButton, mixSlider);
        QWidget::setTabOrder(mixSlider, mixSpinner);
        QWidget::setTabOrder(mixSpinner, durationSpinBox);

        retranslateUi(LumaMixTransition);
        QObject::connect(softnessSlider, &QSlider::valueChanged, softnessSpinner, &QSpinBox::setValue);
        QObject::connect(softnessSpinner, &QSpinBox::valueChanged, softnessSlider, &QSlider::setValue);
        QObject::connect(mixSlider, &QSlider::valueChanged, mixSpinner, &QSpinBox::setValue);
        QObject::connect(mixSpinner, &QSpinBox::valueChanged, mixSlider, &QSlider::setValue);

        QMetaObject::connectSlotsByName(LumaMixTransition);
    } // setupUi

    void retranslateUi(QWidget *LumaMixTransition)
    {
        LumaMixTransition->setWindowTitle(QCoreApplication::translate("LumaMixTransition", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("LumaMixTransition", "Transition", nullptr));
        softnessLabel->setText(QCoreApplication::translate("LumaMixTransition", "Softness", nullptr));
#if QT_CONFIG(tooltip)
        softnessSlider->setToolTip(QCoreApplication::translate("LumaMixTransition", "Change the softness of the edge of the wipe", nullptr));
#endif // QT_CONFIG(tooltip)
        softnessSpinner->setSuffix(QCoreApplication::translate("LumaMixTransition", " %", nullptr));

        const bool __sortingEnabled = lumaCombo->isSortingEnabled();
        lumaCombo->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = lumaCombo->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("LumaMixTransition", "Dissolve", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = lumaCombo->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("LumaMixTransition", "Cut", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = lumaCombo->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("LumaMixTransition", "Custom...", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = lumaCombo->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("LumaMixTransition", "Bar Horizontal", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = lumaCombo->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("LumaMixTransition", "Bar Vertical", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = lumaCombo->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("LumaMixTransition", "Barn Door Horizontal", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = lumaCombo->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("LumaMixTransition", "Barn Door Vertical", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = lumaCombo->item(7);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("LumaMixTransition", "Barn Door Diagonal SW-NE", nullptr));
        QListWidgetItem *___qlistwidgetitem8 = lumaCombo->item(8);
        ___qlistwidgetitem8->setText(QCoreApplication::translate("LumaMixTransition", "Barn Door Diagonal NW-SE", nullptr));
        QListWidgetItem *___qlistwidgetitem9 = lumaCombo->item(9);
        ___qlistwidgetitem9->setText(QCoreApplication::translate("LumaMixTransition", "Diagonal Top Left", nullptr));
        QListWidgetItem *___qlistwidgetitem10 = lumaCombo->item(10);
        ___qlistwidgetitem10->setText(QCoreApplication::translate("LumaMixTransition", "Diagonal Top Right", nullptr));
        QListWidgetItem *___qlistwidgetitem11 = lumaCombo->item(11);
        ___qlistwidgetitem11->setText(QCoreApplication::translate("LumaMixTransition", "Matrix Waterfall Horizontal", nullptr));
        QListWidgetItem *___qlistwidgetitem12 = lumaCombo->item(12);
        ___qlistwidgetitem12->setText(QCoreApplication::translate("LumaMixTransition", "Matrix Waterfall Vertical", nullptr));
        QListWidgetItem *___qlistwidgetitem13 = lumaCombo->item(13);
        ___qlistwidgetitem13->setText(QCoreApplication::translate("LumaMixTransition", "Matrix Snake Horizontal", nullptr));
        QListWidgetItem *___qlistwidgetitem14 = lumaCombo->item(14);
        ___qlistwidgetitem14->setText(QCoreApplication::translate("LumaMixTransition", "Matrix Snake Parallel Horizontal", nullptr));
        QListWidgetItem *___qlistwidgetitem15 = lumaCombo->item(15);
        ___qlistwidgetitem15->setText(QCoreApplication::translate("LumaMixTransition", "Matrix Snake Vertical", nullptr));
        QListWidgetItem *___qlistwidgetitem16 = lumaCombo->item(16);
        ___qlistwidgetitem16->setText(QCoreApplication::translate("LumaMixTransition", "Matrix Snake Parallel Vertical", nullptr));
        QListWidgetItem *___qlistwidgetitem17 = lumaCombo->item(17);
        ___qlistwidgetitem17->setText(QCoreApplication::translate("LumaMixTransition", "Barn V Up", nullptr));
        QListWidgetItem *___qlistwidgetitem18 = lumaCombo->item(18);
        ___qlistwidgetitem18->setText(QCoreApplication::translate("LumaMixTransition", "Iris Circle", nullptr));
        QListWidgetItem *___qlistwidgetitem19 = lumaCombo->item(19);
        ___qlistwidgetitem19->setText(QCoreApplication::translate("LumaMixTransition", "Double Iris", nullptr));
        QListWidgetItem *___qlistwidgetitem20 = lumaCombo->item(20);
        ___qlistwidgetitem20->setText(QCoreApplication::translate("LumaMixTransition", "Iris Box", nullptr));
        QListWidgetItem *___qlistwidgetitem21 = lumaCombo->item(21);
        ___qlistwidgetitem21->setText(QCoreApplication::translate("LumaMixTransition", "Box Bottom Right", nullptr));
        QListWidgetItem *___qlistwidgetitem22 = lumaCombo->item(22);
        ___qlistwidgetitem22->setText(QCoreApplication::translate("LumaMixTransition", "Box Bottom Left", nullptr));
        QListWidgetItem *___qlistwidgetitem23 = lumaCombo->item(23);
        ___qlistwidgetitem23->setText(QCoreApplication::translate("LumaMixTransition", "Box Right Center", nullptr));
        QListWidgetItem *___qlistwidgetitem24 = lumaCombo->item(24);
        ___qlistwidgetitem24->setText(QCoreApplication::translate("LumaMixTransition", "Clock Top", nullptr));
        lumaCombo->setSortingEnabled(__sortingEnabled);

        label_4->setText(QCoreApplication::translate("LumaMixTransition", "Audio", nullptr));
#if QT_CONFIG(tooltip)
        favoriteButton->setToolTip(QCoreApplication::translate("LumaMixTransition", "Save the custom transition as a favorite", nullptr));
#endif // QT_CONFIG(tooltip)
        customLumaLabel->setText(QCoreApplication::translate("LumaMixTransition", "TextLabel", nullptr));
#if QT_CONFIG(tooltip)
        crossfadeRadioButton->setToolTip(QCoreApplication::translate("LumaMixTransition", "Automatically fade-out the audio of clip A\n"
"and fade-in the audio of clip B over the\n"
"duration of the transition.", nullptr));
#endif // QT_CONFIG(tooltip)
        crossfadeRadioButton->setText(QCoreApplication::translate("LumaMixTransition", "Cross-fade", nullptr));
#if QT_CONFIG(tooltip)
        mixRadioButton->setToolTip(QCoreApplication::translate("LumaMixTransition", "Do not alter the audio levels during the\n"
"course of the transition. Instead, set a\n"
"fixed mixing level, or choose only clip A's\n"
"audio (0%) or clip B's audio (100%).", nullptr));
#endif // QT_CONFIG(tooltip)
        mixRadioButton->setText(QCoreApplication::translate("LumaMixTransition", "Mix:", nullptr));
        label_6->setText(QCoreApplication::translate("LumaMixTransition", "A", nullptr));
        label_7->setText(QCoreApplication::translate("LumaMixTransition", "B", nullptr));
        mixSpinner->setSuffix(QCoreApplication::translate("LumaMixTransition", " %", nullptr));
#if QT_CONFIG(tooltip)
        invertCheckBox->setToolTip(QCoreApplication::translate("LumaMixTransition", "Swap the appearance of the A and B clips", nullptr));
#endif // QT_CONFIG(tooltip)
        invertCheckBox->setText(QCoreApplication::translate("LumaMixTransition", "Invert Wipe", nullptr));
        previewCheckBox->setText(QCoreApplication::translate("LumaMixTransition", "Preview", nullptr));
        durationLabel->setText(QCoreApplication::translate("LumaMixTransition", "Duration", nullptr));
#if QT_CONFIG(tooltip)
        durationSpinBox->setToolTip(QCoreApplication::translate("LumaMixTransition", "Change to resize the transition", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("LumaMixTransition", "Video", nullptr));
        getCustomLabel->setText(QCoreApplication::translate("LumaMixTransition", "Get custom transitions on our Web site.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LumaMixTransition: public Ui_LumaMixTransition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LUMAMIXTRANSITION_H
