/********************************************************************************
** Form generated from reading UI file 'pulseaudiowidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PULSEAUDIOWIDGET_H
#define UI_PULSEAUDIOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PulseAudioWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PulseAudioWidget)
    {
        if (PulseAudioWidget->objectName().isEmpty())
            PulseAudioWidget->setObjectName("PulseAudioWidget");
        PulseAudioWidget->resize(392, 292);
#if QT_CONFIG(whatsthis)
        PulseAudioWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-pulseaudio/12938/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(PulseAudioWidget);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(PulseAudioWidget);
        label->setObjectName("label");
        QFont font;
        font.setBold(true);
        label->setFont(font);
        label->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label);

        verticalSpacer = new QSpacerItem(20, 258, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(PulseAudioWidget);

        QMetaObject::connectSlotsByName(PulseAudioWidget);
    } // setupUi

    void retranslateUi(QWidget *PulseAudioWidget)
    {
        PulseAudioWidget->setWindowTitle(QCoreApplication::translate("PulseAudioWidget", "Form", nullptr));
        label->setText(QCoreApplication::translate("PulseAudioWidget", "PulseAudio", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PulseAudioWidget: public Ui_PulseAudioWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PULSEAUDIOWIDGET_H
