/********************************************************************************
** Form generated from reading UI file 'jobsdock.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JOBSDOCK_H
#define UI_JOBSDOCK_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_JobsDock
{
public:
    QAction *actionStopJob;
    QAction *actionViewLog;
    QAction *actionRun;
    QAction *actionRemove;
    QAction *actionRemoveFinished;
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout;
    QTreeView *treeView;
    QHBoxLayout *horizontalLayout;
    QPushButton *menuButton;
    QPushButton *pauseButton;
    QPushButton *cleanButton;
    QSpacerItem *horizontalSpacer;

    void setupUi(QDockWidget *JobsDock)
    {
        if (JobsDock->objectName().isEmpty())
            JobsDock->setObjectName("JobsDock");
        JobsDock->resize(283, 279);
#if QT_CONFIG(whatsthis)
        JobsDock->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/jobs-panel/12945/1"));
#endif // QT_CONFIG(whatsthis)
        actionStopJob = new QAction(JobsDock);
        actionStopJob->setObjectName("actionStopJob");
        actionViewLog = new QAction(JobsDock);
        actionViewLog->setObjectName("actionViewLog");
        actionRun = new QAction(JobsDock);
        actionRun->setObjectName("actionRun");
        actionRemove = new QAction(JobsDock);
        actionRemove->setObjectName("actionRemove");
        actionRemoveFinished = new QAction(JobsDock);
        actionRemoveFinished->setObjectName("actionRemoveFinished");
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        verticalLayout_2 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(dockWidgetContents);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 283, 219));
        verticalLayout = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        treeView = new QTreeView(scrollAreaWidgetContents);
        treeView->setObjectName("treeView");
        treeView->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        treeView->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        treeView->setAlternatingRowColors(true);
        treeView->setTextElideMode(Qt::TextElideMode::ElideMiddle);
        treeView->setRootIsDecorated(false);
        treeView->setUniformRowHeights(true);
        treeView->header()->setVisible(false);

        verticalLayout->addWidget(treeView);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(scrollArea);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        menuButton = new QPushButton(dockWidgetContents);
        menuButton->setObjectName("menuButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("show-menu");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8(":/icons/light/32x32/show-menu.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        menuButton->setIcon(icon);

        horizontalLayout->addWidget(menuButton);

        pauseButton = new QPushButton(dockWidgetContents);
        pauseButton->setObjectName("pauseButton");
        pauseButton->setCheckable(true);

        horizontalLayout->addWidget(pauseButton);

        cleanButton = new QPushButton(dockWidgetContents);
        cleanButton->setObjectName("cleanButton");

        horizontalLayout->addWidget(cleanButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        JobsDock->setWidget(dockWidgetContents);

        retranslateUi(JobsDock);

        QMetaObject::connectSlotsByName(JobsDock);
    } // setupUi

    void retranslateUi(QDockWidget *JobsDock)
    {
        JobsDock->setWindowTitle(QCoreApplication::translate("JobsDock", "Jobs", nullptr));
        actionStopJob->setText(QCoreApplication::translate("JobsDock", "Stop This Job", nullptr));
#if QT_CONFIG(tooltip)
        actionStopJob->setToolTip(QCoreApplication::translate("JobsDock", "Stop the currently selected job", nullptr));
#endif // QT_CONFIG(tooltip)
        actionViewLog->setText(QCoreApplication::translate("JobsDock", "View Log", nullptr));
#if QT_CONFIG(tooltip)
        actionViewLog->setToolTip(QCoreApplication::translate("JobsDock", "View the messages of MLT and FFmpeg ", nullptr));
#endif // QT_CONFIG(tooltip)
        actionRun->setText(QCoreApplication::translate("JobsDock", "Run", nullptr));
#if QT_CONFIG(tooltip)
        actionRun->setToolTip(QCoreApplication::translate("JobsDock", "Restart a stopped job", nullptr));
#endif // QT_CONFIG(tooltip)
        actionRemove->setText(QCoreApplication::translate("JobsDock", "Remove", nullptr));
        actionRemoveFinished->setText(QCoreApplication::translate("JobsDock", "Remove Finished", nullptr));
#if QT_CONFIG(tooltip)
        actionRemoveFinished->setToolTip(QCoreApplication::translate("JobsDock", "Remove Finished", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        menuButton->setToolTip(QCoreApplication::translate("JobsDock", "Jobs Menu", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pauseButton->setToolTip(QCoreApplication::translate("JobsDock", "Stop automatically processing the next pending job in\n"
"the list. This does not stop a currently running job. Right-\n"
"-click a job to open a menu to stop a currently running job.", nullptr));
#endif // QT_CONFIG(tooltip)
        pauseButton->setText(QCoreApplication::translate("JobsDock", "Pause Queue", nullptr));
#if QT_CONFIG(tooltip)
        cleanButton->setToolTip(QCoreApplication::translate("JobsDock", "Remove all of the completed and failed jobs from the list", nullptr));
#endif // QT_CONFIG(tooltip)
        cleanButton->setText(QCoreApplication::translate("JobsDock", "Clean", nullptr));
    } // retranslateUi

};

namespace Ui {
    class JobsDock: public Ui_JobsDock {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_JOBSDOCK_H
