/********************************************************************************
** Form generated from reading UI file 'trackpropertieswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRACKPROPERTIESWIDGET_H
#define UI_TRACKPROPERTIESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TrackPropertiesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    QHBoxLayout *blendModeLayout;
    QLabel *blendModeLabel;
    QComboBox *blendModeCombo;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TrackPropertiesWidget)
    {
        if (TrackPropertiesWidget->objectName().isEmpty())
            TrackPropertiesWidget->setObjectName("TrackPropertiesWidget");
        TrackPropertiesWidget->resize(400, 300);
#if QT_CONFIG(whatsthis)
        TrackPropertiesWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/about-the-timeline/12952/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(TrackPropertiesWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(TrackPropertiesWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        blendModeLayout = new QHBoxLayout();
        blendModeLayout->setObjectName("blendModeLayout");
        blendModeLabel = new QLabel(TrackPropertiesWidget);
        blendModeLabel->setObjectName("blendModeLabel");
        blendModeLabel->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        blendModeLayout->addWidget(blendModeLabel);

        blendModeCombo = new QComboBox(TrackPropertiesWidget);
        blendModeCombo->setObjectName("blendModeCombo");
        blendModeCombo->setMaxVisibleItems(20);

        blendModeLayout->addWidget(blendModeCombo);


        verticalLayout->addLayout(blendModeLayout);

        verticalSpacer = new QSpacerItem(20, 232, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(TrackPropertiesWidget);

        QMetaObject::connectSlotsByName(TrackPropertiesWidget);
    } // setupUi

    void retranslateUi(QWidget *TrackPropertiesWidget)
    {
        TrackPropertiesWidget->setWindowTitle(QCoreApplication::translate("TrackPropertiesWidget", "Form", nullptr));
        nameLabel->setText(QString());
        blendModeLabel->setText(QCoreApplication::translate("TrackPropertiesWidget", "Blend mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TrackPropertiesWidget: public Ui_TrackPropertiesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TRACKPROPERTIESWIDGET_H
