/********************************************************************************
** Form generated from reading UI file 'servicepresetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERVICEPRESETWIDGET_H
#define UI_SERVICEPRESETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ServicePresetWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *presetCombo;
    QPushButton *savePresetButton;
    QPushButton *deletePresetButton;

    void setupUi(QWidget *ServicePresetWidget)
    {
        if (ServicePresetWidget->objectName().isEmpty())
            ServicePresetWidget->setObjectName("ServicePresetWidget");
        ServicePresetWidget->resize(394, 90);
        verticalLayout = new QVBoxLayout(ServicePresetWidget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(ServicePresetWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        presetCombo = new QComboBox(ServicePresetWidget);
        presetCombo->setObjectName("presetCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(presetCombo->sizePolicy().hasHeightForWidth());
        presetCombo->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(presetCombo);

        savePresetButton = new QPushButton(ServicePresetWidget);
        savePresetButton->setObjectName("savePresetButton");

        horizontalLayout->addWidget(savePresetButton);

        deletePresetButton = new QPushButton(ServicePresetWidget);
        deletePresetButton->setObjectName("deletePresetButton");

        horizontalLayout->addWidget(deletePresetButton);


        verticalLayout->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        label->setBuddy(presetCombo);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ServicePresetWidget);

        QMetaObject::connectSlotsByName(ServicePresetWidget);
    } // setupUi

    void retranslateUi(QWidget *ServicePresetWidget)
    {
        ServicePresetWidget->setWindowTitle(QCoreApplication::translate("ServicePresetWidget", "Form", nullptr));
        label->setText(QCoreApplication::translate("ServicePresetWidget", "Preset", nullptr));
        savePresetButton->setText(QCoreApplication::translate("ServicePresetWidget", "Save", nullptr));
        deletePresetButton->setText(QCoreApplication::translate("ServicePresetWidget", "Delete", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ServicePresetWidget: public Ui_ServicePresetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SERVICEPRESETWIDGET_H
