/****************************************************************************
** Meta object code from reading C++ file 'filtersdock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/docks/filtersdock.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filtersdock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11FiltersDockE_t {};
} // unnamed namespace

template <> constexpr inline auto FiltersDock::qt_create_metaobjectdata<qt_meta_tag_ZN11FiltersDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FiltersDock",
        "currentFilterRequested",
        "",
        "attachedIndex",
        "changed",
        "seeked",
        "producerInChanged",
        "delta",
        "producerOutChanged",
        "setCurrentFilter",
        "QmlFilter*",
        "filter",
        "QmlMetadata*",
        "meta",
        "index",
        "onSeeked",
        "position",
        "onShowFrame",
        "SharedFrame",
        "frame",
        "openFilterMenu",
        "showCopyFilterMenu",
        "showAddOnMetadataHelp",
        "serviceName",
        "onServiceInChanged",
        "Mlt::Service*",
        "service",
        "load"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentFilterRequested'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'producerInChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'producerOutChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setCurrentFilter'
        QtMocHelpers::SlotData<void(QmlFilter *, QmlMetadata *, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'onSeeked'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'onShowFrame'
        QtMocHelpers::SlotData<void(const SharedFrame &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'openFilterMenu'
        QtMocHelpers::SlotData<void() const>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showCopyFilterMenu'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showAddOnMetadataHelp'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'onServiceInChanged'
        QtMocHelpers::SlotData<void(int, Mlt::Service *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FiltersDock, qt_meta_tag_ZN11FiltersDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FiltersDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FiltersDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FiltersDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11FiltersDockE_t>.metaTypes,
    nullptr
} };

void FiltersDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FiltersDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentFilterRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->changed(); break;
        case 2: _t->seeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->producerInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->producerOutChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setCurrentFilter((*reinterpret_cast<std::add_pointer_t<QmlFilter*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QmlMetadata*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->onSeeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->onShowFrame((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 8: _t->openFilterMenu(); break;
        case 9: _t->showCopyFilterMenu(); break;
        case 10: _t->showAddOnMetadataHelp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->onServiceInChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Service*>>(_a[2]))); break;
        case 12: _t->load(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FiltersDock::*)(int )>(_a, &FiltersDock::currentFilterRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiltersDock::*)()>(_a, &FiltersDock::changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiltersDock::*)(int )>(_a, &FiltersDock::seeked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiltersDock::*)(int )>(_a, &FiltersDock::producerInChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiltersDock::*)(int )>(_a, &FiltersDock::producerOutChanged, 4))
            return;
    }
}

const QMetaObject *FiltersDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FiltersDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11FiltersDockE_t>.strings))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int FiltersDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void FiltersDock::currentFilterRequested(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FiltersDock::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FiltersDock::seeked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FiltersDock::producerInChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void FiltersDock::producerOutChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
