/********************************************************************************
** Form generated from reading UI file 'newprojectfolder.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWPROJECTFOLDER_H
#define UI_NEWPROJECTFOLDER_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NewProjectFolder
{
public:
    QAction *actionProfileAutomatic;
    QAction *actionAddCustomProfile;
    QAction *actionProfileRemove;
    QAction *actionRecentRemove;
    QGridLayout *gridLayout_2;
    QFrame *frame_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *newProjectLabel_2;
    QWidget *widget_2;
    QVBoxLayout *verticalLayout_3;
    QListView *recentListView;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QLabel *newProjectLabel;
    QWidget *widget;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpacerItem *verticalSpacer_2;
    QPushButton *videoModeButton;
    QPushButton *projectsFolderButton;
    QLineEdit *projectNameLineEdit;
    QHBoxLayout *horizontalLayout;
    QPushButton *startButton;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QLabel *label_2;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *NewProjectFolder)
    {
        if (NewProjectFolder->objectName().isEmpty())
            NewProjectFolder->setObjectName("NewProjectFolder");
        NewProjectFolder->resize(510, 382);
        NewProjectFolder->setMinimumSize(QSize(320, 180));
#if QT_CONFIG(whatsthis)
        NewProjectFolder->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/new-project/12978/1"));
#endif // QT_CONFIG(whatsthis)
        actionProfileAutomatic = new QAction(NewProjectFolder);
        actionProfileAutomatic->setObjectName("actionProfileAutomatic");
        actionProfileAutomatic->setCheckable(true);
        actionProfileAutomatic->setChecked(true);
        actionAddCustomProfile = new QAction(NewProjectFolder);
        actionAddCustomProfile->setObjectName("actionAddCustomProfile");
        actionProfileRemove = new QAction(NewProjectFolder);
        actionProfileRemove->setObjectName("actionProfileRemove");
        actionRecentRemove = new QAction(NewProjectFolder);
        actionRecentRemove->setObjectName("actionRecentRemove");
        actionRecentRemove->setMenuRole(QAction::MenuRole::NoRole);
        gridLayout_2 = new QGridLayout(NewProjectFolder);
        gridLayout_2->setObjectName("gridLayout_2");
        frame_2 = new QFrame(NewProjectFolder);
        frame_2->setObjectName("frame_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(frame_2->sizePolicy().hasHeightForWidth());
        frame_2->setSizePolicy(sizePolicy);
        frame_2->setFrameShape(QFrame::Shape::Box);
        frame_2->setLineWidth(2);
        verticalLayout_2 = new QVBoxLayout(frame_2);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        newProjectLabel_2 = new QLabel(frame_2);
        newProjectLabel_2->setObjectName("newProjectLabel_2");
        QFont font;
        font.setBold(true);
        newProjectLabel_2->setFont(font);
        newProjectLabel_2->setAlignment(Qt::AlignmentFlag::AlignCenter);
        newProjectLabel_2->setMargin(4);

        verticalLayout_2->addWidget(newProjectLabel_2);

        widget_2 = new QWidget(frame_2);
        widget_2->setObjectName("widget_2");
        verticalLayout_3 = new QVBoxLayout(widget_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        recentListView = new QListView(widget_2);
        recentListView->setObjectName("recentListView");
        recentListView->setContextMenuPolicy(Qt::ContextMenuPolicy::CustomContextMenu);
        recentListView->setFrameShape(QFrame::Shape::NoFrame);
        recentListView->setEditTriggers(QAbstractItemView::EditTrigger::NoEditTriggers);
        recentListView->setAlternatingRowColors(true);
        recentListView->setSpacing(2);

        verticalLayout_3->addWidget(recentListView);


        verticalLayout_2->addWidget(widget_2);


        gridLayout_2->addWidget(frame_2, 0, 1, 1, 1);

        frame = new QFrame(NewProjectFolder);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Shape::Panel);
        frame->setLineWidth(2);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        newProjectLabel = new QLabel(frame);
        newProjectLabel->setObjectName("newProjectLabel");
        newProjectLabel->setFont(font);
        newProjectLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);
        newProjectLabel->setMargin(4);

        verticalLayout->addWidget(newProjectLabel);

        widget = new QWidget(frame);
        widget->setObjectName("widget");
        gridLayout = new QGridLayout(widget);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(widget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 5, 1, 1, 1);

        videoModeButton = new QPushButton(widget);
        videoModeButton->setObjectName("videoModeButton");
        videoModeButton->setMaximumSize(QSize(250, 16777215));

        gridLayout->addWidget(videoModeButton, 2, 1, 1, 1);

        projectsFolderButton = new QPushButton(widget);
        projectsFolderButton->setObjectName("projectsFolderButton");
        projectsFolderButton->setMaximumSize(QSize(500, 16777215));

        gridLayout->addWidget(projectsFolderButton, 0, 1, 1, 1);

        projectNameLineEdit = new QLineEdit(widget);
        projectNameLineEdit->setObjectName("projectNameLineEdit");
        projectNameLineEdit->setMaximumSize(QSize(500, 16777215));

        gridLayout->addWidget(projectNameLineEdit, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        startButton = new QPushButton(widget);
        startButton->setObjectName("startButton");
        startButton->setEnabled(false);

        horizontalLayout->addWidget(startButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 4, 1, 1, 1);

        label_3 = new QLabel(widget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        scrollArea = new QScrollArea(widget);
        scrollArea->setObjectName("scrollArea");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy1);
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        scrollArea->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContents);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 164, 264));
        horizontalLayout_2 = new QHBoxLayout(scrollAreaWidgetContents);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        label_4 = new QLabel(scrollAreaWidgetContents);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        label_4->setWordWrap(true);

        horizontalLayout_2->addWidget(label_4);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout->addWidget(scrollArea, 3, 1, 1, 1);

        gridLayout->setRowStretch(5, 4);

        verticalLayout->addWidget(widget);


        gridLayout_2->addWidget(frame, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 1, 0, 1, 1);

        QWidget::setTabOrder(projectsFolderButton, projectNameLineEdit);
        QWidget::setTabOrder(projectNameLineEdit, videoModeButton);
        QWidget::setTabOrder(videoModeButton, startButton);

        retranslateUi(NewProjectFolder);

        QMetaObject::connectSlotsByName(NewProjectFolder);
    } // setupUi

    void retranslateUi(QWidget *NewProjectFolder)
    {
        NewProjectFolder->setWindowTitle(QCoreApplication::translate("NewProjectFolder", "Form", nullptr));
        actionProfileAutomatic->setText(QCoreApplication::translate("NewProjectFolder", "Automatic", nullptr));
        actionAddCustomProfile->setText(QCoreApplication::translate("NewProjectFolder", "Add...", nullptr));
        actionProfileRemove->setText(QCoreApplication::translate("NewProjectFolder", "Remove...", nullptr));
        actionRecentRemove->setText(QCoreApplication::translate("NewProjectFolder", "Remove", nullptr));
        newProjectLabel_2->setText(QCoreApplication::translate("NewProjectFolder", "Projects", nullptr));
        newProjectLabel->setText(QCoreApplication::translate("NewProjectFolder", "New Project", nullptr));
        label->setText(QCoreApplication::translate("NewProjectFolder", "Projects folder", nullptr));
        videoModeButton->setText(QCoreApplication::translate("NewProjectFolder", "PushButton", nullptr));
#if QT_CONFIG(tooltip)
        projectsFolderButton->setToolTip(QCoreApplication::translate("NewProjectFolder", "This is the folder to contain Shotcut project folders.\n"
"A folder will be created in this folder for each project.", nullptr));
#endif // QT_CONFIG(tooltip)
        projectsFolderButton->setText(QCoreApplication::translate("NewProjectFolder", "PushButton", nullptr));
#if QT_CONFIG(tooltip)
        projectNameLineEdit->setToolTip(QCoreApplication::translate("NewProjectFolder", "A folder with this name will be created containing\n"
"a project file with the same name.", nullptr));
#endif // QT_CONFIG(tooltip)
        startButton->setText(QCoreApplication::translate("NewProjectFolder", "Start", nullptr));
        label_3->setText(QCoreApplication::translate("NewProjectFolder", "Video mode", nullptr));
        label_2->setText(QCoreApplication::translate("NewProjectFolder", "Project name", nullptr));
        label_4->setText(QCoreApplication::translate("NewProjectFolder", "Automatic means the resolution and frame rate are based on the <b>first</b> file you <b>add</b> to your project. If the first file is not a video clip (for example, image or audio), then it will be 1920x1080p 25 fps.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NewProjectFolder: public Ui_NewProjectFolder {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NEWPROJECTFOLDER_H
