/****************************************************************************
** Meta object code from reading C++ file 'playlistdock.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/docks/playlistdock.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistdock.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7BinTreeE_t {};
} // unnamed namespace

template <> constexpr inline auto BinTree::qt_create_metaobjectdata<qt_meta_tag_ZN7BinTreeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BinTree",
        "copied",
        "",
        "moved",
        "QList<int>",
        "QPointF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'copied'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'moved'
        QtMocHelpers::SignalData<void(QList<int>, QPointF)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 5, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BinTree, qt_meta_tag_ZN7BinTreeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BinTree::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BinTreeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BinTreeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7BinTreeE_t>.metaTypes,
    nullptr
} };

void BinTree::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BinTree *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->copied((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->moved((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BinTree::*)(QString )>(_a, &BinTree::copied, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BinTree::*)(QList<int> , QPointF )>(_a, &BinTree::moved, 1))
            return;
    }
}

const QMetaObject *BinTree::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BinTree::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7BinTreeE_t>.strings))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int BinTree::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void BinTree::copied(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BinTree::moved(QList<int> _t1, QPointF _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN12PlaylistDockE_t {};
} // unnamed namespace

template <> constexpr inline auto PlaylistDock::qt_create_metaobjectdata<qt_meta_tag_ZN12PlaylistDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlaylistDock",
        "clipOpened",
        "",
        "Mlt::Producer*",
        "producer",
        "play",
        "itemActivated",
        "start",
        "showStatusMessage",
        "addAllTimeline",
        "Mlt::Playlist*",
        "skipProxy",
        "emptyTrack",
        "producerOpened",
        "selectionChanged",
        "enableUpdate",
        "onOpenActionTriggered",
        "onAppendCutActionTriggered",
        "onProducerOpened",
        "onInChanged",
        "onOutChanged",
        "onProducerChanged",
        "onProducerModified",
        "onPlayerDragStarted",
        "onPlaylistModified",
        "onPlaylistCreated",
        "onPlaylistLoaded",
        "onPlaylistCleared",
        "onPlaylistClosed",
        "refreshTimelineSmartBins",
        "viewCustomContextMenuRequested",
        "QPoint",
        "pos",
        "viewDoubleClicked",
        "QModelIndex",
        "index",
        "onDropped",
        "const QMimeData*",
        "data",
        "row",
        "onMoveClip",
        "from",
        "to",
        "onMovedToEnd",
        "onInTimerFired",
        "onOutTimerFired",
        "onMediaTypeClicked",
        "on_treeWidget_itemSelectionChanged",
        "clearStatus",
        "updateStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clipOpened'
        QtMocHelpers::SignalData<void(Mlt::Producer *, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'clipOpened'
        QtMocHelpers::SignalData<void(Mlt::Producer *)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'itemActivated'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'showStatusMessage'
        QtMocHelpers::SignalData<void(QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'addAllTimeline'
        QtMocHelpers::SignalData<void(Mlt::Playlist *, bool, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { QMetaType::Bool, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Signal 'addAllTimeline'
        QtMocHelpers::SignalData<void(Mlt::Playlist *, bool)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'addAllTimeline'
        QtMocHelpers::SignalData<void(Mlt::Playlist *)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'producerOpened'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableUpdate'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onOpenActionTriggered'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAppendCutActionTriggered'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerOpened'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onInChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onOutChanged'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProducerChanged'
        QtMocHelpers::SlotData<void(Mlt::Producer *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onProducerModified'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPlayerDragStarted'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPlaylistModified'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPlaylistCreated'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPlaylistLoaded'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPlaylistCleared'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPlaylistClosed'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshTimelineSmartBins'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'viewCustomContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'viewDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'onDropped'
        QtMocHelpers::SlotData<void(const QMimeData *, int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'onMoveClip'
        QtMocHelpers::SlotData<void(int, int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 41 }, { QMetaType::Int, 42 },
        }}),
        // Slot 'onMovedToEnd'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onInTimerFired'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onOutTimerFired'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMediaTypeClicked'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_treeWidget_itemSelectionChanged'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearStatus'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStatus'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlaylistDock, qt_meta_tag_ZN12PlaylistDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlaylistDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlaylistDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlaylistDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12PlaylistDockE_t>.metaTypes,
    nullptr
} };

void PlaylistDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaylistDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clipOpened((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->clipOpened((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 2: _t->itemActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->showStatusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->addAllTimeline((*reinterpret_cast<std::add_pointer_t<Mlt::Playlist*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 5: _t->addAllTimeline((*reinterpret_cast<std::add_pointer_t<Mlt::Playlist*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->addAllTimeline((*reinterpret_cast<std::add_pointer_t<Mlt::Playlist*>>(_a[1]))); break;
        case 7: _t->producerOpened(); break;
        case 8: _t->selectionChanged(); break;
        case 9: _t->enableUpdate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->onOpenActionTriggered(); break;
        case 11: _t->onAppendCutActionTriggered(); break;
        case 12: _t->onProducerOpened(); break;
        case 13: _t->onInChanged(); break;
        case 14: _t->onOutChanged(); break;
        case 15: _t->onProducerChanged((*reinterpret_cast<std::add_pointer_t<Mlt::Producer*>>(_a[1]))); break;
        case 16: _t->onProducerModified(); break;
        case 17: _t->onPlayerDragStarted(); break;
        case 18: _t->onPlaylistModified(); break;
        case 19: _t->onPlaylistCreated(); break;
        case 20: _t->onPlaylistLoaded(); break;
        case 21: _t->onPlaylistCleared(); break;
        case 22: _t->onPlaylistClosed(); break;
        case 23: _t->refreshTimelineSmartBins(); break;
        case 24: _t->viewCustomContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 25: _t->viewDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 26: _t->onDropped((*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 27: _t->onMoveClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: _t->onMovedToEnd(); break;
        case 29: _t->onInTimerFired(); break;
        case 30: _t->onOutTimerFired(); break;
        case 31: _t->onMediaTypeClicked(); break;
        case 32: _t->on_treeWidget_itemSelectionChanged(); break;
        case 33: _t->clearStatus(); break;
        case 34: _t->updateStatus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlaylistDock::*)(Mlt::Producer * , bool )>(_a, &PlaylistDock::clipOpened, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistDock::*)(int )>(_a, &PlaylistDock::itemActivated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistDock::*)(QString )>(_a, &PlaylistDock::showStatusMessage, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistDock::*)(Mlt::Playlist * , bool , bool )>(_a, &PlaylistDock::addAllTimeline, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistDock::*)()>(_a, &PlaylistDock::producerOpened, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistDock::*)()>(_a, &PlaylistDock::selectionChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistDock::*)(bool )>(_a, &PlaylistDock::enableUpdate, 9))
            return;
    }
}

const QMetaObject *PlaylistDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlaylistDockE_t>.strings))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int PlaylistDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void PlaylistDock::clipOpened(Mlt::Producer * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 2
void PlaylistDock::itemActivated(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PlaylistDock::showStatusMessage(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PlaylistDock::addAllTimeline(Mlt::Playlist * _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void PlaylistDock::producerOpened()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PlaylistDock::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PlaylistDock::enableUpdate(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
