/********************************************************************************
** Form generated from reading UI file 'alsawidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ALSAWIDGET_H
#define UI_ALSAWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_AlsaWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    ServicePresetWidget *preset;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *applyButton;
    QLabel *label;
    QLineEdit *lineEdit;
    QLabel *label_3;
    QSpinBox *alsaChannelsSpinBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AlsaWidget)
    {
        if (AlsaWidget->objectName().isEmpty())
            AlsaWidget->setObjectName("AlsaWidget");
        AlsaWidget->resize(296, 204);
#if QT_CONFIG(whatsthis)
        AlsaWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-alsa-audio/12940/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(AlsaWidget);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(AlsaWidget);
        label_2->setObjectName("label_2");
        QFont font;
        font.setBold(true);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(label_2);

        preset = new ServicePresetWidget(AlsaWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        applyButton = new QPushButton(AlsaWidget);
        applyButton->setObjectName("applyButton");

        gridLayout->addWidget(applyButton, 2, 0, 1, 1);

        label = new QLabel(AlsaWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        lineEdit = new QLineEdit(AlsaWidget);
        lineEdit->setObjectName("lineEdit");

        gridLayout->addWidget(lineEdit, 0, 1, 1, 1);

        label_3 = new QLabel(AlsaWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        alsaChannelsSpinBox = new QSpinBox(AlsaWidget);
        alsaChannelsSpinBox->setObjectName("alsaChannelsSpinBox");
        alsaChannelsSpinBox->setMaximum(8);
        alsaChannelsSpinBox->setValue(2);

        gridLayout->addWidget(alsaChannelsSpinBox, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(lineEdit, alsaChannelsSpinBox);
        QWidget::setTabOrder(alsaChannelsSpinBox, applyButton);

        retranslateUi(AlsaWidget);

        QMetaObject::connectSlotsByName(AlsaWidget);
    } // setupUi

    void retranslateUi(QWidget *AlsaWidget)
    {
        AlsaWidget->setWindowTitle(QCoreApplication::translate("AlsaWidget", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("AlsaWidget", "ALSA Audio", nullptr));
        applyButton->setText(QCoreApplication::translate("AlsaWidget", "Apply", nullptr));
        label->setText(QCoreApplication::translate("AlsaWidget", "PCM Device", nullptr));
        lineEdit->setText(QCoreApplication::translate("AlsaWidget", "default", nullptr));
        label_3->setText(QCoreApplication::translate("AlsaWidget", "Channels", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AlsaWidget: public Ui_AlsaWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ALSAWIDGET_H
