/****************************************************************************
** Meta object code from reading C++ file 'metadatamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/models/metadatamodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'metadatamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MetadataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MetadataModel::qt_create_metaobjectdata<qt_meta_tag_ZN13MetadataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MetadataModel",
        "filterChanged",
        "",
        "searchChanged",
        "rowCount",
        "QModelIndex",
        "parent",
        "get",
        "QmlMetadata*",
        "row",
        "saveFilterSet",
        "name",
        "deleteFilterSet",
        "filter",
        "MetadataFilter",
        "search",
        "NoFilter",
        "FavoritesFilter",
        "VideoFilter",
        "AudioFilter",
        "LinkFilter",
        "FilterSetFilter",
        "GPUFilter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int(const QModelIndex &) const>(4, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int() const>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'get'
        QtMocHelpers::MethodData<QmlMetadata *(int) const>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::Int, 9 },
        }}),
        // Method 'saveFilterSet'
        QtMocHelpers::MethodData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Method 'deleteFilterSet'
        QtMocHelpers::MethodData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filter'
        QtMocHelpers::PropertyData<enum MetadataFilter>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'search'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MetadataFilter'
        QtMocHelpers::EnumData<enum MetadataFilter>(14, 14, QMC::EnumFlags{}).add({
            {   16, MetadataFilter::NoFilter },
            {   17, MetadataFilter::FavoritesFilter },
            {   18, MetadataFilter::VideoFilter },
            {   19, MetadataFilter::AudioFilter },
            {   20, MetadataFilter::LinkFilter },
            {   21, MetadataFilter::FilterSetFilter },
            {   22, MetadataFilter::GPUFilter },
        }),
    };
    return QtMocHelpers::metaObjectData<MetadataModel, qt_meta_tag_ZN13MetadataModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MetadataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MetadataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MetadataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MetadataModelE_t>.metaTypes,
    nullptr
} };

void MetadataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MetadataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterChanged(); break;
        case 1: _t->searchChanged(); break;
        case 2: { int _r = _t->rowCount((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->rowCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { QmlMetadata* _r = _t->get((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QmlMetadata**>(_a[0]) = std::move(_r); }  break;
        case 5: _t->saveFilterSet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->deleteFilterSet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MetadataModel::*)()>(_a, &MetadataModel::filterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MetadataModel::*)()>(_a, &MetadataModel::searchChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum MetadataFilter*>(_v) = _t->filter(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->search(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilter(*reinterpret_cast<enum MetadataFilter*>(_v)); break;
        case 1: _t->setSearch(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MetadataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MetadataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MetadataModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int MetadataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void MetadataModel::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MetadataModel::searchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
