/****************************************************************************
** Meta object code from reading C++ file 'qmlrichtext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/qmltypes/qmlrichtext.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlrichtext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11QmlRichTextE_t {};
} // unnamed namespace

template <> constexpr inline auto QmlRichText::qt_create_metaobjectdata<qt_meta_tag_ZN11QmlRichTextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QmlRichText",
        "targetChanged",
        "",
        "cursorPositionChanged",
        "selectionStartChanged",
        "selectionEndChanged",
        "fontFamilyChanged",
        "fontStyleNameChanged",
        "textColorChanged",
        "alignmentChanged",
        "boldChanged",
        "italicChanged",
        "underlineChanged",
        "fontSizeChanged",
        "strikeoutChanged",
        "fileUrlChanged",
        "textChanged",
        "error",
        "message",
        "sizeChanged",
        "setBold",
        "arg",
        "setItalic",
        "setUnderline",
        "setStrikeout",
        "setFontSize",
        "setTextColor",
        "QColor",
        "setFontFamily",
        "setFontStyleName",
        "setFileUrl",
        "QUrl",
        "setText",
        "saveAs",
        "fileType",
        "insertTable",
        "rows",
        "columns",
        "border",
        "indentLess",
        "indentMore",
        "pastePlain",
        "reset",
        "target",
        "QQuickItem*",
        "cursorPosition",
        "selectionStart",
        "selectionEnd",
        "textColor",
        "fontFamily",
        "fontStyleName",
        "alignment",
        "Qt::Alignment",
        "bold",
        "italic",
        "underline",
        "strikeout",
        "fontSize",
        "fileUrl",
        "text",
        "size",
        "QSizeF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'targetChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionStartChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionEndChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontFamilyChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontStyleNameChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textColorChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignmentChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boldChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'italicChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'underlineChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'strikeoutChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileUrlChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(QString)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBold'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setItalic'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setUnderline'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setStrikeout'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setFontSize'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setTextColor'
        QtMocHelpers::SlotData<void(const QColor &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 21 },
        }}),
        // Slot 'setFontFamily'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setFontStyleName'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setFileUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 21 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void(const QUrl &, QString)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 21 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void(const QUrl &)>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 31, 21 },
        }}),
        // Slot 'insertTable'
        QtMocHelpers::SlotData<void(int, int, int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 37 }, { QMetaType::Int, 38 },
        }}),
        // Slot 'insertTable'
        QtMocHelpers::SlotData<void(int, int)>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 37 },
        }}),
        // Slot 'insertTable'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'insertTable'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'indentLess'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'indentMore'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pastePlain'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'target'
        QtMocHelpers::PropertyData<QQuickItem*>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'cursorPosition'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'selectionStart'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'selectionEnd'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(48, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'fontFamily'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'fontStyleName'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'alignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(51, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'bold'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'italic'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'underline'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'strikeout'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'fontSize'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'fileUrl'
        QtMocHelpers::PropertyData<QUrl>(58, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'size'
        QtMocHelpers::PropertyData<QSizeF>(60, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 16),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QmlRichText, qt_meta_tag_ZN11QmlRichTextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QmlRichText::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlRichTextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlRichTextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11QmlRichTextE_t>.metaTypes,
    nullptr
} };

void QmlRichText::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlRichText *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->targetChanged(); break;
        case 1: _t->cursorPositionChanged(); break;
        case 2: _t->selectionStartChanged(); break;
        case 3: _t->selectionEndChanged(); break;
        case 4: _t->fontFamilyChanged(); break;
        case 5: _t->fontStyleNameChanged(); break;
        case 6: _t->textColorChanged(); break;
        case 7: _t->alignmentChanged(); break;
        case 8: _t->boldChanged(); break;
        case 9: _t->italicChanged(); break;
        case 10: _t->underlineChanged(); break;
        case 11: _t->fontSizeChanged(); break;
        case 12: _t->strikeoutChanged(); break;
        case 13: _t->fileUrlChanged(); break;
        case 14: _t->textChanged(); break;
        case 15: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->sizeChanged(); break;
        case 17: _t->setBold((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setItalic((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setUnderline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setStrikeout((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setFontSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->setTextColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 23: _t->setFontFamily((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->setFontStyleName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->setFileUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 26: _t->setText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 28: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 29: _t->insertTable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 30: _t->insertTable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 31: _t->insertTable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->insertTable(); break;
        case 33: _t->indentLess(); break;
        case 34: _t->indentMore(); break;
        case 35: _t->pastePlain(); break;
        case 36: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::targetChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::cursorPositionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::selectionStartChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::selectionEndChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::fontFamilyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::fontStyleNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::textColorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::alignmentChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::boldChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::italicChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::underlineChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::fontSizeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::strikeoutChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::fileUrlChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::textChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)(QString )>(_a, &QmlRichText::error, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlRichText::*)()>(_a, &QmlRichText::sizeChanged, 16))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickItem**>(_v) = _t->target(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->cursorPosition(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->selectionStart(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->selectionEnd(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->fontFamily(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->fontStyleName(); break;
        case 7: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->bold(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->italic(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->underline(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->strikeout(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->fontSize(); break;
        case 13: *reinterpret_cast<QUrl*>(_v) = _t->fileUrl(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 15: *reinterpret_cast<QSizeF*>(_v) = _t->size(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTarget(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 1: _t->setCursorPosition(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setSelectionStart(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setSelectionEnd(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setFontFamily(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFontStyleName(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setAlignment(*reinterpret_cast<Qt::Alignment*>(_v)); break;
        case 8: _t->setBold(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setItalic(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setUnderline(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setStrikeout(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setFontSize(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setFileUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 14: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QmlRichText::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QmlRichText::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QmlRichTextE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QmlRichText::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 37;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void QmlRichText::targetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QmlRichText::cursorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QmlRichText::selectionStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QmlRichText::selectionEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QmlRichText::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QmlRichText::fontStyleNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QmlRichText::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QmlRichText::alignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QmlRichText::boldChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QmlRichText::italicChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QmlRichText::underlineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QmlRichText::fontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QmlRichText::strikeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QmlRichText::fileUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QmlRichText::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QmlRichText::error(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void QmlRichText::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
QT_WARNING_POP
