/********************************************************************************
** Form generated from reading UI file 'blipproducerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BLIPPRODUCERWIDGET_H
#define UI_BLIPPRODUCERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/servicepresetwidget.h"

QT_BEGIN_NAMESPACE

class Ui_BlipProducerWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *nameLabel;
    ServicePresetWidget *preset;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *periodSpinBox;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *BlipProducerWidget)
    {
        if (BlipProducerWidget->objectName().isEmpty())
            BlipProducerWidget->setObjectName("BlipProducerWidget");
        BlipProducerWidget->resize(394, 294);
#if QT_CONFIG(whatsthis)
        BlipProducerWidget->setWhatsThis(QString::fromUtf8("https://forum.shotcut.org/t/open-other-blip-flash/19163/1"));
#endif // QT_CONFIG(whatsthis)
        verticalLayout = new QVBoxLayout(BlipProducerWidget);
        verticalLayout->setObjectName("verticalLayout");
        nameLabel = new QLabel(BlipProducerWidget);
        nameLabel->setObjectName("nameLabel");
        QFont font;
        font.setBold(true);
        nameLabel->setFont(font);
        nameLabel->setAlignment(Qt::AlignmentFlag::AlignCenter);

        verticalLayout->addWidget(nameLabel);

        preset = new ServicePresetWidget(BlipProducerWidget);
        preset->setObjectName("preset");

        verticalLayout->addWidget(preset);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(BlipProducerWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        periodSpinBox = new QSpinBox(BlipProducerWidget);
        periodSpinBox->setObjectName("periodSpinBox");
        periodSpinBox->setMinimum(1);
        periodSpinBox->setMaximum(10);
        periodSpinBox->setValue(1);

        gridLayout->addWidget(periodSpinBox, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(BlipProducerWidget);

        QMetaObject::connectSlotsByName(BlipProducerWidget);
    } // setupUi

    void retranslateUi(QWidget *BlipProducerWidget)
    {
        BlipProducerWidget->setWindowTitle(QCoreApplication::translate("BlipProducerWidget", "Form", nullptr));
        nameLabel->setText(QCoreApplication::translate("BlipProducerWidget", "Blip Flash", nullptr));
        label->setText(QCoreApplication::translate("BlipProducerWidget", "Frequency", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BlipProducerWidget: public Ui_BlipProducerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BLIPPRODUCERWIDGET_H
